var xe=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function Ce(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function Wy(e){if(e.__esModule)return e;var t=e.default;if(typeof t=="function"){var r=function n(){return this instanceof n?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};r.prototype=t.prototype}else r={};return Object.defineProperty(r,"__esModule",{value:!0}),Object.keys(e).forEach(function(n){var i=Object.getOwnPropertyDescriptor(e,n);Object.defineProperty(r,n,i.get?i:{enumerable:!0,get:function(){return e[n]}})}),r}var eg={exports:{}},Js={};const eu=React;/**
 * @license React
 * react-jsx-runtime.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Ky=eu,Xy=Symbol.for("react.element"),Yy=Symbol.for("react.fragment"),Zy=Object.prototype.hasOwnProperty,Qy=Ky.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentOwner,Jy={key:!0,ref:!0,__self:!0,__source:!0};function tg(e,t,r){var n,i={},a=null,o=null;r!==void 0&&(a=""+r),t.key!==void 0&&(a=""+t.key),t.ref!==void 0&&(o=t.ref);for(n in t)Zy.call(t,n)&&!Jy.hasOwnProperty(n)&&(i[n]=t[n]);if(e&&e.defaultProps)for(n in t=e.defaultProps,t)i[n]===void 0&&(i[n]=t[n]);return{$$typeof:Xy,type:e,key:a,ref:o,props:i,_owner:Qy.current}}Js.Fragment=Yy;Js.jsx=tg;Js.jsxs=tg;eg.exports=Js;var he=eg.exports,zd={};const e6=ReactDOM;var $d=e6;zd.createRoot=$d.createRoot,zd.hydrateRoot=$d.hydrateRoot;/**
 * @remix-run/router v1.14.2
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */function Es(){return Es=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},Es.apply(this,arguments)}var kn;(function(e){e.Pop="POP",e.Push="PUSH",e.Replace="REPLACE"})(kn||(kn={}));const Ud="popstate";function t6(e){e===void 0&&(e={});function t(n,i){let{pathname:a,search:o,hash:s}=n.location;return g0("",{pathname:a,search:o,hash:s},i.state&&i.state.usr||null,i.state&&i.state.key||"default")}function r(n,i){return typeof i=="string"?i:rg(i)}return n6(t,r,null,e)}function Gt(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function rf(e,t){if(!e){typeof console<"u"&&console.warn(t);try{throw new Error(t)}catch{}}}function r6(){return Math.random().toString(36).substr(2,8)}function Hd(e,t){return{usr:e.state,key:e.key,idx:t}}function g0(e,t,r,n){return r===void 0&&(r=null),Es({pathname:typeof e=="string"?e:e.pathname,search:"",hash:""},typeof t=="string"?tu(t):t,{state:r,key:t&&t.key||n||r6()})}function rg(e){let{pathname:t="/",search:r="",hash:n=""}=e;return r&&r!=="?"&&(t+=r.charAt(0)==="?"?r:"?"+r),n&&n!=="#"&&(t+=n.charAt(0)==="#"?n:"#"+n),t}function tu(e){let t={};if(e){let r=e.indexOf("#");r>=0&&(t.hash=e.substr(r),e=e.substr(0,r));let n=e.indexOf("?");n>=0&&(t.search=e.substr(n),e=e.substr(0,n)),e&&(t.pathname=e)}return t}function n6(e,t,r,n){n===void 0&&(n={});let{window:i=document.defaultView,v5Compat:a=!1}=n,o=i.history,s=kn.Pop,u=null,l=c();l==null&&(l=0,o.replaceState(Es({},o.state,{idx:l}),""));function c(){return(o.state||{idx:null}).idx}function f(){s=kn.Pop;let g=c(),v=g==null?null:g-l;l=g,u&&u({action:s,location:m.location,delta:v})}function d(g,v){s=kn.Push;let w=g0(m.location,g,v);r&&r(w,g),l=c()+1;let x=Hd(w,l),N=m.createHref(w);try{o.pushState(x,"",N)}catch(O){if(O instanceof DOMException&&O.name==="DataCloneError")throw O;i.location.assign(N)}a&&u&&u({action:s,location:m.location,delta:1})}function h(g,v){s=kn.Replace;let w=g0(m.location,g,v);r&&r(w,g),l=c();let x=Hd(w,l),N=m.createHref(w);o.replaceState(x,"",N),a&&u&&u({action:s,location:m.location,delta:0})}function p(g){let v=i.location.origin!=="null"?i.location.origin:i.location.href,w=typeof g=="string"?g:rg(g);return Gt(v,"No window.location.(origin|href) available to create URL for href: "+w),new URL(w,v)}let m={get action(){return s},get location(){return e(i,o)},listen(g){if(u)throw new Error("A history only accepts one active listener");return i.addEventListener(Ud,f),u=g,()=>{i.removeEventListener(Ud,f),u=null}},createHref(g){return t(i,g)},createURL:p,encodeLocation(g){let v=p(g);return{pathname:v.pathname,search:v.search,hash:v.hash}},push:d,replace:h,go(g){return o.go(g)}};return m}var qd;(function(e){e.data="data",e.deferred="deferred",e.redirect="redirect",e.error="error"})(qd||(qd={}));function i6(e,t,r){r===void 0&&(r="/");let n=typeof t=="string"?tu(t):t,i=ag(n.pathname||"/",r);if(i==null)return null;let a=ng(e);a6(a);let o=null;for(let s=0;o==null&&s<a.length;++s)o=p6(a[s],b6(i));return o}function ng(e,t,r,n){t===void 0&&(t=[]),r===void 0&&(r=[]),n===void 0&&(n="");let i=(a,o,s)=>{let u={relativePath:s===void 0?a.path||"":s,caseSensitive:a.caseSensitive===!0,childrenIndex:o,route:a};u.relativePath.startsWith("/")&&(Gt(u.relativePath.startsWith(n),'Absolute route path "'+u.relativePath+'" nested under path '+('"'+n+'" is not valid. An absolute child route path ')+"must start with the combined path of all its parent routes."),u.relativePath=u.relativePath.slice(n.length));let l=Mi([n,u.relativePath]),c=r.concat(u);a.children&&a.children.length>0&&(Gt(a.index!==!0,"Index routes must not have child routes. Please remove "+('all child routes from route path "'+l+'".')),ng(a.children,t,c,l)),!(a.path==null&&!a.index)&&t.push({path:l,score:d6(l,a.index),routesMeta:c})};return e.forEach((a,o)=>{var s;if(a.path===""||!((s=a.path)!=null&&s.includes("?")))i(a,o);else for(let u of ig(a.path))i(a,o,u)}),t}function ig(e){let t=e.split("/");if(t.length===0)return[];let[r,...n]=t,i=r.endsWith("?"),a=r.replace(/\?$/,"");if(n.length===0)return i?[a,""]:[a];let o=ig(n.join("/")),s=[];return s.push(...o.map(u=>u===""?a:[a,u].join("/"))),i&&s.push(...o),s.map(u=>e.startsWith("/")&&u===""?"/":u)}function a6(e){e.sort((t,r)=>t.score!==r.score?r.score-t.score:h6(t.routesMeta.map(n=>n.childrenIndex),r.routesMeta.map(n=>n.childrenIndex)))}const o6=/^:[\w-]+$/,s6=3,u6=2,l6=1,c6=10,f6=-2,jd=e=>e==="*";function d6(e,t){let r=e.split("/"),n=r.length;return r.some(jd)&&(n+=f6),t&&(n+=u6),r.filter(i=>!jd(i)).reduce((i,a)=>i+(o6.test(a)?s6:a===""?l6:c6),n)}function h6(e,t){return e.length===t.length&&e.slice(0,-1).every((n,i)=>n===t[i])?e[e.length-1]-t[t.length-1]:0}function p6(e,t){let{routesMeta:r}=e,n={},i="/",a=[];for(let o=0;o<r.length;++o){let s=r[o],u=o===r.length-1,l=i==="/"?t:t.slice(i.length)||"/",c=m6({path:s.relativePath,caseSensitive:s.caseSensitive,end:u},l);if(!c)return null;Object.assign(n,c.params);let f=s.route;a.push({params:n,pathname:Mi([i,c.pathname]),pathnameBase:y6(Mi([i,c.pathnameBase])),route:f}),c.pathnameBase!=="/"&&(i=Mi([i,c.pathnameBase]))}return a}function m6(e,t){typeof e=="string"&&(e={path:e,caseSensitive:!1,end:!0});let[r,n]=g6(e.path,e.caseSensitive,e.end),i=t.match(r);if(!i)return null;let a=i[0],o=a.replace(/(.)\/+$/,"$1"),s=i.slice(1);return{params:n.reduce((l,c,f)=>{let{paramName:d,isOptional:h}=c;if(d==="*"){let m=s[f]||"";o=a.slice(0,a.length-m.length).replace(/(.)\/+$/,"$1")}const p=s[f];return h&&!p?l[d]=void 0:l[d]=v6(p||"",d),l},{}),pathname:a,pathnameBase:o,pattern:e}}function g6(e,t,r){t===void 0&&(t=!1),r===void 0&&(r=!0),rf(e==="*"||!e.endsWith("*")||e.endsWith("/*"),'Route path "'+e+'" will be treated as if it were '+('"'+e.replace(/\*$/,"/*")+'" because the `*` character must ')+"always follow a `/` in the pattern. To get rid of this warning, "+('please change the route path to "'+e.replace(/\*$/,"/*")+'".'));let n=[],i="^"+e.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(o,s,u)=>(n.push({paramName:s,isOptional:u!=null}),u?"/?([^\\/]+)?":"/([^\\/]+)"));return e.endsWith("*")?(n.push({paramName:"*"}),i+=e==="*"||e==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):r?i+="\\/*$":e!==""&&e!=="/"&&(i+="(?:(?=\\/|$))"),[new RegExp(i,t?void 0:"i"),n]}function b6(e){try{return decodeURI(e)}catch(t){return rf(!1,'The URL path "'+e+'" could not be decoded because it is is a malformed URL segment. This is probably due to a bad percent '+("encoding ("+t+").")),e}}function v6(e,t){try{return decodeURIComponent(e)}catch(r){return rf(!1,'The value for the URL param "'+t+'" will not be decoded because'+(' the string "'+e+'" is a malformed URL segment. This is probably')+(" due to a bad percent encoding ("+r+").")),e}}function ag(e,t){if(t==="/")return e;if(!e.toLowerCase().startsWith(t.toLowerCase()))return null;let r=t.endsWith("/")?t.length-1:t.length,n=e.charAt(r);return n&&n!=="/"?null:e.slice(r)||"/"}const Mi=e=>e.join("/").replace(/\/\/+/g,"/"),y6=e=>e.replace(/\/+$/,"").replace(/^\/*/,"/");class w6 extends Error{}function x6(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.internal=="boolean"&&"data"in e}const og=["post","put","patch","delete"];new Set(og);const E6=["get",...og];new Set(E6);/**
 * React Router v6.21.2
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */function Ss(){return Ss=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},Ss.apply(this,arguments)}const S6=React.createContext(null),T6=React.createContext(null),Vd=React.createContext(null),sg=React.createContext(null),ru=React.createContext(null),nu=React.createContext({outlet:null,matches:[],isDataRoute:!1}),ug=React.createContext(null);function nf(){return React.useContext(ru)!=null}function A6(){return nf()||Gt(!1),React.useContext(ru).location}function k6(e,t){return O6(e,t)}function O6(e,t,r,n){nf()||Gt(!1);let{navigator:i}=React.useContext(sg),{matches:a}=React.useContext(nu),o=a[a.length-1],s=o?o.params:{};o&&o.pathname;let u=o?o.pathnameBase:"/";o&&o.route;let l=A6(),c;if(t){var f;let g=typeof t=="string"?tu(t):t;u==="/"||(f=g.pathname)!=null&&f.startsWith(u)||Gt(!1),c=g}else c=l;let d=c.pathname||"/",h=u==="/"?d:d.slice(u.length)||"/",p=i6(e,{pathname:h}),m=R6(p&&p.map(g=>Object.assign({},g,{params:Object.assign({},s,g.params),pathname:Mi([u,i.encodeLocation?i.encodeLocation(g.pathname).pathname:g.pathname]),pathnameBase:g.pathnameBase==="/"?u:Mi([u,i.encodeLocation?i.encodeLocation(g.pathnameBase).pathname:g.pathnameBase])})),a,r,n);return t&&m?React.createElement(ru.Provider,{value:{location:Ss({pathname:"/",search:"",hash:"",state:null,key:"default"},c),navigationType:kn.Pop}},m):m}function N6(){let e=L6(),t=x6(e)?e.status+" "+e.statusText:e instanceof Error?e.message:JSON.stringify(e),r=e instanceof Error?e.stack:null,i={padding:"0.5rem",backgroundColor:"rgba(200,200,200, 0.5)"},a=null;return React.createElement(React.Fragment,null,React.createElement("h2",null,"Unexpected Application Error!"),React.createElement("h3",{style:{fontStyle:"italic"}},t),r?React.createElement("pre",{style:i},r):null,a)}const _6=React.createElement(N6,null);class C6 extends React.Component{constructor(t){super(t),this.state={location:t.location,revalidation:t.revalidation,error:t.error}}static getDerivedStateFromError(t){return{error:t}}static getDerivedStateFromProps(t,r){return r.location!==t.location||r.revalidation!=="idle"&&t.revalidation==="idle"?{error:t.error,location:t.location,revalidation:t.revalidation}:{error:t.error!==void 0?t.error:r.error,location:r.location,revalidation:t.revalidation||r.revalidation}}componentDidCatch(t,r){console.error("React Router caught the following error during render",t,r)}render(){return this.state.error!==void 0?React.createElement(nu.Provider,{value:this.props.routeContext},React.createElement(ug.Provider,{value:this.state.error,children:this.props.component})):this.props.children}}function M6(e){let{routeContext:t,match:r,children:n}=e,i=React.useContext(S6);return i&&i.static&&i.staticContext&&(r.route.errorElement||r.route.ErrorBoundary)&&(i.staticContext._deepestRenderedBoundaryId=r.route.id),React.createElement(nu.Provider,{value:t},n)}function R6(e,t,r,n){var i;if(t===void 0&&(t=[]),r===void 0&&(r=null),n===void 0&&(n=null),e==null){var a;if((a=r)!=null&&a.errors)e=r.matches;else return null}let o=e,s=(i=r)==null?void 0:i.errors;if(s!=null){let c=o.findIndex(f=>f.route.id&&(s==null?void 0:s[f.route.id]));c>=0||Gt(!1),o=o.slice(0,Math.min(o.length,c+1))}let u=!1,l=-1;if(r&&n&&n.v7_partialHydration)for(let c=0;c<o.length;c++){let f=o[c];if((f.route.HydrateFallback||f.route.hydrateFallbackElement)&&(l=c),f.route.id){let{loaderData:d,errors:h}=r,p=f.route.loader&&d[f.route.id]===void 0&&(!h||h[f.route.id]===void 0);if(f.route.lazy||p){u=!0,l>=0?o=o.slice(0,l+1):o=[o[0]];break}}}return o.reduceRight((c,f,d)=>{let h,p=!1,m=null,g=null;r&&(h=s&&f.route.id?s[f.route.id]:void 0,m=f.route.errorElement||_6,u&&(l<0&&d===0?(F6("route-fallback",!1),p=!0,g=null):l===d&&(p=!0,g=f.route.hydrateFallbackElement||null)));let v=t.concat(o.slice(0,d+1)),w=()=>{let x;return h?x=m:p?x=g:f.route.Component?x=React.createElement(f.route.Component,null):f.route.element?x=f.route.element:x=c,React.createElement(M6,{match:f,routeContext:{outlet:c,matches:v,isDataRoute:r!=null},children:x})};return r&&(f.route.ErrorBoundary||f.route.errorElement||d===0)?React.createElement(C6,{location:r.location,revalidation:r.revalidation,component:m,error:h,children:w(),routeContext:{outlet:null,matches:v,isDataRoute:!0}}):w()},null)}var b0=function(e){return e.UseBlocker="useBlocker",e.UseLoaderData="useLoaderData",e.UseActionData="useActionData",e.UseRouteError="useRouteError",e.UseNavigation="useNavigation",e.UseRouteLoaderData="useRouteLoaderData",e.UseMatches="useMatches",e.UseRevalidator="useRevalidator",e.UseNavigateStable="useNavigate",e.UseRouteId="useRouteId",e}(b0||{});function I6(e){let t=React.useContext(T6);return t||Gt(!1),t}function P6(e){let t=React.useContext(nu);return t||Gt(!1),t}function D6(e){let t=P6(),r=t.matches[t.matches.length-1];return r.route.id||Gt(!1),r.route.id}function L6(){var e;let t=React.useContext(ug),r=I6(b0.UseRouteError),n=D6(b0.UseRouteError);return t!==void 0?t:(e=r.errors)==null?void 0:e[n]}const Gd={};function F6(e,t,r){!t&&!Gd[e]&&(Gd[e]=!0)}const B6="startTransition";React[B6];function z6(e){Gt(!1)}function $6(e){let{basename:t="/",children:r=null,location:n,navigationType:i=kn.Pop,navigator:a,static:o=!1,future:s}=e;nf()&&Gt(!1);let u=t.replace(/^\/*/,"/"),l=React.useMemo(()=>({basename:u,navigator:a,static:o,future:Ss({v7_relativeSplatPath:!1},s)}),[u,s,a,o]);typeof n=="string"&&(n=tu(n));let{pathname:c="/",search:f="",hash:d="",state:h=null,key:p="default"}=n,m=React.useMemo(()=>{let g=ag(c,u);return g==null?null:{location:{pathname:g,search:f,hash:d,state:h,key:p},navigationType:i}},[u,c,f,d,h,p,i]);return m==null?null:React.createElement(sg.Provider,{value:l},React.createElement(ru.Provider,{children:r,value:m}))}function P$(e){let{children:t,location:r}=e;return k6(v0(t),r)}var cr=function(e){return e[e.pending=0]="pending",e[e.success=1]="success",e[e.error=2]="error",e}(cr||{});const U6=new Promise(()=>{});class D$ extends React.Component{constructor(t){super(t),this.state={error:null}}static getDerivedStateFromError(t){return{error:t}}componentDidCatch(t,r){console.error("<Await> caught the following error during render",t,r)}render(){let{children:t,errorElement:r,resolve:n}=this.props,i=null,a=cr.pending;if(!(n instanceof Promise))a=cr.success,i=Promise.resolve(),Object.defineProperty(i,"_tracked",{get:()=>!0}),Object.defineProperty(i,"_data",{get:()=>n});else if(this.state.error){a=cr.error;let o=this.state.error;i=Promise.reject().catch(()=>{}),Object.defineProperty(i,"_tracked",{get:()=>!0}),Object.defineProperty(i,"_error",{get:()=>o})}else n._tracked?(i=n,a=i._error!==void 0?cr.error:i._data!==void 0?cr.success:cr.pending):(a=cr.pending,Object.defineProperty(n,"_tracked",{get:()=>!0}),i=n.then(o=>Object.defineProperty(n,"_data",{get:()=>o}),o=>Object.defineProperty(n,"_error",{get:()=>o})));if(a===cr.error&&i._error instanceof w6)throw U6;if(a===cr.error&&!r)throw i._error;if(a===cr.error)return React.createElement(Vd.Provider,{value:i,children:r});if(a===cr.success)return React.createElement(Vd.Provider,{value:i,children:t});throw i}}function v0(e,t){t===void 0&&(t=[]);let r=[];return React.Children.forEach(e,(n,i)=>{if(!React.isValidElement(n))return;let a=[...t,i];if(n.type===React.Fragment){r.push.apply(r,v0(n.props.children,a));return}n.type!==z6&&Gt(!1),!n.props.index||!n.props.children||Gt(!1);let o={id:n.props.id||a.join("-"),caseSensitive:n.props.caseSensitive,element:n.props.element,Component:n.props.Component,index:n.props.index,path:n.props.path,loader:n.props.loader,action:n.props.action,errorElement:n.props.errorElement,ErrorBoundary:n.props.ErrorBoundary,hasErrorBoundary:n.props.ErrorBoundary!=null||n.props.errorElement!=null,shouldRevalidate:n.props.shouldRevalidate,handle:n.props.handle,lazy:n.props.lazy};n.props.children&&(o.children=v0(n.props.children,a)),r.push(o)}),r}/**
 * React Router DOM v6.21.2
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */const H6="startTransition",Wd=React[H6],q6="flushSync";ReactDOM[q6];const j6="useId";React[j6];function L$(e){let{basename:t,children:r,future:n,window:i}=e,a=React.useRef();a.current==null&&(a.current=t6({window:i,v5Compat:!0}));let o=a.current,[s,u]=React.useState({action:o.action,location:o.location}),{v7_startTransition:l}=n||{},c=React.useCallback(f=>{l&&Wd?Wd(()=>u(f)):u(f)},[u,l]);return React.useLayoutEffect(()=>o.listen(c),[o,c]),React.createElement($6,{basename:t,children:r,location:s.location,navigationType:s.action,navigator:o,future:n})}var Kd;(function(e){e.UseScrollRestoration="useScrollRestoration",e.UseSubmit="useSubmit",e.UseSubmitFetcher="useSubmitFetcher",e.UseFetcher="useFetcher",e.useViewTransitionState="useViewTransitionState"})(Kd||(Kd={}));var Xd;(function(e){e.UseFetcher="useFetcher",e.UseFetchers="useFetchers",e.UseScrollRestoration="useScrollRestoration"})(Xd||(Xd={}));var lg={exports:{}};/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/(function(e){(function(){var t={}.hasOwnProperty;function r(){for(var a="",o=0;o<arguments.length;o++){var s=arguments[o];s&&(a=i(a,n(s)))}return a}function n(a){if(typeof a=="string"||typeof a=="number")return a;if(typeof a!="object")return"";if(Array.isArray(a))return r.apply(null,a);if(a.toString!==Object.prototype.toString&&!a.toString.toString().includes("[native code]"))return a.toString();var o="";for(var s in a)t.call(a,s)&&a[s]&&(o=i(o,s));return o}function i(a,o){return o?a?a+" "+o:a+o:a}e.exports?(r.default=r,e.exports=r):window.classNames=r})()})(lg);var V6=lg.exports;const vt=Ce(V6),Yd=["http","https","mailto","tel"];function G6(e){const t=(e||"").trim(),r=t.charAt(0);if(r==="#"||r==="/")return t;const n=t.indexOf(":");if(n===-1)return t;let i=-1;for(;++i<Yd.length;){const a=Yd[i];if(n===a.length&&t.slice(0,a.length).toLowerCase()===a)return t}return i=t.indexOf("?"),i!==-1&&n>i||(i=t.indexOf("#"),i!==-1&&n>i)?t:"javascript:void(0)"}/*!
 * Determine if an object is a Buffer
 *
 * @author   Feross Aboukhadijeh <https://feross.org>
 * @license  MIT
 */var W6=function(t){return t!=null&&t.constructor!=null&&typeof t.constructor.isBuffer=="function"&&t.constructor.isBuffer(t)};const cg=Ce(W6);function pa(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?Zd(e.position):"start"in e||"end"in e?Zd(e):"line"in e||"column"in e?y0(e):""}function y0(e){return Qd(e&&e.line)+":"+Qd(e&&e.column)}function Zd(e){return y0(e&&e.start)+"-"+y0(e&&e.end)}function Qd(e){return e&&typeof e=="number"?e:1}class br extends Error{constructor(t,r,n){const i=[null,null];let a={start:{line:null,column:null},end:{line:null,column:null}};if(super(),typeof r=="string"&&(n=r,r=void 0),typeof n=="string"){const o=n.indexOf(":");o===-1?i[1]=n:(i[0]=n.slice(0,o),i[1]=n.slice(o+1))}r&&("type"in r||"position"in r?r.position&&(a=r.position):"start"in r||"end"in r?a=r:("line"in r||"column"in r)&&(a.start=r)),this.name=pa(r)||"1:1",this.message=typeof t=="object"?t.message:t,this.stack="",typeof t=="object"&&t.stack&&(this.stack=t.stack),this.reason=this.message,this.fatal,this.line=a.start.line,this.column=a.start.column,this.position=a,this.source=i[0],this.ruleId=i[1],this.file,this.actual,this.expected,this.url,this.note}}br.prototype.file="";br.prototype.name="";br.prototype.reason="";br.prototype.message="";br.prototype.stack="";br.prototype.fatal=null;br.prototype.column=null;br.prototype.line=null;br.prototype.source=null;br.prototype.ruleId=null;br.prototype.position=null;const Rr={basename:K6,dirname:X6,extname:Y6,join:Z6,sep:"/"};function K6(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');Ga(e);let r=0,n=-1,i=e.length,a;if(t===void 0||t.length===0||t.length>e.length){for(;i--;)if(e.charCodeAt(i)===47){if(a){r=i+1;break}}else n<0&&(a=!0,n=i+1);return n<0?"":e.slice(r,n)}if(t===e)return"";let o=-1,s=t.length-1;for(;i--;)if(e.charCodeAt(i)===47){if(a){r=i+1;break}}else o<0&&(a=!0,o=i+1),s>-1&&(e.charCodeAt(i)===t.charCodeAt(s--)?s<0&&(n=i):(s=-1,n=o));return r===n?n=o:n<0&&(n=e.length),e.slice(r,n)}function X6(e){if(Ga(e),e.length===0)return".";let t=-1,r=e.length,n;for(;--r;)if(e.charCodeAt(r)===47){if(n){t=r;break}}else n||(n=!0);return t<0?e.charCodeAt(0)===47?"/":".":t===1&&e.charCodeAt(0)===47?"//":e.slice(0,t)}function Y6(e){Ga(e);let t=e.length,r=-1,n=0,i=-1,a=0,o;for(;t--;){const s=e.charCodeAt(t);if(s===47){if(o){n=t+1;break}continue}r<0&&(o=!0,r=t+1),s===46?i<0?i=t:a!==1&&(a=1):i>-1&&(a=-1)}return i<0||r<0||a===0||a===1&&i===r-1&&i===n+1?"":e.slice(i,r)}function Z6(...e){let t=-1,r;for(;++t<e.length;)Ga(e[t]),e[t]&&(r=r===void 0?e[t]:r+"/"+e[t]);return r===void 0?".":Q6(r)}function Q6(e){Ga(e);const t=e.charCodeAt(0)===47;let r=J6(e,!t);return r.length===0&&!t&&(r="."),r.length>0&&e.charCodeAt(e.length-1)===47&&(r+="/"),t?"/"+r:r}function J6(e,t){let r="",n=0,i=-1,a=0,o=-1,s,u;for(;++o<=e.length;){if(o<e.length)s=e.charCodeAt(o);else{if(s===47)break;s=47}if(s===47){if(!(i===o-1||a===1))if(i!==o-1&&a===2){if(r.length<2||n!==2||r.charCodeAt(r.length-1)!==46||r.charCodeAt(r.length-2)!==46){if(r.length>2){if(u=r.lastIndexOf("/"),u!==r.length-1){u<0?(r="",n=0):(r=r.slice(0,u),n=r.length-1-r.lastIndexOf("/")),i=o,a=0;continue}}else if(r.length>0){r="",n=0,i=o,a=0;continue}}t&&(r=r.length>0?r+"/..":"..",n=2)}else r.length>0?r+="/"+e.slice(i+1,o):r=e.slice(i+1,o),n=o-i-1;i=o,a=0}else s===46&&a>-1?a++:a=-1}return r}function Ga(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const e5={cwd:t5};function t5(){return"/"}function w0(e){return e!==null&&typeof e=="object"&&e.href&&e.origin}function r5(e){if(typeof e=="string")e=new URL(e);else if(!w0(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return n5(e)}function n5(e){if(e.hostname!==""){const n=new TypeError('File URL host must be "localhost" or empty on darwin');throw n.code="ERR_INVALID_FILE_URL_HOST",n}const t=e.pathname;let r=-1;for(;++r<t.length;)if(t.charCodeAt(r)===37&&t.charCodeAt(r+1)===50){const n=t.charCodeAt(r+2);if(n===70||n===102){const i=new TypeError("File URL path must not include encoded / characters");throw i.code="ERR_INVALID_FILE_URL_PATH",i}}return decodeURIComponent(t)}const al=["history","path","basename","stem","extname","dirname"];class fg{constructor(t){let r;t?typeof t=="string"||i5(t)?r={value:t}:w0(t)?r={path:t}:r=t:r={},this.data={},this.messages=[],this.history=[],this.cwd=e5.cwd(),this.value,this.stored,this.result,this.map;let n=-1;for(;++n<al.length;){const a=al[n];a in r&&r[a]!==void 0&&r[a]!==null&&(this[a]=a==="history"?[...r[a]]:r[a])}let i;for(i in r)al.includes(i)||(this[i]=r[i])}get path(){return this.history[this.history.length-1]}set path(t){w0(t)&&(t=r5(t)),sl(t,"path"),this.path!==t&&this.history.push(t)}get dirname(){return typeof this.path=="string"?Rr.dirname(this.path):void 0}set dirname(t){Jd(this.basename,"dirname"),this.path=Rr.join(t||"",this.basename)}get basename(){return typeof this.path=="string"?Rr.basename(this.path):void 0}set basename(t){sl(t,"basename"),ol(t,"basename"),this.path=Rr.join(this.dirname||"",t)}get extname(){return typeof this.path=="string"?Rr.extname(this.path):void 0}set extname(t){if(ol(t,"extname"),Jd(this.dirname,"extname"),t){if(t.charCodeAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=Rr.join(this.dirname,this.stem+(t||""))}get stem(){return typeof this.path=="string"?Rr.basename(this.path,this.extname):void 0}set stem(t){sl(t,"stem"),ol(t,"stem"),this.path=Rr.join(this.dirname||"",t+(this.extname||""))}toString(t){return(this.value||"").toString(t||void 0)}message(t,r,n){const i=new br(t,r,n);return this.path&&(i.name=this.path+":"+i.name,i.file=this.path),i.fatal=!1,this.messages.push(i),i}info(t,r,n){const i=this.message(t,r,n);return i.fatal=null,i}fail(t,r,n){const i=this.message(t,r,n);throw i.fatal=!0,i}}function ol(e,t){if(e&&e.includes(Rr.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+Rr.sep+"`")}function sl(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function Jd(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function i5(e){return cg(e)}function eh(e){if(e)throw e}var rs=Object.prototype.hasOwnProperty,dg=Object.prototype.toString,th=Object.defineProperty,rh=Object.getOwnPropertyDescriptor,nh=function(t){return typeof Array.isArray=="function"?Array.isArray(t):dg.call(t)==="[object Array]"},ih=function(t){if(!t||dg.call(t)!=="[object Object]")return!1;var r=rs.call(t,"constructor"),n=t.constructor&&t.constructor.prototype&&rs.call(t.constructor.prototype,"isPrototypeOf");if(t.constructor&&!r&&!n)return!1;var i;for(i in t);return typeof i>"u"||rs.call(t,i)},ah=function(t,r){th&&r.name==="__proto__"?th(t,r.name,{enumerable:!0,configurable:!0,value:r.newValue,writable:!0}):t[r.name]=r.newValue},oh=function(t,r){if(r==="__proto__")if(rs.call(t,r)){if(rh)return rh(t,r).value}else return;return t[r]},a5=function e(){var t,r,n,i,a,o,s=arguments[0],u=1,l=arguments.length,c=!1;for(typeof s=="boolean"&&(c=s,s=arguments[1]||{},u=2),(s==null||typeof s!="object"&&typeof s!="function")&&(s={});u<l;++u)if(t=arguments[u],t!=null)for(r in t)n=oh(s,r),i=oh(t,r),s!==i&&(c&&i&&(ih(i)||(a=nh(i)))?(a?(a=!1,o=n&&nh(n)?n:[]):o=n&&ih(n)?n:{},ah(s,{name:r,newValue:e(c,o,i)})):typeof i<"u"&&ah(s,{name:r,newValue:i}));return s};const sh=Ce(a5);function x0(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function o5(){const e=[],t={run:r,use:n};return t;function r(...i){let a=-1;const o=i.pop();if(typeof o!="function")throw new TypeError("Expected function as last argument, not "+o);s(null,...i);function s(u,...l){const c=e[++a];let f=-1;if(u){o(u);return}for(;++f<i.length;)(l[f]===null||l[f]===void 0)&&(l[f]=i[f]);i=l,c?s5(c,s)(...l):o(null,...l)}}function n(i){if(typeof i!="function")throw new TypeError("Expected `middelware` to be a function, not "+i);return e.push(i),t}}function s5(e,t){let r;return n;function n(...o){const s=e.length>o.length;let u;s&&o.push(i);try{u=e.apply(this,o)}catch(l){const c=l;if(s&&r)throw c;return i(c)}s||(u instanceof Promise?u.then(a,i):u instanceof Error?i(u):a(u))}function i(o,...s){r||(r=!0,t(o,...s))}function a(o){i(null,o)}}const u5=pg().freeze(),hg={}.hasOwnProperty;function pg(){const e=o5(),t=[];let r={},n,i=-1;return a.data=o,a.Parser=void 0,a.Compiler=void 0,a.freeze=s,a.attachers=t,a.use=u,a.parse=l,a.stringify=c,a.run=f,a.runSync=d,a.process=h,a.processSync=p,a;function a(){const m=pg();let g=-1;for(;++g<t.length;)m.use(...t[g]);return m.data(sh(!0,{},r)),m}function o(m,g){return typeof m=="string"?arguments.length===2?(cl("data",n),r[m]=g,a):hg.call(r,m)&&r[m]||null:m?(cl("data",n),r=m,a):r}function s(){if(n)return a;for(;++i<t.length;){const[m,...g]=t[i];if(g[0]===!1)continue;g[0]===!0&&(g[0]=void 0);const v=m.call(a,...g);typeof v=="function"&&e.use(v)}return n=!0,i=Number.POSITIVE_INFINITY,a}function u(m,...g){let v;if(cl("use",n),m!=null)if(typeof m=="function")O(m,...g);else if(typeof m=="object")Array.isArray(m)?N(m):x(m);else throw new TypeError("Expected usable value, not `"+m+"`");return v&&(r.settings=Object.assign(r.settings||{},v)),a;function w(A){if(typeof A=="function")O(A);else if(typeof A=="object")if(Array.isArray(A)){const[D,...H]=A;O(D,...H)}else x(A);else throw new TypeError("Expected usable value, not `"+A+"`")}function x(A){N(A.plugins),A.settings&&(v=Object.assign(v||{},A.settings))}function N(A){let D=-1;if(A!=null)if(Array.isArray(A))for(;++D<A.length;){const H=A[D];w(H)}else throw new TypeError("Expected a list of plugins, not `"+A+"`")}function O(A,D){let H=-1,z;for(;++H<t.length;)if(t[H][0]===A){z=t[H];break}z?(x0(z[1])&&x0(D)&&(D=sh(!0,z[1],D)),z[1]=D):t.push([...arguments])}}function l(m){a.freeze();const g=aa(m),v=a.Parser;return ul("parse",v),uh(v,"parse")?new v(String(g),g).parse():v(String(g),g)}function c(m,g){a.freeze();const v=aa(g),w=a.Compiler;return ll("stringify",w),lh(m),uh(w,"compile")?new w(m,v).compile():w(m,v)}function f(m,g,v){if(lh(m),a.freeze(),!v&&typeof g=="function"&&(v=g,g=void 0),!v)return new Promise(w);w(null,v);function w(x,N){e.run(m,aa(g),O);function O(A,D,H){D=D||m,A?N(A):x?x(D):v(null,D,H)}}}function d(m,g){let v,w;return a.run(m,g,x),ch("runSync","run",w),v;function x(N,O){eh(N),v=O,w=!0}}function h(m,g){if(a.freeze(),ul("process",a.Parser),ll("process",a.Compiler),!g)return new Promise(v);v(null,g);function v(w,x){const N=aa(m);a.run(a.parse(N),N,(A,D,H)=>{if(A||!D||!H)O(A);else{const z=a.stringify(D,H);z==null||(f5(z)?H.value=z:H.result=z),O(A,H)}});function O(A,D){A||!D?x(A):w?w(D):g(null,D)}}}function p(m){let g;a.freeze(),ul("processSync",a.Parser),ll("processSync",a.Compiler);const v=aa(m);return a.process(v,w),ch("processSync","process",g),v;function w(x){g=!0,eh(x)}}}function uh(e,t){return typeof e=="function"&&e.prototype&&(l5(e.prototype)||t in e.prototype)}function l5(e){let t;for(t in e)if(hg.call(e,t))return!0;return!1}function ul(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `Parser`")}function ll(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `Compiler`")}function cl(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function lh(e){if(!x0(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function ch(e,t,r){if(!r)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function aa(e){return c5(e)?e:new fg(e)}function c5(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function f5(e){return typeof e=="string"||cg(e)}const d5={};function h5(e,t){const r=t||d5,n=typeof r.includeImageAlt=="boolean"?r.includeImageAlt:!0,i=typeof r.includeHtml=="boolean"?r.includeHtml:!0;return mg(e,n,i)}function mg(e,t,r){if(p5(e)){if("value"in e)return e.type==="html"&&!r?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return fh(e.children,t,r)}return Array.isArray(e)?fh(e,t,r):""}function fh(e,t,r){const n=[];let i=-1;for(;++i<e.length;)n[i]=mg(e[i],t,r);return n.join("")}function p5(e){return!!(e&&typeof e=="object")}function nr(e,t,r,n){const i=e.length;let a=0,o;if(t<0?t=-t>i?0:i+t:t=t>i?i:t,r=r>0?r:0,n.length<1e4)o=Array.from(n),o.unshift(t,r),e.splice(...o);else for(r&&e.splice(t,r);a<n.length;)o=n.slice(a,a+1e4),o.unshift(t,0),e.splice(...o),a+=1e4,t+=1e4}function fr(e,t){return e.length>0?(nr(e,e.length,0,t),e):t}const dh={}.hasOwnProperty;function gg(e){const t={};let r=-1;for(;++r<e.length;)m5(t,e[r]);return t}function m5(e,t){let r;for(r in t){const i=(dh.call(e,r)?e[r]:void 0)||(e[r]={}),a=t[r];let o;if(a)for(o in a){dh.call(i,o)||(i[o]=[]);const s=a[o];g5(i[o],Array.isArray(s)?s:s?[s]:[])}}}function g5(e,t){let r=-1;const n=[];for(;++r<t.length;)(t[r].add==="after"?e:n).push(t[r]);nr(e,0,0,n)}const b5=/[!-\/:-@\[-`\{-~\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061D-\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u09FD\u0A76\u0AF0\u0C77\u0C84\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1B7D\u1B7E\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E4F\u2E52-\u2E5D\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65]/,Ft=Dn(/[A-Za-z]/),Nt=Dn(/[\dA-Za-z]/),v5=Dn(/[#-'*+\--9=?A-Z^-~]/);function Ts(e){return e!==null&&(e<32||e===127)}const E0=Dn(/\d/),y5=Dn(/[\dA-Fa-f]/),w5=Dn(/[!-/:-@[-`{-~]/);function pe(e){return e!==null&&e<-2}function Qe(e){return e!==null&&(e<0||e===32)}function Ie(e){return e===-2||e===-1||e===32}const iu=Dn(b5),oi=Dn(/\s/);function Dn(e){return t;function t(r){return r!==null&&e.test(String.fromCharCode(r))}}function Me(e,t,r,n){const i=n?n-1:Number.POSITIVE_INFINITY;let a=0;return o;function o(u){return Ie(u)?(e.enter(r),s(u)):t(u)}function s(u){return Ie(u)&&a++<i?(e.consume(u),s):(e.exit(r),t(u))}}const x5={tokenize:E5};function E5(e){const t=e.attempt(this.parser.constructs.contentInitial,n,i);let r;return t;function n(s){if(s===null){e.consume(s);return}return e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),Me(e,t,"linePrefix")}function i(s){return e.enter("paragraph"),a(s)}function a(s){const u=e.enter("chunkText",{contentType:"text",previous:r});return r&&(r.next=u),r=u,o(s)}function o(s){if(s===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(s);return}return pe(s)?(e.consume(s),e.exit("chunkText"),a):(e.consume(s),o)}}const S5={tokenize:T5},hh={tokenize:A5};function T5(e){const t=this,r=[];let n=0,i,a,o;return s;function s(x){if(n<r.length){const N=r[n];return t.containerState=N[1],e.attempt(N[0].continuation,u,l)(x)}return l(x)}function u(x){if(n++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,i&&w();const N=t.events.length;let O=N,A;for(;O--;)if(t.events[O][0]==="exit"&&t.events[O][1].type==="chunkFlow"){A=t.events[O][1].end;break}v(n);let D=N;for(;D<t.events.length;)t.events[D][1].end=Object.assign({},A),D++;return nr(t.events,O+1,0,t.events.slice(N)),t.events.length=D,l(x)}return s(x)}function l(x){if(n===r.length){if(!i)return d(x);if(i.currentConstruct&&i.currentConstruct.concrete)return p(x);t.interrupt=!!(i.currentConstruct&&!i._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(hh,c,f)(x)}function c(x){return i&&w(),v(n),d(x)}function f(x){return t.parser.lazy[t.now().line]=n!==r.length,o=t.now().offset,p(x)}function d(x){return t.containerState={},e.attempt(hh,h,p)(x)}function h(x){return n++,r.push([t.currentConstruct,t.containerState]),d(x)}function p(x){if(x===null){i&&w(),v(0),e.consume(x);return}return i=i||t.parser.flow(t.now()),e.enter("chunkFlow",{contentType:"flow",previous:a,_tokenizer:i}),m(x)}function m(x){if(x===null){g(e.exit("chunkFlow"),!0),v(0),e.consume(x);return}return pe(x)?(e.consume(x),g(e.exit("chunkFlow")),n=0,t.interrupt=void 0,s):(e.consume(x),m)}function g(x,N){const O=t.sliceStream(x);if(N&&O.push(null),x.previous=a,a&&(a.next=x),a=x,i.defineSkip(x.start),i.write(O),t.parser.lazy[x.start.line]){let A=i.events.length;for(;A--;)if(i.events[A][1].start.offset<o&&(!i.events[A][1].end||i.events[A][1].end.offset>o))return;const D=t.events.length;let H=D,z,L;for(;H--;)if(t.events[H][0]==="exit"&&t.events[H][1].type==="chunkFlow"){if(z){L=t.events[H][1].end;break}z=!0}for(v(n),A=D;A<t.events.length;)t.events[A][1].end=Object.assign({},L),A++;nr(t.events,H+1,0,t.events.slice(D)),t.events.length=A}}function v(x){let N=r.length;for(;N-- >x;){const O=r[N];t.containerState=O[1],O[0].exit.call(t,e)}r.length=x}function w(){i.write([null]),a=void 0,i=void 0,t.containerState._closeFlow=void 0}}function A5(e,t,r){return Me(e,e.attempt(this.parser.constructs.document,t,r),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function As(e){if(e===null||Qe(e)||oi(e))return 1;if(iu(e))return 2}function au(e,t,r){const n=[];let i=-1;for(;++i<e.length;){const a=e[i].resolveAll;a&&!n.includes(a)&&(t=a(t,r),n.push(a))}return t}const S0={name:"attention",tokenize:O5,resolveAll:k5};function k5(e,t){let r=-1,n,i,a,o,s,u,l,c;for(;++r<e.length;)if(e[r][0]==="enter"&&e[r][1].type==="attentionSequence"&&e[r][1]._close){for(n=r;n--;)if(e[n][0]==="exit"&&e[n][1].type==="attentionSequence"&&e[n][1]._open&&t.sliceSerialize(e[n][1]).charCodeAt(0)===t.sliceSerialize(e[r][1]).charCodeAt(0)){if((e[n][1]._close||e[r][1]._open)&&(e[r][1].end.offset-e[r][1].start.offset)%3&&!((e[n][1].end.offset-e[n][1].start.offset+e[r][1].end.offset-e[r][1].start.offset)%3))continue;u=e[n][1].end.offset-e[n][1].start.offset>1&&e[r][1].end.offset-e[r][1].start.offset>1?2:1;const f=Object.assign({},e[n][1].end),d=Object.assign({},e[r][1].start);ph(f,-u),ph(d,u),o={type:u>1?"strongSequence":"emphasisSequence",start:f,end:Object.assign({},e[n][1].end)},s={type:u>1?"strongSequence":"emphasisSequence",start:Object.assign({},e[r][1].start),end:d},a={type:u>1?"strongText":"emphasisText",start:Object.assign({},e[n][1].end),end:Object.assign({},e[r][1].start)},i={type:u>1?"strong":"emphasis",start:Object.assign({},o.start),end:Object.assign({},s.end)},e[n][1].end=Object.assign({},o.start),e[r][1].start=Object.assign({},s.end),l=[],e[n][1].end.offset-e[n][1].start.offset&&(l=fr(l,[["enter",e[n][1],t],["exit",e[n][1],t]])),l=fr(l,[["enter",i,t],["enter",o,t],["exit",o,t],["enter",a,t]]),l=fr(l,au(t.parser.constructs.insideSpan.null,e.slice(n+1,r),t)),l=fr(l,[["exit",a,t],["enter",s,t],["exit",s,t],["exit",i,t]]),e[r][1].end.offset-e[r][1].start.offset?(c=2,l=fr(l,[["enter",e[r][1],t],["exit",e[r][1],t]])):c=0,nr(e,n-1,r-n+3,l),r=n+l.length-c-2;break}}for(r=-1;++r<e.length;)e[r][1].type==="attentionSequence"&&(e[r][1].type="data");return e}function O5(e,t){const r=this.parser.constructs.attentionMarkers.null,n=this.previous,i=As(n);let a;return o;function o(u){return a=u,e.enter("attentionSequence"),s(u)}function s(u){if(u===a)return e.consume(u),s;const l=e.exit("attentionSequence"),c=As(u),f=!c||c===2&&i||r.includes(u),d=!i||i===2&&c||r.includes(n);return l._open=!!(a===42?f:f&&(i||!d)),l._close=!!(a===42?d:d&&(c||!f)),t(u)}}function ph(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const N5={name:"autolink",tokenize:_5};function _5(e,t,r){let n=0;return i;function i(h){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(h),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),a}function a(h){return Ft(h)?(e.consume(h),o):l(h)}function o(h){return h===43||h===45||h===46||Nt(h)?(n=1,s(h)):l(h)}function s(h){return h===58?(e.consume(h),n=0,u):(h===43||h===45||h===46||Nt(h))&&n++<32?(e.consume(h),s):(n=0,l(h))}function u(h){return h===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(h),e.exit("autolinkMarker"),e.exit("autolink"),t):h===null||h===32||h===60||Ts(h)?r(h):(e.consume(h),u)}function l(h){return h===64?(e.consume(h),c):v5(h)?(e.consume(h),l):r(h)}function c(h){return Nt(h)?f(h):r(h)}function f(h){return h===46?(e.consume(h),n=0,c):h===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(h),e.exit("autolinkMarker"),e.exit("autolink"),t):d(h)}function d(h){if((h===45||Nt(h))&&n++<63){const p=h===45?d:f;return e.consume(h),p}return r(h)}}const Wa={tokenize:C5,partial:!0};function C5(e,t,r){return n;function n(a){return Ie(a)?Me(e,i,"linePrefix")(a):i(a)}function i(a){return a===null||pe(a)?t(a):r(a)}}const bg={name:"blockQuote",tokenize:M5,continuation:{tokenize:R5},exit:I5};function M5(e,t,r){const n=this;return i;function i(o){if(o===62){const s=n.containerState;return s.open||(e.enter("blockQuote",{_container:!0}),s.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(o),e.exit("blockQuoteMarker"),a}return r(o)}function a(o){return Ie(o)?(e.enter("blockQuotePrefixWhitespace"),e.consume(o),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(o))}}function R5(e,t,r){const n=this;return i;function i(o){return Ie(o)?Me(e,a,"linePrefix",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(o):a(o)}function a(o){return e.attempt(bg,t,r)(o)}}function I5(e){e.exit("blockQuote")}const vg={name:"characterEscape",tokenize:P5};function P5(e,t,r){return n;function n(a){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(a),e.exit("escapeMarker"),i}function i(a){return w5(a)?(e.enter("characterEscapeValue"),e.consume(a),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):r(a)}}const mh=document.createElement("i");function af(e){const t="&"+e+";";mh.innerHTML=t;const r=mh.textContent;return r.charCodeAt(r.length-1)===59&&e!=="semi"||r===t?!1:r}const yg={name:"characterReference",tokenize:D5};function D5(e,t,r){const n=this;let i=0,a,o;return s;function s(f){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(f),e.exit("characterReferenceMarker"),u}function u(f){return f===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(f),e.exit("characterReferenceMarkerNumeric"),l):(e.enter("characterReferenceValue"),a=31,o=Nt,c(f))}function l(f){return f===88||f===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(f),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),a=6,o=y5,c):(e.enter("characterReferenceValue"),a=7,o=E0,c(f))}function c(f){if(f===59&&i){const d=e.exit("characterReferenceValue");return o===Nt&&!af(n.sliceSerialize(d))?r(f):(e.enter("characterReferenceMarker"),e.consume(f),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return o(f)&&i++<a?(e.consume(f),c):r(f)}}const gh={tokenize:F5,partial:!0},bh={name:"codeFenced",tokenize:L5,concrete:!0};function L5(e,t,r){const n=this,i={tokenize:O,partial:!0};let a=0,o=0,s;return u;function u(A){return l(A)}function l(A){const D=n.events[n.events.length-1];return a=D&&D[1].type==="linePrefix"?D[2].sliceSerialize(D[1],!0).length:0,s=A,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),c(A)}function c(A){return A===s?(o++,e.consume(A),c):o<3?r(A):(e.exit("codeFencedFenceSequence"),Ie(A)?Me(e,f,"whitespace")(A):f(A))}function f(A){return A===null||pe(A)?(e.exit("codeFencedFence"),n.interrupt?t(A):e.check(gh,m,N)(A)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),d(A))}function d(A){return A===null||pe(A)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),f(A)):Ie(A)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),Me(e,h,"whitespace")(A)):A===96&&A===s?r(A):(e.consume(A),d)}function h(A){return A===null||pe(A)?f(A):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),p(A))}function p(A){return A===null||pe(A)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),f(A)):A===96&&A===s?r(A):(e.consume(A),p)}function m(A){return e.attempt(i,N,g)(A)}function g(A){return e.enter("lineEnding"),e.consume(A),e.exit("lineEnding"),v}function v(A){return a>0&&Ie(A)?Me(e,w,"linePrefix",a+1)(A):w(A)}function w(A){return A===null||pe(A)?e.check(gh,m,N)(A):(e.enter("codeFlowValue"),x(A))}function x(A){return A===null||pe(A)?(e.exit("codeFlowValue"),w(A)):(e.consume(A),x)}function N(A){return e.exit("codeFenced"),t(A)}function O(A,D,H){let z=0;return L;function L(C){return A.enter("lineEnding"),A.consume(C),A.exit("lineEnding"),I}function I(C){return A.enter("codeFencedFence"),Ie(C)?Me(A,k,"linePrefix",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(C):k(C)}function k(C){return C===s?(A.enter("codeFencedFenceSequence"),M(C)):H(C)}function M(C){return C===s?(z++,A.consume(C),M):z>=o?(A.exit("codeFencedFenceSequence"),Ie(C)?Me(A,F,"whitespace")(C):F(C)):H(C)}function F(C){return C===null||pe(C)?(A.exit("codeFencedFence"),D(C)):H(C)}}}function F5(e,t,r){const n=this;return i;function i(o){return o===null?r(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),a)}function a(o){return n.parser.lazy[n.now().line]?r(o):t(o)}}const fl={name:"codeIndented",tokenize:z5},B5={tokenize:$5,partial:!0};function z5(e,t,r){const n=this;return i;function i(l){return e.enter("codeIndented"),Me(e,a,"linePrefix",4+1)(l)}function a(l){const c=n.events[n.events.length-1];return c&&c[1].type==="linePrefix"&&c[2].sliceSerialize(c[1],!0).length>=4?o(l):r(l)}function o(l){return l===null?u(l):pe(l)?e.attempt(B5,o,u)(l):(e.enter("codeFlowValue"),s(l))}function s(l){return l===null||pe(l)?(e.exit("codeFlowValue"),o(l)):(e.consume(l),s)}function u(l){return e.exit("codeIndented"),t(l)}}function $5(e,t,r){const n=this;return i;function i(o){return n.parser.lazy[n.now().line]?r(o):pe(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),i):Me(e,a,"linePrefix",4+1)(o)}function a(o){const s=n.events[n.events.length-1];return s&&s[1].type==="linePrefix"&&s[2].sliceSerialize(s[1],!0).length>=4?t(o):pe(o)?i(o):r(o)}}const U5={name:"codeText",tokenize:j5,resolve:H5,previous:q5};function H5(e){let t=e.length-4,r=3,n,i;if((e[r][1].type==="lineEnding"||e[r][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(n=r;++n<t;)if(e[n][1].type==="codeTextData"){e[r][1].type="codeTextPadding",e[t][1].type="codeTextPadding",r+=2,t-=2;break}}for(n=r-1,t++;++n<=t;)i===void 0?n!==t&&e[n][1].type!=="lineEnding"&&(i=n):(n===t||e[n][1].type==="lineEnding")&&(e[i][1].type="codeTextData",n!==i+2&&(e[i][1].end=e[n-1][1].end,e.splice(i+2,n-i-2),t-=n-i-2,n=i+2),i=void 0);return e}function q5(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function j5(e,t,r){let n=0,i,a;return o;function o(f){return e.enter("codeText"),e.enter("codeTextSequence"),s(f)}function s(f){return f===96?(e.consume(f),n++,s):(e.exit("codeTextSequence"),u(f))}function u(f){return f===null?r(f):f===32?(e.enter("space"),e.consume(f),e.exit("space"),u):f===96?(a=e.enter("codeTextSequence"),i=0,c(f)):pe(f)?(e.enter("lineEnding"),e.consume(f),e.exit("lineEnding"),u):(e.enter("codeTextData"),l(f))}function l(f){return f===null||f===32||f===96||pe(f)?(e.exit("codeTextData"),u(f)):(e.consume(f),l)}function c(f){return f===96?(e.consume(f),i++,c):i===n?(e.exit("codeTextSequence"),e.exit("codeText"),t(f)):(a.type="codeTextData",l(f))}}function wg(e){const t={};let r=-1,n,i,a,o,s,u,l;for(;++r<e.length;){for(;r in t;)r=t[r];if(n=e[r],r&&n[1].type==="chunkFlow"&&e[r-1][1].type==="listItemPrefix"&&(u=n[1]._tokenizer.events,a=0,a<u.length&&u[a][1].type==="lineEndingBlank"&&(a+=2),a<u.length&&u[a][1].type==="content"))for(;++a<u.length&&u[a][1].type!=="content";)u[a][1].type==="chunkText"&&(u[a][1]._isInFirstContentOfListItem=!0,a++);if(n[0]==="enter")n[1].contentType&&(Object.assign(t,V5(e,r)),r=t[r],l=!0);else if(n[1]._container){for(a=r,i=void 0;a--&&(o=e[a],o[1].type==="lineEnding"||o[1].type==="lineEndingBlank");)o[0]==="enter"&&(i&&(e[i][1].type="lineEndingBlank"),o[1].type="lineEnding",i=a);i&&(n[1].end=Object.assign({},e[i][1].start),s=e.slice(i,r),s.unshift(n),nr(e,i,r-i+1,s))}}return!l}function V5(e,t){const r=e[t][1],n=e[t][2];let i=t-1;const a=[],o=r._tokenizer||n.parser[r.contentType](r.start),s=o.events,u=[],l={};let c,f,d=-1,h=r,p=0,m=0;const g=[m];for(;h;){for(;e[++i][1]!==h;);a.push(i),h._tokenizer||(c=n.sliceStream(h),h.next||c.push(null),f&&o.defineSkip(h.start),h._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=!0),o.write(c),h._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=void 0)),f=h,h=h.next}for(h=r;++d<s.length;)s[d][0]==="exit"&&s[d-1][0]==="enter"&&s[d][1].type===s[d-1][1].type&&s[d][1].start.line!==s[d][1].end.line&&(m=d+1,g.push(m),h._tokenizer=void 0,h.previous=void 0,h=h.next);for(o.events=[],h?(h._tokenizer=void 0,h.previous=void 0):g.pop(),d=g.length;d--;){const v=s.slice(g[d],g[d+1]),w=a.pop();u.unshift([w,w+v.length-1]),nr(e,w,2,v)}for(d=-1;++d<u.length;)l[p+u[d][0]]=p+u[d][1],p+=u[d][1]-u[d][0]-1;return l}const G5={tokenize:X5,resolve:K5},W5={tokenize:Y5,partial:!0};function K5(e){return wg(e),e}function X5(e,t){let r;return n;function n(s){return e.enter("content"),r=e.enter("chunkContent",{contentType:"content"}),i(s)}function i(s){return s===null?a(s):pe(s)?e.check(W5,o,a)(s):(e.consume(s),i)}function a(s){return e.exit("chunkContent"),e.exit("content"),t(s)}function o(s){return e.consume(s),e.exit("chunkContent"),r.next=e.enter("chunkContent",{contentType:"content",previous:r}),r=r.next,i}}function Y5(e,t,r){const n=this;return i;function i(o){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),Me(e,a,"linePrefix")}function a(o){if(o===null||pe(o))return r(o);const s=n.events[n.events.length-1];return!n.parser.constructs.disable.null.includes("codeIndented")&&s&&s[1].type==="linePrefix"&&s[2].sliceSerialize(s[1],!0).length>=4?t(o):e.interrupt(n.parser.constructs.flow,r,t)(o)}}function xg(e,t,r,n,i,a,o,s,u){const l=u||Number.POSITIVE_INFINITY;let c=0;return f;function f(v){return v===60?(e.enter(n),e.enter(i),e.enter(a),e.consume(v),e.exit(a),d):v===null||v===32||v===41||Ts(v)?r(v):(e.enter(n),e.enter(o),e.enter(s),e.enter("chunkString",{contentType:"string"}),m(v))}function d(v){return v===62?(e.enter(a),e.consume(v),e.exit(a),e.exit(i),e.exit(n),t):(e.enter(s),e.enter("chunkString",{contentType:"string"}),h(v))}function h(v){return v===62?(e.exit("chunkString"),e.exit(s),d(v)):v===null||v===60||pe(v)?r(v):(e.consume(v),v===92?p:h)}function p(v){return v===60||v===62||v===92?(e.consume(v),h):h(v)}function m(v){return!c&&(v===null||v===41||Qe(v))?(e.exit("chunkString"),e.exit(s),e.exit(o),e.exit(n),t(v)):c<l&&v===40?(e.consume(v),c++,m):v===41?(e.consume(v),c--,m):v===null||v===32||v===40||Ts(v)?r(v):(e.consume(v),v===92?g:m)}function g(v){return v===40||v===41||v===92?(e.consume(v),m):m(v)}}function Eg(e,t,r,n,i,a){const o=this;let s=0,u;return l;function l(h){return e.enter(n),e.enter(i),e.consume(h),e.exit(i),e.enter(a),c}function c(h){return s>999||h===null||h===91||h===93&&!u||h===94&&!s&&"_hiddenFootnoteSupport"in o.parser.constructs?r(h):h===93?(e.exit(a),e.enter(i),e.consume(h),e.exit(i),e.exit(n),t):pe(h)?(e.enter("lineEnding"),e.consume(h),e.exit("lineEnding"),c):(e.enter("chunkString",{contentType:"string"}),f(h))}function f(h){return h===null||h===91||h===93||pe(h)||s++>999?(e.exit("chunkString"),c(h)):(e.consume(h),u||(u=!Ie(h)),h===92?d:f)}function d(h){return h===91||h===92||h===93?(e.consume(h),s++,f):f(h)}}function Sg(e,t,r,n,i,a){let o;return s;function s(d){return d===34||d===39||d===40?(e.enter(n),e.enter(i),e.consume(d),e.exit(i),o=d===40?41:d,u):r(d)}function u(d){return d===o?(e.enter(i),e.consume(d),e.exit(i),e.exit(n),t):(e.enter(a),l(d))}function l(d){return d===o?(e.exit(a),u(o)):d===null?r(d):pe(d)?(e.enter("lineEnding"),e.consume(d),e.exit("lineEnding"),Me(e,l,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),c(d))}function c(d){return d===o||d===null||pe(d)?(e.exit("chunkString"),l(d)):(e.consume(d),d===92?f:c)}function f(d){return d===o||d===92?(e.consume(d),c):c(d)}}function ma(e,t){let r;return n;function n(i){return pe(i)?(e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),r=!0,n):Ie(i)?Me(e,n,r?"linePrefix":"lineSuffix")(i):t(i)}}function Or(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const Z5={name:"definition",tokenize:J5},Q5={tokenize:e8,partial:!0};function J5(e,t,r){const n=this;let i;return a;function a(h){return e.enter("definition"),o(h)}function o(h){return Eg.call(n,e,s,r,"definitionLabel","definitionLabelMarker","definitionLabelString")(h)}function s(h){return i=Or(n.sliceSerialize(n.events[n.events.length-1][1]).slice(1,-1)),h===58?(e.enter("definitionMarker"),e.consume(h),e.exit("definitionMarker"),u):r(h)}function u(h){return Qe(h)?ma(e,l)(h):l(h)}function l(h){return xg(e,c,r,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(h)}function c(h){return e.attempt(Q5,f,f)(h)}function f(h){return Ie(h)?Me(e,d,"whitespace")(h):d(h)}function d(h){return h===null||pe(h)?(e.exit("definition"),n.parser.defined.push(i),t(h)):r(h)}}function e8(e,t,r){return n;function n(s){return Qe(s)?ma(e,i)(s):r(s)}function i(s){return Sg(e,a,r,"definitionTitle","definitionTitleMarker","definitionTitleString")(s)}function a(s){return Ie(s)?Me(e,o,"whitespace")(s):o(s)}function o(s){return s===null||pe(s)?t(s):r(s)}}const t8={name:"hardBreakEscape",tokenize:r8};function r8(e,t,r){return n;function n(a){return e.enter("hardBreakEscape"),e.consume(a),i}function i(a){return pe(a)?(e.exit("hardBreakEscape"),t(a)):r(a)}}const n8={name:"headingAtx",tokenize:a8,resolve:i8};function i8(e,t){let r=e.length-2,n=3,i,a;return e[n][1].type==="whitespace"&&(n+=2),r-2>n&&e[r][1].type==="whitespace"&&(r-=2),e[r][1].type==="atxHeadingSequence"&&(n===r-1||r-4>n&&e[r-2][1].type==="whitespace")&&(r-=n+1===r?2:4),r>n&&(i={type:"atxHeadingText",start:e[n][1].start,end:e[r][1].end},a={type:"chunkText",start:e[n][1].start,end:e[r][1].end,contentType:"text"},nr(e,n,r-n+1,[["enter",i,t],["enter",a,t],["exit",a,t],["exit",i,t]])),e}function a8(e,t,r){let n=0;return i;function i(c){return e.enter("atxHeading"),a(c)}function a(c){return e.enter("atxHeadingSequence"),o(c)}function o(c){return c===35&&n++<6?(e.consume(c),o):c===null||Qe(c)?(e.exit("atxHeadingSequence"),s(c)):r(c)}function s(c){return c===35?(e.enter("atxHeadingSequence"),u(c)):c===null||pe(c)?(e.exit("atxHeading"),t(c)):Ie(c)?Me(e,s,"whitespace")(c):(e.enter("atxHeadingText"),l(c))}function u(c){return c===35?(e.consume(c),u):(e.exit("atxHeadingSequence"),s(c))}function l(c){return c===null||c===35||Qe(c)?(e.exit("atxHeadingText"),s(c)):(e.consume(c),l)}}const o8=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],vh=["pre","script","style","textarea"],s8={name:"htmlFlow",tokenize:f8,resolveTo:c8,concrete:!0},u8={tokenize:h8,partial:!0},l8={tokenize:d8,partial:!0};function c8(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function f8(e,t,r){const n=this;let i,a,o,s,u;return l;function l(T){return c(T)}function c(T){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(T),f}function f(T){return T===33?(e.consume(T),d):T===47?(e.consume(T),a=!0,m):T===63?(e.consume(T),i=3,n.interrupt?t:_):Ft(T)?(e.consume(T),o=String.fromCharCode(T),g):r(T)}function d(T){return T===45?(e.consume(T),i=2,h):T===91?(e.consume(T),i=5,s=0,p):Ft(T)?(e.consume(T),i=4,n.interrupt?t:_):r(T)}function h(T){return T===45?(e.consume(T),n.interrupt?t:_):r(T)}function p(T){const G="CDATA[";return T===G.charCodeAt(s++)?(e.consume(T),s===G.length?n.interrupt?t:k:p):r(T)}function m(T){return Ft(T)?(e.consume(T),o=String.fromCharCode(T),g):r(T)}function g(T){if(T===null||T===47||T===62||Qe(T)){const G=T===47,ee=o.toLowerCase();return!G&&!a&&vh.includes(ee)?(i=1,n.interrupt?t(T):k(T)):o8.includes(o.toLowerCase())?(i=6,G?(e.consume(T),v):n.interrupt?t(T):k(T)):(i=7,n.interrupt&&!n.parser.lazy[n.now().line]?r(T):a?w(T):x(T))}return T===45||Nt(T)?(e.consume(T),o+=String.fromCharCode(T),g):r(T)}function v(T){return T===62?(e.consume(T),n.interrupt?t:k):r(T)}function w(T){return Ie(T)?(e.consume(T),w):L(T)}function x(T){return T===47?(e.consume(T),L):T===58||T===95||Ft(T)?(e.consume(T),N):Ie(T)?(e.consume(T),x):L(T)}function N(T){return T===45||T===46||T===58||T===95||Nt(T)?(e.consume(T),N):O(T)}function O(T){return T===61?(e.consume(T),A):Ie(T)?(e.consume(T),O):x(T)}function A(T){return T===null||T===60||T===61||T===62||T===96?r(T):T===34||T===39?(e.consume(T),u=T,D):Ie(T)?(e.consume(T),A):H(T)}function D(T){return T===u?(e.consume(T),u=null,z):T===null||pe(T)?r(T):(e.consume(T),D)}function H(T){return T===null||T===34||T===39||T===47||T===60||T===61||T===62||T===96||Qe(T)?O(T):(e.consume(T),H)}function z(T){return T===47||T===62||Ie(T)?x(T):r(T)}function L(T){return T===62?(e.consume(T),I):r(T)}function I(T){return T===null||pe(T)?k(T):Ie(T)?(e.consume(T),I):r(T)}function k(T){return T===45&&i===2?(e.consume(T),U):T===60&&i===1?(e.consume(T),$):T===62&&i===4?(e.consume(T),oe):T===63&&i===3?(e.consume(T),_):T===93&&i===5?(e.consume(T),se):pe(T)&&(i===6||i===7)?(e.exit("htmlFlowData"),e.check(u8,ne,M)(T)):T===null||pe(T)?(e.exit("htmlFlowData"),M(T)):(e.consume(T),k)}function M(T){return e.check(l8,F,ne)(T)}function F(T){return e.enter("lineEnding"),e.consume(T),e.exit("lineEnding"),C}function C(T){return T===null||pe(T)?M(T):(e.enter("htmlFlowData"),k(T))}function U(T){return T===45?(e.consume(T),_):k(T)}function $(T){return T===47?(e.consume(T),o="",V):k(T)}function V(T){if(T===62){const G=o.toLowerCase();return vh.includes(G)?(e.consume(T),oe):k(T)}return Ft(T)&&o.length<8?(e.consume(T),o+=String.fromCharCode(T),V):k(T)}function se(T){return T===93?(e.consume(T),_):k(T)}function _(T){return T===62?(e.consume(T),oe):T===45&&i===2?(e.consume(T),_):k(T)}function oe(T){return T===null||pe(T)?(e.exit("htmlFlowData"),ne(T)):(e.consume(T),oe)}function ne(T){return e.exit("htmlFlow"),t(T)}}function d8(e,t,r){const n=this;return i;function i(o){return pe(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),a):r(o)}function a(o){return n.parser.lazy[n.now().line]?r(o):t(o)}}function h8(e,t,r){return n;function n(i){return e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),e.attempt(Wa,t,r)}}const p8={name:"htmlText",tokenize:m8};function m8(e,t,r){const n=this;let i,a,o;return s;function s(_){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(_),u}function u(_){return _===33?(e.consume(_),l):_===47?(e.consume(_),O):_===63?(e.consume(_),x):Ft(_)?(e.consume(_),H):r(_)}function l(_){return _===45?(e.consume(_),c):_===91?(e.consume(_),a=0,p):Ft(_)?(e.consume(_),w):r(_)}function c(_){return _===45?(e.consume(_),h):r(_)}function f(_){return _===null?r(_):_===45?(e.consume(_),d):pe(_)?(o=f,$(_)):(e.consume(_),f)}function d(_){return _===45?(e.consume(_),h):f(_)}function h(_){return _===62?U(_):_===45?d(_):f(_)}function p(_){const oe="CDATA[";return _===oe.charCodeAt(a++)?(e.consume(_),a===oe.length?m:p):r(_)}function m(_){return _===null?r(_):_===93?(e.consume(_),g):pe(_)?(o=m,$(_)):(e.consume(_),m)}function g(_){return _===93?(e.consume(_),v):m(_)}function v(_){return _===62?U(_):_===93?(e.consume(_),v):m(_)}function w(_){return _===null||_===62?U(_):pe(_)?(o=w,$(_)):(e.consume(_),w)}function x(_){return _===null?r(_):_===63?(e.consume(_),N):pe(_)?(o=x,$(_)):(e.consume(_),x)}function N(_){return _===62?U(_):x(_)}function O(_){return Ft(_)?(e.consume(_),A):r(_)}function A(_){return _===45||Nt(_)?(e.consume(_),A):D(_)}function D(_){return pe(_)?(o=D,$(_)):Ie(_)?(e.consume(_),D):U(_)}function H(_){return _===45||Nt(_)?(e.consume(_),H):_===47||_===62||Qe(_)?z(_):r(_)}function z(_){return _===47?(e.consume(_),U):_===58||_===95||Ft(_)?(e.consume(_),L):pe(_)?(o=z,$(_)):Ie(_)?(e.consume(_),z):U(_)}function L(_){return _===45||_===46||_===58||_===95||Nt(_)?(e.consume(_),L):I(_)}function I(_){return _===61?(e.consume(_),k):pe(_)?(o=I,$(_)):Ie(_)?(e.consume(_),I):z(_)}function k(_){return _===null||_===60||_===61||_===62||_===96?r(_):_===34||_===39?(e.consume(_),i=_,M):pe(_)?(o=k,$(_)):Ie(_)?(e.consume(_),k):(e.consume(_),F)}function M(_){return _===i?(e.consume(_),i=void 0,C):_===null?r(_):pe(_)?(o=M,$(_)):(e.consume(_),M)}function F(_){return _===null||_===34||_===39||_===60||_===61||_===96?r(_):_===47||_===62||Qe(_)?z(_):(e.consume(_),F)}function C(_){return _===47||_===62||Qe(_)?z(_):r(_)}function U(_){return _===62?(e.consume(_),e.exit("htmlTextData"),e.exit("htmlText"),t):r(_)}function $(_){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(_),e.exit("lineEnding"),V}function V(_){return Ie(_)?Me(e,se,"linePrefix",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(_):se(_)}function se(_){return e.enter("htmlTextData"),o(_)}}const of={name:"labelEnd",tokenize:x8,resolveTo:w8,resolveAll:y8},g8={tokenize:E8},b8={tokenize:S8},v8={tokenize:T8};function y8(e){let t=-1;for(;++t<e.length;){const r=e[t][1];(r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd")&&(e.splice(t+1,r.type==="labelImage"?4:2),r.type="data",t++)}return e}function w8(e,t){let r=e.length,n=0,i,a,o,s;for(;r--;)if(i=e[r][1],a){if(i.type==="link"||i.type==="labelLink"&&i._inactive)break;e[r][0]==="enter"&&i.type==="labelLink"&&(i._inactive=!0)}else if(o){if(e[r][0]==="enter"&&(i.type==="labelImage"||i.type==="labelLink")&&!i._balanced&&(a=r,i.type!=="labelLink")){n=2;break}}else i.type==="labelEnd"&&(o=r);const u={type:e[a][1].type==="labelLink"?"link":"image",start:Object.assign({},e[a][1].start),end:Object.assign({},e[e.length-1][1].end)},l={type:"label",start:Object.assign({},e[a][1].start),end:Object.assign({},e[o][1].end)},c={type:"labelText",start:Object.assign({},e[a+n+2][1].end),end:Object.assign({},e[o-2][1].start)};return s=[["enter",u,t],["enter",l,t]],s=fr(s,e.slice(a+1,a+n+3)),s=fr(s,[["enter",c,t]]),s=fr(s,au(t.parser.constructs.insideSpan.null,e.slice(a+n+4,o-3),t)),s=fr(s,[["exit",c,t],e[o-2],e[o-1],["exit",l,t]]),s=fr(s,e.slice(o+1)),s=fr(s,[["exit",u,t]]),nr(e,a,e.length,s),e}function x8(e,t,r){const n=this;let i=n.events.length,a,o;for(;i--;)if((n.events[i][1].type==="labelImage"||n.events[i][1].type==="labelLink")&&!n.events[i][1]._balanced){a=n.events[i][1];break}return s;function s(d){return a?a._inactive?f(d):(o=n.parser.defined.includes(Or(n.sliceSerialize({start:a.end,end:n.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(d),e.exit("labelMarker"),e.exit("labelEnd"),u):r(d)}function u(d){return d===40?e.attempt(g8,c,o?c:f)(d):d===91?e.attempt(b8,c,o?l:f)(d):o?c(d):f(d)}function l(d){return e.attempt(v8,c,f)(d)}function c(d){return t(d)}function f(d){return a._balanced=!0,r(d)}}function E8(e,t,r){return n;function n(f){return e.enter("resource"),e.enter("resourceMarker"),e.consume(f),e.exit("resourceMarker"),i}function i(f){return Qe(f)?ma(e,a)(f):a(f)}function a(f){return f===41?c(f):xg(e,o,s,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(f)}function o(f){return Qe(f)?ma(e,u)(f):c(f)}function s(f){return r(f)}function u(f){return f===34||f===39||f===40?Sg(e,l,r,"resourceTitle","resourceTitleMarker","resourceTitleString")(f):c(f)}function l(f){return Qe(f)?ma(e,c)(f):c(f)}function c(f){return f===41?(e.enter("resourceMarker"),e.consume(f),e.exit("resourceMarker"),e.exit("resource"),t):r(f)}}function S8(e,t,r){const n=this;return i;function i(s){return Eg.call(n,e,a,o,"reference","referenceMarker","referenceString")(s)}function a(s){return n.parser.defined.includes(Or(n.sliceSerialize(n.events[n.events.length-1][1]).slice(1,-1)))?t(s):r(s)}function o(s){return r(s)}}function T8(e,t,r){return n;function n(a){return e.enter("reference"),e.enter("referenceMarker"),e.consume(a),e.exit("referenceMarker"),i}function i(a){return a===93?(e.enter("referenceMarker"),e.consume(a),e.exit("referenceMarker"),e.exit("reference"),t):r(a)}}const A8={name:"labelStartImage",tokenize:k8,resolveAll:of.resolveAll};function k8(e,t,r){const n=this;return i;function i(s){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(s),e.exit("labelImageMarker"),a}function a(s){return s===91?(e.enter("labelMarker"),e.consume(s),e.exit("labelMarker"),e.exit("labelImage"),o):r(s)}function o(s){return s===94&&"_hiddenFootnoteSupport"in n.parser.constructs?r(s):t(s)}}const O8={name:"labelStartLink",tokenize:N8,resolveAll:of.resolveAll};function N8(e,t,r){const n=this;return i;function i(o){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(o),e.exit("labelMarker"),e.exit("labelLink"),a}function a(o){return o===94&&"_hiddenFootnoteSupport"in n.parser.constructs?r(o):t(o)}}const dl={name:"lineEnding",tokenize:_8};function _8(e,t){return r;function r(n){return e.enter("lineEnding"),e.consume(n),e.exit("lineEnding"),Me(e,t,"linePrefix")}}const ns={name:"thematicBreak",tokenize:C8};function C8(e,t,r){let n=0,i;return a;function a(l){return e.enter("thematicBreak"),o(l)}function o(l){return i=l,s(l)}function s(l){return l===i?(e.enter("thematicBreakSequence"),u(l)):n>=3&&(l===null||pe(l))?(e.exit("thematicBreak"),t(l)):r(l)}function u(l){return l===i?(e.consume(l),n++,u):(e.exit("thematicBreakSequence"),Ie(l)?Me(e,s,"whitespace")(l):s(l))}}const Ut={name:"list",tokenize:I8,continuation:{tokenize:P8},exit:L8},M8={tokenize:F8,partial:!0},R8={tokenize:D8,partial:!0};function I8(e,t,r){const n=this,i=n.events[n.events.length-1];let a=i&&i[1].type==="linePrefix"?i[2].sliceSerialize(i[1],!0).length:0,o=0;return s;function s(h){const p=n.containerState.type||(h===42||h===43||h===45?"listUnordered":"listOrdered");if(p==="listUnordered"?!n.containerState.marker||h===n.containerState.marker:E0(h)){if(n.containerState.type||(n.containerState.type=p,e.enter(p,{_container:!0})),p==="listUnordered")return e.enter("listItemPrefix"),h===42||h===45?e.check(ns,r,l)(h):l(h);if(!n.interrupt||h===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),u(h)}return r(h)}function u(h){return E0(h)&&++o<10?(e.consume(h),u):(!n.interrupt||o<2)&&(n.containerState.marker?h===n.containerState.marker:h===41||h===46)?(e.exit("listItemValue"),l(h)):r(h)}function l(h){return e.enter("listItemMarker"),e.consume(h),e.exit("listItemMarker"),n.containerState.marker=n.containerState.marker||h,e.check(Wa,n.interrupt?r:c,e.attempt(M8,d,f))}function c(h){return n.containerState.initialBlankLine=!0,a++,d(h)}function f(h){return Ie(h)?(e.enter("listItemPrefixWhitespace"),e.consume(h),e.exit("listItemPrefixWhitespace"),d):r(h)}function d(h){return n.containerState.size=a+n.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(h)}}function P8(e,t,r){const n=this;return n.containerState._closeFlow=void 0,e.check(Wa,i,a);function i(s){return n.containerState.furtherBlankLines=n.containerState.furtherBlankLines||n.containerState.initialBlankLine,Me(e,t,"listItemIndent",n.containerState.size+1)(s)}function a(s){return n.containerState.furtherBlankLines||!Ie(s)?(n.containerState.furtherBlankLines=void 0,n.containerState.initialBlankLine=void 0,o(s)):(n.containerState.furtherBlankLines=void 0,n.containerState.initialBlankLine=void 0,e.attempt(R8,t,o)(s))}function o(s){return n.containerState._closeFlow=!0,n.interrupt=void 0,Me(e,e.attempt(Ut,t,r),"linePrefix",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(s)}}function D8(e,t,r){const n=this;return Me(e,i,"listItemIndent",n.containerState.size+1);function i(a){const o=n.events[n.events.length-1];return o&&o[1].type==="listItemIndent"&&o[2].sliceSerialize(o[1],!0).length===n.containerState.size?t(a):r(a)}}function L8(e){e.exit(this.containerState.type)}function F8(e,t,r){const n=this;return Me(e,i,"listItemPrefixWhitespace",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4+1);function i(a){const o=n.events[n.events.length-1];return!Ie(a)&&o&&o[1].type==="listItemPrefixWhitespace"?t(a):r(a)}}const yh={name:"setextUnderline",tokenize:z8,resolveTo:B8};function B8(e,t){let r=e.length,n,i,a;for(;r--;)if(e[r][0]==="enter"){if(e[r][1].type==="content"){n=r;break}e[r][1].type==="paragraph"&&(i=r)}else e[r][1].type==="content"&&e.splice(r,1),!a&&e[r][1].type==="definition"&&(a=r);const o={type:"setextHeading",start:Object.assign({},e[i][1].start),end:Object.assign({},e[e.length-1][1].end)};return e[i][1].type="setextHeadingText",a?(e.splice(i,0,["enter",o,t]),e.splice(a+1,0,["exit",e[n][1],t]),e[n][1].end=Object.assign({},e[a][1].end)):e[n][1]=o,e.push(["exit",o,t]),e}function z8(e,t,r){const n=this;let i;return a;function a(l){let c=n.events.length,f;for(;c--;)if(n.events[c][1].type!=="lineEnding"&&n.events[c][1].type!=="linePrefix"&&n.events[c][1].type!=="content"){f=n.events[c][1].type==="paragraph";break}return!n.parser.lazy[n.now().line]&&(n.interrupt||f)?(e.enter("setextHeadingLine"),i=l,o(l)):r(l)}function o(l){return e.enter("setextHeadingLineSequence"),s(l)}function s(l){return l===i?(e.consume(l),s):(e.exit("setextHeadingLineSequence"),Ie(l)?Me(e,u,"lineSuffix")(l):u(l))}function u(l){return l===null||pe(l)?(e.exit("setextHeadingLine"),t(l)):r(l)}}const $8={tokenize:U8};function U8(e){const t=this,r=e.attempt(Wa,n,e.attempt(this.parser.constructs.flowInitial,i,Me(e,e.attempt(this.parser.constructs.flow,i,e.attempt(G5,i)),"linePrefix")));return r;function n(a){if(a===null){e.consume(a);return}return e.enter("lineEndingBlank"),e.consume(a),e.exit("lineEndingBlank"),t.currentConstruct=void 0,r}function i(a){if(a===null){e.consume(a);return}return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),t.currentConstruct=void 0,r}}const H8={resolveAll:Ag()},q8=Tg("string"),j8=Tg("text");function Tg(e){return{tokenize:t,resolveAll:Ag(e==="text"?V8:void 0)};function t(r){const n=this,i=this.parser.constructs[e],a=r.attempt(i,o,s);return o;function o(c){return l(c)?a(c):s(c)}function s(c){if(c===null){r.consume(c);return}return r.enter("data"),r.consume(c),u}function u(c){return l(c)?(r.exit("data"),a(c)):(r.consume(c),u)}function l(c){if(c===null)return!0;const f=i[c];let d=-1;if(f)for(;++d<f.length;){const h=f[d];if(!h.previous||h.previous.call(n,n.previous))return!0}return!1}}}function Ag(e){return t;function t(r,n){let i=-1,a;for(;++i<=r.length;)a===void 0?r[i]&&r[i][1].type==="data"&&(a=i,i++):(!r[i]||r[i][1].type!=="data")&&(i!==a+2&&(r[a][1].end=r[i-1][1].end,r.splice(a+2,i-a-2),i=a+2),a=void 0);return e?e(r,n):r}}function V8(e,t){let r=0;for(;++r<=e.length;)if((r===e.length||e[r][1].type==="lineEnding")&&e[r-1][1].type==="data"){const n=e[r-1][1],i=t.sliceStream(n);let a=i.length,o=-1,s=0,u;for(;a--;){const l=i[a];if(typeof l=="string"){for(o=l.length;l.charCodeAt(o-1)===32;)s++,o--;if(o)break;o=-1}else if(l===-2)u=!0,s++;else if(l!==-1){a++;break}}if(s){const l={type:r===e.length||u||s<2?"lineSuffix":"hardBreakTrailing",start:{line:n.end.line,column:n.end.column-s,offset:n.end.offset-s,_index:n.start._index+a,_bufferIndex:a?o:n.start._bufferIndex+o},end:Object.assign({},n.end)};n.end=Object.assign({},l.start),n.start.offset===n.end.offset?Object.assign(n,l):(e.splice(r,0,["enter",l,t],["exit",l,t]),r+=2)}r++}return e}function G8(e,t,r){let n=Object.assign(r?Object.assign({},r):{line:1,column:1,offset:0},{_index:0,_bufferIndex:-1});const i={},a=[];let o=[],s=[];const u={consume:w,enter:x,exit:N,attempt:D(O),check:D(A),interrupt:D(A,{interrupt:!0})},l={previous:null,code:null,containerState:{},events:[],parser:e,sliceStream:h,sliceSerialize:d,now:p,defineSkip:m,write:f};let c=t.tokenize.call(l,u);return t.resolveAll&&a.push(t),l;function f(I){return o=fr(o,I),g(),o[o.length-1]!==null?[]:(H(t,0),l.events=au(a,l.events,l),l.events)}function d(I,k){return K8(h(I),k)}function h(I){return W8(o,I)}function p(){const{line:I,column:k,offset:M,_index:F,_bufferIndex:C}=n;return{line:I,column:k,offset:M,_index:F,_bufferIndex:C}}function m(I){i[I.line]=I.column,L()}function g(){let I;for(;n._index<o.length;){const k=o[n._index];if(typeof k=="string")for(I=n._index,n._bufferIndex<0&&(n._bufferIndex=0);n._index===I&&n._bufferIndex<k.length;)v(k.charCodeAt(n._bufferIndex));else v(k)}}function v(I){c=c(I)}function w(I){pe(I)?(n.line++,n.column=1,n.offset+=I===-3?2:1,L()):I!==-1&&(n.column++,n.offset++),n._bufferIndex<0?n._index++:(n._bufferIndex++,n._bufferIndex===o[n._index].length&&(n._bufferIndex=-1,n._index++)),l.previous=I}function x(I,k){const M=k||{};return M.type=I,M.start=p(),l.events.push(["enter",M,l]),s.push(M),M}function N(I){const k=s.pop();return k.end=p(),l.events.push(["exit",k,l]),k}function O(I,k){H(I,k.from)}function A(I,k){k.restore()}function D(I,k){return M;function M(F,C,U){let $,V,se,_;return Array.isArray(F)?ne(F):"tokenize"in F?ne([F]):oe(F);function oe(le){return we;function we(Oe){const qe=Oe!==null&&le[Oe],ve=Oe!==null&&le.null,ct=[...Array.isArray(qe)?qe:qe?[qe]:[],...Array.isArray(ve)?ve:ve?[ve]:[]];return ne(ct)(Oe)}}function ne(le){return $=le,V=0,le.length===0?U:T(le[V])}function T(le){return we;function we(Oe){return _=z(),se=le,le.partial||(l.currentConstruct=le),le.name&&l.parser.constructs.disable.null.includes(le.name)?ee():le.tokenize.call(k?Object.assign(Object.create(l),k):l,u,G,ee)(Oe)}}function G(le){return I(se,_),C}function ee(le){return _.restore(),++V<$.length?T($[V]):U}}}function H(I,k){I.resolveAll&&!a.includes(I)&&a.push(I),I.resolve&&nr(l.events,k,l.events.length-k,I.resolve(l.events.slice(k),l)),I.resolveTo&&(l.events=I.resolveTo(l.events,l))}function z(){const I=p(),k=l.previous,M=l.currentConstruct,F=l.events.length,C=Array.from(s);return{restore:U,from:F};function U(){n=I,l.previous=k,l.currentConstruct=M,l.events.length=F,s=C,L()}}function L(){n.line in i&&n.column<2&&(n.column=i[n.line],n.offset+=i[n.line]-1)}}function W8(e,t){const r=t.start._index,n=t.start._bufferIndex,i=t.end._index,a=t.end._bufferIndex;let o;if(r===i)o=[e[r].slice(n,a)];else{if(o=e.slice(r,i),n>-1){const s=o[0];typeof s=="string"?o[0]=s.slice(n):o.shift()}a>0&&o.push(e[i].slice(0,a))}return o}function K8(e,t){let r=-1;const n=[];let i;for(;++r<e.length;){const a=e[r];let o;if(typeof a=="string")o=a;else switch(a){case-5:{o="\r";break}case-4:{o=`
`;break}case-3:{o=`\r
`;break}case-2:{o=t?" ":"	";break}case-1:{if(!t&&i)continue;o=" ";break}default:o=String.fromCharCode(a)}i=a===-2,n.push(o)}return n.join("")}const X8={42:Ut,43:Ut,45:Ut,48:Ut,49:Ut,50:Ut,51:Ut,52:Ut,53:Ut,54:Ut,55:Ut,56:Ut,57:Ut,62:bg},Y8={91:Z5},Z8={[-2]:fl,[-1]:fl,32:fl},Q8={35:n8,42:ns,45:[yh,ns],60:s8,61:yh,95:ns,96:bh,126:bh},J8={38:yg,92:vg},e7={[-5]:dl,[-4]:dl,[-3]:dl,33:A8,38:yg,42:S0,60:[N5,p8],91:O8,92:[t8,vg],93:of,95:S0,96:U5},t7={null:[S0,H8]},r7={null:[42,95]},n7={null:[]},i7=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:r7,contentInitial:Y8,disable:n7,document:X8,flow:Q8,flowInitial:Z8,insideSpan:t7,string:J8,text:e7},Symbol.toStringTag,{value:"Module"}));function a7(e){const r=gg([i7,...(e||{}).extensions||[]]),n={defined:[],lazy:{},constructs:r,content:i(x5),document:i(S5),flow:i($8),string:i(q8),text:i(j8)};return n;function i(a){return o;function o(s){return G8(n,a,s)}}}const wh=/[\0\t\n\r]/g;function o7(){let e=1,t="",r=!0,n;return i;function i(a,o,s){const u=[];let l,c,f,d,h;for(a=t+a.toString(o),f=0,t="",r&&(a.charCodeAt(0)===65279&&f++,r=void 0);f<a.length;){if(wh.lastIndex=f,l=wh.exec(a),d=l&&l.index!==void 0?l.index:a.length,h=a.charCodeAt(d),!l){t=a.slice(f);break}if(h===10&&f===d&&n)u.push(-3),n=void 0;else switch(n&&(u.push(-5),n=void 0),f<d&&(u.push(a.slice(f,d)),e+=d-f),h){case 0:{u.push(65533),e++;break}case 9:{for(c=Math.ceil(e/4)*4,u.push(-2);e++<c;)u.push(-1);break}case 10:{u.push(-4),e=1;break}default:n=!0,e=1}f=d+1}return s&&(n&&u.push(-5),t&&u.push(t),u.push(null)),u}}function s7(e){for(;!wg(e););return e}function kg(e,t){const r=Number.parseInt(e,t);return r<9||r===11||r>13&&r<32||r>126&&r<160||r>55295&&r<57344||r>64975&&r<65008||(r&65535)===65535||(r&65535)===65534||r>1114111?"�":String.fromCharCode(r)}const u7=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function Og(e){return e.replace(u7,l7)}function l7(e,t,r){if(t)return t;if(r.charCodeAt(0)===35){const i=r.charCodeAt(1),a=i===120||i===88;return kg(r.slice(a?2:1),a?16:10)}return af(r)||e}const Ng={}.hasOwnProperty,c7=function(e,t,r){return typeof t!="string"&&(r=t,t=void 0),f7(r)(s7(a7(r).document().write(o7()(e,t,!0))))};function f7(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:s(jn),autolinkProtocol:I,autolinkEmail:I,atxHeading:s(Tr),blockQuote:s(ct),characterEscape:I,characterReference:I,codeFenced:s(ft),codeFencedFenceInfo:u,codeFencedFenceMeta:u,codeIndented:s(ft,u),codeText:s(_r,u),codeTextData:I,data:I,codeFlowValue:I,definition:s(Xt),definitionDestinationString:u,definitionLabelString:u,definitionTitleString:u,emphasis:s(yn),hardBreakEscape:s(At),hardBreakTrailing:s(At),htmlFlow:s($t,u),htmlFlowData:I,htmlText:s($t,u),htmlTextData:I,image:s(Rt),label:u,link:s(jn),listItem:s(ye),listItemValue:p,listOrdered:s(Zr,h),listUnordered:s(Zr),paragraph:s(Ar),reference:ee,referenceString:u,resourceDestinationString:u,resourceTitleString:u,setextHeading:s(Tr),strong:s(ut),thematicBreak:s(Pe)},exit:{atxHeading:c(),atxHeadingSequence:D,autolink:c(),autolinkEmail:ve,autolinkProtocol:qe,blockQuote:c(),characterEscapeValue:k,characterReferenceMarkerHexadecimal:we,characterReferenceMarkerNumeric:we,characterReferenceValue:Oe,codeFenced:c(w),codeFencedFence:v,codeFencedFenceInfo:m,codeFencedFenceMeta:g,codeFlowValue:k,codeIndented:c(x),codeText:c($),codeTextData:k,data:k,definition:c(),definitionDestinationString:A,definitionLabelString:N,definitionTitleString:O,emphasis:c(),hardBreakEscape:c(F),hardBreakTrailing:c(F),htmlFlow:c(C),htmlFlowData:k,htmlText:c(U),htmlTextData:k,image:c(se),label:oe,labelText:_,lineEnding:M,link:c(V),listItem:c(),listOrdered:c(),listUnordered:c(),paragraph:c(),referenceString:le,resourceDestinationString:ne,resourceTitleString:T,resource:G,setextHeading:c(L),setextHeadingLineSequence:z,setextHeadingText:H,strong:c(),thematicBreak:c()}};_g(t,(e||{}).mdastExtensions||[]);const r={};return n;function n(q){let K={type:"root",children:[]};const de={stack:[K],tokenStack:[],config:t,enter:l,exit:f,buffer:u,resume:d,setData:a,getData:o},Z=[];let X=-1;for(;++X<q.length;)if(q[X][1].type==="listOrdered"||q[X][1].type==="listUnordered")if(q[X][0]==="enter")Z.push(X);else{const J=Z.pop();X=i(q,J,X)}for(X=-1;++X<q.length;){const J=t[q[X][0]];Ng.call(J,q[X][1].type)&&J[q[X][1].type].call(Object.assign({sliceSerialize:q[X][2].sliceSerialize},de),q[X][1])}if(de.tokenStack.length>0){const J=de.tokenStack[de.tokenStack.length-1];(J[1]||xh).call(de,void 0,J[0])}for(K.position={start:wn(q.length>0?q[0][1].start:{line:1,column:1,offset:0}),end:wn(q.length>0?q[q.length-2][1].end:{line:1,column:1,offset:0})},X=-1;++X<t.transforms.length;)K=t.transforms[X](K)||K;return K}function i(q,K,de){let Z=K-1,X=-1,J=!1,Ee,Ke,Yt,Vn;for(;++Z<=de;){const dt=q[Z];if(dt[1].type==="listUnordered"||dt[1].type==="listOrdered"||dt[1].type==="blockQuote"?(dt[0]==="enter"?X++:X--,Vn=void 0):dt[1].type==="lineEndingBlank"?dt[0]==="enter"&&(Ee&&!Vn&&!X&&!Yt&&(Yt=Z),Vn=void 0):dt[1].type==="linePrefix"||dt[1].type==="listItemValue"||dt[1].type==="listItemMarker"||dt[1].type==="listItemPrefix"||dt[1].type==="listItemPrefixWhitespace"||(Vn=void 0),!X&&dt[0]==="enter"&&dt[1].type==="listItemPrefix"||X===-1&&dt[0]==="exit"&&(dt[1].type==="listUnordered"||dt[1].type==="listOrdered")){if(Ee){let il=Z;for(Ke=void 0;il--;){const Qr=q[il];if(Qr[1].type==="lineEnding"||Qr[1].type==="lineEndingBlank"){if(Qr[0]==="exit")continue;Ke&&(q[Ke][1].type="lineEndingBlank",J=!0),Qr[1].type="lineEnding",Ke=il}else if(!(Qr[1].type==="linePrefix"||Qr[1].type==="blockQuotePrefix"||Qr[1].type==="blockQuotePrefixWhitespace"||Qr[1].type==="blockQuoteMarker"||Qr[1].type==="listItemIndent"))break}Yt&&(!Ke||Yt<Ke)&&(Ee._spread=!0),Ee.end=Object.assign({},Ke?q[Ke][1].start:dt[1].end),q.splice(Ke||Z,0,["exit",Ee,dt[2]]),Z++,de++}dt[1].type==="listItemPrefix"&&(Ee={type:"listItem",_spread:!1,start:Object.assign({},dt[1].start),end:void 0},q.splice(Z,0,["enter",Ee,dt[2]]),Z++,de++,Yt=void 0,Vn=!0)}}return q[K][1]._spread=J,de}function a(q,K){r[q]=K}function o(q){return r[q]}function s(q,K){return de;function de(Z){l.call(this,q(Z),Z),K&&K.call(this,Z)}}function u(){this.stack.push({type:"fragment",children:[]})}function l(q,K,de){return this.stack[this.stack.length-1].children.push(q),this.stack.push(q),this.tokenStack.push([K,de]),q.position={start:wn(K.start)},q}function c(q){return K;function K(de){q&&q.call(this,de),f.call(this,de)}}function f(q,K){const de=this.stack.pop(),Z=this.tokenStack.pop();if(Z)Z[0].type!==q.type&&(K?K.call(this,q,Z[0]):(Z[1]||xh).call(this,q,Z[0]));else throw new Error("Cannot close `"+q.type+"` ("+pa({start:q.start,end:q.end})+"): it’s not open");return de.position.end=wn(q.end),de}function d(){return h5(this.stack.pop())}function h(){a("expectingFirstListItemValue",!0)}function p(q){if(o("expectingFirstListItemValue")){const K=this.stack[this.stack.length-2];K.start=Number.parseInt(this.sliceSerialize(q),10),a("expectingFirstListItemValue")}}function m(){const q=this.resume(),K=this.stack[this.stack.length-1];K.lang=q}function g(){const q=this.resume(),K=this.stack[this.stack.length-1];K.meta=q}function v(){o("flowCodeInside")||(this.buffer(),a("flowCodeInside",!0))}function w(){const q=this.resume(),K=this.stack[this.stack.length-1];K.value=q.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),a("flowCodeInside")}function x(){const q=this.resume(),K=this.stack[this.stack.length-1];K.value=q.replace(/(\r?\n|\r)$/g,"")}function N(q){const K=this.resume(),de=this.stack[this.stack.length-1];de.label=K,de.identifier=Or(this.sliceSerialize(q)).toLowerCase()}function O(){const q=this.resume(),K=this.stack[this.stack.length-1];K.title=q}function A(){const q=this.resume(),K=this.stack[this.stack.length-1];K.url=q}function D(q){const K=this.stack[this.stack.length-1];if(!K.depth){const de=this.sliceSerialize(q).length;K.depth=de}}function H(){a("setextHeadingSlurpLineEnding",!0)}function z(q){const K=this.stack[this.stack.length-1];K.depth=this.sliceSerialize(q).charCodeAt(0)===61?1:2}function L(){a("setextHeadingSlurpLineEnding")}function I(q){const K=this.stack[this.stack.length-1];let de=K.children[K.children.length-1];(!de||de.type!=="text")&&(de=me(),de.position={start:wn(q.start)},K.children.push(de)),this.stack.push(de)}function k(q){const K=this.stack.pop();K.value+=this.sliceSerialize(q),K.position.end=wn(q.end)}function M(q){const K=this.stack[this.stack.length-1];if(o("atHardBreak")){const de=K.children[K.children.length-1];de.position.end=wn(q.end),a("atHardBreak");return}!o("setextHeadingSlurpLineEnding")&&t.canContainEols.includes(K.type)&&(I.call(this,q),k.call(this,q))}function F(){a("atHardBreak",!0)}function C(){const q=this.resume(),K=this.stack[this.stack.length-1];K.value=q}function U(){const q=this.resume(),K=this.stack[this.stack.length-1];K.value=q}function $(){const q=this.resume(),K=this.stack[this.stack.length-1];K.value=q}function V(){const q=this.stack[this.stack.length-1];if(o("inReference")){const K=o("referenceType")||"shortcut";q.type+="Reference",q.referenceType=K,delete q.url,delete q.title}else delete q.identifier,delete q.label;a("referenceType")}function se(){const q=this.stack[this.stack.length-1];if(o("inReference")){const K=o("referenceType")||"shortcut";q.type+="Reference",q.referenceType=K,delete q.url,delete q.title}else delete q.identifier,delete q.label;a("referenceType")}function _(q){const K=this.sliceSerialize(q),de=this.stack[this.stack.length-2];de.label=Og(K),de.identifier=Or(K).toLowerCase()}function oe(){const q=this.stack[this.stack.length-1],K=this.resume(),de=this.stack[this.stack.length-1];if(a("inReference",!0),de.type==="link"){const Z=q.children;de.children=Z}else de.alt=K}function ne(){const q=this.resume(),K=this.stack[this.stack.length-1];K.url=q}function T(){const q=this.resume(),K=this.stack[this.stack.length-1];K.title=q}function G(){a("inReference")}function ee(){a("referenceType","collapsed")}function le(q){const K=this.resume(),de=this.stack[this.stack.length-1];de.label=K,de.identifier=Or(this.sliceSerialize(q)).toLowerCase(),a("referenceType","full")}function we(q){a("characterReferenceType",q.type)}function Oe(q){const K=this.sliceSerialize(q),de=o("characterReferenceType");let Z;de?(Z=kg(K,de==="characterReferenceMarkerNumeric"?10:16),a("characterReferenceType")):Z=af(K);const X=this.stack.pop();X.value+=Z,X.position.end=wn(q.end)}function qe(q){k.call(this,q);const K=this.stack[this.stack.length-1];K.url=this.sliceSerialize(q)}function ve(q){k.call(this,q);const K=this.stack[this.stack.length-1];K.url="mailto:"+this.sliceSerialize(q)}function ct(){return{type:"blockquote",children:[]}}function ft(){return{type:"code",lang:null,meta:null,value:""}}function _r(){return{type:"inlineCode",value:""}}function Xt(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function yn(){return{type:"emphasis",children:[]}}function Tr(){return{type:"heading",depth:void 0,children:[]}}function At(){return{type:"break"}}function $t(){return{type:"html",value:""}}function Rt(){return{type:"image",title:null,url:"",alt:null}}function jn(){return{type:"link",title:null,url:"",children:[]}}function Zr(q){return{type:"list",ordered:q.type==="listOrdered",start:null,spread:q._spread,children:[]}}function ye(q){return{type:"listItem",spread:q._spread,checked:null,children:[]}}function Ar(){return{type:"paragraph",children:[]}}function ut(){return{type:"strong",children:[]}}function me(){return{type:"text",value:""}}function Pe(){return{type:"thematicBreak"}}}function wn(e){return{line:e.line,column:e.column,offset:e.offset}}function _g(e,t){let r=-1;for(;++r<t.length;){const n=t[r];Array.isArray(n)?_g(e,n):d7(e,n)}}function d7(e,t){let r;for(r in t)if(Ng.call(t,r)){if(r==="canContainEols"){const n=t[r];n&&e[r].push(...n)}else if(r==="transforms"){const n=t[r];n&&e[r].push(...n)}else if(r==="enter"||r==="exit"){const n=t[r];n&&Object.assign(e[r],n)}}}function xh(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+pa({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+pa({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+pa({start:t.start,end:t.end})+") is still open")}function h7(e){Object.assign(this,{Parser:r=>{const n=this.data("settings");return c7(r,Object.assign({},n,e,{extensions:this.data("micromarkExtensions")||[],mdastExtensions:this.data("fromMarkdownExtensions")||[]}))}})}function p7(e,t){const r={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,r),e.applyData(t,r)}function m7(e,t){const r={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,r),[e.applyData(t,r),{type:"text",value:`
`}]}function g7(e,t){const r=t.value?t.value+`
`:"",n=t.lang?t.lang.match(/^[^ \t]+(?=[ \t]|$)/):null,i={};n&&(i.className=["language-"+n]);let a={type:"element",tagName:"code",properties:i,children:[{type:"text",value:r}]};return t.meta&&(a.data={meta:t.meta}),e.patch(t,a),a=e.applyData(t,a),a={type:"element",tagName:"pre",properties:{},children:[a]},e.patch(t,a),a}function b7(e,t){const r={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function v7(e,t){const r={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function Zi(e){const t=[];let r=-1,n=0,i=0;for(;++r<e.length;){const a=e.charCodeAt(r);let o="";if(a===37&&Nt(e.charCodeAt(r+1))&&Nt(e.charCodeAt(r+2)))i=2;else if(a<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(a))||(o=String.fromCharCode(a));else if(a>55295&&a<57344){const s=e.charCodeAt(r+1);a<56320&&s>56319&&s<57344?(o=String.fromCharCode(a,s),i=1):o="�"}else o=String.fromCharCode(a);o&&(t.push(e.slice(n,r),encodeURIComponent(o)),n=r+i+1,o=""),i&&(r+=i,i=0)}return t.join("")+e.slice(n)}function Cg(e,t){const r=String(t.identifier).toUpperCase(),n=Zi(r.toLowerCase()),i=e.footnoteOrder.indexOf(r);let a;i===-1?(e.footnoteOrder.push(r),e.footnoteCounts[r]=1,a=e.footnoteOrder.length):(e.footnoteCounts[r]++,a=i+1);const o=e.footnoteCounts[r],s={type:"element",tagName:"a",properties:{href:"#"+e.clobberPrefix+"fn-"+n,id:e.clobberPrefix+"fnref-"+n+(o>1?"-"+o:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(a)}]};e.patch(t,s);const u={type:"element",tagName:"sup",properties:{},children:[s]};return e.patch(t,u),e.applyData(t,u)}function y7(e,t){const r=e.footnoteById;let n=1;for(;n in r;)n++;const i=String(n);return r[i]={type:"footnoteDefinition",identifier:i,children:[{type:"paragraph",children:t.children}],position:t.position},Cg(e,{type:"footnoteReference",identifier:i,position:t.position})}function w7(e,t){const r={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function x7(e,t){if(e.dangerous){const r={type:"raw",value:t.value};return e.patch(t,r),e.applyData(t,r)}return null}function Mg(e,t){const r=t.referenceType;let n="]";if(r==="collapsed"?n+="[]":r==="full"&&(n+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return{type:"text",value:"!["+t.alt+n};const i=e.all(t),a=i[0];a&&a.type==="text"?a.value="["+a.value:i.unshift({type:"text",value:"["});const o=i[i.length-1];return o&&o.type==="text"?o.value+=n:i.push({type:"text",value:n}),i}function E7(e,t){const r=e.definition(t.identifier);if(!r)return Mg(e,t);const n={src:Zi(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(n.title=r.title);const i={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,i),e.applyData(t,i)}function S7(e,t){const r={src:Zi(t.url)};t.alt!==null&&t.alt!==void 0&&(r.alt=t.alt),t.title!==null&&t.title!==void 0&&(r.title=t.title);const n={type:"element",tagName:"img",properties:r,children:[]};return e.patch(t,n),e.applyData(t,n)}function T7(e,t){const r={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,r);const n={type:"element",tagName:"code",properties:{},children:[r]};return e.patch(t,n),e.applyData(t,n)}function A7(e,t){const r=e.definition(t.identifier);if(!r)return Mg(e,t);const n={href:Zi(r.url||"")};r.title!==null&&r.title!==void 0&&(n.title=r.title);const i={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,i),e.applyData(t,i)}function k7(e,t){const r={href:Zi(t.url)};t.title!==null&&t.title!==void 0&&(r.title=t.title);const n={type:"element",tagName:"a",properties:r,children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function O7(e,t,r){const n=e.all(t),i=r?N7(r):Rg(t),a={},o=[];if(typeof t.checked=="boolean"){const c=n[0];let f;c&&c.type==="element"&&c.tagName==="p"?f=c:(f={type:"element",tagName:"p",properties:{},children:[]},n.unshift(f)),f.children.length>0&&f.children.unshift({type:"text",value:" "}),f.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),a.className=["task-list-item"]}let s=-1;for(;++s<n.length;){const c=n[s];(i||s!==0||c.type!=="element"||c.tagName!=="p")&&o.push({type:"text",value:`
`}),c.type==="element"&&c.tagName==="p"&&!i?o.push(...c.children):o.push(c)}const u=n[n.length-1];u&&(i||u.type!=="element"||u.tagName!=="p")&&o.push({type:"text",value:`
`});const l={type:"element",tagName:"li",properties:a,children:o};return e.patch(t,l),e.applyData(t,l)}function N7(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const r=e.children;let n=-1;for(;!t&&++n<r.length;)t=Rg(r[n])}return t}function Rg(e){const t=e.spread;return t??e.children.length>1}function _7(e,t){const r={},n=e.all(t);let i=-1;for(typeof t.start=="number"&&t.start!==1&&(r.start=t.start);++i<n.length;){const o=n[i];if(o.type==="element"&&o.tagName==="li"&&o.properties&&Array.isArray(o.properties.className)&&o.properties.className.includes("task-list-item")){r.className=["contains-task-list"];break}}const a={type:"element",tagName:t.ordered?"ol":"ul",properties:r,children:e.wrap(n,!0)};return e.patch(t,a),e.applyData(t,a)}function C7(e,t){const r={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function M7(e,t){const r={type:"root",children:e.wrap(e.all(t))};return e.patch(t,r),e.applyData(t,r)}function R7(e,t){const r={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}const sf=Ig("start"),uf=Ig("end");function I7(e){return{start:sf(e),end:uf(e)}}function Ig(e){return t;function t(r){const n=r&&r.position&&r.position[e]||{};return{line:n.line||null,column:n.column||null,offset:n.offset>-1?n.offset:null}}}function P7(e,t){const r=e.all(t),n=r.shift(),i=[];if(n){const o={type:"element",tagName:"thead",properties:{},children:e.wrap([n],!0)};e.patch(t.children[0],o),i.push(o)}if(r.length>0){const o={type:"element",tagName:"tbody",properties:{},children:e.wrap(r,!0)},s=sf(t.children[1]),u=uf(t.children[t.children.length-1]);s.line&&u.line&&(o.position={start:s,end:u}),i.push(o)}const a={type:"element",tagName:"table",properties:{},children:e.wrap(i,!0)};return e.patch(t,a),e.applyData(t,a)}function D7(e,t,r){const n=r?r.children:void 0,a=(n?n.indexOf(t):1)===0?"th":"td",o=r&&r.type==="table"?r.align:void 0,s=o?o.length:t.children.length;let u=-1;const l=[];for(;++u<s;){const f=t.children[u],d={},h=o?o[u]:void 0;h&&(d.align=h);let p={type:"element",tagName:a,properties:d,children:[]};f&&(p.children=e.all(f),e.patch(f,p),p=e.applyData(t,p)),l.push(p)}const c={type:"element",tagName:"tr",properties:{},children:e.wrap(l,!0)};return e.patch(t,c),e.applyData(t,c)}function L7(e,t){const r={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}const Eh=9,Sh=32;function F7(e){const t=String(e),r=/\r?\n|\r/g;let n=r.exec(t),i=0;const a=[];for(;n;)a.push(Th(t.slice(i,n.index),i>0,!0),n[0]),i=n.index+n[0].length,n=r.exec(t);return a.push(Th(t.slice(i),i>0,!1)),a.join("")}function Th(e,t,r){let n=0,i=e.length;if(t){let a=e.codePointAt(n);for(;a===Eh||a===Sh;)n++,a=e.codePointAt(n)}if(r){let a=e.codePointAt(i-1);for(;a===Eh||a===Sh;)i--,a=e.codePointAt(i-1)}return i>n?e.slice(n,i):""}function B7(e,t){const r={type:"text",value:F7(String(t.value))};return e.patch(t,r),e.applyData(t,r)}function z7(e,t){const r={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,r),e.applyData(t,r)}const $7={blockquote:p7,break:m7,code:g7,delete:b7,emphasis:v7,footnoteReference:Cg,footnote:y7,heading:w7,html:x7,imageReference:E7,image:S7,inlineCode:T7,linkReference:A7,link:k7,listItem:O7,list:_7,paragraph:C7,root:M7,strong:R7,table:P7,tableCell:L7,tableRow:D7,text:B7,thematicBreak:z7,toml:mo,yaml:mo,definition:mo,footnoteDefinition:mo};function mo(){return null}const ou=function(e){if(e==null)return j7;if(typeof e=="string")return q7(e);if(typeof e=="object")return Array.isArray(e)?U7(e):H7(e);if(typeof e=="function")return su(e);throw new Error("Expected function, string, or object as test")};function U7(e){const t=[];let r=-1;for(;++r<e.length;)t[r]=ou(e[r]);return su(n);function n(...i){let a=-1;for(;++a<t.length;)if(t[a].call(this,...i))return!0;return!1}}function H7(e){return su(t);function t(r){let n;for(n in e)if(r[n]!==e[n])return!1;return!0}}function q7(e){return su(t);function t(r){return r&&r.type===e}}function su(e){return t;function t(r,...n){return!!(r&&typeof r=="object"&&"type"in r&&e.call(this,r,...n))}}function j7(){return!0}const V7=!0,Ah=!1,G7="skip",Pg=function(e,t,r,n){typeof t=="function"&&typeof r!="function"&&(n=r,r=t,t=null);const i=ou(t),a=n?-1:1;o(e,void 0,[])();function o(s,u,l){const c=s&&typeof s=="object"?s:{};if(typeof c.type=="string"){const d=typeof c.tagName=="string"?c.tagName:typeof c.name=="string"?c.name:void 0;Object.defineProperty(f,"name",{value:"node ("+(s.type+(d?"<"+d+">":""))+")"})}return f;function f(){let d=[],h,p,m;if((!t||i(s,u,l[l.length-1]||null))&&(d=W7(r(s,l)),d[0]===Ah))return d;if(s.children&&d[0]!==G7)for(p=(n?s.children.length:-1)+a,m=l.concat(s);p>-1&&p<s.children.length;){if(h=o(s.children[p],p,m)(),h[0]===Ah)return h;p=typeof h[1]=="number"?h[1]:p+a}return d}}};function W7(e){return Array.isArray(e)?e:typeof e=="number"?[V7,e]:[e]}const uu=function(e,t,r,n){typeof t=="function"&&typeof r!="function"&&(n=r,r=t,t=null),Pg(e,t,i,n);function i(a,o){const s=o[o.length-1];return r(a,s?s.children.indexOf(a):null,s)}};function K7(e){return!e||!e.position||!e.position.start||!e.position.start.line||!e.position.start.column||!e.position.end||!e.position.end.line||!e.position.end.column}const kh={}.hasOwnProperty;function X7(e){const t=Object.create(null);if(!e||!e.type)throw new Error("mdast-util-definitions expected node");return uu(e,"definition",n=>{const i=Oh(n.identifier);i&&!kh.call(t,i)&&(t[i]=n)}),r;function r(n){const i=Oh(n);return i&&kh.call(t,i)?t[i]:null}}function Oh(e){return String(e||"").toUpperCase()}const ks={}.hasOwnProperty;function Y7(e,t){const r=t||{},n=r.allowDangerousHtml||!1,i={};return o.dangerous=n,o.clobberPrefix=r.clobberPrefix===void 0||r.clobberPrefix===null?"user-content-":r.clobberPrefix,o.footnoteLabel=r.footnoteLabel||"Footnotes",o.footnoteLabelTagName=r.footnoteLabelTagName||"h2",o.footnoteLabelProperties=r.footnoteLabelProperties||{className:["sr-only"]},o.footnoteBackLabel=r.footnoteBackLabel||"Back to content",o.unknownHandler=r.unknownHandler,o.passThrough=r.passThrough,o.handlers={...$7,...r.handlers},o.definition=X7(e),o.footnoteById=i,o.footnoteOrder=[],o.footnoteCounts={},o.patch=Z7,o.applyData=Q7,o.one=s,o.all=u,o.wrap=ew,o.augment=a,uu(e,"footnoteDefinition",l=>{const c=String(l.identifier).toUpperCase();ks.call(i,c)||(i[c]=l)}),o;function a(l,c){if(l&&"data"in l&&l.data){const f=l.data;f.hName&&(c.type!=="element"&&(c={type:"element",tagName:"",properties:{},children:[]}),c.tagName=f.hName),c.type==="element"&&f.hProperties&&(c.properties={...c.properties,...f.hProperties}),"children"in c&&c.children&&f.hChildren&&(c.children=f.hChildren)}if(l){const f="type"in l?l:{position:l};K7(f)||(c.position={start:sf(f),end:uf(f)})}return c}function o(l,c,f,d){return Array.isArray(f)&&(d=f,f={}),a(l,{type:"element",tagName:c,properties:f||{},children:d||[]})}function s(l,c){return Dg(o,l,c)}function u(l){return lf(o,l)}}function Z7(e,t){e.position&&(t.position=I7(e))}function Q7(e,t){let r=t;if(e&&e.data){const n=e.data.hName,i=e.data.hChildren,a=e.data.hProperties;typeof n=="string"&&(r.type==="element"?r.tagName=n:r={type:"element",tagName:n,properties:{},children:[]}),r.type==="element"&&a&&(r.properties={...r.properties,...a}),"children"in r&&r.children&&i!==null&&i!==void 0&&(r.children=i)}return r}function Dg(e,t,r){const n=t&&t.type;if(!n)throw new Error("Expected node, got `"+t+"`");return ks.call(e.handlers,n)?e.handlers[n](e,t,r):e.passThrough&&e.passThrough.includes(n)?"children"in t?{...t,children:lf(e,t)}:t:e.unknownHandler?e.unknownHandler(e,t,r):J7(e,t)}function lf(e,t){const r=[];if("children"in t){const n=t.children;let i=-1;for(;++i<n.length;){const a=Dg(e,n[i],t);if(a){if(i&&n[i-1].type==="break"&&(!Array.isArray(a)&&a.type==="text"&&(a.value=a.value.replace(/^\s+/,"")),!Array.isArray(a)&&a.type==="element")){const o=a.children[0];o&&o.type==="text"&&(o.value=o.value.replace(/^\s+/,""))}Array.isArray(a)?r.push(...a):r.push(a)}}}return r}function J7(e,t){const r=t.data||{},n="value"in t&&!(ks.call(r,"hProperties")||ks.call(r,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:lf(e,t)};return e.patch(t,n),e.applyData(t,n)}function ew(e,t){const r=[];let n=-1;for(t&&r.push({type:"text",value:`
`});++n<e.length;)n&&r.push({type:"text",value:`
`}),r.push(e[n]);return t&&e.length>0&&r.push({type:"text",value:`
`}),r}function tw(e){const t=[];let r=-1;for(;++r<e.footnoteOrder.length;){const n=e.footnoteById[e.footnoteOrder[r]];if(!n)continue;const i=e.all(n),a=String(n.identifier).toUpperCase(),o=Zi(a.toLowerCase());let s=0;const u=[];for(;++s<=e.footnoteCounts[a];){const f={type:"element",tagName:"a",properties:{href:"#"+e.clobberPrefix+"fnref-"+o+(s>1?"-"+s:""),dataFootnoteBackref:!0,className:["data-footnote-backref"],ariaLabel:e.footnoteBackLabel},children:[{type:"text",value:"↩"}]};s>1&&f.children.push({type:"element",tagName:"sup",children:[{type:"text",value:String(s)}]}),u.length>0&&u.push({type:"text",value:" "}),u.push(f)}const l=i[i.length-1];if(l&&l.type==="element"&&l.tagName==="p"){const f=l.children[l.children.length-1];f&&f.type==="text"?f.value+=" ":l.children.push({type:"text",value:" "}),l.children.push(...u)}else i.push(...u);const c={type:"element",tagName:"li",properties:{id:e.clobberPrefix+"fn-"+o},children:e.wrap(i,!0)};e.patch(n,c),t.push(c)}if(t.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:e.footnoteLabelTagName,properties:{...JSON.parse(JSON.stringify(e.footnoteLabelProperties)),id:"footnote-label"},children:[{type:"text",value:e.footnoteLabel}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(t,!0)},{type:"text",value:`
`}]}}function Lg(e,t){const r=Y7(e,t),n=r.one(e,null),i=tw(r);return i&&n.children.push({type:"text",value:`
`},i),Array.isArray(n)?{type:"root",children:n}:n}const rw=function(e,t){return e&&"run"in e?iw(e,t):aw(e||t)},nw=rw;function iw(e,t){return(r,n,i)=>{e.run(Lg(r,t),n,a=>{i(a)})}}function aw(e){return t=>Lg(t,e)}var Fg={exports:{}},ow="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED",sw=ow,uw=sw;function Bg(){}function zg(){}zg.resetWarningCache=Bg;var lw=function(){function e(n,i,a,o,s,u){if(u!==uw){var l=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw l.name="Invariant Violation",l}}e.isRequired=e;function t(){return e}var r={array:e,bigint:e,bool:e,func:e,number:e,object:e,string:e,symbol:e,any:e,arrayOf:t,element:e,elementType:e,instanceOf:t,node:e,objectOf:t,oneOf:t,oneOfType:t,shape:t,exact:t,checkPropTypes:zg,resetWarningCache:Bg};return r.PropTypes=r,r};Fg.exports=lw();var cw=Fg.exports;const ke=Ce(cw);let Ka=class{constructor(t,r,n){this.property=t,this.normal=r,n&&(this.space=n)}};Ka.prototype.property={};Ka.prototype.normal={};Ka.prototype.space=null;function $g(e,t){const r={},n={};let i=-1;for(;++i<e.length;)Object.assign(r,e[i].property),Object.assign(n,e[i].normal);return new Ka(r,n,t)}function ka(e){return e.toLowerCase()}class vr{constructor(t,r){this.property=t,this.attribute=r}}vr.prototype.space=null;vr.prototype.boolean=!1;vr.prototype.booleanish=!1;vr.prototype.overloadedBoolean=!1;vr.prototype.number=!1;vr.prototype.commaSeparated=!1;vr.prototype.spaceSeparated=!1;vr.prototype.commaOrSpaceSeparated=!1;vr.prototype.mustUseProperty=!1;vr.prototype.defined=!1;let fw=0;const Ne=li(),mt=li(),Ug=li(),re=li(),et=li(),Ri=li(),Qt=li();function li(){return 2**++fw}const T0=Object.freeze(Object.defineProperty({__proto__:null,boolean:Ne,booleanish:mt,commaOrSpaceSeparated:Qt,commaSeparated:Ri,number:re,overloadedBoolean:Ug,spaceSeparated:et},Symbol.toStringTag,{value:"Module"})),hl=Object.keys(T0);class cf extends vr{constructor(t,r,n,i){let a=-1;if(super(t,r),Nh(this,"space",i),typeof n=="number")for(;++a<hl.length;){const o=hl[a];Nh(this,hl[a],(n&T0[o])===T0[o])}}}cf.prototype.defined=!0;function Nh(e,t,r){r&&(e[t]=r)}const dw={}.hasOwnProperty;function Qi(e){const t={},r={};let n;for(n in e.properties)if(dw.call(e.properties,n)){const i=e.properties[n],a=new cf(n,e.transform(e.attributes||{},n),i,e.space);e.mustUseProperty&&e.mustUseProperty.includes(n)&&(a.mustUseProperty=!0),t[n]=a,r[ka(n)]=n,r[ka(a.attribute)]=n}return new Ka(t,r,e.space)}const Hg=Qi({space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()},properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null}}),qg=Qi({space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()},properties:{xmlLang:null,xmlBase:null,xmlSpace:null}});function jg(e,t){return t in e?e[t]:t}function Vg(e,t){return jg(e,t.toLowerCase())}const Gg=Qi({space:"xmlns",attributes:{xmlnsxlink:"xmlns:xlink"},transform:Vg,properties:{xmlns:null,xmlnsXLink:null}}),Wg=Qi({transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()},properties:{ariaActiveDescendant:null,ariaAtomic:mt,ariaAutoComplete:null,ariaBusy:mt,ariaChecked:mt,ariaColCount:re,ariaColIndex:re,ariaColSpan:re,ariaControls:et,ariaCurrent:null,ariaDescribedBy:et,ariaDetails:null,ariaDisabled:mt,ariaDropEffect:et,ariaErrorMessage:null,ariaExpanded:mt,ariaFlowTo:et,ariaGrabbed:mt,ariaHasPopup:null,ariaHidden:mt,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:et,ariaLevel:re,ariaLive:null,ariaModal:mt,ariaMultiLine:mt,ariaMultiSelectable:mt,ariaOrientation:null,ariaOwns:et,ariaPlaceholder:null,ariaPosInSet:re,ariaPressed:mt,ariaReadOnly:mt,ariaRelevant:null,ariaRequired:mt,ariaRoleDescription:et,ariaRowCount:re,ariaRowIndex:re,ariaRowSpan:re,ariaSelected:mt,ariaSetSize:re,ariaSort:null,ariaValueMax:re,ariaValueMin:re,ariaValueNow:re,ariaValueText:null,role:null}}),hw=Qi({space:"html",attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},transform:Vg,mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:Ri,acceptCharset:et,accessKey:et,action:null,allow:null,allowFullScreen:Ne,allowPaymentRequest:Ne,allowUserMedia:Ne,alt:null,as:null,async:Ne,autoCapitalize:null,autoComplete:et,autoFocus:Ne,autoPlay:Ne,blocking:et,capture:Ne,charSet:null,checked:Ne,cite:null,className:et,cols:re,colSpan:null,content:null,contentEditable:mt,controls:Ne,controlsList:et,coords:re|Ri,crossOrigin:null,data:null,dateTime:null,decoding:null,default:Ne,defer:Ne,dir:null,dirName:null,disabled:Ne,download:Ug,draggable:mt,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:Ne,formTarget:null,headers:et,height:re,hidden:Ne,high:re,href:null,hrefLang:null,htmlFor:et,httpEquiv:et,id:null,imageSizes:null,imageSrcSet:null,inert:Ne,inputMode:null,integrity:null,is:null,isMap:Ne,itemId:null,itemProp:et,itemRef:et,itemScope:Ne,itemType:et,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:Ne,low:re,manifest:null,max:null,maxLength:re,media:null,method:null,min:null,minLength:re,multiple:Ne,muted:Ne,name:null,nonce:null,noModule:Ne,noValidate:Ne,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:Ne,optimum:re,pattern:null,ping:et,placeholder:null,playsInline:Ne,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:Ne,referrerPolicy:null,rel:et,required:Ne,reversed:Ne,rows:re,rowSpan:re,sandbox:et,scope:null,scoped:Ne,seamless:Ne,selected:Ne,shadowRootDelegatesFocus:Ne,shadowRootMode:null,shape:null,size:re,sizes:null,slot:null,span:re,spellCheck:mt,src:null,srcDoc:null,srcLang:null,srcSet:null,start:re,step:null,style:null,tabIndex:re,target:null,title:null,translate:null,type:null,typeMustMatch:Ne,useMap:null,value:mt,width:re,wrap:null,align:null,aLink:null,archive:et,axis:null,background:null,bgColor:null,border:re,borderColor:null,bottomMargin:re,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:Ne,declare:Ne,event:null,face:null,frame:null,frameBorder:null,hSpace:re,leftMargin:re,link:null,longDesc:null,lowSrc:null,marginHeight:re,marginWidth:re,noResize:Ne,noHref:Ne,noShade:Ne,noWrap:Ne,object:null,profile:null,prompt:null,rev:null,rightMargin:re,rules:null,scheme:null,scrolling:mt,standby:null,summary:null,text:null,topMargin:re,valueType:null,version:null,vAlign:null,vLink:null,vSpace:re,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:Ne,disableRemotePlayback:Ne,prefix:null,property:null,results:re,security:null,unselectable:null}}),pw=Qi({space:"svg",attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},transform:jg,properties:{about:Qt,accentHeight:re,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:re,amplitude:re,arabicForm:null,ascent:re,attributeName:null,attributeType:null,azimuth:re,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:re,by:null,calcMode:null,capHeight:re,className:et,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:re,diffuseConstant:re,direction:null,display:null,dur:null,divisor:re,dominantBaseline:null,download:Ne,dx:null,dy:null,edgeMode:null,editable:null,elevation:re,enableBackground:null,end:null,event:null,exponent:re,externalResourcesRequired:null,fill:null,fillOpacity:re,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:Ri,g2:Ri,glyphName:Ri,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:re,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:re,horizOriginX:re,horizOriginY:re,id:null,ideographic:re,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:re,k:re,k1:re,k2:re,k3:re,k4:re,kernelMatrix:Qt,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:re,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:re,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:re,overlineThickness:re,paintOrder:null,panose1:null,path:null,pathLength:re,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:et,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:re,pointsAtY:re,pointsAtZ:re,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:Qt,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:Qt,rev:Qt,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:Qt,requiredFeatures:Qt,requiredFonts:Qt,requiredFormats:Qt,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:re,specularExponent:re,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:re,strikethroughThickness:re,string:null,stroke:null,strokeDashArray:Qt,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:re,strokeOpacity:re,strokeWidth:null,style:null,surfaceScale:re,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:Qt,tabIndex:re,tableValues:null,target:null,targetX:re,targetY:re,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:Qt,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:re,underlineThickness:re,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:re,values:null,vAlphabetic:re,vMathematical:re,vectorEffect:null,vHanging:re,vIdeographic:re,version:null,vertAdvY:re,vertOriginX:re,vertOriginY:re,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:re,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null}}),mw=/^data[-\w.:]+$/i,_h=/-[a-z]/g,gw=/[A-Z]/g;function Kg(e,t){const r=ka(t);let n=t,i=vr;if(r in e.normal)return e.property[e.normal[r]];if(r.length>4&&r.slice(0,4)==="data"&&mw.test(t)){if(t.charAt(4)==="-"){const a=t.slice(5).replace(_h,vw);n="data"+a.charAt(0).toUpperCase()+a.slice(1)}else{const a=t.slice(4);if(!_h.test(a)){let o=a.replace(gw,bw);o.charAt(0)!=="-"&&(o="-"+o),t="data"+o}}i=cf}return new i(n,t)}function bw(e){return"-"+e.toLowerCase()}function vw(e){return e.charAt(1).toUpperCase()}const Ch={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},Xg=$g([qg,Hg,Gg,Wg,hw],"html"),Yg=$g([qg,Hg,Gg,Wg,pw],"svg");function yw(e){if(e.allowedElements&&e.disallowedElements)throw new TypeError("Only one of `allowedElements` and `disallowedElements` should be defined");if(e.allowedElements||e.disallowedElements||e.allowElement)return t=>{uu(t,"element",(r,n,i)=>{const a=i;let o;if(e.allowedElements?o=!e.allowedElements.includes(r.tagName):e.disallowedElements&&(o=e.disallowedElements.includes(r.tagName)),!o&&e.allowElement&&typeof n=="number"&&(o=!e.allowElement(r,n,a)),o&&typeof n=="number")return e.unwrapDisallowed&&r.children?a.children.splice(n,1,...r.children):a.children.splice(n,1),n})}}var Zg={exports:{}},Ge={};/**
 * @license React
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ff=Symbol.for("react.element"),df=Symbol.for("react.portal"),lu=Symbol.for("react.fragment"),cu=Symbol.for("react.strict_mode"),fu=Symbol.for("react.profiler"),du=Symbol.for("react.provider"),hu=Symbol.for("react.context"),ww=Symbol.for("react.server_context"),pu=Symbol.for("react.forward_ref"),mu=Symbol.for("react.suspense"),gu=Symbol.for("react.suspense_list"),bu=Symbol.for("react.memo"),vu=Symbol.for("react.lazy"),xw=Symbol.for("react.offscreen"),Qg;Qg=Symbol.for("react.module.reference");function yr(e){if(typeof e=="object"&&e!==null){var t=e.$$typeof;switch(t){case ff:switch(e=e.type,e){case lu:case fu:case cu:case mu:case gu:return e;default:switch(e=e&&e.$$typeof,e){case ww:case hu:case pu:case vu:case bu:case du:return e;default:return t}}case df:return t}}}Ge.ContextConsumer=hu;Ge.ContextProvider=du;Ge.Element=ff;Ge.ForwardRef=pu;Ge.Fragment=lu;Ge.Lazy=vu;Ge.Memo=bu;Ge.Portal=df;Ge.Profiler=fu;Ge.StrictMode=cu;Ge.Suspense=mu;Ge.SuspenseList=gu;Ge.isAsyncMode=function(){return!1};Ge.isConcurrentMode=function(){return!1};Ge.isContextConsumer=function(e){return yr(e)===hu};Ge.isContextProvider=function(e){return yr(e)===du};Ge.isElement=function(e){return typeof e=="object"&&e!==null&&e.$$typeof===ff};Ge.isForwardRef=function(e){return yr(e)===pu};Ge.isFragment=function(e){return yr(e)===lu};Ge.isLazy=function(e){return yr(e)===vu};Ge.isMemo=function(e){return yr(e)===bu};Ge.isPortal=function(e){return yr(e)===df};Ge.isProfiler=function(e){return yr(e)===fu};Ge.isStrictMode=function(e){return yr(e)===cu};Ge.isSuspense=function(e){return yr(e)===mu};Ge.isSuspenseList=function(e){return yr(e)===gu};Ge.isValidElementType=function(e){return typeof e=="string"||typeof e=="function"||e===lu||e===fu||e===cu||e===mu||e===gu||e===xw||typeof e=="object"&&e!==null&&(e.$$typeof===vu||e.$$typeof===bu||e.$$typeof===du||e.$$typeof===hu||e.$$typeof===pu||e.$$typeof===Qg||e.getModuleId!==void 0)};Ge.typeOf=yr;Zg.exports=Ge;var Ew=Zg.exports;const Sw=Ce(Ew);function Tw(e){const t=e&&typeof e=="object"&&e.type==="text"?e.value||"":e;return typeof t=="string"&&t.replace(/[ \t\n\f\r]/g,"")===""}function Mh(e){const t=String(e||"").trim();return t?t.split(/[ \t\n\r\f]+/g):[]}function Aw(e){return e.join(" ").trim()}function Rh(e){const t=[],r=String(e||"");let n=r.indexOf(","),i=0,a=!1;for(;!a;){n===-1&&(n=r.length,a=!0);const o=r.slice(i,n).trim();(o||!a)&&t.push(o),i=n+1,n=r.indexOf(",",i)}return t}function kw(e,t){const r=t||{};return(e[e.length-1]===""?[...e,""]:e).join((r.padRight?" ":"")+","+(r.padLeft===!1?"":" ")).trim()}var hf={exports:{}},Ih=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,Ow=/\n/g,Nw=/^\s*/,_w=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,Cw=/^:\s*/,Mw=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,Rw=/^[;\s]*/,Iw=/^\s+|\s+$/g,Pw=`
`,Ph="/",Dh="*",Qn="",Dw="comment",Lw="declaration",Fw=function(e,t){if(typeof e!="string")throw new TypeError("First argument must be a string");if(!e)return[];t=t||{};var r=1,n=1;function i(p){var m=p.match(Ow);m&&(r+=m.length);var g=p.lastIndexOf(Pw);n=~g?p.length-g:n+p.length}function a(){var p={line:r,column:n};return function(m){return m.position=new o(p),l(),m}}function o(p){this.start=p,this.end={line:r,column:n},this.source=t.source}o.prototype.content=e;function s(p){var m=new Error(t.source+":"+r+":"+n+": "+p);if(m.reason=p,m.filename=t.source,m.line=r,m.column=n,m.source=e,!t.silent)throw m}function u(p){var m=p.exec(e);if(m){var g=m[0];return i(g),e=e.slice(g.length),m}}function l(){u(Nw)}function c(p){var m;for(p=p||[];m=f();)m!==!1&&p.push(m);return p}function f(){var p=a();if(!(Ph!=e.charAt(0)||Dh!=e.charAt(1))){for(var m=2;Qn!=e.charAt(m)&&(Dh!=e.charAt(m)||Ph!=e.charAt(m+1));)++m;if(m+=2,Qn===e.charAt(m-1))return s("End of comment missing");var g=e.slice(2,m-2);return n+=2,i(g),e=e.slice(m),n+=2,p({type:Dw,comment:g})}}function d(){var p=a(),m=u(_w);if(m){if(f(),!u(Cw))return s("property missing ':'");var g=u(Mw),v=p({type:Lw,property:Lh(m[0].replace(Ih,Qn)),value:g?Lh(g[0].replace(Ih,Qn)):Qn});return u(Rw),v}}function h(){var p=[];c(p);for(var m;m=d();)m!==!1&&(p.push(m),c(p));return p}return l(),h()};function Lh(e){return e?e.replace(Iw,Qn):Qn}var Bw=Fw;function Jg(e,t){var r=null;if(!e||typeof e!="string")return r;for(var n,i=Bw(e),a=typeof t=="function",o,s,u=0,l=i.length;u<l;u++)n=i[u],o=n.property,s=n.value,a?t(o,s,n):s&&(r||(r={}),r[o]=s);return r}hf.exports=Jg;hf.exports.default=Jg;var zw=hf.exports;const $w=Ce(zw),A0={}.hasOwnProperty,Uw=new Set(["table","thead","tbody","tfoot","tr"]);function e2(e,t){const r=[];let n=-1,i;for(;++n<t.children.length;)i=t.children[n],i.type==="element"?r.push(Hw(e,i,n,t)):i.type==="text"?(t.type!=="element"||!Uw.has(t.tagName)||!Tw(i))&&r.push(i.value):i.type==="raw"&&!e.options.skipHtml&&r.push(i.value);return r}function Hw(e,t,r,n){const i=e.options,a=i.transformLinkUri===void 0?G6:i.transformLinkUri,o=e.schema,s=t.tagName,u={};let l=o,c;if(o.space==="html"&&s==="svg"&&(l=Yg,e.schema=l),t.properties)for(c in t.properties)A0.call(t.properties,c)&&jw(u,c,t.properties[c],e);(s==="ol"||s==="ul")&&e.listDepth++;const f=e2(e,t);(s==="ol"||s==="ul")&&e.listDepth--,e.schema=o;const d=t.position||{start:{line:null,column:null,offset:null},end:{line:null,column:null,offset:null}},h=i.components&&A0.call(i.components,s)?i.components[s]:s,p=typeof h=="string"||h===React.Fragment;if(!Sw.isValidElementType(h))throw new TypeError(`Component for name \`${s}\` not defined or is not renderable`);if(u.key=r,s==="a"&&i.linkTarget&&(u.target=typeof i.linkTarget=="function"?i.linkTarget(String(u.href||""),t.children,typeof u.title=="string"?u.title:null):i.linkTarget),s==="a"&&a&&(u.href=a(String(u.href||""),t.children,typeof u.title=="string"?u.title:null)),!p&&s==="code"&&n.type==="element"&&n.tagName!=="pre"&&(u.inline=!0),!p&&(s==="h1"||s==="h2"||s==="h3"||s==="h4"||s==="h5"||s==="h6")&&(u.level=Number.parseInt(s.charAt(1),10)),s==="img"&&i.transformImageUri&&(u.src=i.transformImageUri(String(u.src||""),String(u.alt||""),typeof u.title=="string"?u.title:null)),!p&&s==="li"&&n.type==="element"){const m=qw(t);u.checked=m&&m.properties?!!m.properties.checked:null,u.index=pl(n,t),u.ordered=n.tagName==="ol"}return!p&&(s==="ol"||s==="ul")&&(u.ordered=s==="ol",u.depth=e.listDepth),(s==="td"||s==="th")&&(u.align&&(u.style||(u.style={}),u.style.textAlign=u.align,delete u.align),p||(u.isHeader=s==="th")),!p&&s==="tr"&&n.type==="element"&&(u.isHeader=n.tagName==="thead"),i.sourcePos&&(u["data-sourcepos"]=Ww(d)),!p&&i.rawSourcePos&&(u.sourcePosition=t.position),!p&&i.includeElementIndex&&(u.index=pl(n,t),u.siblingCount=pl(n)),p||(u.node=t),f.length>0?React.createElement(h,u,f):React.createElement(h,u)}function qw(e){let t=-1;for(;++t<e.children.length;){const r=e.children[t];if(r.type==="element"&&r.tagName==="input")return r}return null}function pl(e,t){let r=-1,n=0;for(;++r<e.children.length&&e.children[r]!==t;)e.children[r].type==="element"&&n++;return n}function jw(e,t,r,n){const i=Kg(n.schema,t);let a=r;a==null||a!==a||(Array.isArray(a)&&(a=i.commaSeparated?kw(a):Aw(a)),i.property==="style"&&typeof a=="string"&&(a=Vw(a)),i.space&&i.property?e[A0.call(Ch,i.property)?Ch[i.property]:i.property]=a:i.attribute&&(e[i.attribute]=a))}function Vw(e){const t={};try{$w(e,r)}catch{}return t;function r(n,i){const a=n.slice(0,4)==="-ms-"?`ms-${n.slice(4)}`:n;t[a.replace(/-([a-z])/g,Gw)]=i}}function Gw(e,t){return t.toUpperCase()}function Ww(e){return[e.start.line,":",e.start.column,"-",e.end.line,":",e.end.column].map(String).join("")}const Fh={}.hasOwnProperty,Kw="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",go={plugins:{to:"remarkPlugins",id:"change-plugins-to-remarkplugins"},renderers:{to:"components",id:"change-renderers-to-components"},astPlugins:{id:"remove-buggy-html-in-markdown-parser"},allowDangerousHtml:{id:"remove-buggy-html-in-markdown-parser"},escapeHtml:{id:"remove-buggy-html-in-markdown-parser"},source:{to:"children",id:"change-source-to-children"},allowNode:{to:"allowElement",id:"replace-allownode-allowedtypes-and-disallowedtypes"},allowedTypes:{to:"allowedElements",id:"replace-allownode-allowedtypes-and-disallowedtypes"},disallowedTypes:{to:"disallowedElements",id:"replace-allownode-allowedtypes-and-disallowedtypes"},includeNodeIndex:{to:"includeElementIndex",id:"change-includenodeindex-to-includeelementindex"}};function Xw(e){for(const a in go)if(Fh.call(go,a)&&Fh.call(e,a)){const o=go[a];console.warn(`[react-markdown] Warning: please ${o.to?`use \`${o.to}\` instead of`:"remove"} \`${a}\` (see <${Kw}#${o.id}> for more info)`),delete go[a]}const t=u5().use(h7).use(e.remarkPlugins||[]).use(nw,{...e.remarkRehypeOptions,allowDangerousHtml:!0}).use(e.rehypePlugins||[]).use(yw,e),r=new fg;typeof e.children=="string"?r.value=e.children:e.children!==void 0&&e.children!==null&&console.warn(`[react-markdown] Warning: please pass a string as \`children\` (not: \`${e.children}\`)`);const n=t.runSync(t.parse(r),r);if(n.type!=="root")throw new TypeError("Expected a `root` node");let i=React.createElement(React.Fragment,{},e2({options:e,schema:Xg,listDepth:0},n));return e.className&&(i=React.createElement("div",{className:e.className},i)),i}Xw.propTypes={children:ke.string,className:ke.string,allowElement:ke.func,allowedElements:ke.arrayOf(ke.string),disallowedElements:ke.arrayOf(ke.string),unwrapDisallowed:ke.bool,remarkPlugins:ke.arrayOf(ke.oneOfType([ke.object,ke.func,ke.arrayOf(ke.oneOfType([ke.bool,ke.string,ke.object,ke.func,ke.arrayOf(ke.any)]))])),rehypePlugins:ke.arrayOf(ke.oneOfType([ke.object,ke.func,ke.arrayOf(ke.oneOfType([ke.bool,ke.string,ke.object,ke.func,ke.arrayOf(ke.any)]))])),sourcePos:ke.bool,rawSourcePos:ke.bool,skipHtml:ke.bool,includeElementIndex:ke.bool,transformLinkUri:ke.oneOfType([ke.func,ke.bool]),linkTarget:ke.oneOfType([ke.func,ke.string]),transformImageUri:ke.func,components:ke.object};const Yw={tokenize:Zw,concrete:!0},Bh={tokenize:Qw,partial:!0};function Zw(e,t,r){const n=this,i=n.events[n.events.length-1],a=i&&i[1].type==="linePrefix"?i[2].sliceSerialize(i[1],!0).length:0;let o=0;return s;function s(w){return e.enter("mathFlow"),e.enter("mathFlowFence"),e.enter("mathFlowFenceSequence"),u(w)}function u(w){return w===36?(e.consume(w),o++,u):o<2?r(w):(e.exit("mathFlowFenceSequence"),Me(e,l,"whitespace")(w))}function l(w){return w===null||pe(w)?f(w):(e.enter("mathFlowFenceMeta"),e.enter("chunkString",{contentType:"string"}),c(w))}function c(w){return w===null||pe(w)?(e.exit("chunkString"),e.exit("mathFlowFenceMeta"),f(w)):w===36?r(w):(e.consume(w),c)}function f(w){return e.exit("mathFlowFence"),n.interrupt?t(w):e.attempt(Bh,d,g)(w)}function d(w){return e.attempt({tokenize:v,partial:!0},g,h)(w)}function h(w){return(a?Me(e,p,"linePrefix",a+1):p)(w)}function p(w){return w===null?g(w):pe(w)?e.attempt(Bh,d,g)(w):(e.enter("mathFlowValue"),m(w))}function m(w){return w===null||pe(w)?(e.exit("mathFlowValue"),p(w)):(e.consume(w),m)}function g(w){return e.exit("mathFlow"),t(w)}function v(w,x,N){let O=0;return Me(w,A,"linePrefix",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function A(z){return w.enter("mathFlowFence"),w.enter("mathFlowFenceSequence"),D(z)}function D(z){return z===36?(O++,w.consume(z),D):O<o?N(z):(w.exit("mathFlowFenceSequence"),Me(w,H,"whitespace")(z))}function H(z){return z===null||pe(z)?(w.exit("mathFlowFence"),x(z)):N(z)}}}function Qw(e,t,r){const n=this;return i;function i(o){return o===null?t(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),a)}function a(o){return n.parser.lazy[n.now().line]?r(o):t(o)}}function Jw(e){let r=(e||{}).singleDollarTextMath;return r==null&&(r=!0),{tokenize:n,resolve:ex,previous:tx};function n(i,a,o){let s=0,u,l;return c;function c(m){return i.enter("mathText"),i.enter("mathTextSequence"),f(m)}function f(m){return m===36?(i.consume(m),s++,f):s<2&&!r?o(m):(i.exit("mathTextSequence"),d(m))}function d(m){return m===null?o(m):m===36?(l=i.enter("mathTextSequence"),u=0,p(m)):m===32?(i.enter("space"),i.consume(m),i.exit("space"),d):pe(m)?(i.enter("lineEnding"),i.consume(m),i.exit("lineEnding"),d):(i.enter("mathTextData"),h(m))}function h(m){return m===null||m===32||m===36||pe(m)?(i.exit("mathTextData"),d(m)):(i.consume(m),h)}function p(m){return m===36?(i.consume(m),u++,p):u===s?(i.exit("mathTextSequence"),i.exit("mathText"),a(m)):(l.type="mathTextData",h(m))}}}function ex(e){let t=e.length-4,r=3,n,i;if((e[r][1].type==="lineEnding"||e[r][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(n=r;++n<t;)if(e[n][1].type==="mathTextData"){e[t][1].type="mathTextPadding",e[r][1].type="mathTextPadding",r+=2,t-=2;break}}for(n=r-1,t++;++n<=t;)i===void 0?n!==t&&e[n][1].type!=="lineEnding"&&(i=n):(n===t||e[n][1].type==="lineEnding")&&(e[i][1].type="mathTextData",n!==i+2&&(e[i][1].end=e[n-1][1].end,e.splice(i+2,n-i-2),t-=n-i-2,n=i+2),i=void 0);return e}function tx(e){return e!==36||this.events[this.events.length-1][1].type==="characterEscape"}function rx(e){return{flow:{36:Yw},text:{36:Jw(e)}}}class Jt{constructor(t,r,n){this.lexer=void 0,this.start=void 0,this.end=void 0,this.lexer=t,this.start=r,this.end=n}static range(t,r){return r?!t||!t.loc||!r.loc||t.loc.lexer!==r.loc.lexer?null:new Jt(t.loc.lexer,t.loc.start,r.loc.end):t&&t.loc}}class qr{constructor(t,r){this.text=void 0,this.loc=void 0,this.noexpand=void 0,this.treatAsRelax=void 0,this.text=t,this.loc=r}range(t,r){return new qr(r,Jt.range(this,t))}}class te{constructor(t,r){this.name=void 0,this.position=void 0,this.length=void 0,this.rawMessage=void 0;var n="KaTeX parse error: "+t,i,a,o=r&&r.loc;if(o&&o.start<=o.end){var s=o.lexer.input;i=o.start,a=o.end,i===s.length?n+=" at end of input: ":n+=" at position "+(i+1)+": ";var u=s.slice(i,a).replace(/[^]/g,"$&̲"),l;i>15?l="…"+s.slice(i-15,i):l=s.slice(0,i);var c;a+15<s.length?c=s.slice(a,a+15)+"…":c=s.slice(a),n+=l+u+c}var f=new Error(n);return f.name="ParseError",f.__proto__=te.prototype,f.position=i,i!=null&&a!=null&&(f.length=a-i),f.rawMessage=t,f}}te.prototype.__proto__=Error.prototype;var nx=function(t,r){return t.indexOf(r)!==-1},ix=function(t,r){return t===void 0?r:t},ax=/([A-Z])/g,ox=function(t){return t.replace(ax,"-$1").toLowerCase()},sx={"&":"&amp;",">":"&gt;","<":"&lt;",'"':"&quot;","'":"&#x27;"},ux=/[&><"']/g;function lx(e){return String(e).replace(ux,t=>sx[t])}var t2=function e(t){return t.type==="ordgroup"||t.type==="color"?t.body.length===1?e(t.body[0]):t:t.type==="font"?e(t.body):t},cx=function(t){var r=t2(t);return r.type==="mathord"||r.type==="textord"||r.type==="atom"},fx=function(t){if(!t)throw new Error("Expected non-null, but got "+String(t));return t},dx=function(t){var r=/^\s*([^\\/#]*?)(?::|&#0*58|&#x0*3a)/i.exec(t);return r!=null?r[1]:"_relative"},Te={contains:nx,deflt:ix,escape:lx,hyphenate:ox,getBaseElem:t2,isCharacterBox:cx,protocolFromUrl:dx},is={displayMode:{type:"boolean",description:"Render math in display mode, which puts the math in display style (so \\int and \\sum are large, for example), and centers the math on the page on its own line.",cli:"-d, --display-mode"},output:{type:{enum:["htmlAndMathml","html","mathml"]},description:"Determines the markup language of the output.",cli:"-F, --format <type>"},leqno:{type:"boolean",description:"Render display math in leqno style (left-justified tags)."},fleqn:{type:"boolean",description:"Render display math flush left."},throwOnError:{type:"boolean",default:!0,cli:"-t, --no-throw-on-error",cliDescription:"Render errors (in the color given by --error-color) instead of throwing a ParseError exception when encountering an error."},errorColor:{type:"string",default:"#cc0000",cli:"-c, --error-color <color>",cliDescription:"A color string given in the format 'rgb' or 'rrggbb' (no #). This option determines the color of errors rendered by the -t option.",cliProcessor:e=>"#"+e},macros:{type:"object",cli:"-m, --macro <def>",cliDescription:"Define custom macro of the form '\\foo:expansion' (use multiple -m arguments for multiple macros).",cliDefault:[],cliProcessor:(e,t)=>(t.push(e),t)},minRuleThickness:{type:"number",description:"Specifies a minimum thickness, in ems, for fraction lines, `\\sqrt` top lines, `{array}` vertical lines, `\\hline`, `\\hdashline`, `\\underline`, `\\overline`, and the borders of `\\fbox`, `\\boxed`, and `\\fcolorbox`.",processor:e=>Math.max(0,e),cli:"--min-rule-thickness <size>",cliProcessor:parseFloat},colorIsTextColor:{type:"boolean",description:"Makes \\color behave like LaTeX's 2-argument \\textcolor, instead of LaTeX's one-argument \\color mode change.",cli:"-b, --color-is-text-color"},strict:{type:[{enum:["warn","ignore","error"]},"boolean","function"],description:"Turn on strict / LaTeX faithfulness mode, which throws an error if the input uses features that are not supported by LaTeX.",cli:"-S, --strict",cliDefault:!1},trust:{type:["boolean","function"],description:"Trust the input, enabling all HTML features such as \\url.",cli:"-T, --trust"},maxSize:{type:"number",default:1/0,description:"If non-zero, all user-specified sizes, e.g. in \\rule{500em}{500em}, will be capped to maxSize ems. Otherwise, elements and spaces can be arbitrarily large",processor:e=>Math.max(0,e),cli:"-s, --max-size <n>",cliProcessor:parseInt},maxExpand:{type:"number",default:1e3,description:"Limit the number of macro expansions to the specified number, to prevent e.g. infinite macro loops. If set to Infinity, the macro expander will try to fully expand as in LaTeX.",processor:e=>Math.max(0,e),cli:"-e, --max-expand <n>",cliProcessor:e=>e==="Infinity"?1/0:parseInt(e)},globalGroup:{type:"boolean",cli:!1}};function hx(e){if(e.default)return e.default;var t=e.type,r=Array.isArray(t)?t[0]:t;if(typeof r!="string")return r.enum[0];switch(r){case"boolean":return!1;case"string":return"";case"number":return 0;case"object":return{}}}class pf{constructor(t){this.displayMode=void 0,this.output=void 0,this.leqno=void 0,this.fleqn=void 0,this.throwOnError=void 0,this.errorColor=void 0,this.macros=void 0,this.minRuleThickness=void 0,this.colorIsTextColor=void 0,this.strict=void 0,this.trust=void 0,this.maxSize=void 0,this.maxExpand=void 0,this.globalGroup=void 0,t=t||{};for(var r in is)if(is.hasOwnProperty(r)){var n=is[r];this[r]=t[r]!==void 0?n.processor?n.processor(t[r]):t[r]:hx(n)}}reportNonstrict(t,r,n){var i=this.strict;if(typeof i=="function"&&(i=i(t,r,n)),!(!i||i==="ignore")){if(i===!0||i==="error")throw new te("LaTeX-incompatible input and strict mode is set to 'error': "+(r+" ["+t+"]"),n);i==="warn"?typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(r+" ["+t+"]")):typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+i+"': "+r+" ["+t+"]"))}}useStrictBehavior(t,r,n){var i=this.strict;if(typeof i=="function")try{i=i(t,r,n)}catch{i="error"}return!i||i==="ignore"?!1:i===!0||i==="error"?!0:i==="warn"?(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(r+" ["+t+"]")),!1):(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+i+"': "+r+" ["+t+"]")),!1)}isTrusted(t){t.url&&!t.protocol&&(t.protocol=Te.protocolFromUrl(t.url));var r=typeof this.trust=="function"?this.trust(t):this.trust;return!!r}}class xn{constructor(t,r,n){this.id=void 0,this.size=void 0,this.cramped=void 0,this.id=t,this.size=r,this.cramped=n}sup(){return Dr[px[this.id]]}sub(){return Dr[mx[this.id]]}fracNum(){return Dr[gx[this.id]]}fracDen(){return Dr[bx[this.id]]}cramp(){return Dr[vx[this.id]]}text(){return Dr[yx[this.id]]}isTight(){return this.size>=2}}var mf=0,Os=1,Ii=2,on=3,Oa=4,hr=5,Bi=6,Bt=7,Dr=[new xn(mf,0,!1),new xn(Os,0,!0),new xn(Ii,1,!1),new xn(on,1,!0),new xn(Oa,2,!1),new xn(hr,2,!0),new xn(Bi,3,!1),new xn(Bt,3,!0)],px=[Oa,hr,Oa,hr,Bi,Bt,Bi,Bt],mx=[hr,hr,hr,hr,Bt,Bt,Bt,Bt],gx=[Ii,on,Oa,hr,Bi,Bt,Bi,Bt],bx=[on,on,hr,hr,Bt,Bt,Bt,Bt],vx=[Os,Os,on,on,hr,hr,Bt,Bt],yx=[mf,Os,Ii,on,Ii,on,Ii,on],be={DISPLAY:Dr[mf],TEXT:Dr[Ii],SCRIPT:Dr[Oa],SCRIPTSCRIPT:Dr[Bi]},k0=[{name:"latin",blocks:[[256,591],[768,879]]},{name:"cyrillic",blocks:[[1024,1279]]},{name:"armenian",blocks:[[1328,1423]]},{name:"brahmic",blocks:[[2304,4255]]},{name:"georgian",blocks:[[4256,4351]]},{name:"cjk",blocks:[[12288,12543],[19968,40879],[65280,65376]]},{name:"hangul",blocks:[[44032,55215]]}];function wx(e){for(var t=0;t<k0.length;t++)for(var r=k0[t],n=0;n<r.blocks.length;n++){var i=r.blocks[n];if(e>=i[0]&&e<=i[1])return r.name}return null}var as=[];k0.forEach(e=>e.blocks.forEach(t=>as.push(...t)));function r2(e){for(var t=0;t<as.length;t+=2)if(e>=as[t]&&e<=as[t+1])return!0;return!1}var gi=80,xx=function(t,r){return"M95,"+(622+t+r)+`
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l`+t/2.075+" -"+t+`
c5.3,-9.3,12,-14,20,-14
H400000v`+(40+t)+`H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M`+(834+t)+" "+r+"h400000v"+(40+t)+"h-400000z"},Ex=function(t,r){return"M263,"+(601+t+r)+`c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l`+t/2.084+" -"+t+`
c4.7,-7.3,11,-11,19,-11
H40000v`+(40+t)+`H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M`+(1001+t)+" "+r+"h400000v"+(40+t)+"h-400000z"},Sx=function(t,r){return"M983 "+(10+t+r)+`
l`+t/3.13+" -"+t+`
c4,-6.7,10,-10,18,-10 H400000v`+(40+t)+`
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M`+(1001+t)+" "+r+"h400000v"+(40+t)+"h-400000z"},Tx=function(t,r){return"M424,"+(2398+t+r)+`
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l`+t/4.223+" -"+t+`c4,-6.7,10,-10,18,-10 H400000
v`+(40+t)+`H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M`+(1001+t)+" "+r+`
h400000v`+(40+t)+"h-400000z"},Ax=function(t,r){return"M473,"+(2713+t+r)+`
c339.3,-1799.3,509.3,-2700,510,-2702 l`+t/5.298+" -"+t+`
c3.3,-7.3,9.3,-11,18,-11 H400000v`+(40+t)+`H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM`+(1001+t)+" "+r+"h400000v"+(40+t)+"H1017.7z"},kx=function(t){var r=t/2;return"M400000 "+t+" H0 L"+r+" 0 l65 45 L145 "+(t-80)+" H400000z"},Ox=function(t,r,n){var i=n-54-r-t;return"M702 "+(t+r)+"H400000"+(40+t)+`
H742v`+i+`l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 `+r+"H400000v"+(40+t)+"H742z"},Nx=function(t,r,n){r=1e3*r;var i="";switch(t){case"sqrtMain":i=xx(r,gi);break;case"sqrtSize1":i=Ex(r,gi);break;case"sqrtSize2":i=Sx(r,gi);break;case"sqrtSize3":i=Tx(r,gi);break;case"sqrtSize4":i=Ax(r,gi);break;case"sqrtTall":i=Ox(r,gi,n)}return i},_x=function(t,r){switch(t){case"⎜":return"M291 0 H417 V"+r+" H291z M291 0 H417 V"+r+" H291z";case"∣":return"M145 0 H188 V"+r+" H145z M145 0 H188 V"+r+" H145z";case"∥":return"M145 0 H188 V"+r+" H145z M145 0 H188 V"+r+" H145z"+("M367 0 H410 V"+r+" H367z M367 0 H410 V"+r+" H367z");case"⎟":return"M457 0 H583 V"+r+" H457z M457 0 H583 V"+r+" H457z";case"⎢":return"M319 0 H403 V"+r+" H319z M319 0 H403 V"+r+" H319z";case"⎥":return"M263 0 H347 V"+r+" H263z M263 0 H347 V"+r+" H263z";case"⎪":return"M384 0 H504 V"+r+" H384z M384 0 H504 V"+r+" H384z";case"⏐":return"M312 0 H355 V"+r+" H312z M312 0 H355 V"+r+" H312z";case"‖":return"M257 0 H300 V"+r+" H257z M257 0 H300 V"+r+" H257z"+("M478 0 H521 V"+r+" H478z M478 0 H521 V"+r+" H478z");default:return""}},zh={doubleleftarrow:`M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,doublerightarrow:`M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,leftarrow:`M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,leftbrace:`M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,leftbraceunder:`M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,leftgroup:`M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,leftgroupunder:`M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,leftharpoon:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,leftharpoonplus:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,leftharpoondown:`M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,leftharpoondownplus:`M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,lefthook:`M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,leftlinesegment:`M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,leftmapsto:`M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,leftToFrom:`M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,longequal:`M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,midbrace:`M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,midbraceunder:`M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,oiintSize1:`M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,oiintSize2:`M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,oiiintSize1:`M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,oiiintSize2:`M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,rightarrow:`M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,rightbrace:`M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,rightbraceunder:`M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,rightgroup:`M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,rightgroupunder:`M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,rightharpoon:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,rightharpoonplus:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,rightharpoondown:`M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,rightharpoondownplus:`M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,righthook:`M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,rightlinesegment:`M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,rightToFrom:`M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,twoheadleftarrow:`M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,twoheadrightarrow:`M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,tilde1:`M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,tilde2:`M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,tilde3:`M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,tilde4:`M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,vec:`M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,widehat1:`M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,widehat2:`M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat3:`M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat4:`M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widecheck1:`M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,widecheck2:`M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck3:`M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck4:`M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,baraboveleftarrow:`M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,rightarrowabovebar:`M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,baraboveshortleftharpoon:`M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,rightharpoonaboveshortbar:`M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,shortbaraboveleftharpoon:`M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,shortrightharpoonabovebar:`M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`},Cx=function(t,r){switch(t){case"lbrack":return"M403 1759 V84 H666 V0 H319 V1759 v"+r+` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v`+r+" v1759 h84z";case"rbrack":return"M347 1759 V0 H0 V84 H263 V1759 v"+r+` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v`+r+" v1759 h84z";case"vert":return"M145 15 v585 v"+r+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-r+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+r+" v585 h43z";case"doublevert":return"M145 15 v585 v"+r+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-r+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+r+` v585 h43z
M367 15 v585 v`+r+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-r+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v`+r+" v585 h43z";case"lfloor":return"M319 602 V0 H403 V602 v"+r+` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v`+r+" v1715 H319z";case"rfloor":return"M319 602 V0 H403 V602 v"+r+` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v`+r+" v1715 H319z";case"lceil":return"M403 1759 V84 H666 V0 H319 V1759 v"+r+` v602 h84z
M403 1759 V0 H319 V1759 v`+r+" v602 h84z";case"rceil":return"M347 1759 V0 H0 V84 H263 V1759 v"+r+` v602 h84z
M347 1759 V0 h-84 V1759 v`+r+" v602 h84z";case"lparen":return`M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,`+(r+84)+`c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-`+(r+92)+`c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;case"rparen":return`M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,`+(r+9)+`
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-`+(r+144)+`c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;default:throw new Error("Unknown stretchy delimiter.")}};class Xa{constructor(t){this.children=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.children=t,this.classes=[],this.height=0,this.depth=0,this.maxFontSize=0,this.style={}}hasClass(t){return Te.contains(this.classes,t)}toNode(){for(var t=document.createDocumentFragment(),r=0;r<this.children.length;r++)t.appendChild(this.children[r].toNode());return t}toMarkup(){for(var t="",r=0;r<this.children.length;r++)t+=this.children[r].toMarkup();return t}toText(){var t=r=>r.toText();return this.children.map(t).join("")}}var Ur={"AMS-Regular":{32:[0,0,0,0,.25],65:[0,.68889,0,0,.72222],66:[0,.68889,0,0,.66667],67:[0,.68889,0,0,.72222],68:[0,.68889,0,0,.72222],69:[0,.68889,0,0,.66667],70:[0,.68889,0,0,.61111],71:[0,.68889,0,0,.77778],72:[0,.68889,0,0,.77778],73:[0,.68889,0,0,.38889],74:[.16667,.68889,0,0,.5],75:[0,.68889,0,0,.77778],76:[0,.68889,0,0,.66667],77:[0,.68889,0,0,.94445],78:[0,.68889,0,0,.72222],79:[.16667,.68889,0,0,.77778],80:[0,.68889,0,0,.61111],81:[.16667,.68889,0,0,.77778],82:[0,.68889,0,0,.72222],83:[0,.68889,0,0,.55556],84:[0,.68889,0,0,.66667],85:[0,.68889,0,0,.72222],86:[0,.68889,0,0,.72222],87:[0,.68889,0,0,1],88:[0,.68889,0,0,.72222],89:[0,.68889,0,0,.72222],90:[0,.68889,0,0,.66667],107:[0,.68889,0,0,.55556],160:[0,0,0,0,.25],165:[0,.675,.025,0,.75],174:[.15559,.69224,0,0,.94666],240:[0,.68889,0,0,.55556],295:[0,.68889,0,0,.54028],710:[0,.825,0,0,2.33334],732:[0,.9,0,0,2.33334],770:[0,.825,0,0,2.33334],771:[0,.9,0,0,2.33334],989:[.08167,.58167,0,0,.77778],1008:[0,.43056,.04028,0,.66667],8245:[0,.54986,0,0,.275],8463:[0,.68889,0,0,.54028],8487:[0,.68889,0,0,.72222],8498:[0,.68889,0,0,.55556],8502:[0,.68889,0,0,.66667],8503:[0,.68889,0,0,.44445],8504:[0,.68889,0,0,.66667],8513:[0,.68889,0,0,.63889],8592:[-.03598,.46402,0,0,.5],8594:[-.03598,.46402,0,0,.5],8602:[-.13313,.36687,0,0,1],8603:[-.13313,.36687,0,0,1],8606:[.01354,.52239,0,0,1],8608:[.01354,.52239,0,0,1],8610:[.01354,.52239,0,0,1.11111],8611:[.01354,.52239,0,0,1.11111],8619:[0,.54986,0,0,1],8620:[0,.54986,0,0,1],8621:[-.13313,.37788,0,0,1.38889],8622:[-.13313,.36687,0,0,1],8624:[0,.69224,0,0,.5],8625:[0,.69224,0,0,.5],8630:[0,.43056,0,0,1],8631:[0,.43056,0,0,1],8634:[.08198,.58198,0,0,.77778],8635:[.08198,.58198,0,0,.77778],8638:[.19444,.69224,0,0,.41667],8639:[.19444,.69224,0,0,.41667],8642:[.19444,.69224,0,0,.41667],8643:[.19444,.69224,0,0,.41667],8644:[.1808,.675,0,0,1],8646:[.1808,.675,0,0,1],8647:[.1808,.675,0,0,1],8648:[.19444,.69224,0,0,.83334],8649:[.1808,.675,0,0,1],8650:[.19444,.69224,0,0,.83334],8651:[.01354,.52239,0,0,1],8652:[.01354,.52239,0,0,1],8653:[-.13313,.36687,0,0,1],8654:[-.13313,.36687,0,0,1],8655:[-.13313,.36687,0,0,1],8666:[.13667,.63667,0,0,1],8667:[.13667,.63667,0,0,1],8669:[-.13313,.37788,0,0,1],8672:[-.064,.437,0,0,1.334],8674:[-.064,.437,0,0,1.334],8705:[0,.825,0,0,.5],8708:[0,.68889,0,0,.55556],8709:[.08167,.58167,0,0,.77778],8717:[0,.43056,0,0,.42917],8722:[-.03598,.46402,0,0,.5],8724:[.08198,.69224,0,0,.77778],8726:[.08167,.58167,0,0,.77778],8733:[0,.69224,0,0,.77778],8736:[0,.69224,0,0,.72222],8737:[0,.69224,0,0,.72222],8738:[.03517,.52239,0,0,.72222],8739:[.08167,.58167,0,0,.22222],8740:[.25142,.74111,0,0,.27778],8741:[.08167,.58167,0,0,.38889],8742:[.25142,.74111,0,0,.5],8756:[0,.69224,0,0,.66667],8757:[0,.69224,0,0,.66667],8764:[-.13313,.36687,0,0,.77778],8765:[-.13313,.37788,0,0,.77778],8769:[-.13313,.36687,0,0,.77778],8770:[-.03625,.46375,0,0,.77778],8774:[.30274,.79383,0,0,.77778],8776:[-.01688,.48312,0,0,.77778],8778:[.08167,.58167,0,0,.77778],8782:[.06062,.54986,0,0,.77778],8783:[.06062,.54986,0,0,.77778],8785:[.08198,.58198,0,0,.77778],8786:[.08198,.58198,0,0,.77778],8787:[.08198,.58198,0,0,.77778],8790:[0,.69224,0,0,.77778],8791:[.22958,.72958,0,0,.77778],8796:[.08198,.91667,0,0,.77778],8806:[.25583,.75583,0,0,.77778],8807:[.25583,.75583,0,0,.77778],8808:[.25142,.75726,0,0,.77778],8809:[.25142,.75726,0,0,.77778],8812:[.25583,.75583,0,0,.5],8814:[.20576,.70576,0,0,.77778],8815:[.20576,.70576,0,0,.77778],8816:[.30274,.79383,0,0,.77778],8817:[.30274,.79383,0,0,.77778],8818:[.22958,.72958,0,0,.77778],8819:[.22958,.72958,0,0,.77778],8822:[.1808,.675,0,0,.77778],8823:[.1808,.675,0,0,.77778],8828:[.13667,.63667,0,0,.77778],8829:[.13667,.63667,0,0,.77778],8830:[.22958,.72958,0,0,.77778],8831:[.22958,.72958,0,0,.77778],8832:[.20576,.70576,0,0,.77778],8833:[.20576,.70576,0,0,.77778],8840:[.30274,.79383,0,0,.77778],8841:[.30274,.79383,0,0,.77778],8842:[.13597,.63597,0,0,.77778],8843:[.13597,.63597,0,0,.77778],8847:[.03517,.54986,0,0,.77778],8848:[.03517,.54986,0,0,.77778],8858:[.08198,.58198,0,0,.77778],8859:[.08198,.58198,0,0,.77778],8861:[.08198,.58198,0,0,.77778],8862:[0,.675,0,0,.77778],8863:[0,.675,0,0,.77778],8864:[0,.675,0,0,.77778],8865:[0,.675,0,0,.77778],8872:[0,.69224,0,0,.61111],8873:[0,.69224,0,0,.72222],8874:[0,.69224,0,0,.88889],8876:[0,.68889,0,0,.61111],8877:[0,.68889,0,0,.61111],8878:[0,.68889,0,0,.72222],8879:[0,.68889,0,0,.72222],8882:[.03517,.54986,0,0,.77778],8883:[.03517,.54986,0,0,.77778],8884:[.13667,.63667,0,0,.77778],8885:[.13667,.63667,0,0,.77778],8888:[0,.54986,0,0,1.11111],8890:[.19444,.43056,0,0,.55556],8891:[.19444,.69224,0,0,.61111],8892:[.19444,.69224,0,0,.61111],8901:[0,.54986,0,0,.27778],8903:[.08167,.58167,0,0,.77778],8905:[.08167,.58167,0,0,.77778],8906:[.08167,.58167,0,0,.77778],8907:[0,.69224,0,0,.77778],8908:[0,.69224,0,0,.77778],8909:[-.03598,.46402,0,0,.77778],8910:[0,.54986,0,0,.76042],8911:[0,.54986,0,0,.76042],8912:[.03517,.54986,0,0,.77778],8913:[.03517,.54986,0,0,.77778],8914:[0,.54986,0,0,.66667],8915:[0,.54986,0,0,.66667],8916:[0,.69224,0,0,.66667],8918:[.0391,.5391,0,0,.77778],8919:[.0391,.5391,0,0,.77778],8920:[.03517,.54986,0,0,1.33334],8921:[.03517,.54986,0,0,1.33334],8922:[.38569,.88569,0,0,.77778],8923:[.38569,.88569,0,0,.77778],8926:[.13667,.63667,0,0,.77778],8927:[.13667,.63667,0,0,.77778],8928:[.30274,.79383,0,0,.77778],8929:[.30274,.79383,0,0,.77778],8934:[.23222,.74111,0,0,.77778],8935:[.23222,.74111,0,0,.77778],8936:[.23222,.74111,0,0,.77778],8937:[.23222,.74111,0,0,.77778],8938:[.20576,.70576,0,0,.77778],8939:[.20576,.70576,0,0,.77778],8940:[.30274,.79383,0,0,.77778],8941:[.30274,.79383,0,0,.77778],8994:[.19444,.69224,0,0,.77778],8995:[.19444,.69224,0,0,.77778],9416:[.15559,.69224,0,0,.90222],9484:[0,.69224,0,0,.5],9488:[0,.69224,0,0,.5],9492:[0,.37788,0,0,.5],9496:[0,.37788,0,0,.5],9585:[.19444,.68889,0,0,.88889],9586:[.19444,.74111,0,0,.88889],9632:[0,.675,0,0,.77778],9633:[0,.675,0,0,.77778],9650:[0,.54986,0,0,.72222],9651:[0,.54986,0,0,.72222],9654:[.03517,.54986,0,0,.77778],9660:[0,.54986,0,0,.72222],9661:[0,.54986,0,0,.72222],9664:[.03517,.54986,0,0,.77778],9674:[.11111,.69224,0,0,.66667],9733:[.19444,.69224,0,0,.94445],10003:[0,.69224,0,0,.83334],10016:[0,.69224,0,0,.83334],10731:[.11111,.69224,0,0,.66667],10846:[.19444,.75583,0,0,.61111],10877:[.13667,.63667,0,0,.77778],10878:[.13667,.63667,0,0,.77778],10885:[.25583,.75583,0,0,.77778],10886:[.25583,.75583,0,0,.77778],10887:[.13597,.63597,0,0,.77778],10888:[.13597,.63597,0,0,.77778],10889:[.26167,.75726,0,0,.77778],10890:[.26167,.75726,0,0,.77778],10891:[.48256,.98256,0,0,.77778],10892:[.48256,.98256,0,0,.77778],10901:[.13667,.63667,0,0,.77778],10902:[.13667,.63667,0,0,.77778],10933:[.25142,.75726,0,0,.77778],10934:[.25142,.75726,0,0,.77778],10935:[.26167,.75726,0,0,.77778],10936:[.26167,.75726,0,0,.77778],10937:[.26167,.75726,0,0,.77778],10938:[.26167,.75726,0,0,.77778],10949:[.25583,.75583,0,0,.77778],10950:[.25583,.75583,0,0,.77778],10955:[.28481,.79383,0,0,.77778],10956:[.28481,.79383,0,0,.77778],57350:[.08167,.58167,0,0,.22222],57351:[.08167,.58167,0,0,.38889],57352:[.08167,.58167,0,0,.77778],57353:[0,.43056,.04028,0,.66667],57356:[.25142,.75726,0,0,.77778],57357:[.25142,.75726,0,0,.77778],57358:[.41951,.91951,0,0,.77778],57359:[.30274,.79383,0,0,.77778],57360:[.30274,.79383,0,0,.77778],57361:[.41951,.91951,0,0,.77778],57366:[.25142,.75726,0,0,.77778],57367:[.25142,.75726,0,0,.77778],57368:[.25142,.75726,0,0,.77778],57369:[.25142,.75726,0,0,.77778],57370:[.13597,.63597,0,0,.77778],57371:[.13597,.63597,0,0,.77778]},"Caligraphic-Regular":{32:[0,0,0,0,.25],65:[0,.68333,0,.19445,.79847],66:[0,.68333,.03041,.13889,.65681],67:[0,.68333,.05834,.13889,.52653],68:[0,.68333,.02778,.08334,.77139],69:[0,.68333,.08944,.11111,.52778],70:[0,.68333,.09931,.11111,.71875],71:[.09722,.68333,.0593,.11111,.59487],72:[0,.68333,.00965,.11111,.84452],73:[0,.68333,.07382,0,.54452],74:[.09722,.68333,.18472,.16667,.67778],75:[0,.68333,.01445,.05556,.76195],76:[0,.68333,0,.13889,.68972],77:[0,.68333,0,.13889,1.2009],78:[0,.68333,.14736,.08334,.82049],79:[0,.68333,.02778,.11111,.79611],80:[0,.68333,.08222,.08334,.69556],81:[.09722,.68333,0,.11111,.81667],82:[0,.68333,0,.08334,.8475],83:[0,.68333,.075,.13889,.60556],84:[0,.68333,.25417,0,.54464],85:[0,.68333,.09931,.08334,.62583],86:[0,.68333,.08222,0,.61278],87:[0,.68333,.08222,.08334,.98778],88:[0,.68333,.14643,.13889,.7133],89:[.09722,.68333,.08222,.08334,.66834],90:[0,.68333,.07944,.13889,.72473],160:[0,0,0,0,.25]},"Fraktur-Regular":{32:[0,0,0,0,.25],33:[0,.69141,0,0,.29574],34:[0,.69141,0,0,.21471],38:[0,.69141,0,0,.73786],39:[0,.69141,0,0,.21201],40:[.24982,.74947,0,0,.38865],41:[.24982,.74947,0,0,.38865],42:[0,.62119,0,0,.27764],43:[.08319,.58283,0,0,.75623],44:[0,.10803,0,0,.27764],45:[.08319,.58283,0,0,.75623],46:[0,.10803,0,0,.27764],47:[.24982,.74947,0,0,.50181],48:[0,.47534,0,0,.50181],49:[0,.47534,0,0,.50181],50:[0,.47534,0,0,.50181],51:[.18906,.47534,0,0,.50181],52:[.18906,.47534,0,0,.50181],53:[.18906,.47534,0,0,.50181],54:[0,.69141,0,0,.50181],55:[.18906,.47534,0,0,.50181],56:[0,.69141,0,0,.50181],57:[.18906,.47534,0,0,.50181],58:[0,.47534,0,0,.21606],59:[.12604,.47534,0,0,.21606],61:[-.13099,.36866,0,0,.75623],63:[0,.69141,0,0,.36245],65:[0,.69141,0,0,.7176],66:[0,.69141,0,0,.88397],67:[0,.69141,0,0,.61254],68:[0,.69141,0,0,.83158],69:[0,.69141,0,0,.66278],70:[.12604,.69141,0,0,.61119],71:[0,.69141,0,0,.78539],72:[.06302,.69141,0,0,.7203],73:[0,.69141,0,0,.55448],74:[.12604,.69141,0,0,.55231],75:[0,.69141,0,0,.66845],76:[0,.69141,0,0,.66602],77:[0,.69141,0,0,1.04953],78:[0,.69141,0,0,.83212],79:[0,.69141,0,0,.82699],80:[.18906,.69141,0,0,.82753],81:[.03781,.69141,0,0,.82699],82:[0,.69141,0,0,.82807],83:[0,.69141,0,0,.82861],84:[0,.69141,0,0,.66899],85:[0,.69141,0,0,.64576],86:[0,.69141,0,0,.83131],87:[0,.69141,0,0,1.04602],88:[0,.69141,0,0,.71922],89:[.18906,.69141,0,0,.83293],90:[.12604,.69141,0,0,.60201],91:[.24982,.74947,0,0,.27764],93:[.24982,.74947,0,0,.27764],94:[0,.69141,0,0,.49965],97:[0,.47534,0,0,.50046],98:[0,.69141,0,0,.51315],99:[0,.47534,0,0,.38946],100:[0,.62119,0,0,.49857],101:[0,.47534,0,0,.40053],102:[.18906,.69141,0,0,.32626],103:[.18906,.47534,0,0,.5037],104:[.18906,.69141,0,0,.52126],105:[0,.69141,0,0,.27899],106:[0,.69141,0,0,.28088],107:[0,.69141,0,0,.38946],108:[0,.69141,0,0,.27953],109:[0,.47534,0,0,.76676],110:[0,.47534,0,0,.52666],111:[0,.47534,0,0,.48885],112:[.18906,.52396,0,0,.50046],113:[.18906,.47534,0,0,.48912],114:[0,.47534,0,0,.38919],115:[0,.47534,0,0,.44266],116:[0,.62119,0,0,.33301],117:[0,.47534,0,0,.5172],118:[0,.52396,0,0,.5118],119:[0,.52396,0,0,.77351],120:[.18906,.47534,0,0,.38865],121:[.18906,.47534,0,0,.49884],122:[.18906,.47534,0,0,.39054],160:[0,0,0,0,.25],8216:[0,.69141,0,0,.21471],8217:[0,.69141,0,0,.21471],58112:[0,.62119,0,0,.49749],58113:[0,.62119,0,0,.4983],58114:[.18906,.69141,0,0,.33328],58115:[.18906,.69141,0,0,.32923],58116:[.18906,.47534,0,0,.50343],58117:[0,.69141,0,0,.33301],58118:[0,.62119,0,0,.33409],58119:[0,.47534,0,0,.50073]},"Main-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.35],34:[0,.69444,0,0,.60278],35:[.19444,.69444,0,0,.95833],36:[.05556,.75,0,0,.575],37:[.05556,.75,0,0,.95833],38:[0,.69444,0,0,.89444],39:[0,.69444,0,0,.31944],40:[.25,.75,0,0,.44722],41:[.25,.75,0,0,.44722],42:[0,.75,0,0,.575],43:[.13333,.63333,0,0,.89444],44:[.19444,.15556,0,0,.31944],45:[0,.44444,0,0,.38333],46:[0,.15556,0,0,.31944],47:[.25,.75,0,0,.575],48:[0,.64444,0,0,.575],49:[0,.64444,0,0,.575],50:[0,.64444,0,0,.575],51:[0,.64444,0,0,.575],52:[0,.64444,0,0,.575],53:[0,.64444,0,0,.575],54:[0,.64444,0,0,.575],55:[0,.64444,0,0,.575],56:[0,.64444,0,0,.575],57:[0,.64444,0,0,.575],58:[0,.44444,0,0,.31944],59:[.19444,.44444,0,0,.31944],60:[.08556,.58556,0,0,.89444],61:[-.10889,.39111,0,0,.89444],62:[.08556,.58556,0,0,.89444],63:[0,.69444,0,0,.54305],64:[0,.69444,0,0,.89444],65:[0,.68611,0,0,.86944],66:[0,.68611,0,0,.81805],67:[0,.68611,0,0,.83055],68:[0,.68611,0,0,.88194],69:[0,.68611,0,0,.75555],70:[0,.68611,0,0,.72361],71:[0,.68611,0,0,.90416],72:[0,.68611,0,0,.9],73:[0,.68611,0,0,.43611],74:[0,.68611,0,0,.59444],75:[0,.68611,0,0,.90138],76:[0,.68611,0,0,.69166],77:[0,.68611,0,0,1.09166],78:[0,.68611,0,0,.9],79:[0,.68611,0,0,.86388],80:[0,.68611,0,0,.78611],81:[.19444,.68611,0,0,.86388],82:[0,.68611,0,0,.8625],83:[0,.68611,0,0,.63889],84:[0,.68611,0,0,.8],85:[0,.68611,0,0,.88472],86:[0,.68611,.01597,0,.86944],87:[0,.68611,.01597,0,1.18888],88:[0,.68611,0,0,.86944],89:[0,.68611,.02875,0,.86944],90:[0,.68611,0,0,.70277],91:[.25,.75,0,0,.31944],92:[.25,.75,0,0,.575],93:[.25,.75,0,0,.31944],94:[0,.69444,0,0,.575],95:[.31,.13444,.03194,0,.575],97:[0,.44444,0,0,.55902],98:[0,.69444,0,0,.63889],99:[0,.44444,0,0,.51111],100:[0,.69444,0,0,.63889],101:[0,.44444,0,0,.52708],102:[0,.69444,.10903,0,.35139],103:[.19444,.44444,.01597,0,.575],104:[0,.69444,0,0,.63889],105:[0,.69444,0,0,.31944],106:[.19444,.69444,0,0,.35139],107:[0,.69444,0,0,.60694],108:[0,.69444,0,0,.31944],109:[0,.44444,0,0,.95833],110:[0,.44444,0,0,.63889],111:[0,.44444,0,0,.575],112:[.19444,.44444,0,0,.63889],113:[.19444,.44444,0,0,.60694],114:[0,.44444,0,0,.47361],115:[0,.44444,0,0,.45361],116:[0,.63492,0,0,.44722],117:[0,.44444,0,0,.63889],118:[0,.44444,.01597,0,.60694],119:[0,.44444,.01597,0,.83055],120:[0,.44444,0,0,.60694],121:[.19444,.44444,.01597,0,.60694],122:[0,.44444,0,0,.51111],123:[.25,.75,0,0,.575],124:[.25,.75,0,0,.31944],125:[.25,.75,0,0,.575],126:[.35,.34444,0,0,.575],160:[0,0,0,0,.25],163:[0,.69444,0,0,.86853],168:[0,.69444,0,0,.575],172:[0,.44444,0,0,.76666],176:[0,.69444,0,0,.86944],177:[.13333,.63333,0,0,.89444],184:[.17014,0,0,0,.51111],198:[0,.68611,0,0,1.04166],215:[.13333,.63333,0,0,.89444],216:[.04861,.73472,0,0,.89444],223:[0,.69444,0,0,.59722],230:[0,.44444,0,0,.83055],247:[.13333,.63333,0,0,.89444],248:[.09722,.54167,0,0,.575],305:[0,.44444,0,0,.31944],338:[0,.68611,0,0,1.16944],339:[0,.44444,0,0,.89444],567:[.19444,.44444,0,0,.35139],710:[0,.69444,0,0,.575],711:[0,.63194,0,0,.575],713:[0,.59611,0,0,.575],714:[0,.69444,0,0,.575],715:[0,.69444,0,0,.575],728:[0,.69444,0,0,.575],729:[0,.69444,0,0,.31944],730:[0,.69444,0,0,.86944],732:[0,.69444,0,0,.575],733:[0,.69444,0,0,.575],915:[0,.68611,0,0,.69166],916:[0,.68611,0,0,.95833],920:[0,.68611,0,0,.89444],923:[0,.68611,0,0,.80555],926:[0,.68611,0,0,.76666],928:[0,.68611,0,0,.9],931:[0,.68611,0,0,.83055],933:[0,.68611,0,0,.89444],934:[0,.68611,0,0,.83055],936:[0,.68611,0,0,.89444],937:[0,.68611,0,0,.83055],8211:[0,.44444,.03194,0,.575],8212:[0,.44444,.03194,0,1.14999],8216:[0,.69444,0,0,.31944],8217:[0,.69444,0,0,.31944],8220:[0,.69444,0,0,.60278],8221:[0,.69444,0,0,.60278],8224:[.19444,.69444,0,0,.51111],8225:[.19444,.69444,0,0,.51111],8242:[0,.55556,0,0,.34444],8407:[0,.72444,.15486,0,.575],8463:[0,.69444,0,0,.66759],8465:[0,.69444,0,0,.83055],8467:[0,.69444,0,0,.47361],8472:[.19444,.44444,0,0,.74027],8476:[0,.69444,0,0,.83055],8501:[0,.69444,0,0,.70277],8592:[-.10889,.39111,0,0,1.14999],8593:[.19444,.69444,0,0,.575],8594:[-.10889,.39111,0,0,1.14999],8595:[.19444,.69444,0,0,.575],8596:[-.10889,.39111,0,0,1.14999],8597:[.25,.75,0,0,.575],8598:[.19444,.69444,0,0,1.14999],8599:[.19444,.69444,0,0,1.14999],8600:[.19444,.69444,0,0,1.14999],8601:[.19444,.69444,0,0,1.14999],8636:[-.10889,.39111,0,0,1.14999],8637:[-.10889,.39111,0,0,1.14999],8640:[-.10889,.39111,0,0,1.14999],8641:[-.10889,.39111,0,0,1.14999],8656:[-.10889,.39111,0,0,1.14999],8657:[.19444,.69444,0,0,.70277],8658:[-.10889,.39111,0,0,1.14999],8659:[.19444,.69444,0,0,.70277],8660:[-.10889,.39111,0,0,1.14999],8661:[.25,.75,0,0,.70277],8704:[0,.69444,0,0,.63889],8706:[0,.69444,.06389,0,.62847],8707:[0,.69444,0,0,.63889],8709:[.05556,.75,0,0,.575],8711:[0,.68611,0,0,.95833],8712:[.08556,.58556,0,0,.76666],8715:[.08556,.58556,0,0,.76666],8722:[.13333,.63333,0,0,.89444],8723:[.13333,.63333,0,0,.89444],8725:[.25,.75,0,0,.575],8726:[.25,.75,0,0,.575],8727:[-.02778,.47222,0,0,.575],8728:[-.02639,.47361,0,0,.575],8729:[-.02639,.47361,0,0,.575],8730:[.18,.82,0,0,.95833],8733:[0,.44444,0,0,.89444],8734:[0,.44444,0,0,1.14999],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.31944],8741:[.25,.75,0,0,.575],8743:[0,.55556,0,0,.76666],8744:[0,.55556,0,0,.76666],8745:[0,.55556,0,0,.76666],8746:[0,.55556,0,0,.76666],8747:[.19444,.69444,.12778,0,.56875],8764:[-.10889,.39111,0,0,.89444],8768:[.19444,.69444,0,0,.31944],8771:[.00222,.50222,0,0,.89444],8773:[.027,.638,0,0,.894],8776:[.02444,.52444,0,0,.89444],8781:[.00222,.50222,0,0,.89444],8801:[.00222,.50222,0,0,.89444],8804:[.19667,.69667,0,0,.89444],8805:[.19667,.69667,0,0,.89444],8810:[.08556,.58556,0,0,1.14999],8811:[.08556,.58556,0,0,1.14999],8826:[.08556,.58556,0,0,.89444],8827:[.08556,.58556,0,0,.89444],8834:[.08556,.58556,0,0,.89444],8835:[.08556,.58556,0,0,.89444],8838:[.19667,.69667,0,0,.89444],8839:[.19667,.69667,0,0,.89444],8846:[0,.55556,0,0,.76666],8849:[.19667,.69667,0,0,.89444],8850:[.19667,.69667,0,0,.89444],8851:[0,.55556,0,0,.76666],8852:[0,.55556,0,0,.76666],8853:[.13333,.63333,0,0,.89444],8854:[.13333,.63333,0,0,.89444],8855:[.13333,.63333,0,0,.89444],8856:[.13333,.63333,0,0,.89444],8857:[.13333,.63333,0,0,.89444],8866:[0,.69444,0,0,.70277],8867:[0,.69444,0,0,.70277],8868:[0,.69444,0,0,.89444],8869:[0,.69444,0,0,.89444],8900:[-.02639,.47361,0,0,.575],8901:[-.02639,.47361,0,0,.31944],8902:[-.02778,.47222,0,0,.575],8968:[.25,.75,0,0,.51111],8969:[.25,.75,0,0,.51111],8970:[.25,.75,0,0,.51111],8971:[.25,.75,0,0,.51111],8994:[-.13889,.36111,0,0,1.14999],8995:[-.13889,.36111,0,0,1.14999],9651:[.19444,.69444,0,0,1.02222],9657:[-.02778,.47222,0,0,.575],9661:[.19444,.69444,0,0,1.02222],9667:[-.02778,.47222,0,0,.575],9711:[.19444,.69444,0,0,1.14999],9824:[.12963,.69444,0,0,.89444],9825:[.12963,.69444,0,0,.89444],9826:[.12963,.69444,0,0,.89444],9827:[.12963,.69444,0,0,.89444],9837:[0,.75,0,0,.44722],9838:[.19444,.69444,0,0,.44722],9839:[.19444,.69444,0,0,.44722],10216:[.25,.75,0,0,.44722],10217:[.25,.75,0,0,.44722],10815:[0,.68611,0,0,.9],10927:[.19667,.69667,0,0,.89444],10928:[.19667,.69667,0,0,.89444],57376:[.19444,.69444,0,0,0]},"Main-BoldItalic":{32:[0,0,0,0,.25],33:[0,.69444,.11417,0,.38611],34:[0,.69444,.07939,0,.62055],35:[.19444,.69444,.06833,0,.94444],37:[.05556,.75,.12861,0,.94444],38:[0,.69444,.08528,0,.88555],39:[0,.69444,.12945,0,.35555],40:[.25,.75,.15806,0,.47333],41:[.25,.75,.03306,0,.47333],42:[0,.75,.14333,0,.59111],43:[.10333,.60333,.03306,0,.88555],44:[.19444,.14722,0,0,.35555],45:[0,.44444,.02611,0,.41444],46:[0,.14722,0,0,.35555],47:[.25,.75,.15806,0,.59111],48:[0,.64444,.13167,0,.59111],49:[0,.64444,.13167,0,.59111],50:[0,.64444,.13167,0,.59111],51:[0,.64444,.13167,0,.59111],52:[.19444,.64444,.13167,0,.59111],53:[0,.64444,.13167,0,.59111],54:[0,.64444,.13167,0,.59111],55:[.19444,.64444,.13167,0,.59111],56:[0,.64444,.13167,0,.59111],57:[0,.64444,.13167,0,.59111],58:[0,.44444,.06695,0,.35555],59:[.19444,.44444,.06695,0,.35555],61:[-.10889,.39111,.06833,0,.88555],63:[0,.69444,.11472,0,.59111],64:[0,.69444,.09208,0,.88555],65:[0,.68611,0,0,.86555],66:[0,.68611,.0992,0,.81666],67:[0,.68611,.14208,0,.82666],68:[0,.68611,.09062,0,.87555],69:[0,.68611,.11431,0,.75666],70:[0,.68611,.12903,0,.72722],71:[0,.68611,.07347,0,.89527],72:[0,.68611,.17208,0,.8961],73:[0,.68611,.15681,0,.47166],74:[0,.68611,.145,0,.61055],75:[0,.68611,.14208,0,.89499],76:[0,.68611,0,0,.69777],77:[0,.68611,.17208,0,1.07277],78:[0,.68611,.17208,0,.8961],79:[0,.68611,.09062,0,.85499],80:[0,.68611,.0992,0,.78721],81:[.19444,.68611,.09062,0,.85499],82:[0,.68611,.02559,0,.85944],83:[0,.68611,.11264,0,.64999],84:[0,.68611,.12903,0,.7961],85:[0,.68611,.17208,0,.88083],86:[0,.68611,.18625,0,.86555],87:[0,.68611,.18625,0,1.15999],88:[0,.68611,.15681,0,.86555],89:[0,.68611,.19803,0,.86555],90:[0,.68611,.14208,0,.70888],91:[.25,.75,.1875,0,.35611],93:[.25,.75,.09972,0,.35611],94:[0,.69444,.06709,0,.59111],95:[.31,.13444,.09811,0,.59111],97:[0,.44444,.09426,0,.59111],98:[0,.69444,.07861,0,.53222],99:[0,.44444,.05222,0,.53222],100:[0,.69444,.10861,0,.59111],101:[0,.44444,.085,0,.53222],102:[.19444,.69444,.21778,0,.4],103:[.19444,.44444,.105,0,.53222],104:[0,.69444,.09426,0,.59111],105:[0,.69326,.11387,0,.35555],106:[.19444,.69326,.1672,0,.35555],107:[0,.69444,.11111,0,.53222],108:[0,.69444,.10861,0,.29666],109:[0,.44444,.09426,0,.94444],110:[0,.44444,.09426,0,.64999],111:[0,.44444,.07861,0,.59111],112:[.19444,.44444,.07861,0,.59111],113:[.19444,.44444,.105,0,.53222],114:[0,.44444,.11111,0,.50167],115:[0,.44444,.08167,0,.48694],116:[0,.63492,.09639,0,.385],117:[0,.44444,.09426,0,.62055],118:[0,.44444,.11111,0,.53222],119:[0,.44444,.11111,0,.76777],120:[0,.44444,.12583,0,.56055],121:[.19444,.44444,.105,0,.56166],122:[0,.44444,.13889,0,.49055],126:[.35,.34444,.11472,0,.59111],160:[0,0,0,0,.25],168:[0,.69444,.11473,0,.59111],176:[0,.69444,0,0,.94888],184:[.17014,0,0,0,.53222],198:[0,.68611,.11431,0,1.02277],216:[.04861,.73472,.09062,0,.88555],223:[.19444,.69444,.09736,0,.665],230:[0,.44444,.085,0,.82666],248:[.09722,.54167,.09458,0,.59111],305:[0,.44444,.09426,0,.35555],338:[0,.68611,.11431,0,1.14054],339:[0,.44444,.085,0,.82666],567:[.19444,.44444,.04611,0,.385],710:[0,.69444,.06709,0,.59111],711:[0,.63194,.08271,0,.59111],713:[0,.59444,.10444,0,.59111],714:[0,.69444,.08528,0,.59111],715:[0,.69444,0,0,.59111],728:[0,.69444,.10333,0,.59111],729:[0,.69444,.12945,0,.35555],730:[0,.69444,0,0,.94888],732:[0,.69444,.11472,0,.59111],733:[0,.69444,.11472,0,.59111],915:[0,.68611,.12903,0,.69777],916:[0,.68611,0,0,.94444],920:[0,.68611,.09062,0,.88555],923:[0,.68611,0,0,.80666],926:[0,.68611,.15092,0,.76777],928:[0,.68611,.17208,0,.8961],931:[0,.68611,.11431,0,.82666],933:[0,.68611,.10778,0,.88555],934:[0,.68611,.05632,0,.82666],936:[0,.68611,.10778,0,.88555],937:[0,.68611,.0992,0,.82666],8211:[0,.44444,.09811,0,.59111],8212:[0,.44444,.09811,0,1.18221],8216:[0,.69444,.12945,0,.35555],8217:[0,.69444,.12945,0,.35555],8220:[0,.69444,.16772,0,.62055],8221:[0,.69444,.07939,0,.62055]},"Main-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.12417,0,.30667],34:[0,.69444,.06961,0,.51444],35:[.19444,.69444,.06616,0,.81777],37:[.05556,.75,.13639,0,.81777],38:[0,.69444,.09694,0,.76666],39:[0,.69444,.12417,0,.30667],40:[.25,.75,.16194,0,.40889],41:[.25,.75,.03694,0,.40889],42:[0,.75,.14917,0,.51111],43:[.05667,.56167,.03694,0,.76666],44:[.19444,.10556,0,0,.30667],45:[0,.43056,.02826,0,.35778],46:[0,.10556,0,0,.30667],47:[.25,.75,.16194,0,.51111],48:[0,.64444,.13556,0,.51111],49:[0,.64444,.13556,0,.51111],50:[0,.64444,.13556,0,.51111],51:[0,.64444,.13556,0,.51111],52:[.19444,.64444,.13556,0,.51111],53:[0,.64444,.13556,0,.51111],54:[0,.64444,.13556,0,.51111],55:[.19444,.64444,.13556,0,.51111],56:[0,.64444,.13556,0,.51111],57:[0,.64444,.13556,0,.51111],58:[0,.43056,.0582,0,.30667],59:[.19444,.43056,.0582,0,.30667],61:[-.13313,.36687,.06616,0,.76666],63:[0,.69444,.1225,0,.51111],64:[0,.69444,.09597,0,.76666],65:[0,.68333,0,0,.74333],66:[0,.68333,.10257,0,.70389],67:[0,.68333,.14528,0,.71555],68:[0,.68333,.09403,0,.755],69:[0,.68333,.12028,0,.67833],70:[0,.68333,.13305,0,.65277],71:[0,.68333,.08722,0,.77361],72:[0,.68333,.16389,0,.74333],73:[0,.68333,.15806,0,.38555],74:[0,.68333,.14028,0,.525],75:[0,.68333,.14528,0,.76888],76:[0,.68333,0,0,.62722],77:[0,.68333,.16389,0,.89666],78:[0,.68333,.16389,0,.74333],79:[0,.68333,.09403,0,.76666],80:[0,.68333,.10257,0,.67833],81:[.19444,.68333,.09403,0,.76666],82:[0,.68333,.03868,0,.72944],83:[0,.68333,.11972,0,.56222],84:[0,.68333,.13305,0,.71555],85:[0,.68333,.16389,0,.74333],86:[0,.68333,.18361,0,.74333],87:[0,.68333,.18361,0,.99888],88:[0,.68333,.15806,0,.74333],89:[0,.68333,.19383,0,.74333],90:[0,.68333,.14528,0,.61333],91:[.25,.75,.1875,0,.30667],93:[.25,.75,.10528,0,.30667],94:[0,.69444,.06646,0,.51111],95:[.31,.12056,.09208,0,.51111],97:[0,.43056,.07671,0,.51111],98:[0,.69444,.06312,0,.46],99:[0,.43056,.05653,0,.46],100:[0,.69444,.10333,0,.51111],101:[0,.43056,.07514,0,.46],102:[.19444,.69444,.21194,0,.30667],103:[.19444,.43056,.08847,0,.46],104:[0,.69444,.07671,0,.51111],105:[0,.65536,.1019,0,.30667],106:[.19444,.65536,.14467,0,.30667],107:[0,.69444,.10764,0,.46],108:[0,.69444,.10333,0,.25555],109:[0,.43056,.07671,0,.81777],110:[0,.43056,.07671,0,.56222],111:[0,.43056,.06312,0,.51111],112:[.19444,.43056,.06312,0,.51111],113:[.19444,.43056,.08847,0,.46],114:[0,.43056,.10764,0,.42166],115:[0,.43056,.08208,0,.40889],116:[0,.61508,.09486,0,.33222],117:[0,.43056,.07671,0,.53666],118:[0,.43056,.10764,0,.46],119:[0,.43056,.10764,0,.66444],120:[0,.43056,.12042,0,.46389],121:[.19444,.43056,.08847,0,.48555],122:[0,.43056,.12292,0,.40889],126:[.35,.31786,.11585,0,.51111],160:[0,0,0,0,.25],168:[0,.66786,.10474,0,.51111],176:[0,.69444,0,0,.83129],184:[.17014,0,0,0,.46],198:[0,.68333,.12028,0,.88277],216:[.04861,.73194,.09403,0,.76666],223:[.19444,.69444,.10514,0,.53666],230:[0,.43056,.07514,0,.71555],248:[.09722,.52778,.09194,0,.51111],338:[0,.68333,.12028,0,.98499],339:[0,.43056,.07514,0,.71555],710:[0,.69444,.06646,0,.51111],711:[0,.62847,.08295,0,.51111],713:[0,.56167,.10333,0,.51111],714:[0,.69444,.09694,0,.51111],715:[0,.69444,0,0,.51111],728:[0,.69444,.10806,0,.51111],729:[0,.66786,.11752,0,.30667],730:[0,.69444,0,0,.83129],732:[0,.66786,.11585,0,.51111],733:[0,.69444,.1225,0,.51111],915:[0,.68333,.13305,0,.62722],916:[0,.68333,0,0,.81777],920:[0,.68333,.09403,0,.76666],923:[0,.68333,0,0,.69222],926:[0,.68333,.15294,0,.66444],928:[0,.68333,.16389,0,.74333],931:[0,.68333,.12028,0,.71555],933:[0,.68333,.11111,0,.76666],934:[0,.68333,.05986,0,.71555],936:[0,.68333,.11111,0,.76666],937:[0,.68333,.10257,0,.71555],8211:[0,.43056,.09208,0,.51111],8212:[0,.43056,.09208,0,1.02222],8216:[0,.69444,.12417,0,.30667],8217:[0,.69444,.12417,0,.30667],8220:[0,.69444,.1685,0,.51444],8221:[0,.69444,.06961,0,.51444],8463:[0,.68889,0,0,.54028]},"Main-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.27778],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.77778],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.19444,.10556,0,0,.27778],45:[0,.43056,0,0,.33333],46:[0,.10556,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.64444,0,0,.5],49:[0,.64444,0,0,.5],50:[0,.64444,0,0,.5],51:[0,.64444,0,0,.5],52:[0,.64444,0,0,.5],53:[0,.64444,0,0,.5],54:[0,.64444,0,0,.5],55:[0,.64444,0,0,.5],56:[0,.64444,0,0,.5],57:[0,.64444,0,0,.5],58:[0,.43056,0,0,.27778],59:[.19444,.43056,0,0,.27778],60:[.0391,.5391,0,0,.77778],61:[-.13313,.36687,0,0,.77778],62:[.0391,.5391,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.77778],65:[0,.68333,0,0,.75],66:[0,.68333,0,0,.70834],67:[0,.68333,0,0,.72222],68:[0,.68333,0,0,.76389],69:[0,.68333,0,0,.68056],70:[0,.68333,0,0,.65278],71:[0,.68333,0,0,.78472],72:[0,.68333,0,0,.75],73:[0,.68333,0,0,.36111],74:[0,.68333,0,0,.51389],75:[0,.68333,0,0,.77778],76:[0,.68333,0,0,.625],77:[0,.68333,0,0,.91667],78:[0,.68333,0,0,.75],79:[0,.68333,0,0,.77778],80:[0,.68333,0,0,.68056],81:[.19444,.68333,0,0,.77778],82:[0,.68333,0,0,.73611],83:[0,.68333,0,0,.55556],84:[0,.68333,0,0,.72222],85:[0,.68333,0,0,.75],86:[0,.68333,.01389,0,.75],87:[0,.68333,.01389,0,1.02778],88:[0,.68333,0,0,.75],89:[0,.68333,.025,0,.75],90:[0,.68333,0,0,.61111],91:[.25,.75,0,0,.27778],92:[.25,.75,0,0,.5],93:[.25,.75,0,0,.27778],94:[0,.69444,0,0,.5],95:[.31,.12056,.02778,0,.5],97:[0,.43056,0,0,.5],98:[0,.69444,0,0,.55556],99:[0,.43056,0,0,.44445],100:[0,.69444,0,0,.55556],101:[0,.43056,0,0,.44445],102:[0,.69444,.07778,0,.30556],103:[.19444,.43056,.01389,0,.5],104:[0,.69444,0,0,.55556],105:[0,.66786,0,0,.27778],106:[.19444,.66786,0,0,.30556],107:[0,.69444,0,0,.52778],108:[0,.69444,0,0,.27778],109:[0,.43056,0,0,.83334],110:[0,.43056,0,0,.55556],111:[0,.43056,0,0,.5],112:[.19444,.43056,0,0,.55556],113:[.19444,.43056,0,0,.52778],114:[0,.43056,0,0,.39167],115:[0,.43056,0,0,.39445],116:[0,.61508,0,0,.38889],117:[0,.43056,0,0,.55556],118:[0,.43056,.01389,0,.52778],119:[0,.43056,.01389,0,.72222],120:[0,.43056,0,0,.52778],121:[.19444,.43056,.01389,0,.52778],122:[0,.43056,0,0,.44445],123:[.25,.75,0,0,.5],124:[.25,.75,0,0,.27778],125:[.25,.75,0,0,.5],126:[.35,.31786,0,0,.5],160:[0,0,0,0,.25],163:[0,.69444,0,0,.76909],167:[.19444,.69444,0,0,.44445],168:[0,.66786,0,0,.5],172:[0,.43056,0,0,.66667],176:[0,.69444,0,0,.75],177:[.08333,.58333,0,0,.77778],182:[.19444,.69444,0,0,.61111],184:[.17014,0,0,0,.44445],198:[0,.68333,0,0,.90278],215:[.08333,.58333,0,0,.77778],216:[.04861,.73194,0,0,.77778],223:[0,.69444,0,0,.5],230:[0,.43056,0,0,.72222],247:[.08333,.58333,0,0,.77778],248:[.09722,.52778,0,0,.5],305:[0,.43056,0,0,.27778],338:[0,.68333,0,0,1.01389],339:[0,.43056,0,0,.77778],567:[.19444,.43056,0,0,.30556],710:[0,.69444,0,0,.5],711:[0,.62847,0,0,.5],713:[0,.56778,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.66786,0,0,.27778],730:[0,.69444,0,0,.75],732:[0,.66786,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.68333,0,0,.625],916:[0,.68333,0,0,.83334],920:[0,.68333,0,0,.77778],923:[0,.68333,0,0,.69445],926:[0,.68333,0,0,.66667],928:[0,.68333,0,0,.75],931:[0,.68333,0,0,.72222],933:[0,.68333,0,0,.77778],934:[0,.68333,0,0,.72222],936:[0,.68333,0,0,.77778],937:[0,.68333,0,0,.72222],8211:[0,.43056,.02778,0,.5],8212:[0,.43056,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5],8224:[.19444,.69444,0,0,.44445],8225:[.19444,.69444,0,0,.44445],8230:[0,.123,0,0,1.172],8242:[0,.55556,0,0,.275],8407:[0,.71444,.15382,0,.5],8463:[0,.68889,0,0,.54028],8465:[0,.69444,0,0,.72222],8467:[0,.69444,0,.11111,.41667],8472:[.19444,.43056,0,.11111,.63646],8476:[0,.69444,0,0,.72222],8501:[0,.69444,0,0,.61111],8592:[-.13313,.36687,0,0,1],8593:[.19444,.69444,0,0,.5],8594:[-.13313,.36687,0,0,1],8595:[.19444,.69444,0,0,.5],8596:[-.13313,.36687,0,0,1],8597:[.25,.75,0,0,.5],8598:[.19444,.69444,0,0,1],8599:[.19444,.69444,0,0,1],8600:[.19444,.69444,0,0,1],8601:[.19444,.69444,0,0,1],8614:[.011,.511,0,0,1],8617:[.011,.511,0,0,1.126],8618:[.011,.511,0,0,1.126],8636:[-.13313,.36687,0,0,1],8637:[-.13313,.36687,0,0,1],8640:[-.13313,.36687,0,0,1],8641:[-.13313,.36687,0,0,1],8652:[.011,.671,0,0,1],8656:[-.13313,.36687,0,0,1],8657:[.19444,.69444,0,0,.61111],8658:[-.13313,.36687,0,0,1],8659:[.19444,.69444,0,0,.61111],8660:[-.13313,.36687,0,0,1],8661:[.25,.75,0,0,.61111],8704:[0,.69444,0,0,.55556],8706:[0,.69444,.05556,.08334,.5309],8707:[0,.69444,0,0,.55556],8709:[.05556,.75,0,0,.5],8711:[0,.68333,0,0,.83334],8712:[.0391,.5391,0,0,.66667],8715:[.0391,.5391,0,0,.66667],8722:[.08333,.58333,0,0,.77778],8723:[.08333,.58333,0,0,.77778],8725:[.25,.75,0,0,.5],8726:[.25,.75,0,0,.5],8727:[-.03472,.46528,0,0,.5],8728:[-.05555,.44445,0,0,.5],8729:[-.05555,.44445,0,0,.5],8730:[.2,.8,0,0,.83334],8733:[0,.43056,0,0,.77778],8734:[0,.43056,0,0,1],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.27778],8741:[.25,.75,0,0,.5],8743:[0,.55556,0,0,.66667],8744:[0,.55556,0,0,.66667],8745:[0,.55556,0,0,.66667],8746:[0,.55556,0,0,.66667],8747:[.19444,.69444,.11111,0,.41667],8764:[-.13313,.36687,0,0,.77778],8768:[.19444,.69444,0,0,.27778],8771:[-.03625,.46375,0,0,.77778],8773:[-.022,.589,0,0,.778],8776:[-.01688,.48312,0,0,.77778],8781:[-.03625,.46375,0,0,.77778],8784:[-.133,.673,0,0,.778],8801:[-.03625,.46375,0,0,.77778],8804:[.13597,.63597,0,0,.77778],8805:[.13597,.63597,0,0,.77778],8810:[.0391,.5391,0,0,1],8811:[.0391,.5391,0,0,1],8826:[.0391,.5391,0,0,.77778],8827:[.0391,.5391,0,0,.77778],8834:[.0391,.5391,0,0,.77778],8835:[.0391,.5391,0,0,.77778],8838:[.13597,.63597,0,0,.77778],8839:[.13597,.63597,0,0,.77778],8846:[0,.55556,0,0,.66667],8849:[.13597,.63597,0,0,.77778],8850:[.13597,.63597,0,0,.77778],8851:[0,.55556,0,0,.66667],8852:[0,.55556,0,0,.66667],8853:[.08333,.58333,0,0,.77778],8854:[.08333,.58333,0,0,.77778],8855:[.08333,.58333,0,0,.77778],8856:[.08333,.58333,0,0,.77778],8857:[.08333,.58333,0,0,.77778],8866:[0,.69444,0,0,.61111],8867:[0,.69444,0,0,.61111],8868:[0,.69444,0,0,.77778],8869:[0,.69444,0,0,.77778],8872:[.249,.75,0,0,.867],8900:[-.05555,.44445,0,0,.5],8901:[-.05555,.44445,0,0,.27778],8902:[-.03472,.46528,0,0,.5],8904:[.005,.505,0,0,.9],8942:[.03,.903,0,0,.278],8943:[-.19,.313,0,0,1.172],8945:[-.1,.823,0,0,1.282],8968:[.25,.75,0,0,.44445],8969:[.25,.75,0,0,.44445],8970:[.25,.75,0,0,.44445],8971:[.25,.75,0,0,.44445],8994:[-.14236,.35764,0,0,1],8995:[-.14236,.35764,0,0,1],9136:[.244,.744,0,0,.412],9137:[.244,.745,0,0,.412],9651:[.19444,.69444,0,0,.88889],9657:[-.03472,.46528,0,0,.5],9661:[.19444,.69444,0,0,.88889],9667:[-.03472,.46528,0,0,.5],9711:[.19444,.69444,0,0,1],9824:[.12963,.69444,0,0,.77778],9825:[.12963,.69444,0,0,.77778],9826:[.12963,.69444,0,0,.77778],9827:[.12963,.69444,0,0,.77778],9837:[0,.75,0,0,.38889],9838:[.19444,.69444,0,0,.38889],9839:[.19444,.69444,0,0,.38889],10216:[.25,.75,0,0,.38889],10217:[.25,.75,0,0,.38889],10222:[.244,.744,0,0,.412],10223:[.244,.745,0,0,.412],10229:[.011,.511,0,0,1.609],10230:[.011,.511,0,0,1.638],10231:[.011,.511,0,0,1.859],10232:[.024,.525,0,0,1.609],10233:[.024,.525,0,0,1.638],10234:[.024,.525,0,0,1.858],10236:[.011,.511,0,0,1.638],10815:[0,.68333,0,0,.75],10927:[.13597,.63597,0,0,.77778],10928:[.13597,.63597,0,0,.77778],57376:[.19444,.69444,0,0,0]},"Math-BoldItalic":{32:[0,0,0,0,.25],48:[0,.44444,0,0,.575],49:[0,.44444,0,0,.575],50:[0,.44444,0,0,.575],51:[.19444,.44444,0,0,.575],52:[.19444,.44444,0,0,.575],53:[.19444,.44444,0,0,.575],54:[0,.64444,0,0,.575],55:[.19444,.44444,0,0,.575],56:[0,.64444,0,0,.575],57:[.19444,.44444,0,0,.575],65:[0,.68611,0,0,.86944],66:[0,.68611,.04835,0,.8664],67:[0,.68611,.06979,0,.81694],68:[0,.68611,.03194,0,.93812],69:[0,.68611,.05451,0,.81007],70:[0,.68611,.15972,0,.68889],71:[0,.68611,0,0,.88673],72:[0,.68611,.08229,0,.98229],73:[0,.68611,.07778,0,.51111],74:[0,.68611,.10069,0,.63125],75:[0,.68611,.06979,0,.97118],76:[0,.68611,0,0,.75555],77:[0,.68611,.11424,0,1.14201],78:[0,.68611,.11424,0,.95034],79:[0,.68611,.03194,0,.83666],80:[0,.68611,.15972,0,.72309],81:[.19444,.68611,0,0,.86861],82:[0,.68611,.00421,0,.87235],83:[0,.68611,.05382,0,.69271],84:[0,.68611,.15972,0,.63663],85:[0,.68611,.11424,0,.80027],86:[0,.68611,.25555,0,.67778],87:[0,.68611,.15972,0,1.09305],88:[0,.68611,.07778,0,.94722],89:[0,.68611,.25555,0,.67458],90:[0,.68611,.06979,0,.77257],97:[0,.44444,0,0,.63287],98:[0,.69444,0,0,.52083],99:[0,.44444,0,0,.51342],100:[0,.69444,0,0,.60972],101:[0,.44444,0,0,.55361],102:[.19444,.69444,.11042,0,.56806],103:[.19444,.44444,.03704,0,.5449],104:[0,.69444,0,0,.66759],105:[0,.69326,0,0,.4048],106:[.19444,.69326,.0622,0,.47083],107:[0,.69444,.01852,0,.6037],108:[0,.69444,.0088,0,.34815],109:[0,.44444,0,0,1.0324],110:[0,.44444,0,0,.71296],111:[0,.44444,0,0,.58472],112:[.19444,.44444,0,0,.60092],113:[.19444,.44444,.03704,0,.54213],114:[0,.44444,.03194,0,.5287],115:[0,.44444,0,0,.53125],116:[0,.63492,0,0,.41528],117:[0,.44444,0,0,.68102],118:[0,.44444,.03704,0,.56666],119:[0,.44444,.02778,0,.83148],120:[0,.44444,0,0,.65903],121:[.19444,.44444,.03704,0,.59028],122:[0,.44444,.04213,0,.55509],160:[0,0,0,0,.25],915:[0,.68611,.15972,0,.65694],916:[0,.68611,0,0,.95833],920:[0,.68611,.03194,0,.86722],923:[0,.68611,0,0,.80555],926:[0,.68611,.07458,0,.84125],928:[0,.68611,.08229,0,.98229],931:[0,.68611,.05451,0,.88507],933:[0,.68611,.15972,0,.67083],934:[0,.68611,0,0,.76666],936:[0,.68611,.11653,0,.71402],937:[0,.68611,.04835,0,.8789],945:[0,.44444,0,0,.76064],946:[.19444,.69444,.03403,0,.65972],947:[.19444,.44444,.06389,0,.59003],948:[0,.69444,.03819,0,.52222],949:[0,.44444,0,0,.52882],950:[.19444,.69444,.06215,0,.50833],951:[.19444,.44444,.03704,0,.6],952:[0,.69444,.03194,0,.5618],953:[0,.44444,0,0,.41204],954:[0,.44444,0,0,.66759],955:[0,.69444,0,0,.67083],956:[.19444,.44444,0,0,.70787],957:[0,.44444,.06898,0,.57685],958:[.19444,.69444,.03021,0,.50833],959:[0,.44444,0,0,.58472],960:[0,.44444,.03704,0,.68241],961:[.19444,.44444,0,0,.6118],962:[.09722,.44444,.07917,0,.42361],963:[0,.44444,.03704,0,.68588],964:[0,.44444,.13472,0,.52083],965:[0,.44444,.03704,0,.63055],966:[.19444,.44444,0,0,.74722],967:[.19444,.44444,0,0,.71805],968:[.19444,.69444,.03704,0,.75833],969:[0,.44444,.03704,0,.71782],977:[0,.69444,0,0,.69155],981:[.19444,.69444,0,0,.7125],982:[0,.44444,.03194,0,.975],1009:[.19444,.44444,0,0,.6118],1013:[0,.44444,0,0,.48333],57649:[0,.44444,0,0,.39352],57911:[.19444,.44444,0,0,.43889]},"Math-Italic":{32:[0,0,0,0,.25],48:[0,.43056,0,0,.5],49:[0,.43056,0,0,.5],50:[0,.43056,0,0,.5],51:[.19444,.43056,0,0,.5],52:[.19444,.43056,0,0,.5],53:[.19444,.43056,0,0,.5],54:[0,.64444,0,0,.5],55:[.19444,.43056,0,0,.5],56:[0,.64444,0,0,.5],57:[.19444,.43056,0,0,.5],65:[0,.68333,0,.13889,.75],66:[0,.68333,.05017,.08334,.75851],67:[0,.68333,.07153,.08334,.71472],68:[0,.68333,.02778,.05556,.82792],69:[0,.68333,.05764,.08334,.7382],70:[0,.68333,.13889,.08334,.64306],71:[0,.68333,0,.08334,.78625],72:[0,.68333,.08125,.05556,.83125],73:[0,.68333,.07847,.11111,.43958],74:[0,.68333,.09618,.16667,.55451],75:[0,.68333,.07153,.05556,.84931],76:[0,.68333,0,.02778,.68056],77:[0,.68333,.10903,.08334,.97014],78:[0,.68333,.10903,.08334,.80347],79:[0,.68333,.02778,.08334,.76278],80:[0,.68333,.13889,.08334,.64201],81:[.19444,.68333,0,.08334,.79056],82:[0,.68333,.00773,.08334,.75929],83:[0,.68333,.05764,.08334,.6132],84:[0,.68333,.13889,.08334,.58438],85:[0,.68333,.10903,.02778,.68278],86:[0,.68333,.22222,0,.58333],87:[0,.68333,.13889,0,.94445],88:[0,.68333,.07847,.08334,.82847],89:[0,.68333,.22222,0,.58056],90:[0,.68333,.07153,.08334,.68264],97:[0,.43056,0,0,.52859],98:[0,.69444,0,0,.42917],99:[0,.43056,0,.05556,.43276],100:[0,.69444,0,.16667,.52049],101:[0,.43056,0,.05556,.46563],102:[.19444,.69444,.10764,.16667,.48959],103:[.19444,.43056,.03588,.02778,.47697],104:[0,.69444,0,0,.57616],105:[0,.65952,0,0,.34451],106:[.19444,.65952,.05724,0,.41181],107:[0,.69444,.03148,0,.5206],108:[0,.69444,.01968,.08334,.29838],109:[0,.43056,0,0,.87801],110:[0,.43056,0,0,.60023],111:[0,.43056,0,.05556,.48472],112:[.19444,.43056,0,.08334,.50313],113:[.19444,.43056,.03588,.08334,.44641],114:[0,.43056,.02778,.05556,.45116],115:[0,.43056,0,.05556,.46875],116:[0,.61508,0,.08334,.36111],117:[0,.43056,0,.02778,.57246],118:[0,.43056,.03588,.02778,.48472],119:[0,.43056,.02691,.08334,.71592],120:[0,.43056,0,.02778,.57153],121:[.19444,.43056,.03588,.05556,.49028],122:[0,.43056,.04398,.05556,.46505],160:[0,0,0,0,.25],915:[0,.68333,.13889,.08334,.61528],916:[0,.68333,0,.16667,.83334],920:[0,.68333,.02778,.08334,.76278],923:[0,.68333,0,.16667,.69445],926:[0,.68333,.07569,.08334,.74236],928:[0,.68333,.08125,.05556,.83125],931:[0,.68333,.05764,.08334,.77986],933:[0,.68333,.13889,.05556,.58333],934:[0,.68333,0,.08334,.66667],936:[0,.68333,.11,.05556,.61222],937:[0,.68333,.05017,.08334,.7724],945:[0,.43056,.0037,.02778,.6397],946:[.19444,.69444,.05278,.08334,.56563],947:[.19444,.43056,.05556,0,.51773],948:[0,.69444,.03785,.05556,.44444],949:[0,.43056,0,.08334,.46632],950:[.19444,.69444,.07378,.08334,.4375],951:[.19444,.43056,.03588,.05556,.49653],952:[0,.69444,.02778,.08334,.46944],953:[0,.43056,0,.05556,.35394],954:[0,.43056,0,0,.57616],955:[0,.69444,0,0,.58334],956:[.19444,.43056,0,.02778,.60255],957:[0,.43056,.06366,.02778,.49398],958:[.19444,.69444,.04601,.11111,.4375],959:[0,.43056,0,.05556,.48472],960:[0,.43056,.03588,0,.57003],961:[.19444,.43056,0,.08334,.51702],962:[.09722,.43056,.07986,.08334,.36285],963:[0,.43056,.03588,0,.57141],964:[0,.43056,.1132,.02778,.43715],965:[0,.43056,.03588,.02778,.54028],966:[.19444,.43056,0,.08334,.65417],967:[.19444,.43056,0,.05556,.62569],968:[.19444,.69444,.03588,.11111,.65139],969:[0,.43056,.03588,0,.62245],977:[0,.69444,0,.08334,.59144],981:[.19444,.69444,0,.08334,.59583],982:[0,.43056,.02778,0,.82813],1009:[.19444,.43056,0,.08334,.51702],1013:[0,.43056,0,.05556,.4059],57649:[0,.43056,0,.02778,.32246],57911:[.19444,.43056,0,.08334,.38403]},"SansSerif-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.36667],34:[0,.69444,0,0,.55834],35:[.19444,.69444,0,0,.91667],36:[.05556,.75,0,0,.55],37:[.05556,.75,0,0,1.02912],38:[0,.69444,0,0,.83056],39:[0,.69444,0,0,.30556],40:[.25,.75,0,0,.42778],41:[.25,.75,0,0,.42778],42:[0,.75,0,0,.55],43:[.11667,.61667,0,0,.85556],44:[.10556,.13056,0,0,.30556],45:[0,.45833,0,0,.36667],46:[0,.13056,0,0,.30556],47:[.25,.75,0,0,.55],48:[0,.69444,0,0,.55],49:[0,.69444,0,0,.55],50:[0,.69444,0,0,.55],51:[0,.69444,0,0,.55],52:[0,.69444,0,0,.55],53:[0,.69444,0,0,.55],54:[0,.69444,0,0,.55],55:[0,.69444,0,0,.55],56:[0,.69444,0,0,.55],57:[0,.69444,0,0,.55],58:[0,.45833,0,0,.30556],59:[.10556,.45833,0,0,.30556],61:[-.09375,.40625,0,0,.85556],63:[0,.69444,0,0,.51945],64:[0,.69444,0,0,.73334],65:[0,.69444,0,0,.73334],66:[0,.69444,0,0,.73334],67:[0,.69444,0,0,.70278],68:[0,.69444,0,0,.79445],69:[0,.69444,0,0,.64167],70:[0,.69444,0,0,.61111],71:[0,.69444,0,0,.73334],72:[0,.69444,0,0,.79445],73:[0,.69444,0,0,.33056],74:[0,.69444,0,0,.51945],75:[0,.69444,0,0,.76389],76:[0,.69444,0,0,.58056],77:[0,.69444,0,0,.97778],78:[0,.69444,0,0,.79445],79:[0,.69444,0,0,.79445],80:[0,.69444,0,0,.70278],81:[.10556,.69444,0,0,.79445],82:[0,.69444,0,0,.70278],83:[0,.69444,0,0,.61111],84:[0,.69444,0,0,.73334],85:[0,.69444,0,0,.76389],86:[0,.69444,.01528,0,.73334],87:[0,.69444,.01528,0,1.03889],88:[0,.69444,0,0,.73334],89:[0,.69444,.0275,0,.73334],90:[0,.69444,0,0,.67223],91:[.25,.75,0,0,.34306],93:[.25,.75,0,0,.34306],94:[0,.69444,0,0,.55],95:[.35,.10833,.03056,0,.55],97:[0,.45833,0,0,.525],98:[0,.69444,0,0,.56111],99:[0,.45833,0,0,.48889],100:[0,.69444,0,0,.56111],101:[0,.45833,0,0,.51111],102:[0,.69444,.07639,0,.33611],103:[.19444,.45833,.01528,0,.55],104:[0,.69444,0,0,.56111],105:[0,.69444,0,0,.25556],106:[.19444,.69444,0,0,.28611],107:[0,.69444,0,0,.53056],108:[0,.69444,0,0,.25556],109:[0,.45833,0,0,.86667],110:[0,.45833,0,0,.56111],111:[0,.45833,0,0,.55],112:[.19444,.45833,0,0,.56111],113:[.19444,.45833,0,0,.56111],114:[0,.45833,.01528,0,.37222],115:[0,.45833,0,0,.42167],116:[0,.58929,0,0,.40417],117:[0,.45833,0,0,.56111],118:[0,.45833,.01528,0,.5],119:[0,.45833,.01528,0,.74445],120:[0,.45833,0,0,.5],121:[.19444,.45833,.01528,0,.5],122:[0,.45833,0,0,.47639],126:[.35,.34444,0,0,.55],160:[0,0,0,0,.25],168:[0,.69444,0,0,.55],176:[0,.69444,0,0,.73334],180:[0,.69444,0,0,.55],184:[.17014,0,0,0,.48889],305:[0,.45833,0,0,.25556],567:[.19444,.45833,0,0,.28611],710:[0,.69444,0,0,.55],711:[0,.63542,0,0,.55],713:[0,.63778,0,0,.55],728:[0,.69444,0,0,.55],729:[0,.69444,0,0,.30556],730:[0,.69444,0,0,.73334],732:[0,.69444,0,0,.55],733:[0,.69444,0,0,.55],915:[0,.69444,0,0,.58056],916:[0,.69444,0,0,.91667],920:[0,.69444,0,0,.85556],923:[0,.69444,0,0,.67223],926:[0,.69444,0,0,.73334],928:[0,.69444,0,0,.79445],931:[0,.69444,0,0,.79445],933:[0,.69444,0,0,.85556],934:[0,.69444,0,0,.79445],936:[0,.69444,0,0,.85556],937:[0,.69444,0,0,.79445],8211:[0,.45833,.03056,0,.55],8212:[0,.45833,.03056,0,1.10001],8216:[0,.69444,0,0,.30556],8217:[0,.69444,0,0,.30556],8220:[0,.69444,0,0,.55834],8221:[0,.69444,0,0,.55834]},"SansSerif-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.05733,0,.31945],34:[0,.69444,.00316,0,.5],35:[.19444,.69444,.05087,0,.83334],36:[.05556,.75,.11156,0,.5],37:[.05556,.75,.03126,0,.83334],38:[0,.69444,.03058,0,.75834],39:[0,.69444,.07816,0,.27778],40:[.25,.75,.13164,0,.38889],41:[.25,.75,.02536,0,.38889],42:[0,.75,.11775,0,.5],43:[.08333,.58333,.02536,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,.01946,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,.13164,0,.5],48:[0,.65556,.11156,0,.5],49:[0,.65556,.11156,0,.5],50:[0,.65556,.11156,0,.5],51:[0,.65556,.11156,0,.5],52:[0,.65556,.11156,0,.5],53:[0,.65556,.11156,0,.5],54:[0,.65556,.11156,0,.5],55:[0,.65556,.11156,0,.5],56:[0,.65556,.11156,0,.5],57:[0,.65556,.11156,0,.5],58:[0,.44444,.02502,0,.27778],59:[.125,.44444,.02502,0,.27778],61:[-.13,.37,.05087,0,.77778],63:[0,.69444,.11809,0,.47222],64:[0,.69444,.07555,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,.08293,0,.66667],67:[0,.69444,.11983,0,.63889],68:[0,.69444,.07555,0,.72223],69:[0,.69444,.11983,0,.59722],70:[0,.69444,.13372,0,.56945],71:[0,.69444,.11983,0,.66667],72:[0,.69444,.08094,0,.70834],73:[0,.69444,.13372,0,.27778],74:[0,.69444,.08094,0,.47222],75:[0,.69444,.11983,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,.08094,0,.875],78:[0,.69444,.08094,0,.70834],79:[0,.69444,.07555,0,.73611],80:[0,.69444,.08293,0,.63889],81:[.125,.69444,.07555,0,.73611],82:[0,.69444,.08293,0,.64584],83:[0,.69444,.09205,0,.55556],84:[0,.69444,.13372,0,.68056],85:[0,.69444,.08094,0,.6875],86:[0,.69444,.1615,0,.66667],87:[0,.69444,.1615,0,.94445],88:[0,.69444,.13372,0,.66667],89:[0,.69444,.17261,0,.66667],90:[0,.69444,.11983,0,.61111],91:[.25,.75,.15942,0,.28889],93:[.25,.75,.08719,0,.28889],94:[0,.69444,.0799,0,.5],95:[.35,.09444,.08616,0,.5],97:[0,.44444,.00981,0,.48056],98:[0,.69444,.03057,0,.51667],99:[0,.44444,.08336,0,.44445],100:[0,.69444,.09483,0,.51667],101:[0,.44444,.06778,0,.44445],102:[0,.69444,.21705,0,.30556],103:[.19444,.44444,.10836,0,.5],104:[0,.69444,.01778,0,.51667],105:[0,.67937,.09718,0,.23889],106:[.19444,.67937,.09162,0,.26667],107:[0,.69444,.08336,0,.48889],108:[0,.69444,.09483,0,.23889],109:[0,.44444,.01778,0,.79445],110:[0,.44444,.01778,0,.51667],111:[0,.44444,.06613,0,.5],112:[.19444,.44444,.0389,0,.51667],113:[.19444,.44444,.04169,0,.51667],114:[0,.44444,.10836,0,.34167],115:[0,.44444,.0778,0,.38333],116:[0,.57143,.07225,0,.36111],117:[0,.44444,.04169,0,.51667],118:[0,.44444,.10836,0,.46111],119:[0,.44444,.10836,0,.68334],120:[0,.44444,.09169,0,.46111],121:[.19444,.44444,.10836,0,.46111],122:[0,.44444,.08752,0,.43472],126:[.35,.32659,.08826,0,.5],160:[0,0,0,0,.25],168:[0,.67937,.06385,0,.5],176:[0,.69444,0,0,.73752],184:[.17014,0,0,0,.44445],305:[0,.44444,.04169,0,.23889],567:[.19444,.44444,.04169,0,.26667],710:[0,.69444,.0799,0,.5],711:[0,.63194,.08432,0,.5],713:[0,.60889,.08776,0,.5],714:[0,.69444,.09205,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,.09483,0,.5],729:[0,.67937,.07774,0,.27778],730:[0,.69444,0,0,.73752],732:[0,.67659,.08826,0,.5],733:[0,.69444,.09205,0,.5],915:[0,.69444,.13372,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,.07555,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,.12816,0,.66667],928:[0,.69444,.08094,0,.70834],931:[0,.69444,.11983,0,.72222],933:[0,.69444,.09031,0,.77778],934:[0,.69444,.04603,0,.72222],936:[0,.69444,.09031,0,.77778],937:[0,.69444,.08293,0,.72222],8211:[0,.44444,.08616,0,.5],8212:[0,.44444,.08616,0,1],8216:[0,.69444,.07816,0,.27778],8217:[0,.69444,.07816,0,.27778],8220:[0,.69444,.14205,0,.5],8221:[0,.69444,.00316,0,.5]},"SansSerif-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.31945],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.75834],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,0,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.65556,0,0,.5],49:[0,.65556,0,0,.5],50:[0,.65556,0,0,.5],51:[0,.65556,0,0,.5],52:[0,.65556,0,0,.5],53:[0,.65556,0,0,.5],54:[0,.65556,0,0,.5],55:[0,.65556,0,0,.5],56:[0,.65556,0,0,.5],57:[0,.65556,0,0,.5],58:[0,.44444,0,0,.27778],59:[.125,.44444,0,0,.27778],61:[-.13,.37,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,0,0,.66667],67:[0,.69444,0,0,.63889],68:[0,.69444,0,0,.72223],69:[0,.69444,0,0,.59722],70:[0,.69444,0,0,.56945],71:[0,.69444,0,0,.66667],72:[0,.69444,0,0,.70834],73:[0,.69444,0,0,.27778],74:[0,.69444,0,0,.47222],75:[0,.69444,0,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,0,0,.875],78:[0,.69444,0,0,.70834],79:[0,.69444,0,0,.73611],80:[0,.69444,0,0,.63889],81:[.125,.69444,0,0,.73611],82:[0,.69444,0,0,.64584],83:[0,.69444,0,0,.55556],84:[0,.69444,0,0,.68056],85:[0,.69444,0,0,.6875],86:[0,.69444,.01389,0,.66667],87:[0,.69444,.01389,0,.94445],88:[0,.69444,0,0,.66667],89:[0,.69444,.025,0,.66667],90:[0,.69444,0,0,.61111],91:[.25,.75,0,0,.28889],93:[.25,.75,0,0,.28889],94:[0,.69444,0,0,.5],95:[.35,.09444,.02778,0,.5],97:[0,.44444,0,0,.48056],98:[0,.69444,0,0,.51667],99:[0,.44444,0,0,.44445],100:[0,.69444,0,0,.51667],101:[0,.44444,0,0,.44445],102:[0,.69444,.06944,0,.30556],103:[.19444,.44444,.01389,0,.5],104:[0,.69444,0,0,.51667],105:[0,.67937,0,0,.23889],106:[.19444,.67937,0,0,.26667],107:[0,.69444,0,0,.48889],108:[0,.69444,0,0,.23889],109:[0,.44444,0,0,.79445],110:[0,.44444,0,0,.51667],111:[0,.44444,0,0,.5],112:[.19444,.44444,0,0,.51667],113:[.19444,.44444,0,0,.51667],114:[0,.44444,.01389,0,.34167],115:[0,.44444,0,0,.38333],116:[0,.57143,0,0,.36111],117:[0,.44444,0,0,.51667],118:[0,.44444,.01389,0,.46111],119:[0,.44444,.01389,0,.68334],120:[0,.44444,0,0,.46111],121:[.19444,.44444,.01389,0,.46111],122:[0,.44444,0,0,.43472],126:[.35,.32659,0,0,.5],160:[0,0,0,0,.25],168:[0,.67937,0,0,.5],176:[0,.69444,0,0,.66667],184:[.17014,0,0,0,.44445],305:[0,.44444,0,0,.23889],567:[.19444,.44444,0,0,.26667],710:[0,.69444,0,0,.5],711:[0,.63194,0,0,.5],713:[0,.60889,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.67937,0,0,.27778],730:[0,.69444,0,0,.66667],732:[0,.67659,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.69444,0,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,0,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,0,0,.66667],928:[0,.69444,0,0,.70834],931:[0,.69444,0,0,.72222],933:[0,.69444,0,0,.77778],934:[0,.69444,0,0,.72222],936:[0,.69444,0,0,.77778],937:[0,.69444,0,0,.72222],8211:[0,.44444,.02778,0,.5],8212:[0,.44444,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5]},"Script-Regular":{32:[0,0,0,0,.25],65:[0,.7,.22925,0,.80253],66:[0,.7,.04087,0,.90757],67:[0,.7,.1689,0,.66619],68:[0,.7,.09371,0,.77443],69:[0,.7,.18583,0,.56162],70:[0,.7,.13634,0,.89544],71:[0,.7,.17322,0,.60961],72:[0,.7,.29694,0,.96919],73:[0,.7,.19189,0,.80907],74:[.27778,.7,.19189,0,1.05159],75:[0,.7,.31259,0,.91364],76:[0,.7,.19189,0,.87373],77:[0,.7,.15981,0,1.08031],78:[0,.7,.3525,0,.9015],79:[0,.7,.08078,0,.73787],80:[0,.7,.08078,0,1.01262],81:[0,.7,.03305,0,.88282],82:[0,.7,.06259,0,.85],83:[0,.7,.19189,0,.86767],84:[0,.7,.29087,0,.74697],85:[0,.7,.25815,0,.79996],86:[0,.7,.27523,0,.62204],87:[0,.7,.27523,0,.80532],88:[0,.7,.26006,0,.94445],89:[0,.7,.2939,0,.70961],90:[0,.7,.24037,0,.8212],160:[0,0,0,0,.25]},"Size1-Regular":{32:[0,0,0,0,.25],40:[.35001,.85,0,0,.45834],41:[.35001,.85,0,0,.45834],47:[.35001,.85,0,0,.57778],91:[.35001,.85,0,0,.41667],92:[.35001,.85,0,0,.57778],93:[.35001,.85,0,0,.41667],123:[.35001,.85,0,0,.58334],125:[.35001,.85,0,0,.58334],160:[0,0,0,0,.25],710:[0,.72222,0,0,.55556],732:[0,.72222,0,0,.55556],770:[0,.72222,0,0,.55556],771:[0,.72222,0,0,.55556],8214:[-99e-5,.601,0,0,.77778],8593:[1e-5,.6,0,0,.66667],8595:[1e-5,.6,0,0,.66667],8657:[1e-5,.6,0,0,.77778],8659:[1e-5,.6,0,0,.77778],8719:[.25001,.75,0,0,.94445],8720:[.25001,.75,0,0,.94445],8721:[.25001,.75,0,0,1.05556],8730:[.35001,.85,0,0,1],8739:[-.00599,.606,0,0,.33333],8741:[-.00599,.606,0,0,.55556],8747:[.30612,.805,.19445,0,.47222],8748:[.306,.805,.19445,0,.47222],8749:[.306,.805,.19445,0,.47222],8750:[.30612,.805,.19445,0,.47222],8896:[.25001,.75,0,0,.83334],8897:[.25001,.75,0,0,.83334],8898:[.25001,.75,0,0,.83334],8899:[.25001,.75,0,0,.83334],8968:[.35001,.85,0,0,.47222],8969:[.35001,.85,0,0,.47222],8970:[.35001,.85,0,0,.47222],8971:[.35001,.85,0,0,.47222],9168:[-99e-5,.601,0,0,.66667],10216:[.35001,.85,0,0,.47222],10217:[.35001,.85,0,0,.47222],10752:[.25001,.75,0,0,1.11111],10753:[.25001,.75,0,0,1.11111],10754:[.25001,.75,0,0,1.11111],10756:[.25001,.75,0,0,.83334],10758:[.25001,.75,0,0,.83334]},"Size2-Regular":{32:[0,0,0,0,.25],40:[.65002,1.15,0,0,.59722],41:[.65002,1.15,0,0,.59722],47:[.65002,1.15,0,0,.81111],91:[.65002,1.15,0,0,.47222],92:[.65002,1.15,0,0,.81111],93:[.65002,1.15,0,0,.47222],123:[.65002,1.15,0,0,.66667],125:[.65002,1.15,0,0,.66667],160:[0,0,0,0,.25],710:[0,.75,0,0,1],732:[0,.75,0,0,1],770:[0,.75,0,0,1],771:[0,.75,0,0,1],8719:[.55001,1.05,0,0,1.27778],8720:[.55001,1.05,0,0,1.27778],8721:[.55001,1.05,0,0,1.44445],8730:[.65002,1.15,0,0,1],8747:[.86225,1.36,.44445,0,.55556],8748:[.862,1.36,.44445,0,.55556],8749:[.862,1.36,.44445,0,.55556],8750:[.86225,1.36,.44445,0,.55556],8896:[.55001,1.05,0,0,1.11111],8897:[.55001,1.05,0,0,1.11111],8898:[.55001,1.05,0,0,1.11111],8899:[.55001,1.05,0,0,1.11111],8968:[.65002,1.15,0,0,.52778],8969:[.65002,1.15,0,0,.52778],8970:[.65002,1.15,0,0,.52778],8971:[.65002,1.15,0,0,.52778],10216:[.65002,1.15,0,0,.61111],10217:[.65002,1.15,0,0,.61111],10752:[.55001,1.05,0,0,1.51112],10753:[.55001,1.05,0,0,1.51112],10754:[.55001,1.05,0,0,1.51112],10756:[.55001,1.05,0,0,1.11111],10758:[.55001,1.05,0,0,1.11111]},"Size3-Regular":{32:[0,0,0,0,.25],40:[.95003,1.45,0,0,.73611],41:[.95003,1.45,0,0,.73611],47:[.95003,1.45,0,0,1.04445],91:[.95003,1.45,0,0,.52778],92:[.95003,1.45,0,0,1.04445],93:[.95003,1.45,0,0,.52778],123:[.95003,1.45,0,0,.75],125:[.95003,1.45,0,0,.75],160:[0,0,0,0,.25],710:[0,.75,0,0,1.44445],732:[0,.75,0,0,1.44445],770:[0,.75,0,0,1.44445],771:[0,.75,0,0,1.44445],8730:[.95003,1.45,0,0,1],8968:[.95003,1.45,0,0,.58334],8969:[.95003,1.45,0,0,.58334],8970:[.95003,1.45,0,0,.58334],8971:[.95003,1.45,0,0,.58334],10216:[.95003,1.45,0,0,.75],10217:[.95003,1.45,0,0,.75]},"Size4-Regular":{32:[0,0,0,0,.25],40:[1.25003,1.75,0,0,.79167],41:[1.25003,1.75,0,0,.79167],47:[1.25003,1.75,0,0,1.27778],91:[1.25003,1.75,0,0,.58334],92:[1.25003,1.75,0,0,1.27778],93:[1.25003,1.75,0,0,.58334],123:[1.25003,1.75,0,0,.80556],125:[1.25003,1.75,0,0,.80556],160:[0,0,0,0,.25],710:[0,.825,0,0,1.8889],732:[0,.825,0,0,1.8889],770:[0,.825,0,0,1.8889],771:[0,.825,0,0,1.8889],8730:[1.25003,1.75,0,0,1],8968:[1.25003,1.75,0,0,.63889],8969:[1.25003,1.75,0,0,.63889],8970:[1.25003,1.75,0,0,.63889],8971:[1.25003,1.75,0,0,.63889],9115:[.64502,1.155,0,0,.875],9116:[1e-5,.6,0,0,.875],9117:[.64502,1.155,0,0,.875],9118:[.64502,1.155,0,0,.875],9119:[1e-5,.6,0,0,.875],9120:[.64502,1.155,0,0,.875],9121:[.64502,1.155,0,0,.66667],9122:[-99e-5,.601,0,0,.66667],9123:[.64502,1.155,0,0,.66667],9124:[.64502,1.155,0,0,.66667],9125:[-99e-5,.601,0,0,.66667],9126:[.64502,1.155,0,0,.66667],9127:[1e-5,.9,0,0,.88889],9128:[.65002,1.15,0,0,.88889],9129:[.90001,0,0,0,.88889],9130:[0,.3,0,0,.88889],9131:[1e-5,.9,0,0,.88889],9132:[.65002,1.15,0,0,.88889],9133:[.90001,0,0,0,.88889],9143:[.88502,.915,0,0,1.05556],10216:[1.25003,1.75,0,0,.80556],10217:[1.25003,1.75,0,0,.80556],57344:[-.00499,.605,0,0,1.05556],57345:[-.00499,.605,0,0,1.05556],57680:[0,.12,0,0,.45],57681:[0,.12,0,0,.45],57682:[0,.12,0,0,.45],57683:[0,.12,0,0,.45]},"Typewriter-Regular":{32:[0,0,0,0,.525],33:[0,.61111,0,0,.525],34:[0,.61111,0,0,.525],35:[0,.61111,0,0,.525],36:[.08333,.69444,0,0,.525],37:[.08333,.69444,0,0,.525],38:[0,.61111,0,0,.525],39:[0,.61111,0,0,.525],40:[.08333,.69444,0,0,.525],41:[.08333,.69444,0,0,.525],42:[0,.52083,0,0,.525],43:[-.08056,.53055,0,0,.525],44:[.13889,.125,0,0,.525],45:[-.08056,.53055,0,0,.525],46:[0,.125,0,0,.525],47:[.08333,.69444,0,0,.525],48:[0,.61111,0,0,.525],49:[0,.61111,0,0,.525],50:[0,.61111,0,0,.525],51:[0,.61111,0,0,.525],52:[0,.61111,0,0,.525],53:[0,.61111,0,0,.525],54:[0,.61111,0,0,.525],55:[0,.61111,0,0,.525],56:[0,.61111,0,0,.525],57:[0,.61111,0,0,.525],58:[0,.43056,0,0,.525],59:[.13889,.43056,0,0,.525],60:[-.05556,.55556,0,0,.525],61:[-.19549,.41562,0,0,.525],62:[-.05556,.55556,0,0,.525],63:[0,.61111,0,0,.525],64:[0,.61111,0,0,.525],65:[0,.61111,0,0,.525],66:[0,.61111,0,0,.525],67:[0,.61111,0,0,.525],68:[0,.61111,0,0,.525],69:[0,.61111,0,0,.525],70:[0,.61111,0,0,.525],71:[0,.61111,0,0,.525],72:[0,.61111,0,0,.525],73:[0,.61111,0,0,.525],74:[0,.61111,0,0,.525],75:[0,.61111,0,0,.525],76:[0,.61111,0,0,.525],77:[0,.61111,0,0,.525],78:[0,.61111,0,0,.525],79:[0,.61111,0,0,.525],80:[0,.61111,0,0,.525],81:[.13889,.61111,0,0,.525],82:[0,.61111,0,0,.525],83:[0,.61111,0,0,.525],84:[0,.61111,0,0,.525],85:[0,.61111,0,0,.525],86:[0,.61111,0,0,.525],87:[0,.61111,0,0,.525],88:[0,.61111,0,0,.525],89:[0,.61111,0,0,.525],90:[0,.61111,0,0,.525],91:[.08333,.69444,0,0,.525],92:[.08333,.69444,0,0,.525],93:[.08333,.69444,0,0,.525],94:[0,.61111,0,0,.525],95:[.09514,0,0,0,.525],96:[0,.61111,0,0,.525],97:[0,.43056,0,0,.525],98:[0,.61111,0,0,.525],99:[0,.43056,0,0,.525],100:[0,.61111,0,0,.525],101:[0,.43056,0,0,.525],102:[0,.61111,0,0,.525],103:[.22222,.43056,0,0,.525],104:[0,.61111,0,0,.525],105:[0,.61111,0,0,.525],106:[.22222,.61111,0,0,.525],107:[0,.61111,0,0,.525],108:[0,.61111,0,0,.525],109:[0,.43056,0,0,.525],110:[0,.43056,0,0,.525],111:[0,.43056,0,0,.525],112:[.22222,.43056,0,0,.525],113:[.22222,.43056,0,0,.525],114:[0,.43056,0,0,.525],115:[0,.43056,0,0,.525],116:[0,.55358,0,0,.525],117:[0,.43056,0,0,.525],118:[0,.43056,0,0,.525],119:[0,.43056,0,0,.525],120:[0,.43056,0,0,.525],121:[.22222,.43056,0,0,.525],122:[0,.43056,0,0,.525],123:[.08333,.69444,0,0,.525],124:[.08333,.69444,0,0,.525],125:[.08333,.69444,0,0,.525],126:[0,.61111,0,0,.525],127:[0,.61111,0,0,.525],160:[0,0,0,0,.525],176:[0,.61111,0,0,.525],184:[.19445,0,0,0,.525],305:[0,.43056,0,0,.525],567:[.22222,.43056,0,0,.525],711:[0,.56597,0,0,.525],713:[0,.56555,0,0,.525],714:[0,.61111,0,0,.525],715:[0,.61111,0,0,.525],728:[0,.61111,0,0,.525],730:[0,.61111,0,0,.525],770:[0,.61111,0,0,.525],771:[0,.61111,0,0,.525],776:[0,.61111,0,0,.525],915:[0,.61111,0,0,.525],916:[0,.61111,0,0,.525],920:[0,.61111,0,0,.525],923:[0,.61111,0,0,.525],926:[0,.61111,0,0,.525],928:[0,.61111,0,0,.525],931:[0,.61111,0,0,.525],933:[0,.61111,0,0,.525],934:[0,.61111,0,0,.525],936:[0,.61111,0,0,.525],937:[0,.61111,0,0,.525],8216:[0,.61111,0,0,.525],8217:[0,.61111,0,0,.525],8242:[0,.61111,0,0,.525],9251:[.11111,.21944,0,0,.525]}},bo={slant:[.25,.25,.25],space:[0,0,0],stretch:[0,0,0],shrink:[0,0,0],xHeight:[.431,.431,.431],quad:[1,1.171,1.472],extraSpace:[0,0,0],num1:[.677,.732,.925],num2:[.394,.384,.387],num3:[.444,.471,.504],denom1:[.686,.752,1.025],denom2:[.345,.344,.532],sup1:[.413,.503,.504],sup2:[.363,.431,.404],sup3:[.289,.286,.294],sub1:[.15,.143,.2],sub2:[.247,.286,.4],supDrop:[.386,.353,.494],subDrop:[.05,.071,.1],delim1:[2.39,1.7,1.98],delim2:[1.01,1.157,1.42],axisHeight:[.25,.25,.25],defaultRuleThickness:[.04,.049,.049],bigOpSpacing1:[.111,.111,.111],bigOpSpacing2:[.166,.166,.166],bigOpSpacing3:[.2,.2,.2],bigOpSpacing4:[.6,.611,.611],bigOpSpacing5:[.1,.143,.143],sqrtRuleThickness:[.04,.04,.04],ptPerEm:[10,10,10],doubleRuleSep:[.2,.2,.2],arrayRuleWidth:[.04,.04,.04],fboxsep:[.3,.3,.3],fboxrule:[.04,.04,.04]},$h={Å:"A",Ð:"D",Þ:"o",å:"a",ð:"d",þ:"o",А:"A",Б:"B",В:"B",Г:"F",Д:"A",Е:"E",Ж:"K",З:"3",И:"N",Й:"N",К:"K",Л:"N",М:"M",Н:"H",О:"O",П:"N",Р:"P",С:"C",Т:"T",У:"y",Ф:"O",Х:"X",Ц:"U",Ч:"h",Ш:"W",Щ:"W",Ъ:"B",Ы:"X",Ь:"B",Э:"3",Ю:"X",Я:"R",а:"a",б:"b",в:"a",г:"r",д:"y",е:"e",ж:"m",з:"e",и:"n",й:"n",к:"n",л:"n",м:"m",н:"n",о:"o",п:"n",р:"p",с:"c",т:"o",у:"y",ф:"b",х:"x",ц:"n",ч:"n",ш:"w",щ:"w",ъ:"a",ы:"m",ь:"a",э:"e",ю:"m",я:"r"};function Mx(e,t){Ur[e]=t}function gf(e,t,r){if(!Ur[t])throw new Error("Font metrics not found for font: "+t+".");var n=e.charCodeAt(0),i=Ur[t][n];if(!i&&e[0]in $h&&(n=$h[e[0]].charCodeAt(0),i=Ur[t][n]),!i&&r==="text"&&r2(n)&&(i=Ur[t][77]),i)return{depth:i[0],height:i[1],italic:i[2],skew:i[3],width:i[4]}}var ml={};function Rx(e){var t;if(e>=5?t=0:e>=3?t=1:t=2,!ml[t]){var r=ml[t]={cssEmPerMu:bo.quad[t]/18};for(var n in bo)bo.hasOwnProperty(n)&&(r[n]=bo[n][t])}return ml[t]}var Ix=[[1,1,1],[2,1,1],[3,1,1],[4,2,1],[5,2,1],[6,3,1],[7,4,2],[8,6,3],[9,7,6],[10,8,7],[11,10,9]],Uh=[.5,.6,.7,.8,.9,1,1.2,1.44,1.728,2.074,2.488],Hh=function(t,r){return r.size<2?t:Ix[t-1][r.size-1]};class nn{constructor(t){this.style=void 0,this.color=void 0,this.size=void 0,this.textSize=void 0,this.phantom=void 0,this.font=void 0,this.fontFamily=void 0,this.fontWeight=void 0,this.fontShape=void 0,this.sizeMultiplier=void 0,this.maxSize=void 0,this.minRuleThickness=void 0,this._fontMetrics=void 0,this.style=t.style,this.color=t.color,this.size=t.size||nn.BASESIZE,this.textSize=t.textSize||this.size,this.phantom=!!t.phantom,this.font=t.font||"",this.fontFamily=t.fontFamily||"",this.fontWeight=t.fontWeight||"",this.fontShape=t.fontShape||"",this.sizeMultiplier=Uh[this.size-1],this.maxSize=t.maxSize,this.minRuleThickness=t.minRuleThickness,this._fontMetrics=void 0}extend(t){var r={style:this.style,size:this.size,textSize:this.textSize,color:this.color,phantom:this.phantom,font:this.font,fontFamily:this.fontFamily,fontWeight:this.fontWeight,fontShape:this.fontShape,maxSize:this.maxSize,minRuleThickness:this.minRuleThickness};for(var n in t)t.hasOwnProperty(n)&&(r[n]=t[n]);return new nn(r)}havingStyle(t){return this.style===t?this:this.extend({style:t,size:Hh(this.textSize,t)})}havingCrampedStyle(){return this.havingStyle(this.style.cramp())}havingSize(t){return this.size===t&&this.textSize===t?this:this.extend({style:this.style.text(),size:t,textSize:t,sizeMultiplier:Uh[t-1]})}havingBaseStyle(t){t=t||this.style.text();var r=Hh(nn.BASESIZE,t);return this.size===r&&this.textSize===nn.BASESIZE&&this.style===t?this:this.extend({style:t,size:r})}havingBaseSizing(){var t;switch(this.style.id){case 4:case 5:t=3;break;case 6:case 7:t=1;break;default:t=6}return this.extend({style:this.style.text(),size:t})}withColor(t){return this.extend({color:t})}withPhantom(){return this.extend({phantom:!0})}withFont(t){return this.extend({font:t})}withTextFontFamily(t){return this.extend({fontFamily:t,font:""})}withTextFontWeight(t){return this.extend({fontWeight:t,font:""})}withTextFontShape(t){return this.extend({fontShape:t,font:""})}sizingClasses(t){return t.size!==this.size?["sizing","reset-size"+t.size,"size"+this.size]:[]}baseSizingClasses(){return this.size!==nn.BASESIZE?["sizing","reset-size"+this.size,"size"+nn.BASESIZE]:[]}fontMetrics(){return this._fontMetrics||(this._fontMetrics=Rx(this.size)),this._fontMetrics}getColor(){return this.phantom?"transparent":this.color}}nn.BASESIZE=6;var O0={pt:1,mm:7227/2540,cm:7227/254,in:72.27,bp:803/800,pc:12,dd:1238/1157,cc:14856/1157,nd:685/642,nc:1370/107,sp:1/65536,px:803/800},Px={ex:!0,em:!0,mu:!0},n2=function(t){return typeof t!="string"&&(t=t.unit),t in O0||t in Px||t==="ex"},st=function(t,r){var n;if(t.unit in O0)n=O0[t.unit]/r.fontMetrics().ptPerEm/r.sizeMultiplier;else if(t.unit==="mu")n=r.fontMetrics().cssEmPerMu;else{var i;if(r.style.isTight()?i=r.havingStyle(r.style.text()):i=r,t.unit==="ex")n=i.fontMetrics().xHeight;else if(t.unit==="em")n=i.fontMetrics().quad;else throw new te("Invalid unit: '"+t.unit+"'");i!==r&&(n*=i.sizeMultiplier/r.sizeMultiplier)}return Math.min(t.number*n,r.maxSize)},ie=function(t){return+t.toFixed(4)+"em"},Rn=function(t){return t.filter(r=>r).join(" ")},i2=function(t,r,n){if(this.classes=t||[],this.attributes={},this.height=0,this.depth=0,this.maxFontSize=0,this.style=n||{},r){r.style.isTight()&&this.classes.push("mtight");var i=r.getColor();i&&(this.style.color=i)}},a2=function(t){var r=document.createElement(t);r.className=Rn(this.classes);for(var n in this.style)this.style.hasOwnProperty(n)&&(r.style[n]=this.style[n]);for(var i in this.attributes)this.attributes.hasOwnProperty(i)&&r.setAttribute(i,this.attributes[i]);for(var a=0;a<this.children.length;a++)r.appendChild(this.children[a].toNode());return r},o2=function(t){var r="<"+t;this.classes.length&&(r+=' class="'+Te.escape(Rn(this.classes))+'"');var n="";for(var i in this.style)this.style.hasOwnProperty(i)&&(n+=Te.hyphenate(i)+":"+this.style[i]+";");n&&(r+=' style="'+Te.escape(n)+'"');for(var a in this.attributes)this.attributes.hasOwnProperty(a)&&(r+=" "+a+'="'+Te.escape(this.attributes[a])+'"');r+=">";for(var o=0;o<this.children.length;o++)r+=this.children[o].toMarkup();return r+="</"+t+">",r};class Ya{constructor(t,r,n,i){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.width=void 0,this.maxFontSize=void 0,this.style=void 0,i2.call(this,t,n,i),this.children=r||[]}setAttribute(t,r){this.attributes[t]=r}hasClass(t){return Te.contains(this.classes,t)}toNode(){return a2.call(this,"span")}toMarkup(){return o2.call(this,"span")}}class bf{constructor(t,r,n,i){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,i2.call(this,r,i),this.children=n||[],this.setAttribute("href",t)}setAttribute(t,r){this.attributes[t]=r}hasClass(t){return Te.contains(this.classes,t)}toNode(){return a2.call(this,"a")}toMarkup(){return o2.call(this,"a")}}class Dx{constructor(t,r,n){this.src=void 0,this.alt=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.alt=r,this.src=t,this.classes=["mord"],this.style=n}hasClass(t){return Te.contains(this.classes,t)}toNode(){var t=document.createElement("img");t.src=this.src,t.alt=this.alt,t.className="mord";for(var r in this.style)this.style.hasOwnProperty(r)&&(t.style[r]=this.style[r]);return t}toMarkup(){var t="<img  src='"+this.src+" 'alt='"+this.alt+"' ",r="";for(var n in this.style)this.style.hasOwnProperty(n)&&(r+=Te.hyphenate(n)+":"+this.style[n]+";");return r&&(t+=' style="'+Te.escape(r)+'"'),t+="'/>",t}}var Lx={î:"ı̂",ï:"ı̈",í:"ı́",ì:"ı̀"};class mr{constructor(t,r,n,i,a,o,s,u){this.text=void 0,this.height=void 0,this.depth=void 0,this.italic=void 0,this.skew=void 0,this.width=void 0,this.maxFontSize=void 0,this.classes=void 0,this.style=void 0,this.text=t,this.height=r||0,this.depth=n||0,this.italic=i||0,this.skew=a||0,this.width=o||0,this.classes=s||[],this.style=u||{},this.maxFontSize=0;var l=wx(this.text.charCodeAt(0));l&&this.classes.push(l+"_fallback"),/[îïíì]/.test(this.text)&&(this.text=Lx[this.text])}hasClass(t){return Te.contains(this.classes,t)}toNode(){var t=document.createTextNode(this.text),r=null;this.italic>0&&(r=document.createElement("span"),r.style.marginRight=ie(this.italic)),this.classes.length>0&&(r=r||document.createElement("span"),r.className=Rn(this.classes));for(var n in this.style)this.style.hasOwnProperty(n)&&(r=r||document.createElement("span"),r.style[n]=this.style[n]);return r?(r.appendChild(t),r):t}toMarkup(){var t=!1,r="<span";this.classes.length&&(t=!0,r+=' class="',r+=Te.escape(Rn(this.classes)),r+='"');var n="";this.italic>0&&(n+="margin-right:"+this.italic+"em;");for(var i in this.style)this.style.hasOwnProperty(i)&&(n+=Te.hyphenate(i)+":"+this.style[i]+";");n&&(t=!0,r+=' style="'+Te.escape(n)+'"');var a=Te.escape(this.text);return t?(r+=">",r+=a,r+="</span>",r):a}}class ln{constructor(t,r){this.children=void 0,this.attributes=void 0,this.children=t||[],this.attributes=r||{}}toNode(){var t="http://www.w3.org/2000/svg",r=document.createElementNS(t,"svg");for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&r.setAttribute(n,this.attributes[n]);for(var i=0;i<this.children.length;i++)r.appendChild(this.children[i].toNode());return r}toMarkup(){var t='<svg xmlns="http://www.w3.org/2000/svg"';for(var r in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,r)&&(t+=" "+r+"='"+this.attributes[r]+"'");t+=">";for(var n=0;n<this.children.length;n++)t+=this.children[n].toMarkup();return t+="</svg>",t}}class In{constructor(t,r){this.pathName=void 0,this.alternate=void 0,this.pathName=t,this.alternate=r}toNode(){var t="http://www.w3.org/2000/svg",r=document.createElementNS(t,"path");return this.alternate?r.setAttribute("d",this.alternate):r.setAttribute("d",zh[this.pathName]),r}toMarkup(){return this.alternate?"<path d='"+this.alternate+"'/>":"<path d='"+zh[this.pathName]+"'/>"}}class N0{constructor(t){this.attributes=void 0,this.attributes=t||{}}toNode(){var t="http://www.w3.org/2000/svg",r=document.createElementNS(t,"line");for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&r.setAttribute(n,this.attributes[n]);return r}toMarkup(){var t="<line";for(var r in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,r)&&(t+=" "+r+"='"+this.attributes[r]+"'");return t+="/>",t}}function qh(e){if(e instanceof mr)return e;throw new Error("Expected symbolNode but got "+String(e)+".")}function Fx(e){if(e instanceof Ya)return e;throw new Error("Expected span<HtmlDomNode> but got "+String(e)+".")}var Bx={bin:1,close:1,inner:1,open:1,punct:1,rel:1},zx={"accent-token":1,mathord:1,"op-token":1,spacing:1,textord:1},tt={math:{},text:{}};function b(e,t,r,n,i,a){tt[e][i]={font:t,group:r,replace:n},a&&n&&(tt[e][n]=tt[e][i])}var y="math",Y="text",E="main",R="ams",at="accent-token",ue="bin",zt="close",Ji="inner",ge="mathord",bt="op-token",ar="open",yu="punct",P="rel",mn="spacing",B="textord";b(y,E,P,"≡","\\equiv",!0);b(y,E,P,"≺","\\prec",!0);b(y,E,P,"≻","\\succ",!0);b(y,E,P,"∼","\\sim",!0);b(y,E,P,"⊥","\\perp");b(y,E,P,"⪯","\\preceq",!0);b(y,E,P,"⪰","\\succeq",!0);b(y,E,P,"≃","\\simeq",!0);b(y,E,P,"∣","\\mid",!0);b(y,E,P,"≪","\\ll",!0);b(y,E,P,"≫","\\gg",!0);b(y,E,P,"≍","\\asymp",!0);b(y,E,P,"∥","\\parallel");b(y,E,P,"⋈","\\bowtie",!0);b(y,E,P,"⌣","\\smile",!0);b(y,E,P,"⊑","\\sqsubseteq",!0);b(y,E,P,"⊒","\\sqsupseteq",!0);b(y,E,P,"≐","\\doteq",!0);b(y,E,P,"⌢","\\frown",!0);b(y,E,P,"∋","\\ni",!0);b(y,E,P,"∝","\\propto",!0);b(y,E,P,"⊢","\\vdash",!0);b(y,E,P,"⊣","\\dashv",!0);b(y,E,P,"∋","\\owns");b(y,E,yu,".","\\ldotp");b(y,E,yu,"⋅","\\cdotp");b(y,E,B,"#","\\#");b(Y,E,B,"#","\\#");b(y,E,B,"&","\\&");b(Y,E,B,"&","\\&");b(y,E,B,"ℵ","\\aleph",!0);b(y,E,B,"∀","\\forall",!0);b(y,E,B,"ℏ","\\hbar",!0);b(y,E,B,"∃","\\exists",!0);b(y,E,B,"∇","\\nabla",!0);b(y,E,B,"♭","\\flat",!0);b(y,E,B,"ℓ","\\ell",!0);b(y,E,B,"♮","\\natural",!0);b(y,E,B,"♣","\\clubsuit",!0);b(y,E,B,"℘","\\wp",!0);b(y,E,B,"♯","\\sharp",!0);b(y,E,B,"♢","\\diamondsuit",!0);b(y,E,B,"ℜ","\\Re",!0);b(y,E,B,"♡","\\heartsuit",!0);b(y,E,B,"ℑ","\\Im",!0);b(y,E,B,"♠","\\spadesuit",!0);b(y,E,B,"§","\\S",!0);b(Y,E,B,"§","\\S");b(y,E,B,"¶","\\P",!0);b(Y,E,B,"¶","\\P");b(y,E,B,"†","\\dag");b(Y,E,B,"†","\\dag");b(Y,E,B,"†","\\textdagger");b(y,E,B,"‡","\\ddag");b(Y,E,B,"‡","\\ddag");b(Y,E,B,"‡","\\textdaggerdbl");b(y,E,zt,"⎱","\\rmoustache",!0);b(y,E,ar,"⎰","\\lmoustache",!0);b(y,E,zt,"⟯","\\rgroup",!0);b(y,E,ar,"⟮","\\lgroup",!0);b(y,E,ue,"∓","\\mp",!0);b(y,E,ue,"⊖","\\ominus",!0);b(y,E,ue,"⊎","\\uplus",!0);b(y,E,ue,"⊓","\\sqcap",!0);b(y,E,ue,"∗","\\ast");b(y,E,ue,"⊔","\\sqcup",!0);b(y,E,ue,"◯","\\bigcirc",!0);b(y,E,ue,"∙","\\bullet",!0);b(y,E,ue,"‡","\\ddagger");b(y,E,ue,"≀","\\wr",!0);b(y,E,ue,"⨿","\\amalg");b(y,E,ue,"&","\\And");b(y,E,P,"⟵","\\longleftarrow",!0);b(y,E,P,"⇐","\\Leftarrow",!0);b(y,E,P,"⟸","\\Longleftarrow",!0);b(y,E,P,"⟶","\\longrightarrow",!0);b(y,E,P,"⇒","\\Rightarrow",!0);b(y,E,P,"⟹","\\Longrightarrow",!0);b(y,E,P,"↔","\\leftrightarrow",!0);b(y,E,P,"⟷","\\longleftrightarrow",!0);b(y,E,P,"⇔","\\Leftrightarrow",!0);b(y,E,P,"⟺","\\Longleftrightarrow",!0);b(y,E,P,"↦","\\mapsto",!0);b(y,E,P,"⟼","\\longmapsto",!0);b(y,E,P,"↗","\\nearrow",!0);b(y,E,P,"↩","\\hookleftarrow",!0);b(y,E,P,"↪","\\hookrightarrow",!0);b(y,E,P,"↘","\\searrow",!0);b(y,E,P,"↼","\\leftharpoonup",!0);b(y,E,P,"⇀","\\rightharpoonup",!0);b(y,E,P,"↙","\\swarrow",!0);b(y,E,P,"↽","\\leftharpoondown",!0);b(y,E,P,"⇁","\\rightharpoondown",!0);b(y,E,P,"↖","\\nwarrow",!0);b(y,E,P,"⇌","\\rightleftharpoons",!0);b(y,R,P,"≮","\\nless",!0);b(y,R,P,"","\\@nleqslant");b(y,R,P,"","\\@nleqq");b(y,R,P,"⪇","\\lneq",!0);b(y,R,P,"≨","\\lneqq",!0);b(y,R,P,"","\\@lvertneqq");b(y,R,P,"⋦","\\lnsim",!0);b(y,R,P,"⪉","\\lnapprox",!0);b(y,R,P,"⊀","\\nprec",!0);b(y,R,P,"⋠","\\npreceq",!0);b(y,R,P,"⋨","\\precnsim",!0);b(y,R,P,"⪹","\\precnapprox",!0);b(y,R,P,"≁","\\nsim",!0);b(y,R,P,"","\\@nshortmid");b(y,R,P,"∤","\\nmid",!0);b(y,R,P,"⊬","\\nvdash",!0);b(y,R,P,"⊭","\\nvDash",!0);b(y,R,P,"⋪","\\ntriangleleft");b(y,R,P,"⋬","\\ntrianglelefteq",!0);b(y,R,P,"⊊","\\subsetneq",!0);b(y,R,P,"","\\@varsubsetneq");b(y,R,P,"⫋","\\subsetneqq",!0);b(y,R,P,"","\\@varsubsetneqq");b(y,R,P,"≯","\\ngtr",!0);b(y,R,P,"","\\@ngeqslant");b(y,R,P,"","\\@ngeqq");b(y,R,P,"⪈","\\gneq",!0);b(y,R,P,"≩","\\gneqq",!0);b(y,R,P,"","\\@gvertneqq");b(y,R,P,"⋧","\\gnsim",!0);b(y,R,P,"⪊","\\gnapprox",!0);b(y,R,P,"⊁","\\nsucc",!0);b(y,R,P,"⋡","\\nsucceq",!0);b(y,R,P,"⋩","\\succnsim",!0);b(y,R,P,"⪺","\\succnapprox",!0);b(y,R,P,"≆","\\ncong",!0);b(y,R,P,"","\\@nshortparallel");b(y,R,P,"∦","\\nparallel",!0);b(y,R,P,"⊯","\\nVDash",!0);b(y,R,P,"⋫","\\ntriangleright");b(y,R,P,"⋭","\\ntrianglerighteq",!0);b(y,R,P,"","\\@nsupseteqq");b(y,R,P,"⊋","\\supsetneq",!0);b(y,R,P,"","\\@varsupsetneq");b(y,R,P,"⫌","\\supsetneqq",!0);b(y,R,P,"","\\@varsupsetneqq");b(y,R,P,"⊮","\\nVdash",!0);b(y,R,P,"⪵","\\precneqq",!0);b(y,R,P,"⪶","\\succneqq",!0);b(y,R,P,"","\\@nsubseteqq");b(y,R,ue,"⊴","\\unlhd");b(y,R,ue,"⊵","\\unrhd");b(y,R,P,"↚","\\nleftarrow",!0);b(y,R,P,"↛","\\nrightarrow",!0);b(y,R,P,"⇍","\\nLeftarrow",!0);b(y,R,P,"⇏","\\nRightarrow",!0);b(y,R,P,"↮","\\nleftrightarrow",!0);b(y,R,P,"⇎","\\nLeftrightarrow",!0);b(y,R,P,"△","\\vartriangle");b(y,R,B,"ℏ","\\hslash");b(y,R,B,"▽","\\triangledown");b(y,R,B,"◊","\\lozenge");b(y,R,B,"Ⓢ","\\circledS");b(y,R,B,"®","\\circledR");b(Y,R,B,"®","\\circledR");b(y,R,B,"∡","\\measuredangle",!0);b(y,R,B,"∄","\\nexists");b(y,R,B,"℧","\\mho");b(y,R,B,"Ⅎ","\\Finv",!0);b(y,R,B,"⅁","\\Game",!0);b(y,R,B,"‵","\\backprime");b(y,R,B,"▲","\\blacktriangle");b(y,R,B,"▼","\\blacktriangledown");b(y,R,B,"■","\\blacksquare");b(y,R,B,"⧫","\\blacklozenge");b(y,R,B,"★","\\bigstar");b(y,R,B,"∢","\\sphericalangle",!0);b(y,R,B,"∁","\\complement",!0);b(y,R,B,"ð","\\eth",!0);b(Y,E,B,"ð","ð");b(y,R,B,"╱","\\diagup");b(y,R,B,"╲","\\diagdown");b(y,R,B,"□","\\square");b(y,R,B,"□","\\Box");b(y,R,B,"◊","\\Diamond");b(y,R,B,"¥","\\yen",!0);b(Y,R,B,"¥","\\yen",!0);b(y,R,B,"✓","\\checkmark",!0);b(Y,R,B,"✓","\\checkmark");b(y,R,B,"ℶ","\\beth",!0);b(y,R,B,"ℸ","\\daleth",!0);b(y,R,B,"ℷ","\\gimel",!0);b(y,R,B,"ϝ","\\digamma",!0);b(y,R,B,"ϰ","\\varkappa");b(y,R,ar,"┌","\\@ulcorner",!0);b(y,R,zt,"┐","\\@urcorner",!0);b(y,R,ar,"└","\\@llcorner",!0);b(y,R,zt,"┘","\\@lrcorner",!0);b(y,R,P,"≦","\\leqq",!0);b(y,R,P,"⩽","\\leqslant",!0);b(y,R,P,"⪕","\\eqslantless",!0);b(y,R,P,"≲","\\lesssim",!0);b(y,R,P,"⪅","\\lessapprox",!0);b(y,R,P,"≊","\\approxeq",!0);b(y,R,ue,"⋖","\\lessdot");b(y,R,P,"⋘","\\lll",!0);b(y,R,P,"≶","\\lessgtr",!0);b(y,R,P,"⋚","\\lesseqgtr",!0);b(y,R,P,"⪋","\\lesseqqgtr",!0);b(y,R,P,"≑","\\doteqdot");b(y,R,P,"≓","\\risingdotseq",!0);b(y,R,P,"≒","\\fallingdotseq",!0);b(y,R,P,"∽","\\backsim",!0);b(y,R,P,"⋍","\\backsimeq",!0);b(y,R,P,"⫅","\\subseteqq",!0);b(y,R,P,"⋐","\\Subset",!0);b(y,R,P,"⊏","\\sqsubset",!0);b(y,R,P,"≼","\\preccurlyeq",!0);b(y,R,P,"⋞","\\curlyeqprec",!0);b(y,R,P,"≾","\\precsim",!0);b(y,R,P,"⪷","\\precapprox",!0);b(y,R,P,"⊲","\\vartriangleleft");b(y,R,P,"⊴","\\trianglelefteq");b(y,R,P,"⊨","\\vDash",!0);b(y,R,P,"⊪","\\Vvdash",!0);b(y,R,P,"⌣","\\smallsmile");b(y,R,P,"⌢","\\smallfrown");b(y,R,P,"≏","\\bumpeq",!0);b(y,R,P,"≎","\\Bumpeq",!0);b(y,R,P,"≧","\\geqq",!0);b(y,R,P,"⩾","\\geqslant",!0);b(y,R,P,"⪖","\\eqslantgtr",!0);b(y,R,P,"≳","\\gtrsim",!0);b(y,R,P,"⪆","\\gtrapprox",!0);b(y,R,ue,"⋗","\\gtrdot");b(y,R,P,"⋙","\\ggg",!0);b(y,R,P,"≷","\\gtrless",!0);b(y,R,P,"⋛","\\gtreqless",!0);b(y,R,P,"⪌","\\gtreqqless",!0);b(y,R,P,"≖","\\eqcirc",!0);b(y,R,P,"≗","\\circeq",!0);b(y,R,P,"≜","\\triangleq",!0);b(y,R,P,"∼","\\thicksim");b(y,R,P,"≈","\\thickapprox");b(y,R,P,"⫆","\\supseteqq",!0);b(y,R,P,"⋑","\\Supset",!0);b(y,R,P,"⊐","\\sqsupset",!0);b(y,R,P,"≽","\\succcurlyeq",!0);b(y,R,P,"⋟","\\curlyeqsucc",!0);b(y,R,P,"≿","\\succsim",!0);b(y,R,P,"⪸","\\succapprox",!0);b(y,R,P,"⊳","\\vartriangleright");b(y,R,P,"⊵","\\trianglerighteq");b(y,R,P,"⊩","\\Vdash",!0);b(y,R,P,"∣","\\shortmid");b(y,R,P,"∥","\\shortparallel");b(y,R,P,"≬","\\between",!0);b(y,R,P,"⋔","\\pitchfork",!0);b(y,R,P,"∝","\\varpropto");b(y,R,P,"◀","\\blacktriangleleft");b(y,R,P,"∴","\\therefore",!0);b(y,R,P,"∍","\\backepsilon");b(y,R,P,"▶","\\blacktriangleright");b(y,R,P,"∵","\\because",!0);b(y,R,P,"⋘","\\llless");b(y,R,P,"⋙","\\gggtr");b(y,R,ue,"⊲","\\lhd");b(y,R,ue,"⊳","\\rhd");b(y,R,P,"≂","\\eqsim",!0);b(y,E,P,"⋈","\\Join");b(y,R,P,"≑","\\Doteq",!0);b(y,R,ue,"∔","\\dotplus",!0);b(y,R,ue,"∖","\\smallsetminus");b(y,R,ue,"⋒","\\Cap",!0);b(y,R,ue,"⋓","\\Cup",!0);b(y,R,ue,"⩞","\\doublebarwedge",!0);b(y,R,ue,"⊟","\\boxminus",!0);b(y,R,ue,"⊞","\\boxplus",!0);b(y,R,ue,"⋇","\\divideontimes",!0);b(y,R,ue,"⋉","\\ltimes",!0);b(y,R,ue,"⋊","\\rtimes",!0);b(y,R,ue,"⋋","\\leftthreetimes",!0);b(y,R,ue,"⋌","\\rightthreetimes",!0);b(y,R,ue,"⋏","\\curlywedge",!0);b(y,R,ue,"⋎","\\curlyvee",!0);b(y,R,ue,"⊝","\\circleddash",!0);b(y,R,ue,"⊛","\\circledast",!0);b(y,R,ue,"⋅","\\centerdot");b(y,R,ue,"⊺","\\intercal",!0);b(y,R,ue,"⋒","\\doublecap");b(y,R,ue,"⋓","\\doublecup");b(y,R,ue,"⊠","\\boxtimes",!0);b(y,R,P,"⇢","\\dashrightarrow",!0);b(y,R,P,"⇠","\\dashleftarrow",!0);b(y,R,P,"⇇","\\leftleftarrows",!0);b(y,R,P,"⇆","\\leftrightarrows",!0);b(y,R,P,"⇚","\\Lleftarrow",!0);b(y,R,P,"↞","\\twoheadleftarrow",!0);b(y,R,P,"↢","\\leftarrowtail",!0);b(y,R,P,"↫","\\looparrowleft",!0);b(y,R,P,"⇋","\\leftrightharpoons",!0);b(y,R,P,"↶","\\curvearrowleft",!0);b(y,R,P,"↺","\\circlearrowleft",!0);b(y,R,P,"↰","\\Lsh",!0);b(y,R,P,"⇈","\\upuparrows",!0);b(y,R,P,"↿","\\upharpoonleft",!0);b(y,R,P,"⇃","\\downharpoonleft",!0);b(y,E,P,"⊶","\\origof",!0);b(y,E,P,"⊷","\\imageof",!0);b(y,R,P,"⊸","\\multimap",!0);b(y,R,P,"↭","\\leftrightsquigarrow",!0);b(y,R,P,"⇉","\\rightrightarrows",!0);b(y,R,P,"⇄","\\rightleftarrows",!0);b(y,R,P,"↠","\\twoheadrightarrow",!0);b(y,R,P,"↣","\\rightarrowtail",!0);b(y,R,P,"↬","\\looparrowright",!0);b(y,R,P,"↷","\\curvearrowright",!0);b(y,R,P,"↻","\\circlearrowright",!0);b(y,R,P,"↱","\\Rsh",!0);b(y,R,P,"⇊","\\downdownarrows",!0);b(y,R,P,"↾","\\upharpoonright",!0);b(y,R,P,"⇂","\\downharpoonright",!0);b(y,R,P,"⇝","\\rightsquigarrow",!0);b(y,R,P,"⇝","\\leadsto");b(y,R,P,"⇛","\\Rrightarrow",!0);b(y,R,P,"↾","\\restriction");b(y,E,B,"‘","`");b(y,E,B,"$","\\$");b(Y,E,B,"$","\\$");b(Y,E,B,"$","\\textdollar");b(y,E,B,"%","\\%");b(Y,E,B,"%","\\%");b(y,E,B,"_","\\_");b(Y,E,B,"_","\\_");b(Y,E,B,"_","\\textunderscore");b(y,E,B,"∠","\\angle",!0);b(y,E,B,"∞","\\infty",!0);b(y,E,B,"′","\\prime");b(y,E,B,"△","\\triangle");b(y,E,B,"Γ","\\Gamma",!0);b(y,E,B,"Δ","\\Delta",!0);b(y,E,B,"Θ","\\Theta",!0);b(y,E,B,"Λ","\\Lambda",!0);b(y,E,B,"Ξ","\\Xi",!0);b(y,E,B,"Π","\\Pi",!0);b(y,E,B,"Σ","\\Sigma",!0);b(y,E,B,"Υ","\\Upsilon",!0);b(y,E,B,"Φ","\\Phi",!0);b(y,E,B,"Ψ","\\Psi",!0);b(y,E,B,"Ω","\\Omega",!0);b(y,E,B,"A","Α");b(y,E,B,"B","Β");b(y,E,B,"E","Ε");b(y,E,B,"Z","Ζ");b(y,E,B,"H","Η");b(y,E,B,"I","Ι");b(y,E,B,"K","Κ");b(y,E,B,"M","Μ");b(y,E,B,"N","Ν");b(y,E,B,"O","Ο");b(y,E,B,"P","Ρ");b(y,E,B,"T","Τ");b(y,E,B,"X","Χ");b(y,E,B,"¬","\\neg",!0);b(y,E,B,"¬","\\lnot");b(y,E,B,"⊤","\\top");b(y,E,B,"⊥","\\bot");b(y,E,B,"∅","\\emptyset");b(y,R,B,"∅","\\varnothing");b(y,E,ge,"α","\\alpha",!0);b(y,E,ge,"β","\\beta",!0);b(y,E,ge,"γ","\\gamma",!0);b(y,E,ge,"δ","\\delta",!0);b(y,E,ge,"ϵ","\\epsilon",!0);b(y,E,ge,"ζ","\\zeta",!0);b(y,E,ge,"η","\\eta",!0);b(y,E,ge,"θ","\\theta",!0);b(y,E,ge,"ι","\\iota",!0);b(y,E,ge,"κ","\\kappa",!0);b(y,E,ge,"λ","\\lambda",!0);b(y,E,ge,"μ","\\mu",!0);b(y,E,ge,"ν","\\nu",!0);b(y,E,ge,"ξ","\\xi",!0);b(y,E,ge,"ο","\\omicron",!0);b(y,E,ge,"π","\\pi",!0);b(y,E,ge,"ρ","\\rho",!0);b(y,E,ge,"σ","\\sigma",!0);b(y,E,ge,"τ","\\tau",!0);b(y,E,ge,"υ","\\upsilon",!0);b(y,E,ge,"ϕ","\\phi",!0);b(y,E,ge,"χ","\\chi",!0);b(y,E,ge,"ψ","\\psi",!0);b(y,E,ge,"ω","\\omega",!0);b(y,E,ge,"ε","\\varepsilon",!0);b(y,E,ge,"ϑ","\\vartheta",!0);b(y,E,ge,"ϖ","\\varpi",!0);b(y,E,ge,"ϱ","\\varrho",!0);b(y,E,ge,"ς","\\varsigma",!0);b(y,E,ge,"φ","\\varphi",!0);b(y,E,ue,"∗","*",!0);b(y,E,ue,"+","+");b(y,E,ue,"−","-",!0);b(y,E,ue,"⋅","\\cdot",!0);b(y,E,ue,"∘","\\circ",!0);b(y,E,ue,"÷","\\div",!0);b(y,E,ue,"±","\\pm",!0);b(y,E,ue,"×","\\times",!0);b(y,E,ue,"∩","\\cap",!0);b(y,E,ue,"∪","\\cup",!0);b(y,E,ue,"∖","\\setminus",!0);b(y,E,ue,"∧","\\land");b(y,E,ue,"∨","\\lor");b(y,E,ue,"∧","\\wedge",!0);b(y,E,ue,"∨","\\vee",!0);b(y,E,B,"√","\\surd");b(y,E,ar,"⟨","\\langle",!0);b(y,E,ar,"∣","\\lvert");b(y,E,ar,"∥","\\lVert");b(y,E,zt,"?","?");b(y,E,zt,"!","!");b(y,E,zt,"⟩","\\rangle",!0);b(y,E,zt,"∣","\\rvert");b(y,E,zt,"∥","\\rVert");b(y,E,P,"=","=");b(y,E,P,":",":");b(y,E,P,"≈","\\approx",!0);b(y,E,P,"≅","\\cong",!0);b(y,E,P,"≥","\\ge");b(y,E,P,"≥","\\geq",!0);b(y,E,P,"←","\\gets");b(y,E,P,">","\\gt",!0);b(y,E,P,"∈","\\in",!0);b(y,E,P,"","\\@not");b(y,E,P,"⊂","\\subset",!0);b(y,E,P,"⊃","\\supset",!0);b(y,E,P,"⊆","\\subseteq",!0);b(y,E,P,"⊇","\\supseteq",!0);b(y,R,P,"⊈","\\nsubseteq",!0);b(y,R,P,"⊉","\\nsupseteq",!0);b(y,E,P,"⊨","\\models");b(y,E,P,"←","\\leftarrow",!0);b(y,E,P,"≤","\\le");b(y,E,P,"≤","\\leq",!0);b(y,E,P,"<","\\lt",!0);b(y,E,P,"→","\\rightarrow",!0);b(y,E,P,"→","\\to");b(y,R,P,"≱","\\ngeq",!0);b(y,R,P,"≰","\\nleq",!0);b(y,E,mn," ","\\ ");b(y,E,mn," ","\\space");b(y,E,mn," ","\\nobreakspace");b(Y,E,mn," ","\\ ");b(Y,E,mn," "," ");b(Y,E,mn," ","\\space");b(Y,E,mn," ","\\nobreakspace");b(y,E,mn,null,"\\nobreak");b(y,E,mn,null,"\\allowbreak");b(y,E,yu,",",",");b(y,E,yu,";",";");b(y,R,ue,"⊼","\\barwedge",!0);b(y,R,ue,"⊻","\\veebar",!0);b(y,E,ue,"⊙","\\odot",!0);b(y,E,ue,"⊕","\\oplus",!0);b(y,E,ue,"⊗","\\otimes",!0);b(y,E,B,"∂","\\partial",!0);b(y,E,ue,"⊘","\\oslash",!0);b(y,R,ue,"⊚","\\circledcirc",!0);b(y,R,ue,"⊡","\\boxdot",!0);b(y,E,ue,"△","\\bigtriangleup");b(y,E,ue,"▽","\\bigtriangledown");b(y,E,ue,"†","\\dagger");b(y,E,ue,"⋄","\\diamond");b(y,E,ue,"⋆","\\star");b(y,E,ue,"◃","\\triangleleft");b(y,E,ue,"▹","\\triangleright");b(y,E,ar,"{","\\{");b(Y,E,B,"{","\\{");b(Y,E,B,"{","\\textbraceleft");b(y,E,zt,"}","\\}");b(Y,E,B,"}","\\}");b(Y,E,B,"}","\\textbraceright");b(y,E,ar,"{","\\lbrace");b(y,E,zt,"}","\\rbrace");b(y,E,ar,"[","\\lbrack",!0);b(Y,E,B,"[","\\lbrack",!0);b(y,E,zt,"]","\\rbrack",!0);b(Y,E,B,"]","\\rbrack",!0);b(y,E,ar,"(","\\lparen",!0);b(y,E,zt,")","\\rparen",!0);b(Y,E,B,"<","\\textless",!0);b(Y,E,B,">","\\textgreater",!0);b(y,E,ar,"⌊","\\lfloor",!0);b(y,E,zt,"⌋","\\rfloor",!0);b(y,E,ar,"⌈","\\lceil",!0);b(y,E,zt,"⌉","\\rceil",!0);b(y,E,B,"\\","\\backslash");b(y,E,B,"∣","|");b(y,E,B,"∣","\\vert");b(Y,E,B,"|","\\textbar",!0);b(y,E,B,"∥","\\|");b(y,E,B,"∥","\\Vert");b(Y,E,B,"∥","\\textbardbl");b(Y,E,B,"~","\\textasciitilde");b(Y,E,B,"\\","\\textbackslash");b(Y,E,B,"^","\\textasciicircum");b(y,E,P,"↑","\\uparrow",!0);b(y,E,P,"⇑","\\Uparrow",!0);b(y,E,P,"↓","\\downarrow",!0);b(y,E,P,"⇓","\\Downarrow",!0);b(y,E,P,"↕","\\updownarrow",!0);b(y,E,P,"⇕","\\Updownarrow",!0);b(y,E,bt,"∐","\\coprod");b(y,E,bt,"⋁","\\bigvee");b(y,E,bt,"⋀","\\bigwedge");b(y,E,bt,"⨄","\\biguplus");b(y,E,bt,"⋂","\\bigcap");b(y,E,bt,"⋃","\\bigcup");b(y,E,bt,"∫","\\int");b(y,E,bt,"∫","\\intop");b(y,E,bt,"∬","\\iint");b(y,E,bt,"∭","\\iiint");b(y,E,bt,"∏","\\prod");b(y,E,bt,"∑","\\sum");b(y,E,bt,"⨂","\\bigotimes");b(y,E,bt,"⨁","\\bigoplus");b(y,E,bt,"⨀","\\bigodot");b(y,E,bt,"∮","\\oint");b(y,E,bt,"∯","\\oiint");b(y,E,bt,"∰","\\oiiint");b(y,E,bt,"⨆","\\bigsqcup");b(y,E,bt,"∫","\\smallint");b(Y,E,Ji,"…","\\textellipsis");b(y,E,Ji,"…","\\mathellipsis");b(Y,E,Ji,"…","\\ldots",!0);b(y,E,Ji,"…","\\ldots",!0);b(y,E,Ji,"⋯","\\@cdots",!0);b(y,E,Ji,"⋱","\\ddots",!0);b(y,E,B,"⋮","\\varvdots");b(y,E,at,"ˊ","\\acute");b(y,E,at,"ˋ","\\grave");b(y,E,at,"¨","\\ddot");b(y,E,at,"~","\\tilde");b(y,E,at,"ˉ","\\bar");b(y,E,at,"˘","\\breve");b(y,E,at,"ˇ","\\check");b(y,E,at,"^","\\hat");b(y,E,at,"⃗","\\vec");b(y,E,at,"˙","\\dot");b(y,E,at,"˚","\\mathring");b(y,E,ge,"","\\@imath");b(y,E,ge,"","\\@jmath");b(y,E,B,"ı","ı");b(y,E,B,"ȷ","ȷ");b(Y,E,B,"ı","\\i",!0);b(Y,E,B,"ȷ","\\j",!0);b(Y,E,B,"ß","\\ss",!0);b(Y,E,B,"æ","\\ae",!0);b(Y,E,B,"œ","\\oe",!0);b(Y,E,B,"ø","\\o",!0);b(Y,E,B,"Æ","\\AE",!0);b(Y,E,B,"Œ","\\OE",!0);b(Y,E,B,"Ø","\\O",!0);b(Y,E,at,"ˊ","\\'");b(Y,E,at,"ˋ","\\`");b(Y,E,at,"ˆ","\\^");b(Y,E,at,"˜","\\~");b(Y,E,at,"ˉ","\\=");b(Y,E,at,"˘","\\u");b(Y,E,at,"˙","\\.");b(Y,E,at,"¸","\\c");b(Y,E,at,"˚","\\r");b(Y,E,at,"ˇ","\\v");b(Y,E,at,"¨",'\\"');b(Y,E,at,"˝","\\H");b(Y,E,at,"◯","\\textcircled");var s2={"--":!0,"---":!0,"``":!0,"''":!0};b(Y,E,B,"–","--",!0);b(Y,E,B,"–","\\textendash");b(Y,E,B,"—","---",!0);b(Y,E,B,"—","\\textemdash");b(Y,E,B,"‘","`",!0);b(Y,E,B,"‘","\\textquoteleft");b(Y,E,B,"’","'",!0);b(Y,E,B,"’","\\textquoteright");b(Y,E,B,"“","``",!0);b(Y,E,B,"“","\\textquotedblleft");b(Y,E,B,"”","''",!0);b(Y,E,B,"”","\\textquotedblright");b(y,E,B,"°","\\degree",!0);b(Y,E,B,"°","\\degree");b(Y,E,B,"°","\\textdegree",!0);b(y,E,B,"£","\\pounds");b(y,E,B,"£","\\mathsterling",!0);b(Y,E,B,"£","\\pounds");b(Y,E,B,"£","\\textsterling",!0);b(y,R,B,"✠","\\maltese");b(Y,R,B,"✠","\\maltese");var jh='0123456789/@."';for(var gl=0;gl<jh.length;gl++){var Vh=jh.charAt(gl);b(y,E,B,Vh,Vh)}var Gh='0123456789!@*()-=+";:?/.,';for(var bl=0;bl<Gh.length;bl++){var Wh=Gh.charAt(bl);b(Y,E,B,Wh,Wh)}var Ns="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";for(var vl=0;vl<Ns.length;vl++){var vo=Ns.charAt(vl);b(y,E,ge,vo,vo),b(Y,E,B,vo,vo)}b(y,R,B,"C","ℂ");b(Y,R,B,"C","ℂ");b(y,R,B,"H","ℍ");b(Y,R,B,"H","ℍ");b(y,R,B,"N","ℕ");b(Y,R,B,"N","ℕ");b(y,R,B,"P","ℙ");b(Y,R,B,"P","ℙ");b(y,R,B,"Q","ℚ");b(Y,R,B,"Q","ℚ");b(y,R,B,"R","ℝ");b(Y,R,B,"R","ℝ");b(y,R,B,"Z","ℤ");b(Y,R,B,"Z","ℤ");b(y,E,ge,"h","ℎ");b(Y,E,ge,"h","ℎ");var Se="";for(var It=0;It<Ns.length;It++){var lt=Ns.charAt(It);Se=String.fromCharCode(55349,56320+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56372+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56424+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56580+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56684+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56736+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56788+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56840+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56944+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),It<26&&(Se=String.fromCharCode(55349,56632+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se),Se=String.fromCharCode(55349,56476+It),b(y,E,ge,lt,Se),b(Y,E,B,lt,Se))}Se=String.fromCharCode(55349,56668);b(y,E,ge,"k",Se);b(Y,E,B,"k",Se);for(var Gn=0;Gn<10;Gn++){var En=Gn.toString();Se=String.fromCharCode(55349,57294+Gn),b(y,E,ge,En,Se),b(Y,E,B,En,Se),Se=String.fromCharCode(55349,57314+Gn),b(y,E,ge,En,Se),b(Y,E,B,En,Se),Se=String.fromCharCode(55349,57324+Gn),b(y,E,ge,En,Se),b(Y,E,B,En,Se),Se=String.fromCharCode(55349,57334+Gn),b(y,E,ge,En,Se),b(Y,E,B,En,Se)}var _0="ÐÞþ";for(var yl=0;yl<_0.length;yl++){var yo=_0.charAt(yl);b(y,E,ge,yo,yo),b(Y,E,B,yo,yo)}var wo=[["mathbf","textbf","Main-Bold"],["mathbf","textbf","Main-Bold"],["mathnormal","textit","Math-Italic"],["mathnormal","textit","Math-Italic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["mathscr","textscr","Script-Regular"],["","",""],["","",""],["","",""],["mathfrak","textfrak","Fraktur-Regular"],["mathfrak","textfrak","Fraktur-Regular"],["mathbb","textbb","AMS-Regular"],["mathbb","textbb","AMS-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathitsf","textitsf","SansSerif-Italic"],["mathitsf","textitsf","SansSerif-Italic"],["","",""],["","",""],["mathtt","texttt","Typewriter-Regular"],["mathtt","texttt","Typewriter-Regular"]],Kh=[["mathbf","textbf","Main-Bold"],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathtt","texttt","Typewriter-Regular"]],$x=function(t,r){var n=t.charCodeAt(0),i=t.charCodeAt(1),a=(n-55296)*1024+(i-56320)+65536,o=r==="math"?0:1;if(119808<=a&&a<120484){var s=Math.floor((a-119808)/26);return[wo[s][2],wo[s][o]]}else if(120782<=a&&a<=120831){var u=Math.floor((a-120782)/10);return[Kh[u][2],Kh[u][o]]}else{if(a===120485||a===120486)return[wo[0][2],wo[0][o]];if(120486<a&&a<120782)return["",""];throw new te("Unsupported character: "+t)}},wu=function(t,r,n){return tt[n][t]&&tt[n][t].replace&&(t=tt[n][t].replace),{value:t,metrics:gf(t,r,n)}},kr=function(t,r,n,i,a){var o=wu(t,r,n),s=o.metrics;t=o.value;var u;if(s){var l=s.italic;(n==="text"||i&&i.font==="mathit")&&(l=0),u=new mr(t,s.height,s.depth,l,s.skew,s.width,a)}else typeof console<"u"&&console.warn("No character metrics "+("for '"+t+"' in style '"+r+"' and mode '"+n+"'")),u=new mr(t,0,0,0,0,0,a);if(i){u.maxFontSize=i.sizeMultiplier,i.style.isTight()&&u.classes.push("mtight");var c=i.getColor();c&&(u.style.color=c)}return u},Ux=function(t,r,n,i){return i===void 0&&(i=[]),n.font==="boldsymbol"&&wu(t,"Main-Bold",r).metrics?kr(t,"Main-Bold",r,n,i.concat(["mathbf"])):t==="\\"||tt[r][t].font==="main"?kr(t,"Main-Regular",r,n,i):kr(t,"AMS-Regular",r,n,i.concat(["amsrm"]))},Hx=function(t,r,n,i,a){return a!=="textord"&&wu(t,"Math-BoldItalic",r).metrics?{fontName:"Math-BoldItalic",fontClass:"boldsymbol"}:{fontName:"Main-Bold",fontClass:"mathbf"}},qx=function(t,r,n){var i=t.mode,a=t.text,o=["mord"],s=i==="math"||i==="text"&&r.font,u=s?r.font:r.fontFamily,l="",c="";if(a.charCodeAt(0)===55349&&([l,c]=$x(a,i)),l.length>0)return kr(a,l,i,r,o.concat(c));if(u){var f,d;if(u==="boldsymbol"){var h=Hx(a,i,r,o,n);f=h.fontName,d=[h.fontClass]}else s?(f=c2[u].fontName,d=[u]):(f=xo(u,r.fontWeight,r.fontShape),d=[u,r.fontWeight,r.fontShape]);if(wu(a,f,i).metrics)return kr(a,f,i,r,o.concat(d));if(s2.hasOwnProperty(a)&&f.slice(0,10)==="Typewriter"){for(var p=[],m=0;m<a.length;m++)p.push(kr(a[m],f,i,r,o.concat(d)));return l2(p)}}if(n==="mathord")return kr(a,"Math-Italic",i,r,o.concat(["mathnormal"]));if(n==="textord"){var g=tt[i][a]&&tt[i][a].font;if(g==="ams"){var v=xo("amsrm",r.fontWeight,r.fontShape);return kr(a,v,i,r,o.concat("amsrm",r.fontWeight,r.fontShape))}else if(g==="main"||!g){var w=xo("textrm",r.fontWeight,r.fontShape);return kr(a,w,i,r,o.concat(r.fontWeight,r.fontShape))}else{var x=xo(g,r.fontWeight,r.fontShape);return kr(a,x,i,r,o.concat(x,r.fontWeight,r.fontShape))}}else throw new Error("unexpected type: "+n+" in makeOrd")},jx=(e,t)=>{if(Rn(e.classes)!==Rn(t.classes)||e.skew!==t.skew||e.maxFontSize!==t.maxFontSize)return!1;if(e.classes.length===1){var r=e.classes[0];if(r==="mbin"||r==="mord")return!1}for(var n in e.style)if(e.style.hasOwnProperty(n)&&e.style[n]!==t.style[n])return!1;for(var i in t.style)if(t.style.hasOwnProperty(i)&&e.style[i]!==t.style[i])return!1;return!0},Vx=e=>{for(var t=0;t<e.length-1;t++){var r=e[t],n=e[t+1];r instanceof mr&&n instanceof mr&&jx(r,n)&&(r.text+=n.text,r.height=Math.max(r.height,n.height),r.depth=Math.max(r.depth,n.depth),r.italic=n.italic,e.splice(t+1,1),t--)}return e},vf=function(t){for(var r=0,n=0,i=0,a=0;a<t.children.length;a++){var o=t.children[a];o.height>r&&(r=o.height),o.depth>n&&(n=o.depth),o.maxFontSize>i&&(i=o.maxFontSize)}t.height=r,t.depth=n,t.maxFontSize=i},Ht=function(t,r,n,i){var a=new Ya(t,r,n,i);return vf(a),a},u2=(e,t,r,n)=>new Ya(e,t,r,n),Gx=function(t,r,n){var i=Ht([t],[],r);return i.height=Math.max(n||r.fontMetrics().defaultRuleThickness,r.minRuleThickness),i.style.borderBottomWidth=ie(i.height),i.maxFontSize=1,i},Wx=function(t,r,n,i){var a=new bf(t,r,n,i);return vf(a),a},l2=function(t){var r=new Xa(t);return vf(r),r},Kx=function(t,r){return t instanceof Xa?Ht([],[t],r):t},Xx=function(t){if(t.positionType==="individualShift"){for(var r=t.children,n=[r[0]],i=-r[0].shift-r[0].elem.depth,a=i,o=1;o<r.length;o++){var s=-r[o].shift-a-r[o].elem.depth,u=s-(r[o-1].elem.height+r[o-1].elem.depth);a=a+s,n.push({type:"kern",size:u}),n.push(r[o])}return{children:n,depth:i}}var l;if(t.positionType==="top"){for(var c=t.positionData,f=0;f<t.children.length;f++){var d=t.children[f];c-=d.type==="kern"?d.size:d.elem.height+d.elem.depth}l=c}else if(t.positionType==="bottom")l=-t.positionData;else{var h=t.children[0];if(h.type!=="elem")throw new Error('First child must have type "elem".');if(t.positionType==="shift")l=-h.elem.depth-t.positionData;else if(t.positionType==="firstBaseline")l=-h.elem.depth;else throw new Error("Invalid positionType "+t.positionType+".")}return{children:t.children,depth:l}},Yx=function(t,r){for(var{children:n,depth:i}=Xx(t),a=0,o=0;o<n.length;o++){var s=n[o];if(s.type==="elem"){var u=s.elem;a=Math.max(a,u.maxFontSize,u.height)}}a+=2;var l=Ht(["pstrut"],[]);l.style.height=ie(a);for(var c=[],f=i,d=i,h=i,p=0;p<n.length;p++){var m=n[p];if(m.type==="kern")h+=m.size;else{var g=m.elem,v=m.wrapperClasses||[],w=m.wrapperStyle||{},x=Ht(v,[l,g],void 0,w);x.style.top=ie(-a-h-g.depth),m.marginLeft&&(x.style.marginLeft=m.marginLeft),m.marginRight&&(x.style.marginRight=m.marginRight),c.push(x),h+=g.height+g.depth}f=Math.min(f,h),d=Math.max(d,h)}var N=Ht(["vlist"],c);N.style.height=ie(d);var O;if(f<0){var A=Ht([],[]),D=Ht(["vlist"],[A]);D.style.height=ie(-f);var H=Ht(["vlist-s"],[new mr("​")]);O=[Ht(["vlist-r"],[N,H]),Ht(["vlist-r"],[D])]}else O=[Ht(["vlist-r"],[N])];var z=Ht(["vlist-t"],O);return O.length===2&&z.classes.push("vlist-t2"),z.height=d,z.depth=-f,z},Zx=(e,t)=>{var r=Ht(["mspace"],[],t),n=st(e,t);return r.style.marginRight=ie(n),r},xo=function(t,r,n){var i="";switch(t){case"amsrm":i="AMS";break;case"textrm":i="Main";break;case"textsf":i="SansSerif";break;case"texttt":i="Typewriter";break;default:i=t}var a;return r==="textbf"&&n==="textit"?a="BoldItalic":r==="textbf"?a="Bold":r==="textit"?a="Italic":a="Regular",i+"-"+a},c2={mathbf:{variant:"bold",fontName:"Main-Bold"},mathrm:{variant:"normal",fontName:"Main-Regular"},textit:{variant:"italic",fontName:"Main-Italic"},mathit:{variant:"italic",fontName:"Main-Italic"},mathnormal:{variant:"italic",fontName:"Math-Italic"},mathbb:{variant:"double-struck",fontName:"AMS-Regular"},mathcal:{variant:"script",fontName:"Caligraphic-Regular"},mathfrak:{variant:"fraktur",fontName:"Fraktur-Regular"},mathscr:{variant:"script",fontName:"Script-Regular"},mathsf:{variant:"sans-serif",fontName:"SansSerif-Regular"},mathtt:{variant:"monospace",fontName:"Typewriter-Regular"}},f2={vec:["vec",.471,.714],oiintSize1:["oiintSize1",.957,.499],oiintSize2:["oiintSize2",1.472,.659],oiiintSize1:["oiiintSize1",1.304,.499],oiiintSize2:["oiiintSize2",1.98,.659]},Qx=function(t,r){var[n,i,a]=f2[t],o=new In(n),s=new ln([o],{width:ie(i),height:ie(a),style:"width:"+ie(i),viewBox:"0 0 "+1e3*i+" "+1e3*a,preserveAspectRatio:"xMinYMin"}),u=u2(["overlay"],[s],r);return u.height=a,u.style.height=ie(a),u.style.width=ie(i),u},j={fontMap:c2,makeSymbol:kr,mathsym:Ux,makeSpan:Ht,makeSvgSpan:u2,makeLineSpan:Gx,makeAnchor:Wx,makeFragment:l2,wrapFragment:Kx,makeVList:Yx,makeOrd:qx,makeGlue:Zx,staticSvg:Qx,svgData:f2,tryCombineChars:Vx},ot={number:3,unit:"mu"},Wn={number:4,unit:"mu"},Jr={number:5,unit:"mu"},Jx={mord:{mop:ot,mbin:Wn,mrel:Jr,minner:ot},mop:{mord:ot,mop:ot,mrel:Jr,minner:ot},mbin:{mord:Wn,mop:Wn,mopen:Wn,minner:Wn},mrel:{mord:Jr,mop:Jr,mopen:Jr,minner:Jr},mopen:{},mclose:{mop:ot,mbin:Wn,mrel:Jr,minner:ot},mpunct:{mord:ot,mop:ot,mrel:Jr,mopen:ot,mclose:ot,mpunct:ot,minner:ot},minner:{mord:ot,mop:ot,mbin:Wn,mrel:Jr,mopen:ot,mpunct:ot,minner:ot}},e9={mord:{mop:ot},mop:{mord:ot,mop:ot},mbin:{},mrel:{},mopen:{},mclose:{mop:ot},mpunct:{},minner:{mop:ot}},d2={},_s={},Cs={};function ae(e){for(var{type:t,names:r,props:n,handler:i,htmlBuilder:a,mathmlBuilder:o}=e,s={type:t,numArgs:n.numArgs,argTypes:n.argTypes,allowedInArgument:!!n.allowedInArgument,allowedInText:!!n.allowedInText,allowedInMath:n.allowedInMath===void 0?!0:n.allowedInMath,numOptionalArgs:n.numOptionalArgs||0,infix:!!n.infix,primitive:!!n.primitive,handler:i},u=0;u<r.length;++u)d2[r[u]]=s;t&&(a&&(_s[t]=a),o&&(Cs[t]=o))}function ci(e){var{type:t,htmlBuilder:r,mathmlBuilder:n}=e;ae({type:t,names:[],props:{numArgs:0},handler(){throw new Error("Should never be called.")},htmlBuilder:r,mathmlBuilder:n})}var Ms=function(t){return t.type==="ordgroup"&&t.body.length===1?t.body[0]:t},pt=function(t){return t.type==="ordgroup"?t.body:[t]},cn=j.makeSpan,t9=["leftmost","mbin","mopen","mrel","mop","mpunct"],r9=["rightmost","mrel","mclose","mpunct"],n9={display:be.DISPLAY,text:be.TEXT,script:be.SCRIPT,scriptscript:be.SCRIPTSCRIPT},i9={mord:"mord",mop:"mop",mbin:"mbin",mrel:"mrel",mopen:"mopen",mclose:"mclose",mpunct:"mpunct",minner:"minner"},yt=function(t,r,n,i){i===void 0&&(i=[null,null]);for(var a=[],o=0;o<t.length;o++){var s=Ue(t[o],r);if(s instanceof Xa){var u=s.children;a.push(...u)}else a.push(s)}if(j.tryCombineChars(a),!n)return a;var l=r;if(t.length===1){var c=t[0];c.type==="sizing"?l=r.havingSize(c.size):c.type==="styling"&&(l=r.havingStyle(n9[c.style]))}var f=cn([i[0]||"leftmost"],[],r),d=cn([i[1]||"rightmost"],[],r),h=n==="root";return Xh(a,(p,m)=>{var g=m.classes[0],v=p.classes[0];g==="mbin"&&Te.contains(r9,v)?m.classes[0]="mord":v==="mbin"&&Te.contains(t9,g)&&(p.classes[0]="mord")},{node:f},d,h),Xh(a,(p,m)=>{var g=C0(m),v=C0(p),w=g&&v?p.hasClass("mtight")?e9[g][v]:Jx[g][v]:null;if(w)return j.makeGlue(w,l)},{node:f},d,h),a},Xh=function e(t,r,n,i,a){i&&t.push(i);for(var o=0;o<t.length;o++){var s=t[o],u=h2(s);if(u){e(u.children,r,n,null,a);continue}var l=!s.hasClass("mspace");if(l){var c=r(s,n.node);c&&(n.insertAfter?n.insertAfter(c):(t.unshift(c),o++))}l?n.node=s:a&&s.hasClass("newline")&&(n.node=cn(["leftmost"])),n.insertAfter=(f=>d=>{t.splice(f+1,0,d),o++})(o)}i&&t.pop()},h2=function(t){return t instanceof Xa||t instanceof bf||t instanceof Ya&&t.hasClass("enclosing")?t:null},a9=function e(t,r){var n=h2(t);if(n){var i=n.children;if(i.length){if(r==="right")return e(i[i.length-1],"right");if(r==="left")return e(i[0],"left")}}return t},C0=function(t,r){return t?(r&&(t=a9(t,r)),i9[t.classes[0]]||null):null},Na=function(t,r){var n=["nulldelimiter"].concat(t.baseSizingClasses());return cn(r.concat(n))},Ue=function(t,r,n){if(!t)return cn();if(_s[t.type]){var i=_s[t.type](t,r);if(n&&r.size!==n.size){i=cn(r.sizingClasses(n),[i],r);var a=r.sizeMultiplier/n.sizeMultiplier;i.height*=a,i.depth*=a}return i}else throw new te("Got group of unknown type: '"+t.type+"'")};function Eo(e,t){var r=cn(["base"],e,t),n=cn(["strut"]);return n.style.height=ie(r.height+r.depth),r.depth&&(n.style.verticalAlign=ie(-r.depth)),r.children.unshift(n),r}function M0(e,t){var r=null;e.length===1&&e[0].type==="tag"&&(r=e[0].tag,e=e[0].body);var n=yt(e,t,"root"),i;n.length===2&&n[1].hasClass("tag")&&(i=n.pop());for(var a=[],o=[],s=0;s<n.length;s++)if(o.push(n[s]),n[s].hasClass("mbin")||n[s].hasClass("mrel")||n[s].hasClass("allowbreak")){for(var u=!1;s<n.length-1&&n[s+1].hasClass("mspace")&&!n[s+1].hasClass("newline");)s++,o.push(n[s]),n[s].hasClass("nobreak")&&(u=!0);u||(a.push(Eo(o,t)),o=[])}else n[s].hasClass("newline")&&(o.pop(),o.length>0&&(a.push(Eo(o,t)),o=[]),a.push(n[s]));o.length>0&&a.push(Eo(o,t));var l;r?(l=Eo(yt(r,t,!0)),l.classes=["tag"],a.push(l)):i&&a.push(i);var c=cn(["katex-html"],a);if(c.setAttribute("aria-hidden","true"),l){var f=l.children[0];f.style.height=ie(c.height+c.depth),c.depth&&(f.style.verticalAlign=ie(-c.depth))}return c}function p2(e){return new Xa(e)}class dr{constructor(t,r,n){this.type=void 0,this.attributes=void 0,this.children=void 0,this.classes=void 0,this.type=t,this.attributes={},this.children=r||[],this.classes=n||[]}setAttribute(t,r){this.attributes[t]=r}getAttribute(t){return this.attributes[t]}toNode(){var t=document.createElementNS("http://www.w3.org/1998/Math/MathML",this.type);for(var r in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,r)&&t.setAttribute(r,this.attributes[r]);this.classes.length>0&&(t.className=Rn(this.classes));for(var n=0;n<this.children.length;n++)t.appendChild(this.children[n].toNode());return t}toMarkup(){var t="<"+this.type;for(var r in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,r)&&(t+=" "+r+'="',t+=Te.escape(this.attributes[r]),t+='"');this.classes.length>0&&(t+=' class ="'+Te.escape(Rn(this.classes))+'"'),t+=">";for(var n=0;n<this.children.length;n++)t+=this.children[n].toMarkup();return t+="</"+this.type+">",t}toText(){return this.children.map(t=>t.toText()).join("")}}class ga{constructor(t){this.text=void 0,this.text=t}toNode(){return document.createTextNode(this.text)}toMarkup(){return Te.escape(this.toText())}toText(){return this.text}}class o9{constructor(t){this.width=void 0,this.character=void 0,this.width=t,t>=.05555&&t<=.05556?this.character=" ":t>=.1666&&t<=.1667?this.character=" ":t>=.2222&&t<=.2223?this.character=" ":t>=.2777&&t<=.2778?this.character="  ":t>=-.05556&&t<=-.05555?this.character=" ⁣":t>=-.1667&&t<=-.1666?this.character=" ⁣":t>=-.2223&&t<=-.2222?this.character=" ⁣":t>=-.2778&&t<=-.2777?this.character=" ⁣":this.character=null}toNode(){if(this.character)return document.createTextNode(this.character);var t=document.createElementNS("http://www.w3.org/1998/Math/MathML","mspace");return t.setAttribute("width",ie(this.width)),t}toMarkup(){return this.character?"<mtext>"+this.character+"</mtext>":'<mspace width="'+ie(this.width)+'"/>'}toText(){return this.character?this.character:" "}}var Q={MathNode:dr,TextNode:ga,SpaceNode:o9,newDocumentFragment:p2},gr=function(t,r,n){return tt[r][t]&&tt[r][t].replace&&t.charCodeAt(0)!==55349&&!(s2.hasOwnProperty(t)&&n&&(n.fontFamily&&n.fontFamily.slice(4,6)==="tt"||n.font&&n.font.slice(4,6)==="tt"))&&(t=tt[r][t].replace),new Q.TextNode(t)},yf=function(t){return t.length===1?t[0]:new Q.MathNode("mrow",t)},wf=function(t,r){if(r.fontFamily==="texttt")return"monospace";if(r.fontFamily==="textsf")return r.fontShape==="textit"&&r.fontWeight==="textbf"?"sans-serif-bold-italic":r.fontShape==="textit"?"sans-serif-italic":r.fontWeight==="textbf"?"bold-sans-serif":"sans-serif";if(r.fontShape==="textit"&&r.fontWeight==="textbf")return"bold-italic";if(r.fontShape==="textit")return"italic";if(r.fontWeight==="textbf")return"bold";var n=r.font;if(!n||n==="mathnormal")return null;var i=t.mode;if(n==="mathit")return"italic";if(n==="boldsymbol")return t.type==="textord"?"bold":"bold-italic";if(n==="mathbf")return"bold";if(n==="mathbb")return"double-struck";if(n==="mathfrak")return"fraktur";if(n==="mathscr"||n==="mathcal")return"script";if(n==="mathsf")return"sans-serif";if(n==="mathtt")return"monospace";var a=t.text;if(Te.contains(["\\imath","\\jmath"],a))return null;tt[i][a]&&tt[i][a].replace&&(a=tt[i][a].replace);var o=j.fontMap[n].fontName;return gf(a,o,i)?j.fontMap[n].variant:null},Kt=function(t,r,n){if(t.length===1){var i=Je(t[0],r);return n&&i instanceof dr&&i.type==="mo"&&(i.setAttribute("lspace","0em"),i.setAttribute("rspace","0em")),[i]}for(var a=[],o,s=0;s<t.length;s++){var u=Je(t[s],r);if(u instanceof dr&&o instanceof dr){if(u.type==="mtext"&&o.type==="mtext"&&u.getAttribute("mathvariant")===o.getAttribute("mathvariant")){o.children.push(...u.children);continue}else if(u.type==="mn"&&o.type==="mn"){o.children.push(...u.children);continue}else if(u.type==="mi"&&u.children.length===1&&o.type==="mn"){var l=u.children[0];if(l instanceof ga&&l.text==="."){o.children.push(...u.children);continue}}else if(o.type==="mi"&&o.children.length===1){var c=o.children[0];if(c instanceof ga&&c.text==="̸"&&(u.type==="mo"||u.type==="mi"||u.type==="mn")){var f=u.children[0];f instanceof ga&&f.text.length>0&&(f.text=f.text.slice(0,1)+"̸"+f.text.slice(1),a.pop())}}}a.push(u),o=u}return a},Pn=function(t,r,n){return yf(Kt(t,r,n))},Je=function(t,r){if(!t)return new Q.MathNode("mrow");if(Cs[t.type]){var n=Cs[t.type](t,r);return n}else throw new te("Got group of unknown type: '"+t.type+"'")};function Yh(e,t,r,n,i){var a=Kt(e,r),o;a.length===1&&a[0]instanceof dr&&Te.contains(["mrow","mtable"],a[0].type)?o=a[0]:o=new Q.MathNode("mrow",a);var s=new Q.MathNode("annotation",[new Q.TextNode(t)]);s.setAttribute("encoding","application/x-tex");var u=new Q.MathNode("semantics",[o,s]),l=new Q.MathNode("math",[u]);l.setAttribute("xmlns","http://www.w3.org/1998/Math/MathML"),n&&l.setAttribute("display","block");var c=i?"katex":"katex-mathml";return j.makeSpan([c],[l])}var m2=function(t){return new nn({style:t.displayMode?be.DISPLAY:be.TEXT,maxSize:t.maxSize,minRuleThickness:t.minRuleThickness})},g2=function(t,r){if(r.displayMode){var n=["katex-display"];r.leqno&&n.push("leqno"),r.fleqn&&n.push("fleqn"),t=j.makeSpan(n,[t])}return t},s9=function(t,r,n){var i=m2(n),a;if(n.output==="mathml")return Yh(t,r,i,n.displayMode,!0);if(n.output==="html"){var o=M0(t,i);a=j.makeSpan(["katex"],[o])}else{var s=Yh(t,r,i,n.displayMode,!1),u=M0(t,i);a=j.makeSpan(["katex"],[s,u])}return g2(a,n)},u9=function(t,r,n){var i=m2(n),a=M0(t,i),o=j.makeSpan(["katex"],[a]);return g2(o,n)},l9={widehat:"^",widecheck:"ˇ",widetilde:"~",utilde:"~",overleftarrow:"←",underleftarrow:"←",xleftarrow:"←",overrightarrow:"→",underrightarrow:"→",xrightarrow:"→",underbrace:"⏟",overbrace:"⏞",overgroup:"⏠",undergroup:"⏡",overleftrightarrow:"↔",underleftrightarrow:"↔",xleftrightarrow:"↔",Overrightarrow:"⇒",xRightarrow:"⇒",overleftharpoon:"↼",xleftharpoonup:"↼",overrightharpoon:"⇀",xrightharpoonup:"⇀",xLeftarrow:"⇐",xLeftrightarrow:"⇔",xhookleftarrow:"↩",xhookrightarrow:"↪",xmapsto:"↦",xrightharpoondown:"⇁",xleftharpoondown:"↽",xrightleftharpoons:"⇌",xleftrightharpoons:"⇋",xtwoheadleftarrow:"↞",xtwoheadrightarrow:"↠",xlongequal:"=",xtofrom:"⇄",xrightleftarrows:"⇄",xrightequilibrium:"⇌",xleftequilibrium:"⇋","\\cdrightarrow":"→","\\cdleftarrow":"←","\\cdlongequal":"="},c9=function(t){var r=new Q.MathNode("mo",[new Q.TextNode(l9[t.replace(/^\\/,"")])]);return r.setAttribute("stretchy","true"),r},f9={overrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],overleftarrow:[["leftarrow"],.888,522,"xMinYMin"],underrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],underleftarrow:[["leftarrow"],.888,522,"xMinYMin"],xrightarrow:[["rightarrow"],1.469,522,"xMaxYMin"],"\\cdrightarrow":[["rightarrow"],3,522,"xMaxYMin"],xleftarrow:[["leftarrow"],1.469,522,"xMinYMin"],"\\cdleftarrow":[["leftarrow"],3,522,"xMinYMin"],Overrightarrow:[["doublerightarrow"],.888,560,"xMaxYMin"],xRightarrow:[["doublerightarrow"],1.526,560,"xMaxYMin"],xLeftarrow:[["doubleleftarrow"],1.526,560,"xMinYMin"],overleftharpoon:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoonup:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoondown:[["leftharpoondown"],.888,522,"xMinYMin"],overrightharpoon:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoonup:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoondown:[["rightharpoondown"],.888,522,"xMaxYMin"],xlongequal:[["longequal"],.888,334,"xMinYMin"],"\\cdlongequal":[["longequal"],3,334,"xMinYMin"],xtwoheadleftarrow:[["twoheadleftarrow"],.888,334,"xMinYMin"],xtwoheadrightarrow:[["twoheadrightarrow"],.888,334,"xMaxYMin"],overleftrightarrow:[["leftarrow","rightarrow"],.888,522],overbrace:[["leftbrace","midbrace","rightbrace"],1.6,548],underbrace:[["leftbraceunder","midbraceunder","rightbraceunder"],1.6,548],underleftrightarrow:[["leftarrow","rightarrow"],.888,522],xleftrightarrow:[["leftarrow","rightarrow"],1.75,522],xLeftrightarrow:[["doubleleftarrow","doublerightarrow"],1.75,560],xrightleftharpoons:[["leftharpoondownplus","rightharpoonplus"],1.75,716],xleftrightharpoons:[["leftharpoonplus","rightharpoondownplus"],1.75,716],xhookleftarrow:[["leftarrow","righthook"],1.08,522],xhookrightarrow:[["lefthook","rightarrow"],1.08,522],overlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],underlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],overgroup:[["leftgroup","rightgroup"],.888,342],undergroup:[["leftgroupunder","rightgroupunder"],.888,342],xmapsto:[["leftmapsto","rightarrow"],1.5,522],xtofrom:[["leftToFrom","rightToFrom"],1.75,528],xrightleftarrows:[["baraboveleftarrow","rightarrowabovebar"],1.75,901],xrightequilibrium:[["baraboveshortleftharpoon","rightharpoonaboveshortbar"],1.75,716],xleftequilibrium:[["shortbaraboveleftharpoon","shortrightharpoonabovebar"],1.75,716]},d9=function(t){return t.type==="ordgroup"?t.body.length:1},h9=function(t,r){function n(){var s=4e5,u=t.label.slice(1);if(Te.contains(["widehat","widecheck","widetilde","utilde"],u)){var l=t,c=d9(l.base),f,d,h;if(c>5)u==="widehat"||u==="widecheck"?(f=420,s=2364,h=.42,d=u+"4"):(f=312,s=2340,h=.34,d="tilde4");else{var p=[1,1,2,2,3,3][c];u==="widehat"||u==="widecheck"?(s=[0,1062,2364,2364,2364][p],f=[0,239,300,360,420][p],h=[0,.24,.3,.3,.36,.42][p],d=u+p):(s=[0,600,1033,2339,2340][p],f=[0,260,286,306,312][p],h=[0,.26,.286,.3,.306,.34][p],d="tilde"+p)}var m=new In(d),g=new ln([m],{width:"100%",height:ie(h),viewBox:"0 0 "+s+" "+f,preserveAspectRatio:"none"});return{span:j.makeSvgSpan([],[g],r),minWidth:0,height:h}}else{var v=[],w=f9[u],[x,N,O]=w,A=O/1e3,D=x.length,H,z;if(D===1){var L=w[3];H=["hide-tail"],z=[L]}else if(D===2)H=["halfarrow-left","halfarrow-right"],z=["xMinYMin","xMaxYMin"];else if(D===3)H=["brace-left","brace-center","brace-right"],z=["xMinYMin","xMidYMin","xMaxYMin"];else throw new Error(`Correct katexImagesData or update code here to support
                    `+D+" children.");for(var I=0;I<D;I++){var k=new In(x[I]),M=new ln([k],{width:"400em",height:ie(A),viewBox:"0 0 "+s+" "+O,preserveAspectRatio:z[I]+" slice"}),F=j.makeSvgSpan([H[I]],[M],r);if(D===1)return{span:F,minWidth:N,height:A};F.style.height=ie(A),v.push(F)}return{span:j.makeSpan(["stretchy"],v,r),minWidth:N,height:A}}}var{span:i,minWidth:a,height:o}=n();return i.height=o,i.style.height=ie(o),a>0&&(i.style.minWidth=ie(a)),i},p9=function(t,r,n,i,a){var o,s=t.height+t.depth+n+i;if(/fbox|color|angl/.test(r)){if(o=j.makeSpan(["stretchy",r],[],a),r==="fbox"){var u=a.color&&a.getColor();u&&(o.style.borderColor=u)}}else{var l=[];/^[bx]cancel$/.test(r)&&l.push(new N0({x1:"0",y1:"0",x2:"100%",y2:"100%","stroke-width":"0.046em"})),/^x?cancel$/.test(r)&&l.push(new N0({x1:"0",y1:"100%",x2:"100%",y2:"0","stroke-width":"0.046em"}));var c=new ln(l,{width:"100%",height:ie(s)});o=j.makeSvgSpan([],[c],a)}return o.height=s,o.style.height=ie(s),o},fn={encloseSpan:p9,mathMLnode:c9,svgSpan:h9};function _e(e,t){if(!e||e.type!==t)throw new Error("Expected node of type "+t+", but got "+(e?"node of type "+e.type:String(e)));return e}function xf(e){var t=xu(e);if(!t)throw new Error("Expected node of symbol group type, but got "+(e?"node of type "+e.type:String(e)));return t}function xu(e){return e&&(e.type==="atom"||zx.hasOwnProperty(e.type))?e:null}var Ef=(e,t)=>{var r,n,i;e&&e.type==="supsub"?(n=_e(e.base,"accent"),r=n.base,e.base=r,i=Fx(Ue(e,t)),e.base=n):(n=_e(e,"accent"),r=n.base);var a=Ue(r,t.havingCrampedStyle()),o=n.isShifty&&Te.isCharacterBox(r),s=0;if(o){var u=Te.getBaseElem(r),l=Ue(u,t.havingCrampedStyle());s=qh(l).skew}var c=n.label==="\\c",f=c?a.height+a.depth:Math.min(a.height,t.fontMetrics().xHeight),d;if(n.isStretchy)d=fn.svgSpan(n,t),d=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:a},{type:"elem",elem:d,wrapperClasses:["svg-align"],wrapperStyle:s>0?{width:"calc(100% - "+ie(2*s)+")",marginLeft:ie(2*s)}:void 0}]},t);else{var h,p;n.label==="\\vec"?(h=j.staticSvg("vec",t),p=j.svgData.vec[1]):(h=j.makeOrd({mode:n.mode,text:n.label},t,"textord"),h=qh(h),h.italic=0,p=h.width,c&&(f+=h.depth)),d=j.makeSpan(["accent-body"],[h]);var m=n.label==="\\textcircled";m&&(d.classes.push("accent-full"),f=a.height);var g=s;m||(g-=p/2),d.style.left=ie(g),n.label==="\\textcircled"&&(d.style.top=".2em"),d=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:a},{type:"kern",size:-f},{type:"elem",elem:d}]},t)}var v=j.makeSpan(["mord","accent"],[d],t);return i?(i.children[0]=v,i.height=Math.max(v.height,i.height),i.classes[0]="mord",i):v},b2=(e,t)=>{var r=e.isStretchy?fn.mathMLnode(e.label):new Q.MathNode("mo",[gr(e.label,e.mode)]),n=new Q.MathNode("mover",[Je(e.base,t),r]);return n.setAttribute("accent","true"),n},m9=new RegExp(["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring"].map(e=>"\\"+e).join("|"));ae({type:"accent",names:["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring","\\widecheck","\\widehat","\\widetilde","\\overrightarrow","\\overleftarrow","\\Overrightarrow","\\overleftrightarrow","\\overgroup","\\overlinesegment","\\overleftharpoon","\\overrightharpoon"],props:{numArgs:1},handler:(e,t)=>{var r=Ms(t[0]),n=!m9.test(e.funcName),i=!n||e.funcName==="\\widehat"||e.funcName==="\\widetilde"||e.funcName==="\\widecheck";return{type:"accent",mode:e.parser.mode,label:e.funcName,isStretchy:n,isShifty:i,base:r}},htmlBuilder:Ef,mathmlBuilder:b2});ae({type:"accent",names:["\\'","\\`","\\^","\\~","\\=","\\u","\\.",'\\"',"\\c","\\r","\\H","\\v","\\textcircled"],props:{numArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["primitive"]},handler:(e,t)=>{var r=t[0],n=e.parser.mode;return n==="math"&&(e.parser.settings.reportNonstrict("mathVsTextAccents","LaTeX's accent "+e.funcName+" works only in text mode"),n="text"),{type:"accent",mode:n,label:e.funcName,isStretchy:!1,isShifty:!0,base:r}},htmlBuilder:Ef,mathmlBuilder:b2});ae({type:"accentUnder",names:["\\underleftarrow","\\underrightarrow","\\underleftrightarrow","\\undergroup","\\underlinesegment","\\utilde"],props:{numArgs:1},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=t[0];return{type:"accentUnder",mode:r.mode,label:n,base:i}},htmlBuilder:(e,t)=>{var r=Ue(e.base,t),n=fn.svgSpan(e,t),i=e.label==="\\utilde"?.12:0,a=j.makeVList({positionType:"top",positionData:r.height,children:[{type:"elem",elem:n,wrapperClasses:["svg-align"]},{type:"kern",size:i},{type:"elem",elem:r}]},t);return j.makeSpan(["mord","accentunder"],[a],t)},mathmlBuilder:(e,t)=>{var r=fn.mathMLnode(e.label),n=new Q.MathNode("munder",[Je(e.base,t),r]);return n.setAttribute("accentunder","true"),n}});var So=e=>{var t=new Q.MathNode("mpadded",e?[e]:[]);return t.setAttribute("width","+0.6em"),t.setAttribute("lspace","0.3em"),t};ae({type:"xArrow",names:["\\xleftarrow","\\xrightarrow","\\xLeftarrow","\\xRightarrow","\\xleftrightarrow","\\xLeftrightarrow","\\xhookleftarrow","\\xhookrightarrow","\\xmapsto","\\xrightharpoondown","\\xrightharpoonup","\\xleftharpoondown","\\xleftharpoonup","\\xrightleftharpoons","\\xleftrightharpoons","\\xlongequal","\\xtwoheadrightarrow","\\xtwoheadleftarrow","\\xtofrom","\\xrightleftarrows","\\xrightequilibrium","\\xleftequilibrium","\\\\cdrightarrow","\\\\cdleftarrow","\\\\cdlongequal"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,r){var{parser:n,funcName:i}=e;return{type:"xArrow",mode:n.mode,label:i,body:t[0],below:r[0]}},htmlBuilder(e,t){var r=t.style,n=t.havingStyle(r.sup()),i=j.wrapFragment(Ue(e.body,n,t),t),a=e.label.slice(0,2)==="\\x"?"x":"cd";i.classes.push(a+"-arrow-pad");var o;e.below&&(n=t.havingStyle(r.sub()),o=j.wrapFragment(Ue(e.below,n,t),t),o.classes.push(a+"-arrow-pad"));var s=fn.svgSpan(e,t),u=-t.fontMetrics().axisHeight+.5*s.height,l=-t.fontMetrics().axisHeight-.5*s.height-.111;(i.depth>.25||e.label==="\\xleftequilibrium")&&(l-=i.depth);var c;if(o){var f=-t.fontMetrics().axisHeight+o.height+.5*s.height+.111;c=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:i,shift:l},{type:"elem",elem:s,shift:u},{type:"elem",elem:o,shift:f}]},t)}else c=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:i,shift:l},{type:"elem",elem:s,shift:u}]},t);return c.children[0].children[0].children[1].classes.push("svg-align"),j.makeSpan(["mrel","x-arrow"],[c],t)},mathmlBuilder(e,t){var r=fn.mathMLnode(e.label);r.setAttribute("minsize",e.label.charAt(0)==="x"?"1.75em":"3.0em");var n;if(e.body){var i=So(Je(e.body,t));if(e.below){var a=So(Je(e.below,t));n=new Q.MathNode("munderover",[r,a,i])}else n=new Q.MathNode("mover",[r,i])}else if(e.below){var o=So(Je(e.below,t));n=new Q.MathNode("munder",[r,o])}else n=So(),n=new Q.MathNode("mover",[r,n]);return n}});var g9=j.makeSpan;function v2(e,t){var r=yt(e.body,t,!0);return g9([e.mclass],r,t)}function y2(e,t){var r,n=Kt(e.body,t);return e.mclass==="minner"?r=new Q.MathNode("mpadded",n):e.mclass==="mord"?e.isCharacterBox?(r=n[0],r.type="mi"):r=new Q.MathNode("mi",n):(e.isCharacterBox?(r=n[0],r.type="mo"):r=new Q.MathNode("mo",n),e.mclass==="mbin"?(r.attributes.lspace="0.22em",r.attributes.rspace="0.22em"):e.mclass==="mpunct"?(r.attributes.lspace="0em",r.attributes.rspace="0.17em"):e.mclass==="mopen"||e.mclass==="mclose"?(r.attributes.lspace="0em",r.attributes.rspace="0em"):e.mclass==="minner"&&(r.attributes.lspace="0.0556em",r.attributes.width="+0.1111em")),r}ae({type:"mclass",names:["\\mathord","\\mathbin","\\mathrel","\\mathopen","\\mathclose","\\mathpunct","\\mathinner"],props:{numArgs:1,primitive:!0},handler(e,t){var{parser:r,funcName:n}=e,i=t[0];return{type:"mclass",mode:r.mode,mclass:"m"+n.slice(5),body:pt(i),isCharacterBox:Te.isCharacterBox(i)}},htmlBuilder:v2,mathmlBuilder:y2});var Eu=e=>{var t=e.type==="ordgroup"&&e.body.length?e.body[0]:e;return t.type==="atom"&&(t.family==="bin"||t.family==="rel")?"m"+t.family:"mord"};ae({type:"mclass",names:["\\@binrel"],props:{numArgs:2},handler(e,t){var{parser:r}=e;return{type:"mclass",mode:r.mode,mclass:Eu(t[0]),body:pt(t[1]),isCharacterBox:Te.isCharacterBox(t[1])}}});ae({type:"mclass",names:["\\stackrel","\\overset","\\underset"],props:{numArgs:2},handler(e,t){var{parser:r,funcName:n}=e,i=t[1],a=t[0],o;n!=="\\stackrel"?o=Eu(i):o="mrel";var s={type:"op",mode:i.mode,limits:!0,alwaysHandleSupSub:!0,parentIsSupSub:!1,symbol:!1,suppressBaseShift:n!=="\\stackrel",body:pt(i)},u={type:"supsub",mode:a.mode,base:s,sup:n==="\\underset"?null:a,sub:n==="\\underset"?a:null};return{type:"mclass",mode:r.mode,mclass:o,body:[u],isCharacterBox:Te.isCharacterBox(u)}},htmlBuilder:v2,mathmlBuilder:y2});ae({type:"pmb",names:["\\pmb"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:r}=e;return{type:"pmb",mode:r.mode,mclass:Eu(t[0]),body:pt(t[0])}},htmlBuilder(e,t){var r=yt(e.body,t,!0),n=j.makeSpan([e.mclass],r,t);return n.style.textShadow="0.02em 0.01em 0.04px",n},mathmlBuilder(e,t){var r=Kt(e.body,t),n=new Q.MathNode("mstyle",r);return n.setAttribute("style","text-shadow: 0.02em 0.01em 0.04px"),n}});var b9={">":"\\\\cdrightarrow","<":"\\\\cdleftarrow","=":"\\\\cdlongequal",A:"\\uparrow",V:"\\downarrow","|":"\\Vert",".":"no arrow"},Zh=()=>({type:"styling",body:[],mode:"math",style:"display"}),Qh=e=>e.type==="textord"&&e.text==="@",v9=(e,t)=>(e.type==="mathord"||e.type==="atom")&&e.text===t;function y9(e,t,r){var n=b9[e];switch(n){case"\\\\cdrightarrow":case"\\\\cdleftarrow":return r.callFunction(n,[t[0]],[t[1]]);case"\\uparrow":case"\\downarrow":{var i=r.callFunction("\\\\cdleft",[t[0]],[]),a={type:"atom",text:n,mode:"math",family:"rel"},o=r.callFunction("\\Big",[a],[]),s=r.callFunction("\\\\cdright",[t[1]],[]),u={type:"ordgroup",mode:"math",body:[i,o,s]};return r.callFunction("\\\\cdparent",[u],[])}case"\\\\cdlongequal":return r.callFunction("\\\\cdlongequal",[],[]);case"\\Vert":{var l={type:"textord",text:"\\Vert",mode:"math"};return r.callFunction("\\Big",[l],[])}default:return{type:"textord",text:" ",mode:"math"}}}function w9(e){var t=[];for(e.gullet.beginGroup(),e.gullet.macros.set("\\cr","\\\\\\relax"),e.gullet.beginGroup();;){t.push(e.parseExpression(!1,"\\\\")),e.gullet.endGroup(),e.gullet.beginGroup();var r=e.fetch().text;if(r==="&"||r==="\\\\")e.consume();else if(r==="\\end"){t[t.length-1].length===0&&t.pop();break}else throw new te("Expected \\\\ or \\cr or \\end",e.nextToken)}for(var n=[],i=[n],a=0;a<t.length;a++){for(var o=t[a],s=Zh(),u=0;u<o.length;u++)if(!Qh(o[u]))s.body.push(o[u]);else{n.push(s),u+=1;var l=xf(o[u]).text,c=new Array(2);if(c[0]={type:"ordgroup",mode:"math",body:[]},c[1]={type:"ordgroup",mode:"math",body:[]},!("=|.".indexOf(l)>-1))if("<>AV".indexOf(l)>-1)for(var f=0;f<2;f++){for(var d=!0,h=u+1;h<o.length;h++){if(v9(o[h],l)){d=!1,u=h;break}if(Qh(o[h]))throw new te("Missing a "+l+" character to complete a CD arrow.",o[h]);c[f].body.push(o[h])}if(d)throw new te("Missing a "+l+" character to complete a CD arrow.",o[u])}else throw new te('Expected one of "<>AV=|." after @',o[u]);var p=y9(l,c,e),m={type:"styling",body:[p],mode:"math",style:"display"};n.push(m),s=Zh()}a%2===0?n.push(s):n.shift(),n=[],i.push(n)}e.gullet.endGroup(),e.gullet.endGroup();var g=new Array(i[0].length).fill({type:"align",align:"c",pregap:.25,postgap:.25});return{type:"array",mode:"math",body:i,arraystretch:1,addJot:!0,rowGaps:[null],cols:g,colSeparationType:"CD",hLinesBeforeRow:new Array(i.length+1).fill([])}}ae({type:"cdlabel",names:["\\\\cdleft","\\\\cdright"],props:{numArgs:1},handler(e,t){var{parser:r,funcName:n}=e;return{type:"cdlabel",mode:r.mode,side:n.slice(4),label:t[0]}},htmlBuilder(e,t){var r=t.havingStyle(t.style.sup()),n=j.wrapFragment(Ue(e.label,r,t),t);return n.classes.push("cd-label-"+e.side),n.style.bottom=ie(.8-n.depth),n.height=0,n.depth=0,n},mathmlBuilder(e,t){var r=new Q.MathNode("mrow",[Je(e.label,t)]);return r=new Q.MathNode("mpadded",[r]),r.setAttribute("width","0"),e.side==="left"&&r.setAttribute("lspace","-1width"),r.setAttribute("voffset","0.7em"),r=new Q.MathNode("mstyle",[r]),r.setAttribute("displaystyle","false"),r.setAttribute("scriptlevel","1"),r}});ae({type:"cdlabelparent",names:["\\\\cdparent"],props:{numArgs:1},handler(e,t){var{parser:r}=e;return{type:"cdlabelparent",mode:r.mode,fragment:t[0]}},htmlBuilder(e,t){var r=j.wrapFragment(Ue(e.fragment,t),t);return r.classes.push("cd-vert-arrow"),r},mathmlBuilder(e,t){return new Q.MathNode("mrow",[Je(e.fragment,t)])}});ae({type:"textord",names:["\\@char"],props:{numArgs:1,allowedInText:!0},handler(e,t){for(var{parser:r}=e,n=_e(t[0],"ordgroup"),i=n.body,a="",o=0;o<i.length;o++){var s=_e(i[o],"textord");a+=s.text}var u=parseInt(a),l;if(isNaN(u))throw new te("\\@char has non-numeric argument "+a);if(u<0||u>=1114111)throw new te("\\@char with invalid code point "+a);return u<=65535?l=String.fromCharCode(u):(u-=65536,l=String.fromCharCode((u>>10)+55296,(u&1023)+56320)),{type:"textord",mode:r.mode,text:l}}});var w2=(e,t)=>{var r=yt(e.body,t.withColor(e.color),!1);return j.makeFragment(r)},x2=(e,t)=>{var r=Kt(e.body,t.withColor(e.color)),n=new Q.MathNode("mstyle",r);return n.setAttribute("mathcolor",e.color),n};ae({type:"color",names:["\\textcolor"],props:{numArgs:2,allowedInText:!0,argTypes:["color","original"]},handler(e,t){var{parser:r}=e,n=_e(t[0],"color-token").color,i=t[1];return{type:"color",mode:r.mode,color:n,body:pt(i)}},htmlBuilder:w2,mathmlBuilder:x2});ae({type:"color",names:["\\color"],props:{numArgs:1,allowedInText:!0,argTypes:["color"]},handler(e,t){var{parser:r,breakOnTokenText:n}=e,i=_e(t[0],"color-token").color;r.gullet.macros.set("\\current@color",i);var a=r.parseExpression(!0,n);return{type:"color",mode:r.mode,color:i,body:a}},htmlBuilder:w2,mathmlBuilder:x2});ae({type:"cr",names:["\\\\"],props:{numArgs:0,numOptionalArgs:0,allowedInText:!0},handler(e,t,r){var{parser:n}=e,i=n.gullet.future().text==="["?n.parseSizeGroup(!0):null,a=!n.settings.displayMode||!n.settings.useStrictBehavior("newLineInDisplayMode","In LaTeX, \\\\ or \\newline does nothing in display mode");return{type:"cr",mode:n.mode,newLine:a,size:i&&_e(i,"size").value}},htmlBuilder(e,t){var r=j.makeSpan(["mspace"],[],t);return e.newLine&&(r.classes.push("newline"),e.size&&(r.style.marginTop=ie(st(e.size,t)))),r},mathmlBuilder(e,t){var r=new Q.MathNode("mspace");return e.newLine&&(r.setAttribute("linebreak","newline"),e.size&&r.setAttribute("height",ie(st(e.size,t)))),r}});var R0={"\\global":"\\global","\\long":"\\\\globallong","\\\\globallong":"\\\\globallong","\\def":"\\gdef","\\gdef":"\\gdef","\\edef":"\\xdef","\\xdef":"\\xdef","\\let":"\\\\globallet","\\futurelet":"\\\\globalfuture"},E2=e=>{var t=e.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(t))throw new te("Expected a control sequence",e);return t},x9=e=>{var t=e.gullet.popToken();return t.text==="="&&(t=e.gullet.popToken(),t.text===" "&&(t=e.gullet.popToken())),t},S2=(e,t,r,n)=>{var i=e.gullet.macros.get(r.text);i==null&&(r.noexpand=!0,i={tokens:[r],numArgs:0,unexpandable:!e.gullet.isExpandable(r.text)}),e.gullet.macros.set(t,i,n)};ae({type:"internal",names:["\\global","\\long","\\\\globallong"],props:{numArgs:0,allowedInText:!0},handler(e){var{parser:t,funcName:r}=e;t.consumeSpaces();var n=t.fetch();if(R0[n.text])return(r==="\\global"||r==="\\\\globallong")&&(n.text=R0[n.text]),_e(t.parseFunction(),"internal");throw new te("Invalid token after macro prefix",n)}});ae({type:"internal",names:["\\def","\\gdef","\\edef","\\xdef"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:r}=e,n=t.gullet.popToken(),i=n.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(i))throw new te("Expected a control sequence",n);for(var a=0,o,s=[[]];t.gullet.future().text!=="{";)if(n=t.gullet.popToken(),n.text==="#"){if(t.gullet.future().text==="{"){o=t.gullet.future(),s[a].push("{");break}if(n=t.gullet.popToken(),!/^[1-9]$/.test(n.text))throw new te('Invalid argument number "'+n.text+'"');if(parseInt(n.text)!==a+1)throw new te('Argument number "'+n.text+'" out of order');a++,s.push([])}else{if(n.text==="EOF")throw new te("Expected a macro definition");s[a].push(n.text)}var{tokens:u}=t.gullet.consumeArg();return o&&u.unshift(o),(r==="\\edef"||r==="\\xdef")&&(u=t.gullet.expandTokens(u),u.reverse()),t.gullet.macros.set(i,{tokens:u,numArgs:a,delimiters:s},r===R0[r]),{type:"internal",mode:t.mode}}});ae({type:"internal",names:["\\let","\\\\globallet"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:r}=e,n=E2(t.gullet.popToken());t.gullet.consumeSpaces();var i=x9(t);return S2(t,n,i,r==="\\\\globallet"),{type:"internal",mode:t.mode}}});ae({type:"internal",names:["\\futurelet","\\\\globalfuture"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:r}=e,n=E2(t.gullet.popToken()),i=t.gullet.popToken(),a=t.gullet.popToken();return S2(t,n,a,r==="\\\\globalfuture"),t.gullet.pushToken(a),t.gullet.pushToken(i),{type:"internal",mode:t.mode}}});var ca=function(t,r,n){var i=tt.math[t]&&tt.math[t].replace,a=gf(i||t,r,n);if(!a)throw new Error("Unsupported symbol "+t+" and font size "+r+".");return a},Sf=function(t,r,n,i){var a=n.havingBaseStyle(r),o=j.makeSpan(i.concat(a.sizingClasses(n)),[t],n),s=a.sizeMultiplier/n.sizeMultiplier;return o.height*=s,o.depth*=s,o.maxFontSize=a.sizeMultiplier,o},T2=function(t,r,n){var i=r.havingBaseStyle(n),a=(1-r.sizeMultiplier/i.sizeMultiplier)*r.fontMetrics().axisHeight;t.classes.push("delimcenter"),t.style.top=ie(a),t.height-=a,t.depth+=a},E9=function(t,r,n,i,a,o){var s=j.makeSymbol(t,"Main-Regular",a,i),u=Sf(s,r,i,o);return n&&T2(u,i,r),u},S9=function(t,r,n,i){return j.makeSymbol(t,"Size"+r+"-Regular",n,i)},A2=function(t,r,n,i,a,o){var s=S9(t,r,a,i),u=Sf(j.makeSpan(["delimsizing","size"+r],[s],i),be.TEXT,i,o);return n&&T2(u,i,be.TEXT),u},wl=function(t,r,n){var i;r==="Size1-Regular"?i="delim-size1":i="delim-size4";var a=j.makeSpan(["delimsizinginner",i],[j.makeSpan([],[j.makeSymbol(t,r,n)])]);return{type:"elem",elem:a}},xl=function(t,r,n){var i=Ur["Size4-Regular"][t.charCodeAt(0)]?Ur["Size4-Regular"][t.charCodeAt(0)][4]:Ur["Size1-Regular"][t.charCodeAt(0)][4],a=new In("inner",_x(t,Math.round(1e3*r))),o=new ln([a],{width:ie(i),height:ie(r),style:"width:"+ie(i),viewBox:"0 0 "+1e3*i+" "+Math.round(1e3*r),preserveAspectRatio:"xMinYMin"}),s=j.makeSvgSpan([],[o],n);return s.height=r,s.style.height=ie(r),s.style.width=ie(i),{type:"elem",elem:s}},I0=.008,To={type:"kern",size:-1*I0},T9=["|","\\lvert","\\rvert","\\vert"],A9=["\\|","\\lVert","\\rVert","\\Vert"],k2=function(t,r,n,i,a,o){var s,u,l,c,f="",d=0;s=l=c=t,u=null;var h="Size1-Regular";t==="\\uparrow"?l=c="⏐":t==="\\Uparrow"?l=c="‖":t==="\\downarrow"?s=l="⏐":t==="\\Downarrow"?s=l="‖":t==="\\updownarrow"?(s="\\uparrow",l="⏐",c="\\downarrow"):t==="\\Updownarrow"?(s="\\Uparrow",l="‖",c="\\Downarrow"):Te.contains(T9,t)?(l="∣",f="vert",d=333):Te.contains(A9,t)?(l="∥",f="doublevert",d=556):t==="["||t==="\\lbrack"?(s="⎡",l="⎢",c="⎣",h="Size4-Regular",f="lbrack",d=667):t==="]"||t==="\\rbrack"?(s="⎤",l="⎥",c="⎦",h="Size4-Regular",f="rbrack",d=667):t==="\\lfloor"||t==="⌊"?(l=s="⎢",c="⎣",h="Size4-Regular",f="lfloor",d=667):t==="\\lceil"||t==="⌈"?(s="⎡",l=c="⎢",h="Size4-Regular",f="lceil",d=667):t==="\\rfloor"||t==="⌋"?(l=s="⎥",c="⎦",h="Size4-Regular",f="rfloor",d=667):t==="\\rceil"||t==="⌉"?(s="⎤",l=c="⎥",h="Size4-Regular",f="rceil",d=667):t==="("||t==="\\lparen"?(s="⎛",l="⎜",c="⎝",h="Size4-Regular",f="lparen",d=875):t===")"||t==="\\rparen"?(s="⎞",l="⎟",c="⎠",h="Size4-Regular",f="rparen",d=875):t==="\\{"||t==="\\lbrace"?(s="⎧",u="⎨",c="⎩",l="⎪",h="Size4-Regular"):t==="\\}"||t==="\\rbrace"?(s="⎫",u="⎬",c="⎭",l="⎪",h="Size4-Regular"):t==="\\lgroup"||t==="⟮"?(s="⎧",c="⎩",l="⎪",h="Size4-Regular"):t==="\\rgroup"||t==="⟯"?(s="⎫",c="⎭",l="⎪",h="Size4-Regular"):t==="\\lmoustache"||t==="⎰"?(s="⎧",c="⎭",l="⎪",h="Size4-Regular"):(t==="\\rmoustache"||t==="⎱")&&(s="⎫",c="⎩",l="⎪",h="Size4-Regular");var p=ca(s,h,a),m=p.height+p.depth,g=ca(l,h,a),v=g.height+g.depth,w=ca(c,h,a),x=w.height+w.depth,N=0,O=1;if(u!==null){var A=ca(u,h,a);N=A.height+A.depth,O=2}var D=m+x+N,H=Math.max(0,Math.ceil((r-D)/(O*v))),z=D+H*O*v,L=i.fontMetrics().axisHeight;n&&(L*=i.sizeMultiplier);var I=z/2-L,k=[];if(f.length>0){var M=z-m-x,F=Math.round(z*1e3),C=Cx(f,Math.round(M*1e3)),U=new In(f,C),$=(d/1e3).toFixed(3)+"em",V=(F/1e3).toFixed(3)+"em",se=new ln([U],{width:$,height:V,viewBox:"0 0 "+d+" "+F}),_=j.makeSvgSpan([],[se],i);_.height=F/1e3,_.style.width=$,_.style.height=V,k.push({type:"elem",elem:_})}else{if(k.push(wl(c,h,a)),k.push(To),u===null){var oe=z-m-x+2*I0;k.push(xl(l,oe,i))}else{var ne=(z-m-x-N)/2+2*I0;k.push(xl(l,ne,i)),k.push(To),k.push(wl(u,h,a)),k.push(To),k.push(xl(l,ne,i))}k.push(To),k.push(wl(s,h,a))}var T=i.havingBaseStyle(be.TEXT),G=j.makeVList({positionType:"bottom",positionData:I,children:k},T);return Sf(j.makeSpan(["delimsizing","mult"],[G],T),be.TEXT,i,o)},El=80,Sl=.08,Tl=function(t,r,n,i,a){var o=Nx(t,i,n),s=new In(t,o),u=new ln([s],{width:"400em",height:ie(r),viewBox:"0 0 400000 "+n,preserveAspectRatio:"xMinYMin slice"});return j.makeSvgSpan(["hide-tail"],[u],a)},k9=function(t,r){var n=r.havingBaseSizing(),i=C2("\\surd",t*n.sizeMultiplier,_2,n),a=n.sizeMultiplier,o=Math.max(0,r.minRuleThickness-r.fontMetrics().sqrtRuleThickness),s,u=0,l=0,c=0,f;return i.type==="small"?(c=1e3+1e3*o+El,t<1?a=1:t<1.4&&(a=.7),u=(1+o+Sl)/a,l=(1+o)/a,s=Tl("sqrtMain",u,c,o,r),s.style.minWidth="0.853em",f=.833/a):i.type==="large"?(c=(1e3+El)*ba[i.size],l=(ba[i.size]+o)/a,u=(ba[i.size]+o+Sl)/a,s=Tl("sqrtSize"+i.size,u,c,o,r),s.style.minWidth="1.02em",f=1/a):(u=t+o+Sl,l=t+o,c=Math.floor(1e3*t+o)+El,s=Tl("sqrtTall",u,c,o,r),s.style.minWidth="0.742em",f=1.056),s.height=l,s.style.height=ie(u),{span:s,advanceWidth:f,ruleWidth:(r.fontMetrics().sqrtRuleThickness+o)*a}},O2=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","\\surd"],O9=["\\uparrow","\\downarrow","\\updownarrow","\\Uparrow","\\Downarrow","\\Updownarrow","|","\\|","\\vert","\\Vert","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱"],N2=["<",">","\\langle","\\rangle","/","\\backslash","\\lt","\\gt"],ba=[0,1.2,1.8,2.4,3],N9=function(t,r,n,i,a){if(t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle"),Te.contains(O2,t)||Te.contains(N2,t))return A2(t,r,!1,n,i,a);if(Te.contains(O9,t))return k2(t,ba[r],!1,n,i,a);throw new te("Illegal delimiter: '"+t+"'")},_9=[{type:"small",style:be.SCRIPTSCRIPT},{type:"small",style:be.SCRIPT},{type:"small",style:be.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4}],C9=[{type:"small",style:be.SCRIPTSCRIPT},{type:"small",style:be.SCRIPT},{type:"small",style:be.TEXT},{type:"stack"}],_2=[{type:"small",style:be.SCRIPTSCRIPT},{type:"small",style:be.SCRIPT},{type:"small",style:be.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4},{type:"stack"}],M9=function(t){if(t.type==="small")return"Main-Regular";if(t.type==="large")return"Size"+t.size+"-Regular";if(t.type==="stack")return"Size4-Regular";throw new Error("Add support for delim type '"+t.type+"' here.")},C2=function(t,r,n,i){for(var a=Math.min(2,3-i.style.size),o=a;o<n.length&&n[o].type!=="stack";o++){var s=ca(t,M9(n[o]),"math"),u=s.height+s.depth;if(n[o].type==="small"){var l=i.havingBaseStyle(n[o].style);u*=l.sizeMultiplier}if(u>r)return n[o]}return n[n.length-1]},M2=function(t,r,n,i,a,o){t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle");var s;Te.contains(N2,t)?s=_9:Te.contains(O2,t)?s=_2:s=C9;var u=C2(t,r,s,i);return u.type==="small"?E9(t,u.style,n,i,a,o):u.type==="large"?A2(t,u.size,n,i,a,o):k2(t,r,n,i,a,o)},R9=function(t,r,n,i,a,o){var s=i.fontMetrics().axisHeight*i.sizeMultiplier,u=901,l=5/i.fontMetrics().ptPerEm,c=Math.max(r-s,n+s),f=Math.max(c/500*u,2*c-l);return M2(t,f,!0,i,a,o)},sn={sqrtImage:k9,sizedDelim:N9,sizeToMaxHeight:ba,customSizedDelim:M2,leftRightDelim:R9},Jh={"\\bigl":{mclass:"mopen",size:1},"\\Bigl":{mclass:"mopen",size:2},"\\biggl":{mclass:"mopen",size:3},"\\Biggl":{mclass:"mopen",size:4},"\\bigr":{mclass:"mclose",size:1},"\\Bigr":{mclass:"mclose",size:2},"\\biggr":{mclass:"mclose",size:3},"\\Biggr":{mclass:"mclose",size:4},"\\bigm":{mclass:"mrel",size:1},"\\Bigm":{mclass:"mrel",size:2},"\\biggm":{mclass:"mrel",size:3},"\\Biggm":{mclass:"mrel",size:4},"\\big":{mclass:"mord",size:1},"\\Big":{mclass:"mord",size:2},"\\bigg":{mclass:"mord",size:3},"\\Bigg":{mclass:"mord",size:4}},I9=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","<",">","\\langle","⟨","\\rangle","⟩","\\lt","\\gt","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱","/","\\backslash","|","\\vert","\\|","\\Vert","\\uparrow","\\Uparrow","\\downarrow","\\Downarrow","\\updownarrow","\\Updownarrow","."];function Su(e,t){var r=xu(e);if(r&&Te.contains(I9,r.text))return r;throw r?new te("Invalid delimiter '"+r.text+"' after '"+t.funcName+"'",e):new te("Invalid delimiter type '"+e.type+"'",e)}ae({type:"delimsizing",names:["\\bigl","\\Bigl","\\biggl","\\Biggl","\\bigr","\\Bigr","\\biggr","\\Biggr","\\bigm","\\Bigm","\\biggm","\\Biggm","\\big","\\Big","\\bigg","\\Bigg"],props:{numArgs:1,argTypes:["primitive"]},handler:(e,t)=>{var r=Su(t[0],e);return{type:"delimsizing",mode:e.parser.mode,size:Jh[e.funcName].size,mclass:Jh[e.funcName].mclass,delim:r.text}},htmlBuilder:(e,t)=>e.delim==="."?j.makeSpan([e.mclass]):sn.sizedDelim(e.delim,e.size,t,e.mode,[e.mclass]),mathmlBuilder:e=>{var t=[];e.delim!=="."&&t.push(gr(e.delim,e.mode));var r=new Q.MathNode("mo",t);e.mclass==="mopen"||e.mclass==="mclose"?r.setAttribute("fence","true"):r.setAttribute("fence","false"),r.setAttribute("stretchy","true");var n=ie(sn.sizeToMaxHeight[e.size]);return r.setAttribute("minsize",n),r.setAttribute("maxsize",n),r}});function e1(e){if(!e.body)throw new Error("Bug: The leftright ParseNode wasn't fully parsed.")}ae({type:"leftright-right",names:["\\right"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var r=e.parser.gullet.macros.get("\\current@color");if(r&&typeof r!="string")throw new te("\\current@color set to non-string in \\right");return{type:"leftright-right",mode:e.parser.mode,delim:Su(t[0],e).text,color:r}}});ae({type:"leftright",names:["\\left"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var r=Su(t[0],e),n=e.parser;++n.leftrightDepth;var i=n.parseExpression(!1);--n.leftrightDepth,n.expect("\\right",!1);var a=_e(n.parseFunction(),"leftright-right");return{type:"leftright",mode:n.mode,body:i,left:r.text,right:a.delim,rightColor:a.color}},htmlBuilder:(e,t)=>{e1(e);for(var r=yt(e.body,t,!0,["mopen","mclose"]),n=0,i=0,a=!1,o=0;o<r.length;o++)r[o].isMiddle?a=!0:(n=Math.max(r[o].height,n),i=Math.max(r[o].depth,i));n*=t.sizeMultiplier,i*=t.sizeMultiplier;var s;if(e.left==="."?s=Na(t,["mopen"]):s=sn.leftRightDelim(e.left,n,i,t,e.mode,["mopen"]),r.unshift(s),a)for(var u=1;u<r.length;u++){var l=r[u],c=l.isMiddle;c&&(r[u]=sn.leftRightDelim(c.delim,n,i,c.options,e.mode,[]))}var f;if(e.right===".")f=Na(t,["mclose"]);else{var d=e.rightColor?t.withColor(e.rightColor):t;f=sn.leftRightDelim(e.right,n,i,d,e.mode,["mclose"])}return r.push(f),j.makeSpan(["minner"],r,t)},mathmlBuilder:(e,t)=>{e1(e);var r=Kt(e.body,t);if(e.left!=="."){var n=new Q.MathNode("mo",[gr(e.left,e.mode)]);n.setAttribute("fence","true"),r.unshift(n)}if(e.right!=="."){var i=new Q.MathNode("mo",[gr(e.right,e.mode)]);i.setAttribute("fence","true"),e.rightColor&&i.setAttribute("mathcolor",e.rightColor),r.push(i)}return yf(r)}});ae({type:"middle",names:["\\middle"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var r=Su(t[0],e);if(!e.parser.leftrightDepth)throw new te("\\middle without preceding \\left",r);return{type:"middle",mode:e.parser.mode,delim:r.text}},htmlBuilder:(e,t)=>{var r;if(e.delim===".")r=Na(t,[]);else{r=sn.sizedDelim(e.delim,1,t,e.mode,[]);var n={delim:e.delim,options:t};r.isMiddle=n}return r},mathmlBuilder:(e,t)=>{var r=e.delim==="\\vert"||e.delim==="|"?gr("|","text"):gr(e.delim,e.mode),n=new Q.MathNode("mo",[r]);return n.setAttribute("fence","true"),n.setAttribute("lspace","0.05em"),n.setAttribute("rspace","0.05em"),n}});var Tf=(e,t)=>{var r=j.wrapFragment(Ue(e.body,t),t),n=e.label.slice(1),i=t.sizeMultiplier,a,o=0,s=Te.isCharacterBox(e.body);if(n==="sout")a=j.makeSpan(["stretchy","sout"]),a.height=t.fontMetrics().defaultRuleThickness/i,o=-.5*t.fontMetrics().xHeight;else if(n==="phase"){var u=st({number:.6,unit:"pt"},t),l=st({number:.35,unit:"ex"},t),c=t.havingBaseSizing();i=i/c.sizeMultiplier;var f=r.height+r.depth+u+l;r.style.paddingLeft=ie(f/2+u);var d=Math.floor(1e3*f*i),h=kx(d),p=new ln([new In("phase",h)],{width:"400em",height:ie(d/1e3),viewBox:"0 0 400000 "+d,preserveAspectRatio:"xMinYMin slice"});a=j.makeSvgSpan(["hide-tail"],[p],t),a.style.height=ie(f),o=r.depth+u+l}else{/cancel/.test(n)?s||r.classes.push("cancel-pad"):n==="angl"?r.classes.push("anglpad"):r.classes.push("boxpad");var m=0,g=0,v=0;/box/.test(n)?(v=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness),m=t.fontMetrics().fboxsep+(n==="colorbox"?0:v),g=m):n==="angl"?(v=Math.max(t.fontMetrics().defaultRuleThickness,t.minRuleThickness),m=4*v,g=Math.max(0,.25-r.depth)):(m=s?.2:0,g=m),a=fn.encloseSpan(r,n,m,g,t),/fbox|boxed|fcolorbox/.test(n)?(a.style.borderStyle="solid",a.style.borderWidth=ie(v)):n==="angl"&&v!==.049&&(a.style.borderTopWidth=ie(v),a.style.borderRightWidth=ie(v)),o=r.depth+g,e.backgroundColor&&(a.style.backgroundColor=e.backgroundColor,e.borderColor&&(a.style.borderColor=e.borderColor))}var w;if(e.backgroundColor)w=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:a,shift:o},{type:"elem",elem:r,shift:0}]},t);else{var x=/cancel|phase/.test(n)?["svg-align"]:[];w=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:r,shift:0},{type:"elem",elem:a,shift:o,wrapperClasses:x}]},t)}return/cancel/.test(n)&&(w.height=r.height,w.depth=r.depth),/cancel/.test(n)&&!s?j.makeSpan(["mord","cancel-lap"],[w],t):j.makeSpan(["mord"],[w],t)},Af=(e,t)=>{var r=0,n=new Q.MathNode(e.label.indexOf("colorbox")>-1?"mpadded":"menclose",[Je(e.body,t)]);switch(e.label){case"\\cancel":n.setAttribute("notation","updiagonalstrike");break;case"\\bcancel":n.setAttribute("notation","downdiagonalstrike");break;case"\\phase":n.setAttribute("notation","phasorangle");break;case"\\sout":n.setAttribute("notation","horizontalstrike");break;case"\\fbox":n.setAttribute("notation","box");break;case"\\angl":n.setAttribute("notation","actuarial");break;case"\\fcolorbox":case"\\colorbox":if(r=t.fontMetrics().fboxsep*t.fontMetrics().ptPerEm,n.setAttribute("width","+"+2*r+"pt"),n.setAttribute("height","+"+2*r+"pt"),n.setAttribute("lspace",r+"pt"),n.setAttribute("voffset",r+"pt"),e.label==="\\fcolorbox"){var i=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness);n.setAttribute("style","border: "+i+"em solid "+String(e.borderColor))}break;case"\\xcancel":n.setAttribute("notation","updiagonalstrike downdiagonalstrike");break}return e.backgroundColor&&n.setAttribute("mathbackground",e.backgroundColor),n};ae({type:"enclose",names:["\\colorbox"],props:{numArgs:2,allowedInText:!0,argTypes:["color","text"]},handler(e,t,r){var{parser:n,funcName:i}=e,a=_e(t[0],"color-token").color,o=t[1];return{type:"enclose",mode:n.mode,label:i,backgroundColor:a,body:o}},htmlBuilder:Tf,mathmlBuilder:Af});ae({type:"enclose",names:["\\fcolorbox"],props:{numArgs:3,allowedInText:!0,argTypes:["color","color","text"]},handler(e,t,r){var{parser:n,funcName:i}=e,a=_e(t[0],"color-token").color,o=_e(t[1],"color-token").color,s=t[2];return{type:"enclose",mode:n.mode,label:i,backgroundColor:o,borderColor:a,body:s}},htmlBuilder:Tf,mathmlBuilder:Af});ae({type:"enclose",names:["\\fbox"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!0},handler(e,t){var{parser:r}=e;return{type:"enclose",mode:r.mode,label:"\\fbox",body:t[0]}}});ae({type:"enclose",names:["\\cancel","\\bcancel","\\xcancel","\\sout","\\phase"],props:{numArgs:1},handler(e,t){var{parser:r,funcName:n}=e,i=t[0];return{type:"enclose",mode:r.mode,label:n,body:i}},htmlBuilder:Tf,mathmlBuilder:Af});ae({type:"enclose",names:["\\angl"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!1},handler(e,t){var{parser:r}=e;return{type:"enclose",mode:r.mode,label:"\\angl",body:t[0]}}});var R2={};function Gr(e){for(var{type:t,names:r,props:n,handler:i,htmlBuilder:a,mathmlBuilder:o}=e,s={type:t,numArgs:n.numArgs||0,allowedInText:!1,numOptionalArgs:0,handler:i},u=0;u<r.length;++u)R2[r[u]]=s;a&&(_s[t]=a),o&&(Cs[t]=o)}var I2={};function S(e,t){I2[e]=t}function t1(e){var t=[];e.consumeSpaces();var r=e.fetch().text;for(r==="\\relax"&&(e.consume(),e.consumeSpaces(),r=e.fetch().text);r==="\\hline"||r==="\\hdashline";)e.consume(),t.push(r==="\\hdashline"),e.consumeSpaces(),r=e.fetch().text;return t}var Tu=e=>{var t=e.parser.settings;if(!t.displayMode)throw new te("{"+e.envName+"} can be used only in display mode.")};function kf(e){if(e.indexOf("ed")===-1)return e.indexOf("*")===-1}function Ln(e,t,r){var{hskipBeforeAndAfter:n,addJot:i,cols:a,arraystretch:o,colSeparationType:s,autoTag:u,singleRow:l,emptySingleRow:c,maxNumCols:f,leqno:d}=t;if(e.gullet.beginGroup(),l||e.gullet.macros.set("\\cr","\\\\\\relax"),!o){var h=e.gullet.expandMacroAsText("\\arraystretch");if(h==null)o=1;else if(o=parseFloat(h),!o||o<0)throw new te("Invalid \\arraystretch: "+h)}e.gullet.beginGroup();var p=[],m=[p],g=[],v=[],w=u!=null?[]:void 0;function x(){u&&e.gullet.macros.set("\\@eqnsw","1",!0)}function N(){w&&(e.gullet.macros.get("\\df@tag")?(w.push(e.subparse([new qr("\\df@tag")])),e.gullet.macros.set("\\df@tag",void 0,!0)):w.push(!!u&&e.gullet.macros.get("\\@eqnsw")==="1"))}for(x(),v.push(t1(e));;){var O=e.parseExpression(!1,l?"\\end":"\\\\");e.gullet.endGroup(),e.gullet.beginGroup(),O={type:"ordgroup",mode:e.mode,body:O},r&&(O={type:"styling",mode:e.mode,style:r,body:[O]}),p.push(O);var A=e.fetch().text;if(A==="&"){if(f&&p.length===f){if(l||s)throw new te("Too many tab characters: &",e.nextToken);e.settings.reportNonstrict("textEnv","Too few columns specified in the {array} column argument.")}e.consume()}else if(A==="\\end"){N(),p.length===1&&O.type==="styling"&&O.body[0].body.length===0&&(m.length>1||!c)&&m.pop(),v.length<m.length+1&&v.push([]);break}else if(A==="\\\\"){e.consume();var D=void 0;e.gullet.future().text!==" "&&(D=e.parseSizeGroup(!0)),g.push(D?D.value:null),N(),v.push(t1(e)),p=[],m.push(p),x()}else throw new te("Expected & or \\\\ or \\cr or \\end",e.nextToken)}return e.gullet.endGroup(),e.gullet.endGroup(),{type:"array",mode:e.mode,addJot:i,arraystretch:o,body:m,cols:a,rowGaps:g,hskipBeforeAndAfter:n,hLinesBeforeRow:v,colSeparationType:s,tags:w,leqno:d}}function Of(e){return e.slice(0,1)==="d"?"display":"text"}var Wr=function(t,r){var n,i,a=t.body.length,o=t.hLinesBeforeRow,s=0,u=new Array(a),l=[],c=Math.max(r.fontMetrics().arrayRuleWidth,r.minRuleThickness),f=1/r.fontMetrics().ptPerEm,d=5*f;if(t.colSeparationType&&t.colSeparationType==="small"){var h=r.havingStyle(be.SCRIPT).sizeMultiplier;d=.2778*(h/r.sizeMultiplier)}var p=t.colSeparationType==="CD"?st({number:3,unit:"ex"},r):12*f,m=3*f,g=t.arraystretch*p,v=.7*g,w=.3*g,x=0;function N($t){for(var Rt=0;Rt<$t.length;++Rt)Rt>0&&(x+=.25),l.push({pos:x,isDashed:$t[Rt]})}for(N(o[0]),n=0;n<t.body.length;++n){var O=t.body[n],A=v,D=w;s<O.length&&(s=O.length);var H=new Array(O.length);for(i=0;i<O.length;++i){var z=Ue(O[i],r);D<z.depth&&(D=z.depth),A<z.height&&(A=z.height),H[i]=z}var L=t.rowGaps[n],I=0;L&&(I=st(L,r),I>0&&(I+=w,D<I&&(D=I),I=0)),t.addJot&&(D+=m),H.height=A,H.depth=D,x+=A,H.pos=x,x+=D+I,u[n]=H,N(o[n+1])}var k=x/2+r.fontMetrics().axisHeight,M=t.cols||[],F=[],C,U,$=[];if(t.tags&&t.tags.some($t=>$t))for(n=0;n<a;++n){var V=u[n],se=V.pos-k,_=t.tags[n],oe=void 0;_===!0?oe=j.makeSpan(["eqn-num"],[],r):_===!1?oe=j.makeSpan([],[],r):oe=j.makeSpan([],yt(_,r,!0),r),oe.depth=V.depth,oe.height=V.height,$.push({type:"elem",elem:oe,shift:se})}for(i=0,U=0;i<s||U<M.length;++i,++U){for(var ne=M[U]||{},T=!0;ne.type==="separator";){if(T||(C=j.makeSpan(["arraycolsep"],[]),C.style.width=ie(r.fontMetrics().doubleRuleSep),F.push(C)),ne.separator==="|"||ne.separator===":"){var G=ne.separator==="|"?"solid":"dashed",ee=j.makeSpan(["vertical-separator"],[],r);ee.style.height=ie(x),ee.style.borderRightWidth=ie(c),ee.style.borderRightStyle=G,ee.style.margin="0 "+ie(-c/2);var le=x-k;le&&(ee.style.verticalAlign=ie(-le)),F.push(ee)}else throw new te("Invalid separator type: "+ne.separator);U++,ne=M[U]||{},T=!1}if(!(i>=s)){var we=void 0;(i>0||t.hskipBeforeAndAfter)&&(we=Te.deflt(ne.pregap,d),we!==0&&(C=j.makeSpan(["arraycolsep"],[]),C.style.width=ie(we),F.push(C)));var Oe=[];for(n=0;n<a;++n){var qe=u[n],ve=qe[i];if(ve){var ct=qe.pos-k;ve.depth=qe.depth,ve.height=qe.height,Oe.push({type:"elem",elem:ve,shift:ct})}}Oe=j.makeVList({positionType:"individualShift",children:Oe},r),Oe=j.makeSpan(["col-align-"+(ne.align||"c")],[Oe]),F.push(Oe),(i<s-1||t.hskipBeforeAndAfter)&&(we=Te.deflt(ne.postgap,d),we!==0&&(C=j.makeSpan(["arraycolsep"],[]),C.style.width=ie(we),F.push(C)))}}if(u=j.makeSpan(["mtable"],F),l.length>0){for(var ft=j.makeLineSpan("hline",r,c),_r=j.makeLineSpan("hdashline",r,c),Xt=[{type:"elem",elem:u,shift:0}];l.length>0;){var yn=l.pop(),Tr=yn.pos-k;yn.isDashed?Xt.push({type:"elem",elem:_r,shift:Tr}):Xt.push({type:"elem",elem:ft,shift:Tr})}u=j.makeVList({positionType:"individualShift",children:Xt},r)}if($.length===0)return j.makeSpan(["mord"],[u],r);var At=j.makeVList({positionType:"individualShift",children:$},r);return At=j.makeSpan(["tag"],[At],r),j.makeFragment([u,At])},P9={c:"center ",l:"left ",r:"right "},Kr=function(t,r){for(var n=[],i=new Q.MathNode("mtd",[],["mtr-glue"]),a=new Q.MathNode("mtd",[],["mml-eqn-num"]),o=0;o<t.body.length;o++){for(var s=t.body[o],u=[],l=0;l<s.length;l++)u.push(new Q.MathNode("mtd",[Je(s[l],r)]));t.tags&&t.tags[o]&&(u.unshift(i),u.push(i),t.leqno?u.unshift(a):u.push(a)),n.push(new Q.MathNode("mtr",u))}var c=new Q.MathNode("mtable",n),f=t.arraystretch===.5?.1:.16+t.arraystretch-1+(t.addJot?.09:0);c.setAttribute("rowspacing",ie(f));var d="",h="";if(t.cols&&t.cols.length>0){var p=t.cols,m="",g=!1,v=0,w=p.length;p[0].type==="separator"&&(d+="top ",v=1),p[p.length-1].type==="separator"&&(d+="bottom ",w-=1);for(var x=v;x<w;x++)p[x].type==="align"?(h+=P9[p[x].align],g&&(m+="none "),g=!0):p[x].type==="separator"&&g&&(m+=p[x].separator==="|"?"solid ":"dashed ",g=!1);c.setAttribute("columnalign",h.trim()),/[sd]/.test(m)&&c.setAttribute("columnlines",m.trim())}if(t.colSeparationType==="align"){for(var N=t.cols||[],O="",A=1;A<N.length;A++)O+=A%2?"0em ":"1em ";c.setAttribute("columnspacing",O.trim())}else t.colSeparationType==="alignat"||t.colSeparationType==="gather"?c.setAttribute("columnspacing","0em"):t.colSeparationType==="small"?c.setAttribute("columnspacing","0.2778em"):t.colSeparationType==="CD"?c.setAttribute("columnspacing","0.5em"):c.setAttribute("columnspacing","1em");var D="",H=t.hLinesBeforeRow;d+=H[0].length>0?"left ":"",d+=H[H.length-1].length>0?"right ":"";for(var z=1;z<H.length-1;z++)D+=H[z].length===0?"none ":H[z][0]?"dashed ":"solid ";return/[sd]/.test(D)&&c.setAttribute("rowlines",D.trim()),d!==""&&(c=new Q.MathNode("menclose",[c]),c.setAttribute("notation",d.trim())),t.arraystretch&&t.arraystretch<1&&(c=new Q.MathNode("mstyle",[c]),c.setAttribute("scriptlevel","1")),c},P2=function(t,r){t.envName.indexOf("ed")===-1&&Tu(t);var n=[],i=t.envName.indexOf("at")>-1?"alignat":"align",a=t.envName==="split",o=Ln(t.parser,{cols:n,addJot:!0,autoTag:a?void 0:kf(t.envName),emptySingleRow:!0,colSeparationType:i,maxNumCols:a?2:void 0,leqno:t.parser.settings.leqno},"display"),s,u=0,l={type:"ordgroup",mode:t.mode,body:[]};if(r[0]&&r[0].type==="ordgroup"){for(var c="",f=0;f<r[0].body.length;f++){var d=_e(r[0].body[f],"textord");c+=d.text}s=Number(c),u=s*2}var h=!u;o.body.forEach(function(v){for(var w=1;w<v.length;w+=2){var x=_e(v[w],"styling"),N=_e(x.body[0],"ordgroup");N.body.unshift(l)}if(h)u<v.length&&(u=v.length);else{var O=v.length/2;if(s<O)throw new te("Too many math in a row: "+("expected "+s+", but got "+O),v[0])}});for(var p=0;p<u;++p){var m="r",g=0;p%2===1?m="l":p>0&&h&&(g=1),n[p]={type:"align",align:m,pregap:g,postgap:0}}return o.colSeparationType=h?"align":"alignat",o};Gr({type:"array",names:["array","darray"],props:{numArgs:1},handler(e,t){var r=xu(t[0]),n=r?[t[0]]:_e(t[0],"ordgroup").body,i=n.map(function(o){var s=xf(o),u=s.text;if("lcr".indexOf(u)!==-1)return{type:"align",align:u};if(u==="|")return{type:"separator",separator:"|"};if(u===":")return{type:"separator",separator:":"};throw new te("Unknown column alignment: "+u,o)}),a={cols:i,hskipBeforeAndAfter:!0,maxNumCols:i.length};return Ln(e.parser,a,Of(e.envName))},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["matrix","pmatrix","bmatrix","Bmatrix","vmatrix","Vmatrix","matrix*","pmatrix*","bmatrix*","Bmatrix*","vmatrix*","Vmatrix*"],props:{numArgs:0},handler(e){var t={matrix:null,pmatrix:["(",")"],bmatrix:["[","]"],Bmatrix:["\\{","\\}"],vmatrix:["|","|"],Vmatrix:["\\Vert","\\Vert"]}[e.envName.replace("*","")],r="c",n={hskipBeforeAndAfter:!1,cols:[{type:"align",align:r}]};if(e.envName.charAt(e.envName.length-1)==="*"){var i=e.parser;if(i.consumeSpaces(),i.fetch().text==="["){if(i.consume(),i.consumeSpaces(),r=i.fetch().text,"lcr".indexOf(r)===-1)throw new te("Expected l or c or r",i.nextToken);i.consume(),i.consumeSpaces(),i.expect("]"),i.consume(),n.cols=[{type:"align",align:r}]}}var a=Ln(e.parser,n,Of(e.envName)),o=Math.max(0,...a.body.map(s=>s.length));return a.cols=new Array(o).fill({type:"align",align:r}),t?{type:"leftright",mode:e.mode,body:[a],left:t[0],right:t[1],rightColor:void 0}:a},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["smallmatrix"],props:{numArgs:0},handler(e){var t={arraystretch:.5},r=Ln(e.parser,t,"script");return r.colSeparationType="small",r},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["subarray"],props:{numArgs:1},handler(e,t){var r=xu(t[0]),n=r?[t[0]]:_e(t[0],"ordgroup").body,i=n.map(function(o){var s=xf(o),u=s.text;if("lc".indexOf(u)!==-1)return{type:"align",align:u};throw new te("Unknown column alignment: "+u,o)});if(i.length>1)throw new te("{subarray} can contain only one column");var a={cols:i,hskipBeforeAndAfter:!1,arraystretch:.5};if(a=Ln(e.parser,a,"script"),a.body.length>0&&a.body[0].length>1)throw new te("{subarray} can contain only one column");return a},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["cases","dcases","rcases","drcases"],props:{numArgs:0},handler(e){var t={arraystretch:1.2,cols:[{type:"align",align:"l",pregap:0,postgap:1},{type:"align",align:"l",pregap:0,postgap:0}]},r=Ln(e.parser,t,Of(e.envName));return{type:"leftright",mode:e.mode,body:[r],left:e.envName.indexOf("r")>-1?".":"\\{",right:e.envName.indexOf("r")>-1?"\\}":".",rightColor:void 0}},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["align","align*","aligned","split"],props:{numArgs:0},handler:P2,htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["gathered","gather","gather*"],props:{numArgs:0},handler(e){Te.contains(["gather","gather*"],e.envName)&&Tu(e);var t={cols:[{type:"align",align:"c"}],addJot:!0,colSeparationType:"gather",autoTag:kf(e.envName),emptySingleRow:!0,leqno:e.parser.settings.leqno};return Ln(e.parser,t,"display")},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["alignat","alignat*","alignedat"],props:{numArgs:1},handler:P2,htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["equation","equation*"],props:{numArgs:0},handler(e){Tu(e);var t={autoTag:kf(e.envName),emptySingleRow:!0,singleRow:!0,maxNumCols:1,leqno:e.parser.settings.leqno};return Ln(e.parser,t,"display")},htmlBuilder:Wr,mathmlBuilder:Kr});Gr({type:"array",names:["CD"],props:{numArgs:0},handler(e){return Tu(e),w9(e.parser)},htmlBuilder:Wr,mathmlBuilder:Kr});S("\\nonumber","\\gdef\\@eqnsw{0}");S("\\notag","\\nonumber");ae({type:"text",names:["\\hline","\\hdashline"],props:{numArgs:0,allowedInText:!0,allowedInMath:!0},handler(e,t){throw new te(e.funcName+" valid only within array environment")}});var r1=R2;ae({type:"environment",names:["\\begin","\\end"],props:{numArgs:1,argTypes:["text"]},handler(e,t){var{parser:r,funcName:n}=e,i=t[0];if(i.type!=="ordgroup")throw new te("Invalid environment name",i);for(var a="",o=0;o<i.body.length;++o)a+=_e(i.body[o],"textord").text;if(n==="\\begin"){if(!r1.hasOwnProperty(a))throw new te("No such environment: "+a,i);var s=r1[a],{args:u,optArgs:l}=r.parseArguments("\\begin{"+a+"}",s),c={mode:r.mode,envName:a,parser:r},f=s.handler(c,u,l);r.expect("\\end",!1);var d=r.nextToken,h=_e(r.parseFunction(),"environment");if(h.name!==a)throw new te("Mismatch: \\begin{"+a+"} matched by \\end{"+h.name+"}",d);return f}return{type:"environment",mode:r.mode,name:a,nameGroup:i}}});var D2=(e,t)=>{var r=e.font,n=t.withFont(r);return Ue(e.body,n)},L2=(e,t)=>{var r=e.font,n=t.withFont(r);return Je(e.body,n)},n1={"\\Bbb":"\\mathbb","\\bold":"\\mathbf","\\frak":"\\mathfrak","\\bm":"\\boldsymbol"};ae({type:"font",names:["\\mathrm","\\mathit","\\mathbf","\\mathnormal","\\mathbb","\\mathcal","\\mathfrak","\\mathscr","\\mathsf","\\mathtt","\\Bbb","\\bold","\\frak"],props:{numArgs:1,allowedInArgument:!0},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=Ms(t[0]),a=n;return a in n1&&(a=n1[a]),{type:"font",mode:r.mode,font:a.slice(1),body:i}},htmlBuilder:D2,mathmlBuilder:L2});ae({type:"mclass",names:["\\boldsymbol","\\bm"],props:{numArgs:1},handler:(e,t)=>{var{parser:r}=e,n=t[0],i=Te.isCharacterBox(n);return{type:"mclass",mode:r.mode,mclass:Eu(n),body:[{type:"font",mode:r.mode,font:"boldsymbol",body:n}],isCharacterBox:i}}});ae({type:"font",names:["\\rm","\\sf","\\tt","\\bf","\\it","\\cal"],props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{parser:r,funcName:n,breakOnTokenText:i}=e,{mode:a}=r,o=r.parseExpression(!0,i),s="math"+n.slice(1);return{type:"font",mode:a,font:s,body:{type:"ordgroup",mode:r.mode,body:o}}},htmlBuilder:D2,mathmlBuilder:L2});var F2=(e,t)=>{var r=t;return e==="display"?r=r.id>=be.SCRIPT.id?r.text():be.DISPLAY:e==="text"&&r.size===be.DISPLAY.size?r=be.TEXT:e==="script"?r=be.SCRIPT:e==="scriptscript"&&(r=be.SCRIPTSCRIPT),r},Nf=(e,t)=>{var r=F2(e.size,t.style),n=r.fracNum(),i=r.fracDen(),a;a=t.havingStyle(n);var o=Ue(e.numer,a,t);if(e.continued){var s=8.5/t.fontMetrics().ptPerEm,u=3.5/t.fontMetrics().ptPerEm;o.height=o.height<s?s:o.height,o.depth=o.depth<u?u:o.depth}a=t.havingStyle(i);var l=Ue(e.denom,a,t),c,f,d;e.hasBarLine?(e.barSize?(f=st(e.barSize,t),c=j.makeLineSpan("frac-line",t,f)):c=j.makeLineSpan("frac-line",t),f=c.height,d=c.height):(c=null,f=0,d=t.fontMetrics().defaultRuleThickness);var h,p,m;r.size===be.DISPLAY.size||e.size==="display"?(h=t.fontMetrics().num1,f>0?p=3*d:p=7*d,m=t.fontMetrics().denom1):(f>0?(h=t.fontMetrics().num2,p=d):(h=t.fontMetrics().num3,p=3*d),m=t.fontMetrics().denom2);var g;if(c){var w=t.fontMetrics().axisHeight;h-o.depth-(w+.5*f)<p&&(h+=p-(h-o.depth-(w+.5*f))),w-.5*f-(l.height-m)<p&&(m+=p-(w-.5*f-(l.height-m)));var x=-(w-.5*f);g=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:l,shift:m},{type:"elem",elem:c,shift:x},{type:"elem",elem:o,shift:-h}]},t)}else{var v=h-o.depth-(l.height-m);v<p&&(h+=.5*(p-v),m+=.5*(p-v)),g=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:l,shift:m},{type:"elem",elem:o,shift:-h}]},t)}a=t.havingStyle(r),g.height*=a.sizeMultiplier/t.sizeMultiplier,g.depth*=a.sizeMultiplier/t.sizeMultiplier;var N;r.size===be.DISPLAY.size?N=t.fontMetrics().delim1:r.size===be.SCRIPTSCRIPT.size?N=t.havingStyle(be.SCRIPT).fontMetrics().delim2:N=t.fontMetrics().delim2;var O,A;return e.leftDelim==null?O=Na(t,["mopen"]):O=sn.customSizedDelim(e.leftDelim,N,!0,t.havingStyle(r),e.mode,["mopen"]),e.continued?A=j.makeSpan([]):e.rightDelim==null?A=Na(t,["mclose"]):A=sn.customSizedDelim(e.rightDelim,N,!0,t.havingStyle(r),e.mode,["mclose"]),j.makeSpan(["mord"].concat(a.sizingClasses(t)),[O,j.makeSpan(["mfrac"],[g]),A],t)},_f=(e,t)=>{var r=new Q.MathNode("mfrac",[Je(e.numer,t),Je(e.denom,t)]);if(!e.hasBarLine)r.setAttribute("linethickness","0px");else if(e.barSize){var n=st(e.barSize,t);r.setAttribute("linethickness",ie(n))}var i=F2(e.size,t.style);if(i.size!==t.style.size){r=new Q.MathNode("mstyle",[r]);var a=i.size===be.DISPLAY.size?"true":"false";r.setAttribute("displaystyle",a),r.setAttribute("scriptlevel","0")}if(e.leftDelim!=null||e.rightDelim!=null){var o=[];if(e.leftDelim!=null){var s=new Q.MathNode("mo",[new Q.TextNode(e.leftDelim.replace("\\",""))]);s.setAttribute("fence","true"),o.push(s)}if(o.push(r),e.rightDelim!=null){var u=new Q.MathNode("mo",[new Q.TextNode(e.rightDelim.replace("\\",""))]);u.setAttribute("fence","true"),o.push(u)}return yf(o)}return r};ae({type:"genfrac",names:["\\dfrac","\\frac","\\tfrac","\\dbinom","\\binom","\\tbinom","\\\\atopfrac","\\\\bracefrac","\\\\brackfrac"],props:{numArgs:2,allowedInArgument:!0},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=t[0],a=t[1],o,s=null,u=null,l="auto";switch(n){case"\\dfrac":case"\\frac":case"\\tfrac":o=!0;break;case"\\\\atopfrac":o=!1;break;case"\\dbinom":case"\\binom":case"\\tbinom":o=!1,s="(",u=")";break;case"\\\\bracefrac":o=!1,s="\\{",u="\\}";break;case"\\\\brackfrac":o=!1,s="[",u="]";break;default:throw new Error("Unrecognized genfrac command")}switch(n){case"\\dfrac":case"\\dbinom":l="display";break;case"\\tfrac":case"\\tbinom":l="text";break}return{type:"genfrac",mode:r.mode,continued:!1,numer:i,denom:a,hasBarLine:o,leftDelim:s,rightDelim:u,size:l,barSize:null}},htmlBuilder:Nf,mathmlBuilder:_f});ae({type:"genfrac",names:["\\cfrac"],props:{numArgs:2},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=t[0],a=t[1];return{type:"genfrac",mode:r.mode,continued:!0,numer:i,denom:a,hasBarLine:!0,leftDelim:null,rightDelim:null,size:"display",barSize:null}}});ae({type:"infix",names:["\\over","\\choose","\\atop","\\brace","\\brack"],props:{numArgs:0,infix:!0},handler(e){var{parser:t,funcName:r,token:n}=e,i;switch(r){case"\\over":i="\\frac";break;case"\\choose":i="\\binom";break;case"\\atop":i="\\\\atopfrac";break;case"\\brace":i="\\\\bracefrac";break;case"\\brack":i="\\\\brackfrac";break;default:throw new Error("Unrecognized infix genfrac command")}return{type:"infix",mode:t.mode,replaceWith:i,token:n}}});var i1=["display","text","script","scriptscript"],a1=function(t){var r=null;return t.length>0&&(r=t,r=r==="."?null:r),r};ae({type:"genfrac",names:["\\genfrac"],props:{numArgs:6,allowedInArgument:!0,argTypes:["math","math","size","text","math","math"]},handler(e,t){var{parser:r}=e,n=t[4],i=t[5],a=Ms(t[0]),o=a.type==="atom"&&a.family==="open"?a1(a.text):null,s=Ms(t[1]),u=s.type==="atom"&&s.family==="close"?a1(s.text):null,l=_e(t[2],"size"),c,f=null;l.isBlank?c=!0:(f=l.value,c=f.number>0);var d="auto",h=t[3];if(h.type==="ordgroup"){if(h.body.length>0){var p=_e(h.body[0],"textord");d=i1[Number(p.text)]}}else h=_e(h,"textord"),d=i1[Number(h.text)];return{type:"genfrac",mode:r.mode,numer:n,denom:i,continued:!1,hasBarLine:c,barSize:f,leftDelim:o,rightDelim:u,size:d}},htmlBuilder:Nf,mathmlBuilder:_f});ae({type:"infix",names:["\\above"],props:{numArgs:1,argTypes:["size"],infix:!0},handler(e,t){var{parser:r,funcName:n,token:i}=e;return{type:"infix",mode:r.mode,replaceWith:"\\\\abovefrac",size:_e(t[0],"size").value,token:i}}});ae({type:"genfrac",names:["\\\\abovefrac"],props:{numArgs:3,argTypes:["math","size","math"]},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=t[0],a=fx(_e(t[1],"infix").size),o=t[2],s=a.number>0;return{type:"genfrac",mode:r.mode,numer:i,denom:o,continued:!1,hasBarLine:s,barSize:a,leftDelim:null,rightDelim:null,size:"auto"}},htmlBuilder:Nf,mathmlBuilder:_f});var B2=(e,t)=>{var r=t.style,n,i;e.type==="supsub"?(n=e.sup?Ue(e.sup,t.havingStyle(r.sup()),t):Ue(e.sub,t.havingStyle(r.sub()),t),i=_e(e.base,"horizBrace")):i=_e(e,"horizBrace");var a=Ue(i.base,t.havingBaseStyle(be.DISPLAY)),o=fn.svgSpan(i,t),s;if(i.isOver?(s=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:a},{type:"kern",size:.1},{type:"elem",elem:o}]},t),s.children[0].children[0].children[1].classes.push("svg-align")):(s=j.makeVList({positionType:"bottom",positionData:a.depth+.1+o.height,children:[{type:"elem",elem:o},{type:"kern",size:.1},{type:"elem",elem:a}]},t),s.children[0].children[0].children[0].classes.push("svg-align")),n){var u=j.makeSpan(["mord",i.isOver?"mover":"munder"],[s],t);i.isOver?s=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:u},{type:"kern",size:.2},{type:"elem",elem:n}]},t):s=j.makeVList({positionType:"bottom",positionData:u.depth+.2+n.height+n.depth,children:[{type:"elem",elem:n},{type:"kern",size:.2},{type:"elem",elem:u}]},t)}return j.makeSpan(["mord",i.isOver?"mover":"munder"],[s],t)},D9=(e,t)=>{var r=fn.mathMLnode(e.label);return new Q.MathNode(e.isOver?"mover":"munder",[Je(e.base,t),r])};ae({type:"horizBrace",names:["\\overbrace","\\underbrace"],props:{numArgs:1},handler(e,t){var{parser:r,funcName:n}=e;return{type:"horizBrace",mode:r.mode,label:n,isOver:/^\\over/.test(n),base:t[0]}},htmlBuilder:B2,mathmlBuilder:D9});ae({type:"href",names:["\\href"],props:{numArgs:2,argTypes:["url","original"],allowedInText:!0},handler:(e,t)=>{var{parser:r}=e,n=t[1],i=_e(t[0],"url").url;return r.settings.isTrusted({command:"\\href",url:i})?{type:"href",mode:r.mode,href:i,body:pt(n)}:r.formatUnsupportedCmd("\\href")},htmlBuilder:(e,t)=>{var r=yt(e.body,t,!1);return j.makeAnchor(e.href,[],r,t)},mathmlBuilder:(e,t)=>{var r=Pn(e.body,t);return r instanceof dr||(r=new dr("mrow",[r])),r.setAttribute("href",e.href),r}});ae({type:"href",names:["\\url"],props:{numArgs:1,argTypes:["url"],allowedInText:!0},handler:(e,t)=>{var{parser:r}=e,n=_e(t[0],"url").url;if(!r.settings.isTrusted({command:"\\url",url:n}))return r.formatUnsupportedCmd("\\url");for(var i=[],a=0;a<n.length;a++){var o=n[a];o==="~"&&(o="\\textasciitilde"),i.push({type:"textord",mode:"text",text:o})}var s={type:"text",mode:r.mode,font:"\\texttt",body:i};return{type:"href",mode:r.mode,href:n,body:pt(s)}}});ae({type:"hbox",names:["\\hbox"],props:{numArgs:1,argTypes:["text"],allowedInText:!0,primitive:!0},handler(e,t){var{parser:r}=e;return{type:"hbox",mode:r.mode,body:pt(t[0])}},htmlBuilder(e,t){var r=yt(e.body,t,!1);return j.makeFragment(r)},mathmlBuilder(e,t){return new Q.MathNode("mrow",Kt(e.body,t))}});ae({type:"html",names:["\\htmlClass","\\htmlId","\\htmlStyle","\\htmlData"],props:{numArgs:2,argTypes:["raw","original"],allowedInText:!0},handler:(e,t)=>{var{parser:r,funcName:n,token:i}=e,a=_e(t[0],"raw").string,o=t[1];r.settings.strict&&r.settings.reportNonstrict("htmlExtension","HTML extension is disabled on strict mode");var s,u={};switch(n){case"\\htmlClass":u.class=a,s={command:"\\htmlClass",class:a};break;case"\\htmlId":u.id=a,s={command:"\\htmlId",id:a};break;case"\\htmlStyle":u.style=a,s={command:"\\htmlStyle",style:a};break;case"\\htmlData":{for(var l=a.split(","),c=0;c<l.length;c++){var f=l[c].split("=");if(f.length!==2)throw new te("Error parsing key-value for \\htmlData");u["data-"+f[0].trim()]=f[1].trim()}s={command:"\\htmlData",attributes:u};break}default:throw new Error("Unrecognized html command")}return r.settings.isTrusted(s)?{type:"html",mode:r.mode,attributes:u,body:pt(o)}:r.formatUnsupportedCmd(n)},htmlBuilder:(e,t)=>{var r=yt(e.body,t,!1),n=["enclosing"];e.attributes.class&&n.push(...e.attributes.class.trim().split(/\s+/));var i=j.makeSpan(n,r,t);for(var a in e.attributes)a!=="class"&&e.attributes.hasOwnProperty(a)&&i.setAttribute(a,e.attributes[a]);return i},mathmlBuilder:(e,t)=>Pn(e.body,t)});ae({type:"htmlmathml",names:["\\html@mathml"],props:{numArgs:2,allowedInText:!0},handler:(e,t)=>{var{parser:r}=e;return{type:"htmlmathml",mode:r.mode,html:pt(t[0]),mathml:pt(t[1])}},htmlBuilder:(e,t)=>{var r=yt(e.html,t,!1);return j.makeFragment(r)},mathmlBuilder:(e,t)=>Pn(e.mathml,t)});var Al=function(t){if(/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(t))return{number:+t,unit:"bp"};var r=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(t);if(!r)throw new te("Invalid size: '"+t+"' in \\includegraphics");var n={number:+(r[1]+r[2]),unit:r[3]};if(!n2(n))throw new te("Invalid unit: '"+n.unit+"' in \\includegraphics.");return n};ae({type:"includegraphics",names:["\\includegraphics"],props:{numArgs:1,numOptionalArgs:1,argTypes:["raw","url"],allowedInText:!1},handler:(e,t,r)=>{var{parser:n}=e,i={number:0,unit:"em"},a={number:.9,unit:"em"},o={number:0,unit:"em"},s="";if(r[0])for(var u=_e(r[0],"raw").string,l=u.split(","),c=0;c<l.length;c++){var f=l[c].split("=");if(f.length===2){var d=f[1].trim();switch(f[0].trim()){case"alt":s=d;break;case"width":i=Al(d);break;case"height":a=Al(d);break;case"totalheight":o=Al(d);break;default:throw new te("Invalid key: '"+f[0]+"' in \\includegraphics.")}}}var h=_e(t[0],"url").url;return s===""&&(s=h,s=s.replace(/^.*[\\/]/,""),s=s.substring(0,s.lastIndexOf("."))),n.settings.isTrusted({command:"\\includegraphics",url:h})?{type:"includegraphics",mode:n.mode,alt:s,width:i,height:a,totalheight:o,src:h}:n.formatUnsupportedCmd("\\includegraphics")},htmlBuilder:(e,t)=>{var r=st(e.height,t),n=0;e.totalheight.number>0&&(n=st(e.totalheight,t)-r);var i=0;e.width.number>0&&(i=st(e.width,t));var a={height:ie(r+n)};i>0&&(a.width=ie(i)),n>0&&(a.verticalAlign=ie(-n));var o=new Dx(e.src,e.alt,a);return o.height=r,o.depth=n,o},mathmlBuilder:(e,t)=>{var r=new Q.MathNode("mglyph",[]);r.setAttribute("alt",e.alt);var n=st(e.height,t),i=0;if(e.totalheight.number>0&&(i=st(e.totalheight,t)-n,r.setAttribute("valign",ie(-i))),r.setAttribute("height",ie(n+i)),e.width.number>0){var a=st(e.width,t);r.setAttribute("width",ie(a))}return r.setAttribute("src",e.src),r}});ae({type:"kern",names:["\\kern","\\mkern","\\hskip","\\mskip"],props:{numArgs:1,argTypes:["size"],primitive:!0,allowedInText:!0},handler(e,t){var{parser:r,funcName:n}=e,i=_e(t[0],"size");if(r.settings.strict){var a=n[1]==="m",o=i.value.unit==="mu";a?(o||r.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+n+" supports only mu units, "+("not "+i.value.unit+" units")),r.mode!=="math"&&r.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+n+" works only in math mode")):o&&r.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+n+" doesn't support mu units")}return{type:"kern",mode:r.mode,dimension:i.value}},htmlBuilder(e,t){return j.makeGlue(e.dimension,t)},mathmlBuilder(e,t){var r=st(e.dimension,t);return new Q.SpaceNode(r)}});ae({type:"lap",names:["\\mathllap","\\mathrlap","\\mathclap"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=t[0];return{type:"lap",mode:r.mode,alignment:n.slice(5),body:i}},htmlBuilder:(e,t)=>{var r;e.alignment==="clap"?(r=j.makeSpan([],[Ue(e.body,t)]),r=j.makeSpan(["inner"],[r],t)):r=j.makeSpan(["inner"],[Ue(e.body,t)]);var n=j.makeSpan(["fix"],[]),i=j.makeSpan([e.alignment],[r,n],t),a=j.makeSpan(["strut"]);return a.style.height=ie(i.height+i.depth),i.depth&&(a.style.verticalAlign=ie(-i.depth)),i.children.unshift(a),i=j.makeSpan(["thinbox"],[i],t),j.makeSpan(["mord","vbox"],[i],t)},mathmlBuilder:(e,t)=>{var r=new Q.MathNode("mpadded",[Je(e.body,t)]);if(e.alignment!=="rlap"){var n=e.alignment==="llap"?"-1":"-0.5";r.setAttribute("lspace",n+"width")}return r.setAttribute("width","0px"),r}});ae({type:"styling",names:["\\(","$"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){var{funcName:r,parser:n}=e,i=n.mode;n.switchMode("math");var a=r==="\\("?"\\)":"$",o=n.parseExpression(!1,a);return n.expect(a),n.switchMode(i),{type:"styling",mode:n.mode,style:"text",body:o}}});ae({type:"text",names:["\\)","\\]"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){throw new te("Mismatched "+e.funcName)}});var o1=(e,t)=>{switch(t.style.size){case be.DISPLAY.size:return e.display;case be.TEXT.size:return e.text;case be.SCRIPT.size:return e.script;case be.SCRIPTSCRIPT.size:return e.scriptscript;default:return e.text}};ae({type:"mathchoice",names:["\\mathchoice"],props:{numArgs:4,primitive:!0},handler:(e,t)=>{var{parser:r}=e;return{type:"mathchoice",mode:r.mode,display:pt(t[0]),text:pt(t[1]),script:pt(t[2]),scriptscript:pt(t[3])}},htmlBuilder:(e,t)=>{var r=o1(e,t),n=yt(r,t,!1);return j.makeFragment(n)},mathmlBuilder:(e,t)=>{var r=o1(e,t);return Pn(r,t)}});var z2=(e,t,r,n,i,a,o)=>{e=j.makeSpan([],[e]);var s=r&&Te.isCharacterBox(r),u,l;if(t){var c=Ue(t,n.havingStyle(i.sup()),n);l={elem:c,kern:Math.max(n.fontMetrics().bigOpSpacing1,n.fontMetrics().bigOpSpacing3-c.depth)}}if(r){var f=Ue(r,n.havingStyle(i.sub()),n);u={elem:f,kern:Math.max(n.fontMetrics().bigOpSpacing2,n.fontMetrics().bigOpSpacing4-f.height)}}var d;if(l&&u){var h=n.fontMetrics().bigOpSpacing5+u.elem.height+u.elem.depth+u.kern+e.depth+o;d=j.makeVList({positionType:"bottom",positionData:h,children:[{type:"kern",size:n.fontMetrics().bigOpSpacing5},{type:"elem",elem:u.elem,marginLeft:ie(-a)},{type:"kern",size:u.kern},{type:"elem",elem:e},{type:"kern",size:l.kern},{type:"elem",elem:l.elem,marginLeft:ie(a)},{type:"kern",size:n.fontMetrics().bigOpSpacing5}]},n)}else if(u){var p=e.height-o;d=j.makeVList({positionType:"top",positionData:p,children:[{type:"kern",size:n.fontMetrics().bigOpSpacing5},{type:"elem",elem:u.elem,marginLeft:ie(-a)},{type:"kern",size:u.kern},{type:"elem",elem:e}]},n)}else if(l){var m=e.depth+o;d=j.makeVList({positionType:"bottom",positionData:m,children:[{type:"elem",elem:e},{type:"kern",size:l.kern},{type:"elem",elem:l.elem,marginLeft:ie(a)},{type:"kern",size:n.fontMetrics().bigOpSpacing5}]},n)}else return e;var g=[d];if(u&&a!==0&&!s){var v=j.makeSpan(["mspace"],[],n);v.style.marginRight=ie(a),g.unshift(v)}return j.makeSpan(["mop","op-limits"],g,n)},$2=["\\smallint"],ea=(e,t)=>{var r,n,i=!1,a;e.type==="supsub"?(r=e.sup,n=e.sub,a=_e(e.base,"op"),i=!0):a=_e(e,"op");var o=t.style,s=!1;o.size===be.DISPLAY.size&&a.symbol&&!Te.contains($2,a.name)&&(s=!0);var u;if(a.symbol){var l=s?"Size2-Regular":"Size1-Regular",c="";if((a.name==="\\oiint"||a.name==="\\oiiint")&&(c=a.name.slice(1),a.name=c==="oiint"?"\\iint":"\\iiint"),u=j.makeSymbol(a.name,l,"math",t,["mop","op-symbol",s?"large-op":"small-op"]),c.length>0){var f=u.italic,d=j.staticSvg(c+"Size"+(s?"2":"1"),t);u=j.makeVList({positionType:"individualShift",children:[{type:"elem",elem:u,shift:0},{type:"elem",elem:d,shift:s?.08:0}]},t),a.name="\\"+c,u.classes.unshift("mop"),u.italic=f}}else if(a.body){var h=yt(a.body,t,!0);h.length===1&&h[0]instanceof mr?(u=h[0],u.classes[0]="mop"):u=j.makeSpan(["mop"],h,t)}else{for(var p=[],m=1;m<a.name.length;m++)p.push(j.mathsym(a.name[m],a.mode,t));u=j.makeSpan(["mop"],p,t)}var g=0,v=0;return(u instanceof mr||a.name==="\\oiint"||a.name==="\\oiiint")&&!a.suppressBaseShift&&(g=(u.height-u.depth)/2-t.fontMetrics().axisHeight,v=u.italic),i?z2(u,r,n,t,o,v,g):(g&&(u.style.position="relative",u.style.top=ie(g)),u)},Za=(e,t)=>{var r;if(e.symbol)r=new dr("mo",[gr(e.name,e.mode)]),Te.contains($2,e.name)&&r.setAttribute("largeop","false");else if(e.body)r=new dr("mo",Kt(e.body,t));else{r=new dr("mi",[new ga(e.name.slice(1))]);var n=new dr("mo",[gr("⁡","text")]);e.parentIsSupSub?r=new dr("mrow",[r,n]):r=p2([r,n])}return r},L9={"∏":"\\prod","∐":"\\coprod","∑":"\\sum","⋀":"\\bigwedge","⋁":"\\bigvee","⋂":"\\bigcap","⋃":"\\bigcup","⨀":"\\bigodot","⨁":"\\bigoplus","⨂":"\\bigotimes","⨄":"\\biguplus","⨆":"\\bigsqcup"};ae({type:"op",names:["\\coprod","\\bigvee","\\bigwedge","\\biguplus","\\bigcap","\\bigcup","\\intop","\\prod","\\sum","\\bigotimes","\\bigoplus","\\bigodot","\\bigsqcup","\\smallint","∏","∐","∑","⋀","⋁","⋂","⋃","⨀","⨁","⨂","⨄","⨆"],props:{numArgs:0},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=n;return i.length===1&&(i=L9[i]),{type:"op",mode:r.mode,limits:!0,parentIsSupSub:!1,symbol:!0,name:i}},htmlBuilder:ea,mathmlBuilder:Za});ae({type:"op",names:["\\mathop"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var{parser:r}=e,n=t[0];return{type:"op",mode:r.mode,limits:!1,parentIsSupSub:!1,symbol:!1,body:pt(n)}},htmlBuilder:ea,mathmlBuilder:Za});var F9={"∫":"\\int","∬":"\\iint","∭":"\\iiint","∮":"\\oint","∯":"\\oiint","∰":"\\oiiint"};ae({type:"op",names:["\\arcsin","\\arccos","\\arctan","\\arctg","\\arcctg","\\arg","\\ch","\\cos","\\cosec","\\cosh","\\cot","\\cotg","\\coth","\\csc","\\ctg","\\cth","\\deg","\\dim","\\exp","\\hom","\\ker","\\lg","\\ln","\\log","\\sec","\\sin","\\sinh","\\sh","\\tan","\\tanh","\\tg","\\th"],props:{numArgs:0},handler(e){var{parser:t,funcName:r}=e;return{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!1,name:r}},htmlBuilder:ea,mathmlBuilder:Za});ae({type:"op",names:["\\det","\\gcd","\\inf","\\lim","\\max","\\min","\\Pr","\\sup"],props:{numArgs:0},handler(e){var{parser:t,funcName:r}=e;return{type:"op",mode:t.mode,limits:!0,parentIsSupSub:!1,symbol:!1,name:r}},htmlBuilder:ea,mathmlBuilder:Za});ae({type:"op",names:["\\int","\\iint","\\iiint","\\oint","\\oiint","\\oiiint","∫","∬","∭","∮","∯","∰"],props:{numArgs:0},handler(e){var{parser:t,funcName:r}=e,n=r;return n.length===1&&(n=F9[n]),{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!0,name:n}},htmlBuilder:ea,mathmlBuilder:Za});var U2=(e,t)=>{var r,n,i=!1,a;e.type==="supsub"?(r=e.sup,n=e.sub,a=_e(e.base,"operatorname"),i=!0):a=_e(e,"operatorname");var o;if(a.body.length>0){for(var s=a.body.map(f=>{var d=f.text;return typeof d=="string"?{type:"textord",mode:f.mode,text:d}:f}),u=yt(s,t.withFont("mathrm"),!0),l=0;l<u.length;l++){var c=u[l];c instanceof mr&&(c.text=c.text.replace(/\u2212/,"-").replace(/\u2217/,"*"))}o=j.makeSpan(["mop"],u,t)}else o=j.makeSpan(["mop"],[],t);return i?z2(o,r,n,t,t.style,0,0):o},B9=(e,t)=>{for(var r=Kt(e.body,t.withFont("mathrm")),n=!0,i=0;i<r.length;i++){var a=r[i];if(!(a instanceof Q.SpaceNode))if(a instanceof Q.MathNode)switch(a.type){case"mi":case"mn":case"ms":case"mspace":case"mtext":break;case"mo":{var o=a.children[0];a.children.length===1&&o instanceof Q.TextNode?o.text=o.text.replace(/\u2212/,"-").replace(/\u2217/,"*"):n=!1;break}default:n=!1}else n=!1}if(n){var s=r.map(c=>c.toText()).join("");r=[new Q.TextNode(s)]}var u=new Q.MathNode("mi",r);u.setAttribute("mathvariant","normal");var l=new Q.MathNode("mo",[gr("⁡","text")]);return e.parentIsSupSub?new Q.MathNode("mrow",[u,l]):Q.newDocumentFragment([u,l])};ae({type:"operatorname",names:["\\operatorname@","\\operatornamewithlimits"],props:{numArgs:1},handler:(e,t)=>{var{parser:r,funcName:n}=e,i=t[0];return{type:"operatorname",mode:r.mode,body:pt(i),alwaysHandleSupSub:n==="\\operatornamewithlimits",limits:!1,parentIsSupSub:!1}},htmlBuilder:U2,mathmlBuilder:B9});S("\\operatorname","\\@ifstar\\operatornamewithlimits\\operatorname@");ci({type:"ordgroup",htmlBuilder(e,t){return e.semisimple?j.makeFragment(yt(e.body,t,!1)):j.makeSpan(["mord"],yt(e.body,t,!0),t)},mathmlBuilder(e,t){return Pn(e.body,t,!0)}});ae({type:"overline",names:["\\overline"],props:{numArgs:1},handler(e,t){var{parser:r}=e,n=t[0];return{type:"overline",mode:r.mode,body:n}},htmlBuilder(e,t){var r=Ue(e.body,t.havingCrampedStyle()),n=j.makeLineSpan("overline-line",t),i=t.fontMetrics().defaultRuleThickness,a=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:r},{type:"kern",size:3*i},{type:"elem",elem:n},{type:"kern",size:i}]},t);return j.makeSpan(["mord","overline"],[a],t)},mathmlBuilder(e,t){var r=new Q.MathNode("mo",[new Q.TextNode("‾")]);r.setAttribute("stretchy","true");var n=new Q.MathNode("mover",[Je(e.body,t),r]);return n.setAttribute("accent","true"),n}});ae({type:"phantom",names:["\\phantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:r}=e,n=t[0];return{type:"phantom",mode:r.mode,body:pt(n)}},htmlBuilder:(e,t)=>{var r=yt(e.body,t.withPhantom(),!1);return j.makeFragment(r)},mathmlBuilder:(e,t)=>{var r=Kt(e.body,t);return new Q.MathNode("mphantom",r)}});ae({type:"hphantom",names:["\\hphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:r}=e,n=t[0];return{type:"hphantom",mode:r.mode,body:n}},htmlBuilder:(e,t)=>{var r=j.makeSpan([],[Ue(e.body,t.withPhantom())]);if(r.height=0,r.depth=0,r.children)for(var n=0;n<r.children.length;n++)r.children[n].height=0,r.children[n].depth=0;return r=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:r}]},t),j.makeSpan(["mord"],[r],t)},mathmlBuilder:(e,t)=>{var r=Kt(pt(e.body),t),n=new Q.MathNode("mphantom",r),i=new Q.MathNode("mpadded",[n]);return i.setAttribute("height","0px"),i.setAttribute("depth","0px"),i}});ae({type:"vphantom",names:["\\vphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:r}=e,n=t[0];return{type:"vphantom",mode:r.mode,body:n}},htmlBuilder:(e,t)=>{var r=j.makeSpan(["inner"],[Ue(e.body,t.withPhantom())]),n=j.makeSpan(["fix"],[]);return j.makeSpan(["mord","rlap"],[r,n],t)},mathmlBuilder:(e,t)=>{var r=Kt(pt(e.body),t),n=new Q.MathNode("mphantom",r),i=new Q.MathNode("mpadded",[n]);return i.setAttribute("width","0px"),i}});ae({type:"raisebox",names:["\\raisebox"],props:{numArgs:2,argTypes:["size","hbox"],allowedInText:!0},handler(e,t){var{parser:r}=e,n=_e(t[0],"size").value,i=t[1];return{type:"raisebox",mode:r.mode,dy:n,body:i}},htmlBuilder(e,t){var r=Ue(e.body,t),n=st(e.dy,t);return j.makeVList({positionType:"shift",positionData:-n,children:[{type:"elem",elem:r}]},t)},mathmlBuilder(e,t){var r=new Q.MathNode("mpadded",[Je(e.body,t)]),n=e.dy.number+e.dy.unit;return r.setAttribute("voffset",n),r}});ae({type:"internal",names:["\\relax"],props:{numArgs:0,allowedInText:!0},handler(e){var{parser:t}=e;return{type:"internal",mode:t.mode}}});ae({type:"rule",names:["\\rule"],props:{numArgs:2,numOptionalArgs:1,argTypes:["size","size","size"]},handler(e,t,r){var{parser:n}=e,i=r[0],a=_e(t[0],"size"),o=_e(t[1],"size");return{type:"rule",mode:n.mode,shift:i&&_e(i,"size").value,width:a.value,height:o.value}},htmlBuilder(e,t){var r=j.makeSpan(["mord","rule"],[],t),n=st(e.width,t),i=st(e.height,t),a=e.shift?st(e.shift,t):0;return r.style.borderRightWidth=ie(n),r.style.borderTopWidth=ie(i),r.style.bottom=ie(a),r.width=n,r.height=i+a,r.depth=-a,r.maxFontSize=i*1.125*t.sizeMultiplier,r},mathmlBuilder(e,t){var r=st(e.width,t),n=st(e.height,t),i=e.shift?st(e.shift,t):0,a=t.color&&t.getColor()||"black",o=new Q.MathNode("mspace");o.setAttribute("mathbackground",a),o.setAttribute("width",ie(r)),o.setAttribute("height",ie(n));var s=new Q.MathNode("mpadded",[o]);return i>=0?s.setAttribute("height",ie(i)):(s.setAttribute("height",ie(i)),s.setAttribute("depth",ie(-i))),s.setAttribute("voffset",ie(i)),s}});function H2(e,t,r){for(var n=yt(e,t,!1),i=t.sizeMultiplier/r.sizeMultiplier,a=0;a<n.length;a++){var o=n[a].classes.indexOf("sizing");o<0?Array.prototype.push.apply(n[a].classes,t.sizingClasses(r)):n[a].classes[o+1]==="reset-size"+t.size&&(n[a].classes[o+1]="reset-size"+r.size),n[a].height*=i,n[a].depth*=i}return j.makeFragment(n)}var s1=["\\tiny","\\sixptsize","\\scriptsize","\\footnotesize","\\small","\\normalsize","\\large","\\Large","\\LARGE","\\huge","\\Huge"],z9=(e,t)=>{var r=t.havingSize(e.size);return H2(e.body,r,t)};ae({type:"sizing",names:s1,props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{breakOnTokenText:r,funcName:n,parser:i}=e,a=i.parseExpression(!1,r);return{type:"sizing",mode:i.mode,size:s1.indexOf(n)+1,body:a}},htmlBuilder:z9,mathmlBuilder:(e,t)=>{var r=t.havingSize(e.size),n=Kt(e.body,r),i=new Q.MathNode("mstyle",n);return i.setAttribute("mathsize",ie(r.sizeMultiplier)),i}});ae({type:"smash",names:["\\smash"],props:{numArgs:1,numOptionalArgs:1,allowedInText:!0},handler:(e,t,r)=>{var{parser:n}=e,i=!1,a=!1,o=r[0]&&_e(r[0],"ordgroup");if(o)for(var s="",u=0;u<o.body.length;++u){var l=o.body[u];if(s=l.text,s==="t")i=!0;else if(s==="b")a=!0;else{i=!1,a=!1;break}}else i=!0,a=!0;var c=t[0];return{type:"smash",mode:n.mode,body:c,smashHeight:i,smashDepth:a}},htmlBuilder:(e,t)=>{var r=j.makeSpan([],[Ue(e.body,t)]);if(!e.smashHeight&&!e.smashDepth)return r;if(e.smashHeight&&(r.height=0,r.children))for(var n=0;n<r.children.length;n++)r.children[n].height=0;if(e.smashDepth&&(r.depth=0,r.children))for(var i=0;i<r.children.length;i++)r.children[i].depth=0;var a=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:r}]},t);return j.makeSpan(["mord"],[a],t)},mathmlBuilder:(e,t)=>{var r=new Q.MathNode("mpadded",[Je(e.body,t)]);return e.smashHeight&&r.setAttribute("height","0px"),e.smashDepth&&r.setAttribute("depth","0px"),r}});ae({type:"sqrt",names:["\\sqrt"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,r){var{parser:n}=e,i=r[0],a=t[0];return{type:"sqrt",mode:n.mode,body:a,index:i}},htmlBuilder(e,t){var r=Ue(e.body,t.havingCrampedStyle());r.height===0&&(r.height=t.fontMetrics().xHeight),r=j.wrapFragment(r,t);var n=t.fontMetrics(),i=n.defaultRuleThickness,a=i;t.style.id<be.TEXT.id&&(a=t.fontMetrics().xHeight);var o=i+a/4,s=r.height+r.depth+o+i,{span:u,ruleWidth:l,advanceWidth:c}=sn.sqrtImage(s,t),f=u.height-l;f>r.height+r.depth+o&&(o=(o+f-r.height-r.depth)/2);var d=u.height-r.height-o-l;r.style.paddingLeft=ie(c);var h=j.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:r,wrapperClasses:["svg-align"]},{type:"kern",size:-(r.height+d)},{type:"elem",elem:u},{type:"kern",size:l}]},t);if(e.index){var p=t.havingStyle(be.SCRIPTSCRIPT),m=Ue(e.index,p,t),g=.6*(h.height-h.depth),v=j.makeVList({positionType:"shift",positionData:-g,children:[{type:"elem",elem:m}]},t),w=j.makeSpan(["root"],[v]);return j.makeSpan(["mord","sqrt"],[w,h],t)}else return j.makeSpan(["mord","sqrt"],[h],t)},mathmlBuilder(e,t){var{body:r,index:n}=e;return n?new Q.MathNode("mroot",[Je(r,t),Je(n,t)]):new Q.MathNode("msqrt",[Je(r,t)])}});var u1={display:be.DISPLAY,text:be.TEXT,script:be.SCRIPT,scriptscript:be.SCRIPTSCRIPT};ae({type:"styling",names:["\\displaystyle","\\textstyle","\\scriptstyle","\\scriptscriptstyle"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e,t){var{breakOnTokenText:r,funcName:n,parser:i}=e,a=i.parseExpression(!0,r),o=n.slice(1,n.length-5);return{type:"styling",mode:i.mode,style:o,body:a}},htmlBuilder(e,t){var r=u1[e.style],n=t.havingStyle(r).withFont("");return H2(e.body,n,t)},mathmlBuilder(e,t){var r=u1[e.style],n=t.havingStyle(r),i=Kt(e.body,n),a=new Q.MathNode("mstyle",i),o={display:["0","true"],text:["0","false"],script:["1","false"],scriptscript:["2","false"]},s=o[e.style];return a.setAttribute("scriptlevel",s[0]),a.setAttribute("displaystyle",s[1]),a}});var $9=function(t,r){var n=t.base;if(n)if(n.type==="op"){var i=n.limits&&(r.style.size===be.DISPLAY.size||n.alwaysHandleSupSub);return i?ea:null}else if(n.type==="operatorname"){var a=n.alwaysHandleSupSub&&(r.style.size===be.DISPLAY.size||n.limits);return a?U2:null}else{if(n.type==="accent")return Te.isCharacterBox(n.base)?Ef:null;if(n.type==="horizBrace"){var o=!t.sub;return o===n.isOver?B2:null}else return null}else return null};ci({type:"supsub",htmlBuilder(e,t){var r=$9(e,t);if(r)return r(e,t);var{base:n,sup:i,sub:a}=e,o=Ue(n,t),s,u,l=t.fontMetrics(),c=0,f=0,d=n&&Te.isCharacterBox(n);if(i){var h=t.havingStyle(t.style.sup());s=Ue(i,h,t),d||(c=o.height-h.fontMetrics().supDrop*h.sizeMultiplier/t.sizeMultiplier)}if(a){var p=t.havingStyle(t.style.sub());u=Ue(a,p,t),d||(f=o.depth+p.fontMetrics().subDrop*p.sizeMultiplier/t.sizeMultiplier)}var m;t.style===be.DISPLAY?m=l.sup1:t.style.cramped?m=l.sup3:m=l.sup2;var g=t.sizeMultiplier,v=ie(.5/l.ptPerEm/g),w=null;if(u){var x=e.base&&e.base.type==="op"&&e.base.name&&(e.base.name==="\\oiint"||e.base.name==="\\oiiint");(o instanceof mr||x)&&(w=ie(-o.italic))}var N;if(s&&u){c=Math.max(c,m,s.depth+.25*l.xHeight),f=Math.max(f,l.sub2);var O=l.defaultRuleThickness,A=4*O;if(c-s.depth-(u.height-f)<A){f=A-(c-s.depth)+u.height;var D=.8*l.xHeight-(c-s.depth);D>0&&(c+=D,f-=D)}var H=[{type:"elem",elem:u,shift:f,marginRight:v,marginLeft:w},{type:"elem",elem:s,shift:-c,marginRight:v}];N=j.makeVList({positionType:"individualShift",children:H},t)}else if(u){f=Math.max(f,l.sub1,u.height-.8*l.xHeight);var z=[{type:"elem",elem:u,marginLeft:w,marginRight:v}];N=j.makeVList({positionType:"shift",positionData:f,children:z},t)}else if(s)c=Math.max(c,m,s.depth+.25*l.xHeight),N=j.makeVList({positionType:"shift",positionData:-c,children:[{type:"elem",elem:s,marginRight:v}]},t);else throw new Error("supsub must have either sup or sub.");var L=C0(o,"right")||"mord";return j.makeSpan([L],[o,j.makeSpan(["msupsub"],[N])],t)},mathmlBuilder(e,t){var r=!1,n,i;e.base&&e.base.type==="horizBrace"&&(i=!!e.sup,i===e.base.isOver&&(r=!0,n=e.base.isOver)),e.base&&(e.base.type==="op"||e.base.type==="operatorname")&&(e.base.parentIsSupSub=!0);var a=[Je(e.base,t)];e.sub&&a.push(Je(e.sub,t)),e.sup&&a.push(Je(e.sup,t));var o;if(r)o=n?"mover":"munder";else if(e.sub)if(e.sup){var l=e.base;l&&l.type==="op"&&l.limits&&t.style===be.DISPLAY||l&&l.type==="operatorname"&&l.alwaysHandleSupSub&&(t.style===be.DISPLAY||l.limits)?o="munderover":o="msubsup"}else{var u=e.base;u&&u.type==="op"&&u.limits&&(t.style===be.DISPLAY||u.alwaysHandleSupSub)||u&&u.type==="operatorname"&&u.alwaysHandleSupSub&&(u.limits||t.style===be.DISPLAY)?o="munder":o="msub"}else{var s=e.base;s&&s.type==="op"&&s.limits&&(t.style===be.DISPLAY||s.alwaysHandleSupSub)||s&&s.type==="operatorname"&&s.alwaysHandleSupSub&&(s.limits||t.style===be.DISPLAY)?o="mover":o="msup"}return new Q.MathNode(o,a)}});ci({type:"atom",htmlBuilder(e,t){return j.mathsym(e.text,e.mode,t,["m"+e.family])},mathmlBuilder(e,t){var r=new Q.MathNode("mo",[gr(e.text,e.mode)]);if(e.family==="bin"){var n=wf(e,t);n==="bold-italic"&&r.setAttribute("mathvariant",n)}else e.family==="punct"?r.setAttribute("separator","true"):(e.family==="open"||e.family==="close")&&r.setAttribute("stretchy","false");return r}});var q2={mi:"italic",mn:"normal",mtext:"normal"};ci({type:"mathord",htmlBuilder(e,t){return j.makeOrd(e,t,"mathord")},mathmlBuilder(e,t){var r=new Q.MathNode("mi",[gr(e.text,e.mode,t)]),n=wf(e,t)||"italic";return n!==q2[r.type]&&r.setAttribute("mathvariant",n),r}});ci({type:"textord",htmlBuilder(e,t){return j.makeOrd(e,t,"textord")},mathmlBuilder(e,t){var r=gr(e.text,e.mode,t),n=wf(e,t)||"normal",i;return e.mode==="text"?i=new Q.MathNode("mtext",[r]):/[0-9]/.test(e.text)?i=new Q.MathNode("mn",[r]):e.text==="\\prime"?i=new Q.MathNode("mo",[r]):i=new Q.MathNode("mi",[r]),n!==q2[i.type]&&i.setAttribute("mathvariant",n),i}});var kl={"\\nobreak":"nobreak","\\allowbreak":"allowbreak"},Ol={" ":{},"\\ ":{},"~":{className:"nobreak"},"\\space":{},"\\nobreakspace":{className:"nobreak"}};ci({type:"spacing",htmlBuilder(e,t){if(Ol.hasOwnProperty(e.text)){var r=Ol[e.text].className||"";if(e.mode==="text"){var n=j.makeOrd(e,t,"textord");return n.classes.push(r),n}else return j.makeSpan(["mspace",r],[j.mathsym(e.text,e.mode,t)],t)}else{if(kl.hasOwnProperty(e.text))return j.makeSpan(["mspace",kl[e.text]],[],t);throw new te('Unknown type of space "'+e.text+'"')}},mathmlBuilder(e,t){var r;if(Ol.hasOwnProperty(e.text))r=new Q.MathNode("mtext",[new Q.TextNode(" ")]);else{if(kl.hasOwnProperty(e.text))return new Q.MathNode("mspace");throw new te('Unknown type of space "'+e.text+'"')}return r}});var l1=()=>{var e=new Q.MathNode("mtd",[]);return e.setAttribute("width","50%"),e};ci({type:"tag",mathmlBuilder(e,t){var r=new Q.MathNode("mtable",[new Q.MathNode("mtr",[l1(),new Q.MathNode("mtd",[Pn(e.body,t)]),l1(),new Q.MathNode("mtd",[Pn(e.tag,t)])])]);return r.setAttribute("width","100%"),r}});var c1={"\\text":void 0,"\\textrm":"textrm","\\textsf":"textsf","\\texttt":"texttt","\\textnormal":"textrm"},f1={"\\textbf":"textbf","\\textmd":"textmd"},U9={"\\textit":"textit","\\textup":"textup"},d1=(e,t)=>{var r=e.font;return r?c1[r]?t.withTextFontFamily(c1[r]):f1[r]?t.withTextFontWeight(f1[r]):t.withTextFontShape(U9[r]):t};ae({type:"text",names:["\\text","\\textrm","\\textsf","\\texttt","\\textnormal","\\textbf","\\textmd","\\textit","\\textup"],props:{numArgs:1,argTypes:["text"],allowedInArgument:!0,allowedInText:!0},handler(e,t){var{parser:r,funcName:n}=e,i=t[0];return{type:"text",mode:r.mode,body:pt(i),font:n}},htmlBuilder(e,t){var r=d1(e,t),n=yt(e.body,r,!0);return j.makeSpan(["mord","text"],n,r)},mathmlBuilder(e,t){var r=d1(e,t);return Pn(e.body,r)}});ae({type:"underline",names:["\\underline"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:r}=e;return{type:"underline",mode:r.mode,body:t[0]}},htmlBuilder(e,t){var r=Ue(e.body,t),n=j.makeLineSpan("underline-line",t),i=t.fontMetrics().defaultRuleThickness,a=j.makeVList({positionType:"top",positionData:r.height,children:[{type:"kern",size:i},{type:"elem",elem:n},{type:"kern",size:3*i},{type:"elem",elem:r}]},t);return j.makeSpan(["mord","underline"],[a],t)},mathmlBuilder(e,t){var r=new Q.MathNode("mo",[new Q.TextNode("‾")]);r.setAttribute("stretchy","true");var n=new Q.MathNode("munder",[Je(e.body,t),r]);return n.setAttribute("accentunder","true"),n}});ae({type:"vcenter",names:["\\vcenter"],props:{numArgs:1,argTypes:["original"],allowedInText:!1},handler(e,t){var{parser:r}=e;return{type:"vcenter",mode:r.mode,body:t[0]}},htmlBuilder(e,t){var r=Ue(e.body,t),n=t.fontMetrics().axisHeight,i=.5*(r.height-n-(r.depth+n));return j.makeVList({positionType:"shift",positionData:i,children:[{type:"elem",elem:r}]},t)},mathmlBuilder(e,t){return new Q.MathNode("mpadded",[Je(e.body,t)],["vcenter"])}});ae({type:"verb",names:["\\verb"],props:{numArgs:0,allowedInText:!0},handler(e,t,r){throw new te("\\verb ended by end of line instead of matching delimiter")},htmlBuilder(e,t){for(var r=h1(e),n=[],i=t.havingStyle(t.style.text()),a=0;a<r.length;a++){var o=r[a];o==="~"&&(o="\\textasciitilde"),n.push(j.makeSymbol(o,"Typewriter-Regular",e.mode,i,["mord","texttt"]))}return j.makeSpan(["mord","text"].concat(i.sizingClasses(t)),j.tryCombineChars(n),i)},mathmlBuilder(e,t){var r=new Q.TextNode(h1(e)),n=new Q.MathNode("mtext",[r]);return n.setAttribute("mathvariant","monospace"),n}});var h1=e=>e.body.replace(/ /g,e.star?"␣":" "),On=d2,j2=`[ \r
	]`,H9="\\\\[a-zA-Z@]+",q9="\\\\[^\uD800-\uDFFF]",j9="("+H9+")"+j2+"*",V9=`\\\\(
|[ \r	]+
?)[ \r	]*`,P0="[̀-ͯ]",G9=new RegExp(P0+"+$"),W9="("+j2+"+)|"+(V9+"|")+"([!-\\[\\]-‧‪-퟿豈-]"+(P0+"*")+"|[\uD800-\uDBFF][\uDC00-\uDFFF]"+(P0+"*")+"|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5"+("|"+j9)+("|"+q9+")");class p1{constructor(t,r){this.input=void 0,this.settings=void 0,this.tokenRegex=void 0,this.catcodes=void 0,this.input=t,this.settings=r,this.tokenRegex=new RegExp(W9,"g"),this.catcodes={"%":14,"~":13}}setCatcode(t,r){this.catcodes[t]=r}lex(){var t=this.input,r=this.tokenRegex.lastIndex;if(r===t.length)return new qr("EOF",new Jt(this,r,r));var n=this.tokenRegex.exec(t);if(n===null||n.index!==r)throw new te("Unexpected character: '"+t[r]+"'",new qr(t[r],new Jt(this,r,r+1)));var i=n[6]||n[3]||(n[2]?"\\ ":" ");if(this.catcodes[i]===14){var a=t.indexOf(`
`,this.tokenRegex.lastIndex);return a===-1?(this.tokenRegex.lastIndex=t.length,this.settings.reportNonstrict("commentAtEnd","% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")):this.tokenRegex.lastIndex=a+1,this.lex()}return new qr(i,new Jt(this,r,this.tokenRegex.lastIndex))}}class K9{constructor(t,r){t===void 0&&(t={}),r===void 0&&(r={}),this.current=void 0,this.builtins=void 0,this.undefStack=void 0,this.current=r,this.builtins=t,this.undefStack=[]}beginGroup(){this.undefStack.push({})}endGroup(){if(this.undefStack.length===0)throw new te("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");var t=this.undefStack.pop();for(var r in t)t.hasOwnProperty(r)&&(t[r]==null?delete this.current[r]:this.current[r]=t[r])}endGroups(){for(;this.undefStack.length>0;)this.endGroup()}has(t){return this.current.hasOwnProperty(t)||this.builtins.hasOwnProperty(t)}get(t){return this.current.hasOwnProperty(t)?this.current[t]:this.builtins[t]}set(t,r,n){if(n===void 0&&(n=!1),n){for(var i=0;i<this.undefStack.length;i++)delete this.undefStack[i][t];this.undefStack.length>0&&(this.undefStack[this.undefStack.length-1][t]=r)}else{var a=this.undefStack[this.undefStack.length-1];a&&!a.hasOwnProperty(t)&&(a[t]=this.current[t])}r==null?delete this.current[t]:this.current[t]=r}}var X9=I2;S("\\noexpand",function(e){var t=e.popToken();return e.isExpandable(t.text)&&(t.noexpand=!0,t.treatAsRelax=!0),{tokens:[t],numArgs:0}});S("\\expandafter",function(e){var t=e.popToken();return e.expandOnce(!0),{tokens:[t],numArgs:0}});S("\\@firstoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[0],numArgs:0}});S("\\@secondoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[1],numArgs:0}});S("\\@ifnextchar",function(e){var t=e.consumeArgs(3);e.consumeSpaces();var r=e.future();return t[0].length===1&&t[0][0].text===r.text?{tokens:t[1],numArgs:0}:{tokens:t[2],numArgs:0}});S("\\@ifstar","\\@ifnextchar *{\\@firstoftwo{#1}}");S("\\TextOrMath",function(e){var t=e.consumeArgs(2);return e.mode==="text"?{tokens:t[0],numArgs:0}:{tokens:t[1],numArgs:0}});var m1={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,a:10,A:10,b:11,B:11,c:12,C:12,d:13,D:13,e:14,E:14,f:15,F:15};S("\\char",function(e){var t=e.popToken(),r,n="";if(t.text==="'")r=8,t=e.popToken();else if(t.text==='"')r=16,t=e.popToken();else if(t.text==="`")if(t=e.popToken(),t.text[0]==="\\")n=t.text.charCodeAt(1);else{if(t.text==="EOF")throw new te("\\char` missing argument");n=t.text.charCodeAt(0)}else r=10;if(r){if(n=m1[t.text],n==null||n>=r)throw new te("Invalid base-"+r+" digit "+t.text);for(var i;(i=m1[e.future().text])!=null&&i<r;)n*=r,n+=i,e.popToken()}return"\\@char{"+n+"}"});var Cf=(e,t,r)=>{var n=e.consumeArg().tokens;if(n.length!==1)throw new te("\\newcommand's first argument must be a macro name");var i=n[0].text,a=e.isDefined(i);if(a&&!t)throw new te("\\newcommand{"+i+"} attempting to redefine "+(i+"; use \\renewcommand"));if(!a&&!r)throw new te("\\renewcommand{"+i+"} when command "+i+" does not yet exist; use \\newcommand");var o=0;if(n=e.consumeArg().tokens,n.length===1&&n[0].text==="["){for(var s="",u=e.expandNextToken();u.text!=="]"&&u.text!=="EOF";)s+=u.text,u=e.expandNextToken();if(!s.match(/^\s*[0-9]+\s*$/))throw new te("Invalid number of arguments: "+s);o=parseInt(s),n=e.consumeArg().tokens}return e.macros.set(i,{tokens:n,numArgs:o}),""};S("\\newcommand",e=>Cf(e,!1,!0));S("\\renewcommand",e=>Cf(e,!0,!1));S("\\providecommand",e=>Cf(e,!0,!0));S("\\message",e=>{var t=e.consumeArgs(1)[0];return console.log(t.reverse().map(r=>r.text).join("")),""});S("\\errmessage",e=>{var t=e.consumeArgs(1)[0];return console.error(t.reverse().map(r=>r.text).join("")),""});S("\\show",e=>{var t=e.popToken(),r=t.text;return console.log(t,e.macros.get(r),On[r],tt.math[r],tt.text[r]),""});S("\\bgroup","{");S("\\egroup","}");S("~","\\nobreakspace");S("\\lq","`");S("\\rq","'");S("\\aa","\\r a");S("\\AA","\\r A");S("\\textcopyright","\\html@mathml{\\textcircled{c}}{\\char`©}");S("\\copyright","\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");S("\\textregistered","\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");S("ℬ","\\mathscr{B}");S("ℰ","\\mathscr{E}");S("ℱ","\\mathscr{F}");S("ℋ","\\mathscr{H}");S("ℐ","\\mathscr{I}");S("ℒ","\\mathscr{L}");S("ℳ","\\mathscr{M}");S("ℛ","\\mathscr{R}");S("ℭ","\\mathfrak{C}");S("ℌ","\\mathfrak{H}");S("ℨ","\\mathfrak{Z}");S("\\Bbbk","\\Bbb{k}");S("·","\\cdotp");S("\\llap","\\mathllap{\\textrm{#1}}");S("\\rlap","\\mathrlap{\\textrm{#1}}");S("\\clap","\\mathclap{\\textrm{#1}}");S("\\mathstrut","\\vphantom{(}");S("\\underbar","\\underline{\\text{#1}}");S("\\not",'\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}');S("\\neq","\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");S("\\ne","\\neq");S("≠","\\neq");S("\\notin","\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");S("∉","\\notin");S("≘","\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");S("≙","\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");S("≚","\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");S("≛","\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");S("≝","\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");S("≞","\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");S("≟","\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");S("⟂","\\perp");S("‼","\\mathclose{!\\mkern-0.8mu!}");S("∌","\\notni");S("⌜","\\ulcorner");S("⌝","\\urcorner");S("⌞","\\llcorner");S("⌟","\\lrcorner");S("©","\\copyright");S("®","\\textregistered");S("️","\\textregistered");S("\\ulcorner",'\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');S("\\urcorner",'\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');S("\\llcorner",'\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');S("\\lrcorner",'\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');S("\\vdots","\\mathord{\\varvdots\\rule{0pt}{15pt}}");S("⋮","\\vdots");S("\\varGamma","\\mathit{\\Gamma}");S("\\varDelta","\\mathit{\\Delta}");S("\\varTheta","\\mathit{\\Theta}");S("\\varLambda","\\mathit{\\Lambda}");S("\\varXi","\\mathit{\\Xi}");S("\\varPi","\\mathit{\\Pi}");S("\\varSigma","\\mathit{\\Sigma}");S("\\varUpsilon","\\mathit{\\Upsilon}");S("\\varPhi","\\mathit{\\Phi}");S("\\varPsi","\\mathit{\\Psi}");S("\\varOmega","\\mathit{\\Omega}");S("\\substack","\\begin{subarray}{c}#1\\end{subarray}");S("\\colon","\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");S("\\boxed","\\fbox{$\\displaystyle{#1}$}");S("\\iff","\\DOTSB\\;\\Longleftrightarrow\\;");S("\\implies","\\DOTSB\\;\\Longrightarrow\\;");S("\\impliedby","\\DOTSB\\;\\Longleftarrow\\;");var g1={",":"\\dotsc","\\not":"\\dotsb","+":"\\dotsb","=":"\\dotsb","<":"\\dotsb",">":"\\dotsb","-":"\\dotsb","*":"\\dotsb",":":"\\dotsb","\\DOTSB":"\\dotsb","\\coprod":"\\dotsb","\\bigvee":"\\dotsb","\\bigwedge":"\\dotsb","\\biguplus":"\\dotsb","\\bigcap":"\\dotsb","\\bigcup":"\\dotsb","\\prod":"\\dotsb","\\sum":"\\dotsb","\\bigotimes":"\\dotsb","\\bigoplus":"\\dotsb","\\bigodot":"\\dotsb","\\bigsqcup":"\\dotsb","\\And":"\\dotsb","\\longrightarrow":"\\dotsb","\\Longrightarrow":"\\dotsb","\\longleftarrow":"\\dotsb","\\Longleftarrow":"\\dotsb","\\longleftrightarrow":"\\dotsb","\\Longleftrightarrow":"\\dotsb","\\mapsto":"\\dotsb","\\longmapsto":"\\dotsb","\\hookrightarrow":"\\dotsb","\\doteq":"\\dotsb","\\mathbin":"\\dotsb","\\mathrel":"\\dotsb","\\relbar":"\\dotsb","\\Relbar":"\\dotsb","\\xrightarrow":"\\dotsb","\\xleftarrow":"\\dotsb","\\DOTSI":"\\dotsi","\\int":"\\dotsi","\\oint":"\\dotsi","\\iint":"\\dotsi","\\iiint":"\\dotsi","\\iiiint":"\\dotsi","\\idotsint":"\\dotsi","\\DOTSX":"\\dotsx"};S("\\dots",function(e){var t="\\dotso",r=e.expandAfterFuture().text;return r in g1?t=g1[r]:(r.slice(0,4)==="\\not"||r in tt.math&&Te.contains(["bin","rel"],tt.math[r].group))&&(t="\\dotsb"),t});var Mf={")":!0,"]":!0,"\\rbrack":!0,"\\}":!0,"\\rbrace":!0,"\\rangle":!0,"\\rceil":!0,"\\rfloor":!0,"\\rgroup":!0,"\\rmoustache":!0,"\\right":!0,"\\bigr":!0,"\\biggr":!0,"\\Bigr":!0,"\\Biggr":!0,$:!0,";":!0,".":!0,",":!0};S("\\dotso",function(e){var t=e.future().text;return t in Mf?"\\ldots\\,":"\\ldots"});S("\\dotsc",function(e){var t=e.future().text;return t in Mf&&t!==","?"\\ldots\\,":"\\ldots"});S("\\cdots",function(e){var t=e.future().text;return t in Mf?"\\@cdots\\,":"\\@cdots"});S("\\dotsb","\\cdots");S("\\dotsm","\\cdots");S("\\dotsi","\\!\\cdots");S("\\dotsx","\\ldots\\,");S("\\DOTSI","\\relax");S("\\DOTSB","\\relax");S("\\DOTSX","\\relax");S("\\tmspace","\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");S("\\,","\\tmspace+{3mu}{.1667em}");S("\\thinspace","\\,");S("\\>","\\mskip{4mu}");S("\\:","\\tmspace+{4mu}{.2222em}");S("\\medspace","\\:");S("\\;","\\tmspace+{5mu}{.2777em}");S("\\thickspace","\\;");S("\\!","\\tmspace-{3mu}{.1667em}");S("\\negthinspace","\\!");S("\\negmedspace","\\tmspace-{4mu}{.2222em}");S("\\negthickspace","\\tmspace-{5mu}{.277em}");S("\\enspace","\\kern.5em ");S("\\enskip","\\hskip.5em\\relax");S("\\quad","\\hskip1em\\relax");S("\\qquad","\\hskip2em\\relax");S("\\tag","\\@ifstar\\tag@literal\\tag@paren");S("\\tag@paren","\\tag@literal{({#1})}");S("\\tag@literal",e=>{if(e.macros.get("\\df@tag"))throw new te("Multiple \\tag");return"\\gdef\\df@tag{\\text{#1}}"});S("\\bmod","\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");S("\\pod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");S("\\pmod","\\pod{{\\rm mod}\\mkern6mu#1}");S("\\mod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");S("\\newline","\\\\\\relax");S("\\TeX","\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");var V2=ie(Ur["Main-Regular"]["T".charCodeAt(0)][1]-.7*Ur["Main-Regular"]["A".charCodeAt(0)][1]);S("\\LaTeX","\\textrm{\\html@mathml{"+("L\\kern-.36em\\raisebox{"+V2+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{LaTeX}}");S("\\KaTeX","\\textrm{\\html@mathml{"+("K\\kern-.17em\\raisebox{"+V2+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{KaTeX}}");S("\\hspace","\\@ifstar\\@hspacer\\@hspace");S("\\@hspace","\\hskip #1\\relax");S("\\@hspacer","\\rule{0pt}{0pt}\\hskip #1\\relax");S("\\ordinarycolon",":");S("\\vcentcolon","\\mathrel{\\mathop\\ordinarycolon}");S("\\dblcolon",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');S("\\coloneqq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');S("\\Coloneqq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');S("\\coloneq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');S("\\Coloneq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');S("\\eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');S("\\Eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');S("\\eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');S("\\Eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');S("\\colonapprox",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');S("\\Colonapprox",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');S("\\colonsim",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');S("\\Colonsim",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');S("∷","\\dblcolon");S("∹","\\eqcolon");S("≔","\\coloneqq");S("≕","\\eqqcolon");S("⩴","\\Coloneqq");S("\\ratio","\\vcentcolon");S("\\coloncolon","\\dblcolon");S("\\colonequals","\\coloneqq");S("\\coloncolonequals","\\Coloneqq");S("\\equalscolon","\\eqqcolon");S("\\equalscoloncolon","\\Eqqcolon");S("\\colonminus","\\coloneq");S("\\coloncolonminus","\\Coloneq");S("\\minuscolon","\\eqcolon");S("\\minuscoloncolon","\\Eqcolon");S("\\coloncolonapprox","\\Colonapprox");S("\\coloncolonsim","\\Colonsim");S("\\simcolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");S("\\simcoloncolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");S("\\approxcolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");S("\\approxcoloncolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");S("\\notni","\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");S("\\limsup","\\DOTSB\\operatorname*{lim\\,sup}");S("\\liminf","\\DOTSB\\operatorname*{lim\\,inf}");S("\\injlim","\\DOTSB\\operatorname*{inj\\,lim}");S("\\projlim","\\DOTSB\\operatorname*{proj\\,lim}");S("\\varlimsup","\\DOTSB\\operatorname*{\\overline{lim}}");S("\\varliminf","\\DOTSB\\operatorname*{\\underline{lim}}");S("\\varinjlim","\\DOTSB\\operatorname*{\\underrightarrow{lim}}");S("\\varprojlim","\\DOTSB\\operatorname*{\\underleftarrow{lim}}");S("\\gvertneqq","\\html@mathml{\\@gvertneqq}{≩}");S("\\lvertneqq","\\html@mathml{\\@lvertneqq}{≨}");S("\\ngeqq","\\html@mathml{\\@ngeqq}{≱}");S("\\ngeqslant","\\html@mathml{\\@ngeqslant}{≱}");S("\\nleqq","\\html@mathml{\\@nleqq}{≰}");S("\\nleqslant","\\html@mathml{\\@nleqslant}{≰}");S("\\nshortmid","\\html@mathml{\\@nshortmid}{∤}");S("\\nshortparallel","\\html@mathml{\\@nshortparallel}{∦}");S("\\nsubseteqq","\\html@mathml{\\@nsubseteqq}{⊈}");S("\\nsupseteqq","\\html@mathml{\\@nsupseteqq}{⊉}");S("\\varsubsetneq","\\html@mathml{\\@varsubsetneq}{⊊}");S("\\varsubsetneqq","\\html@mathml{\\@varsubsetneqq}{⫋}");S("\\varsupsetneq","\\html@mathml{\\@varsupsetneq}{⊋}");S("\\varsupsetneqq","\\html@mathml{\\@varsupsetneqq}{⫌}");S("\\imath","\\html@mathml{\\@imath}{ı}");S("\\jmath","\\html@mathml{\\@jmath}{ȷ}");S("\\llbracket","\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");S("\\rrbracket","\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");S("⟦","\\llbracket");S("⟧","\\rrbracket");S("\\lBrace","\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");S("\\rBrace","\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");S("⦃","\\lBrace");S("⦄","\\rBrace");S("\\minuso","\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");S("⦵","\\minuso");S("\\darr","\\downarrow");S("\\dArr","\\Downarrow");S("\\Darr","\\Downarrow");S("\\lang","\\langle");S("\\rang","\\rangle");S("\\uarr","\\uparrow");S("\\uArr","\\Uparrow");S("\\Uarr","\\Uparrow");S("\\N","\\mathbb{N}");S("\\R","\\mathbb{R}");S("\\Z","\\mathbb{Z}");S("\\alef","\\aleph");S("\\alefsym","\\aleph");S("\\Alpha","\\mathrm{A}");S("\\Beta","\\mathrm{B}");S("\\bull","\\bullet");S("\\Chi","\\mathrm{X}");S("\\clubs","\\clubsuit");S("\\cnums","\\mathbb{C}");S("\\Complex","\\mathbb{C}");S("\\Dagger","\\ddagger");S("\\diamonds","\\diamondsuit");S("\\empty","\\emptyset");S("\\Epsilon","\\mathrm{E}");S("\\Eta","\\mathrm{H}");S("\\exist","\\exists");S("\\harr","\\leftrightarrow");S("\\hArr","\\Leftrightarrow");S("\\Harr","\\Leftrightarrow");S("\\hearts","\\heartsuit");S("\\image","\\Im");S("\\infin","\\infty");S("\\Iota","\\mathrm{I}");S("\\isin","\\in");S("\\Kappa","\\mathrm{K}");S("\\larr","\\leftarrow");S("\\lArr","\\Leftarrow");S("\\Larr","\\Leftarrow");S("\\lrarr","\\leftrightarrow");S("\\lrArr","\\Leftrightarrow");S("\\Lrarr","\\Leftrightarrow");S("\\Mu","\\mathrm{M}");S("\\natnums","\\mathbb{N}");S("\\Nu","\\mathrm{N}");S("\\Omicron","\\mathrm{O}");S("\\plusmn","\\pm");S("\\rarr","\\rightarrow");S("\\rArr","\\Rightarrow");S("\\Rarr","\\Rightarrow");S("\\real","\\Re");S("\\reals","\\mathbb{R}");S("\\Reals","\\mathbb{R}");S("\\Rho","\\mathrm{P}");S("\\sdot","\\cdot");S("\\sect","\\S");S("\\spades","\\spadesuit");S("\\sub","\\subset");S("\\sube","\\subseteq");S("\\supe","\\supseteq");S("\\Tau","\\mathrm{T}");S("\\thetasym","\\vartheta");S("\\weierp","\\wp");S("\\Zeta","\\mathrm{Z}");S("\\argmin","\\DOTSB\\operatorname*{arg\\,min}");S("\\argmax","\\DOTSB\\operatorname*{arg\\,max}");S("\\plim","\\DOTSB\\mathop{\\operatorname{plim}}\\limits");S("\\bra","\\mathinner{\\langle{#1}|}");S("\\ket","\\mathinner{|{#1}\\rangle}");S("\\braket","\\mathinner{\\langle{#1}\\rangle}");S("\\Bra","\\left\\langle#1\\right|");S("\\Ket","\\left|#1\\right\\rangle");var G2=e=>t=>{var r=t.consumeArg().tokens,n=t.consumeArg().tokens,i=t.consumeArg().tokens,a=t.consumeArg().tokens,o=t.macros.get("|"),s=t.macros.get("\\|");t.macros.beginGroup();var u=f=>d=>{e&&(d.macros.set("|",o),i.length&&d.macros.set("\\|",s));var h=f;if(!f&&i.length){var p=d.future();p.text==="|"&&(d.popToken(),h=!0)}return{tokens:h?i:n,numArgs:0}};t.macros.set("|",u(!1)),i.length&&t.macros.set("\\|",u(!0));var l=t.consumeArg().tokens,c=t.expandTokens([...a,...l,...r]);return t.macros.endGroup(),{tokens:c.reverse(),numArgs:0}};S("\\bra@ket",G2(!1));S("\\bra@set",G2(!0));S("\\Braket","\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");S("\\Set","\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");S("\\set","\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");S("\\angln","{\\angl n}");S("\\blue","\\textcolor{##6495ed}{#1}");S("\\orange","\\textcolor{##ffa500}{#1}");S("\\pink","\\textcolor{##ff00af}{#1}");S("\\red","\\textcolor{##df0030}{#1}");S("\\green","\\textcolor{##28ae7b}{#1}");S("\\gray","\\textcolor{gray}{#1}");S("\\purple","\\textcolor{##9d38bd}{#1}");S("\\blueA","\\textcolor{##ccfaff}{#1}");S("\\blueB","\\textcolor{##80f6ff}{#1}");S("\\blueC","\\textcolor{##63d9ea}{#1}");S("\\blueD","\\textcolor{##11accd}{#1}");S("\\blueE","\\textcolor{##0c7f99}{#1}");S("\\tealA","\\textcolor{##94fff5}{#1}");S("\\tealB","\\textcolor{##26edd5}{#1}");S("\\tealC","\\textcolor{##01d1c1}{#1}");S("\\tealD","\\textcolor{##01a995}{#1}");S("\\tealE","\\textcolor{##208170}{#1}");S("\\greenA","\\textcolor{##b6ffb0}{#1}");S("\\greenB","\\textcolor{##8af281}{#1}");S("\\greenC","\\textcolor{##74cf70}{#1}");S("\\greenD","\\textcolor{##1fab54}{#1}");S("\\greenE","\\textcolor{##0d923f}{#1}");S("\\goldA","\\textcolor{##ffd0a9}{#1}");S("\\goldB","\\textcolor{##ffbb71}{#1}");S("\\goldC","\\textcolor{##ff9c39}{#1}");S("\\goldD","\\textcolor{##e07d10}{#1}");S("\\goldE","\\textcolor{##a75a05}{#1}");S("\\redA","\\textcolor{##fca9a9}{#1}");S("\\redB","\\textcolor{##ff8482}{#1}");S("\\redC","\\textcolor{##f9685d}{#1}");S("\\redD","\\textcolor{##e84d39}{#1}");S("\\redE","\\textcolor{##bc2612}{#1}");S("\\maroonA","\\textcolor{##ffbde0}{#1}");S("\\maroonB","\\textcolor{##ff92c6}{#1}");S("\\maroonC","\\textcolor{##ed5fa6}{#1}");S("\\maroonD","\\textcolor{##ca337c}{#1}");S("\\maroonE","\\textcolor{##9e034e}{#1}");S("\\purpleA","\\textcolor{##ddd7ff}{#1}");S("\\purpleB","\\textcolor{##c6b9fc}{#1}");S("\\purpleC","\\textcolor{##aa87ff}{#1}");S("\\purpleD","\\textcolor{##7854ab}{#1}");S("\\purpleE","\\textcolor{##543b78}{#1}");S("\\mintA","\\textcolor{##f5f9e8}{#1}");S("\\mintB","\\textcolor{##edf2df}{#1}");S("\\mintC","\\textcolor{##e0e5cc}{#1}");S("\\grayA","\\textcolor{##f6f7f7}{#1}");S("\\grayB","\\textcolor{##f0f1f2}{#1}");S("\\grayC","\\textcolor{##e3e5e6}{#1}");S("\\grayD","\\textcolor{##d6d8da}{#1}");S("\\grayE","\\textcolor{##babec2}{#1}");S("\\grayF","\\textcolor{##888d93}{#1}");S("\\grayG","\\textcolor{##626569}{#1}");S("\\grayH","\\textcolor{##3b3e40}{#1}");S("\\grayI","\\textcolor{##21242c}{#1}");S("\\kaBlue","\\textcolor{##314453}{#1}");S("\\kaGreen","\\textcolor{##71B307}{#1}");var W2={"^":!0,_:!0,"\\limits":!0,"\\nolimits":!0};class Y9{constructor(t,r,n){this.settings=void 0,this.expansionCount=void 0,this.lexer=void 0,this.macros=void 0,this.stack=void 0,this.mode=void 0,this.settings=r,this.expansionCount=0,this.feed(t),this.macros=new K9(X9,r.macros),this.mode=n,this.stack=[]}feed(t){this.lexer=new p1(t,this.settings)}switchMode(t){this.mode=t}beginGroup(){this.macros.beginGroup()}endGroup(){this.macros.endGroup()}endGroups(){this.macros.endGroups()}future(){return this.stack.length===0&&this.pushToken(this.lexer.lex()),this.stack[this.stack.length-1]}popToken(){return this.future(),this.stack.pop()}pushToken(t){this.stack.push(t)}pushTokens(t){this.stack.push(...t)}scanArgument(t){var r,n,i;if(t){if(this.consumeSpaces(),this.future().text!=="[")return null;r=this.popToken(),{tokens:i,end:n}=this.consumeArg(["]"])}else({tokens:i,start:r,end:n}=this.consumeArg());return this.pushToken(new qr("EOF",n.loc)),this.pushTokens(i),r.range(n,"")}consumeSpaces(){for(;;){var t=this.future();if(t.text===" ")this.stack.pop();else break}}consumeArg(t){var r=[],n=t&&t.length>0;n||this.consumeSpaces();var i=this.future(),a,o=0,s=0;do{if(a=this.popToken(),r.push(a),a.text==="{")++o;else if(a.text==="}"){if(--o,o===-1)throw new te("Extra }",a)}else if(a.text==="EOF")throw new te("Unexpected end of input in a macro argument, expected '"+(t&&n?t[s]:"}")+"'",a);if(t&&n)if((o===0||o===1&&t[s]==="{")&&a.text===t[s]){if(++s,s===t.length){r.splice(-s,s);break}}else s=0}while(o!==0||n);return i.text==="{"&&r[r.length-1].text==="}"&&(r.pop(),r.shift()),r.reverse(),{tokens:r,start:i,end:a}}consumeArgs(t,r){if(r){if(r.length!==t+1)throw new te("The length of delimiters doesn't match the number of args!");for(var n=r[0],i=0;i<n.length;i++){var a=this.popToken();if(n[i]!==a.text)throw new te("Use of the macro doesn't match its definition",a)}}for(var o=[],s=0;s<t;s++)o.push(this.consumeArg(r&&r[s+1]).tokens);return o}expandOnce(t){var r=this.popToken(),n=r.text,i=r.noexpand?null:this._getExpansion(n);if(i==null||t&&i.unexpandable){if(t&&i==null&&n[0]==="\\"&&!this.isDefined(n))throw new te("Undefined control sequence: "+n);return this.pushToken(r),!1}if(this.expansionCount++,this.expansionCount>this.settings.maxExpand)throw new te("Too many expansions: infinite loop or need to increase maxExpand setting");var a=i.tokens,o=this.consumeArgs(i.numArgs,i.delimiters);if(i.numArgs){a=a.slice();for(var s=a.length-1;s>=0;--s){var u=a[s];if(u.text==="#"){if(s===0)throw new te("Incomplete placeholder at end of macro body",u);if(u=a[--s],u.text==="#")a.splice(s+1,1);else if(/^[1-9]$/.test(u.text))a.splice(s,2,...o[+u.text-1]);else throw new te("Not a valid argument number",u)}}}return this.pushTokens(a),a.length}expandAfterFuture(){return this.expandOnce(),this.future()}expandNextToken(){for(;;)if(this.expandOnce()===!1){var t=this.stack.pop();return t.treatAsRelax&&(t.text="\\relax"),t}throw new Error}expandMacro(t){return this.macros.has(t)?this.expandTokens([new qr(t)]):void 0}expandTokens(t){var r=[],n=this.stack.length;for(this.pushTokens(t);this.stack.length>n;)if(this.expandOnce(!0)===!1){var i=this.stack.pop();i.treatAsRelax&&(i.noexpand=!1,i.treatAsRelax=!1),r.push(i)}return r}expandMacroAsText(t){var r=this.expandMacro(t);return r&&r.map(n=>n.text).join("")}_getExpansion(t){var r=this.macros.get(t);if(r==null)return r;if(t.length===1){var n=this.lexer.catcodes[t];if(n!=null&&n!==13)return}var i=typeof r=="function"?r(this):r;if(typeof i=="string"){var a=0;if(i.indexOf("#")!==-1)for(var o=i.replace(/##/g,"");o.indexOf("#"+(a+1))!==-1;)++a;for(var s=new p1(i,this.settings),u=[],l=s.lex();l.text!=="EOF";)u.push(l),l=s.lex();u.reverse();var c={tokens:u,numArgs:a};return c}return i}isDefined(t){return this.macros.has(t)||On.hasOwnProperty(t)||tt.math.hasOwnProperty(t)||tt.text.hasOwnProperty(t)||W2.hasOwnProperty(t)}isExpandable(t){var r=this.macros.get(t);return r!=null?typeof r=="string"||typeof r=="function"||!r.unexpandable:On.hasOwnProperty(t)&&!On[t].primitive}}var b1=/^[₊₋₌₍₎₀₁₂₃₄₅₆₇₈₉ₐₑₕᵢⱼₖₗₘₙₒₚᵣₛₜᵤᵥₓᵦᵧᵨᵩᵪ]/,Ao=Object.freeze({"₊":"+","₋":"-","₌":"=","₍":"(","₎":")","₀":"0","₁":"1","₂":"2","₃":"3","₄":"4","₅":"5","₆":"6","₇":"7","₈":"8","₉":"9","ₐ":"a","ₑ":"e","ₕ":"h","ᵢ":"i","ⱼ":"j","ₖ":"k","ₗ":"l","ₘ":"m","ₙ":"n","ₒ":"o","ₚ":"p","ᵣ":"r","ₛ":"s","ₜ":"t","ᵤ":"u","ᵥ":"v","ₓ":"x","ᵦ":"β","ᵧ":"γ","ᵨ":"ρ","ᵩ":"ϕ","ᵪ":"χ","⁺":"+","⁻":"-","⁼":"=","⁽":"(","⁾":")","⁰":"0","¹":"1","²":"2","³":"3","⁴":"4","⁵":"5","⁶":"6","⁷":"7","⁸":"8","⁹":"9","ᴬ":"A","ᴮ":"B","ᴰ":"D","ᴱ":"E","ᴳ":"G","ᴴ":"H","ᴵ":"I","ᴶ":"J","ᴷ":"K","ᴸ":"L","ᴹ":"M","ᴺ":"N","ᴼ":"O","ᴾ":"P","ᴿ":"R","ᵀ":"T","ᵁ":"U","ⱽ":"V","ᵂ":"W","ᵃ":"a","ᵇ":"b","ᶜ":"c","ᵈ":"d","ᵉ":"e","ᶠ":"f","ᵍ":"g",ʰ:"h","ⁱ":"i",ʲ:"j","ᵏ":"k",ˡ:"l","ᵐ":"m",ⁿ:"n","ᵒ":"o","ᵖ":"p",ʳ:"r",ˢ:"s","ᵗ":"t","ᵘ":"u","ᵛ":"v",ʷ:"w",ˣ:"x",ʸ:"y","ᶻ":"z","ᵝ":"β","ᵞ":"γ","ᵟ":"δ","ᵠ":"ϕ","ᵡ":"χ","ᶿ":"θ"}),Nl={"́":{text:"\\'",math:"\\acute"},"̀":{text:"\\`",math:"\\grave"},"̈":{text:'\\"',math:"\\ddot"},"̃":{text:"\\~",math:"\\tilde"},"̄":{text:"\\=",math:"\\bar"},"̆":{text:"\\u",math:"\\breve"},"̌":{text:"\\v",math:"\\check"},"̂":{text:"\\^",math:"\\hat"},"̇":{text:"\\.",math:"\\dot"},"̊":{text:"\\r",math:"\\mathring"},"̋":{text:"\\H"},"̧":{text:"\\c"}},v1={á:"á",à:"à",ä:"ä",ǟ:"ǟ",ã:"ã",ā:"ā",ă:"ă",ắ:"ắ",ằ:"ằ",ẵ:"ẵ",ǎ:"ǎ",â:"â",ấ:"ấ",ầ:"ầ",ẫ:"ẫ",ȧ:"ȧ",ǡ:"ǡ",å:"å",ǻ:"ǻ",ḃ:"ḃ",ć:"ć",ḉ:"ḉ",č:"č",ĉ:"ĉ",ċ:"ċ",ç:"ç",ď:"ď",ḋ:"ḋ",ḑ:"ḑ",é:"é",è:"è",ë:"ë",ẽ:"ẽ",ē:"ē",ḗ:"ḗ",ḕ:"ḕ",ĕ:"ĕ",ḝ:"ḝ",ě:"ě",ê:"ê",ế:"ế",ề:"ề",ễ:"ễ",ė:"ė",ȩ:"ȩ",ḟ:"ḟ",ǵ:"ǵ",ḡ:"ḡ",ğ:"ğ",ǧ:"ǧ",ĝ:"ĝ",ġ:"ġ",ģ:"ģ",ḧ:"ḧ",ȟ:"ȟ",ĥ:"ĥ",ḣ:"ḣ",ḩ:"ḩ",í:"í",ì:"ì",ï:"ï",ḯ:"ḯ",ĩ:"ĩ",ī:"ī",ĭ:"ĭ",ǐ:"ǐ",î:"î",ǰ:"ǰ",ĵ:"ĵ",ḱ:"ḱ",ǩ:"ǩ",ķ:"ķ",ĺ:"ĺ",ľ:"ľ",ļ:"ļ",ḿ:"ḿ",ṁ:"ṁ",ń:"ń",ǹ:"ǹ",ñ:"ñ",ň:"ň",ṅ:"ṅ",ņ:"ņ",ó:"ó",ò:"ò",ö:"ö",ȫ:"ȫ",õ:"õ",ṍ:"ṍ",ṏ:"ṏ",ȭ:"ȭ",ō:"ō",ṓ:"ṓ",ṑ:"ṑ",ŏ:"ŏ",ǒ:"ǒ",ô:"ô",ố:"ố",ồ:"ồ",ỗ:"ỗ",ȯ:"ȯ",ȱ:"ȱ",ő:"ő",ṕ:"ṕ",ṗ:"ṗ",ŕ:"ŕ",ř:"ř",ṙ:"ṙ",ŗ:"ŗ",ś:"ś",ṥ:"ṥ",š:"š",ṧ:"ṧ",ŝ:"ŝ",ṡ:"ṡ",ş:"ş",ẗ:"ẗ",ť:"ť",ṫ:"ṫ",ţ:"ţ",ú:"ú",ù:"ù",ü:"ü",ǘ:"ǘ",ǜ:"ǜ",ǖ:"ǖ",ǚ:"ǚ",ũ:"ũ",ṹ:"ṹ",ū:"ū",ṻ:"ṻ",ŭ:"ŭ",ǔ:"ǔ",û:"û",ů:"ů",ű:"ű",ṽ:"ṽ",ẃ:"ẃ",ẁ:"ẁ",ẅ:"ẅ",ŵ:"ŵ",ẇ:"ẇ",ẘ:"ẘ",ẍ:"ẍ",ẋ:"ẋ",ý:"ý",ỳ:"ỳ",ÿ:"ÿ",ỹ:"ỹ",ȳ:"ȳ",ŷ:"ŷ",ẏ:"ẏ",ẙ:"ẙ",ź:"ź",ž:"ž",ẑ:"ẑ",ż:"ż",Á:"Á",À:"À",Ä:"Ä",Ǟ:"Ǟ",Ã:"Ã",Ā:"Ā",Ă:"Ă",Ắ:"Ắ",Ằ:"Ằ",Ẵ:"Ẵ",Ǎ:"Ǎ",Â:"Â",Ấ:"Ấ",Ầ:"Ầ",Ẫ:"Ẫ",Ȧ:"Ȧ",Ǡ:"Ǡ",Å:"Å",Ǻ:"Ǻ",Ḃ:"Ḃ",Ć:"Ć",Ḉ:"Ḉ",Č:"Č",Ĉ:"Ĉ",Ċ:"Ċ",Ç:"Ç",Ď:"Ď",Ḋ:"Ḋ",Ḑ:"Ḑ",É:"É",È:"È",Ë:"Ë",Ẽ:"Ẽ",Ē:"Ē",Ḗ:"Ḗ",Ḕ:"Ḕ",Ĕ:"Ĕ",Ḝ:"Ḝ",Ě:"Ě",Ê:"Ê",Ế:"Ế",Ề:"Ề",Ễ:"Ễ",Ė:"Ė",Ȩ:"Ȩ",Ḟ:"Ḟ",Ǵ:"Ǵ",Ḡ:"Ḡ",Ğ:"Ğ",Ǧ:"Ǧ",Ĝ:"Ĝ",Ġ:"Ġ",Ģ:"Ģ",Ḧ:"Ḧ",Ȟ:"Ȟ",Ĥ:"Ĥ",Ḣ:"Ḣ",Ḩ:"Ḩ",Í:"Í",Ì:"Ì",Ï:"Ï",Ḯ:"Ḯ",Ĩ:"Ĩ",Ī:"Ī",Ĭ:"Ĭ",Ǐ:"Ǐ",Î:"Î",İ:"İ",Ĵ:"Ĵ",Ḱ:"Ḱ",Ǩ:"Ǩ",Ķ:"Ķ",Ĺ:"Ĺ",Ľ:"Ľ",Ļ:"Ļ",Ḿ:"Ḿ",Ṁ:"Ṁ",Ń:"Ń",Ǹ:"Ǹ",Ñ:"Ñ",Ň:"Ň",Ṅ:"Ṅ",Ņ:"Ņ",Ó:"Ó",Ò:"Ò",Ö:"Ö",Ȫ:"Ȫ",Õ:"Õ",Ṍ:"Ṍ",Ṏ:"Ṏ",Ȭ:"Ȭ",Ō:"Ō",Ṓ:"Ṓ",Ṑ:"Ṑ",Ŏ:"Ŏ",Ǒ:"Ǒ",Ô:"Ô",Ố:"Ố",Ồ:"Ồ",Ỗ:"Ỗ",Ȯ:"Ȯ",Ȱ:"Ȱ",Ő:"Ő",Ṕ:"Ṕ",Ṗ:"Ṗ",Ŕ:"Ŕ",Ř:"Ř",Ṙ:"Ṙ",Ŗ:"Ŗ",Ś:"Ś",Ṥ:"Ṥ",Š:"Š",Ṧ:"Ṧ",Ŝ:"Ŝ",Ṡ:"Ṡ",Ş:"Ş",Ť:"Ť",Ṫ:"Ṫ",Ţ:"Ţ",Ú:"Ú",Ù:"Ù",Ü:"Ü",Ǘ:"Ǘ",Ǜ:"Ǜ",Ǖ:"Ǖ",Ǚ:"Ǚ",Ũ:"Ũ",Ṹ:"Ṹ",Ū:"Ū",Ṻ:"Ṻ",Ŭ:"Ŭ",Ǔ:"Ǔ",Û:"Û",Ů:"Ů",Ű:"Ű",Ṽ:"Ṽ",Ẃ:"Ẃ",Ẁ:"Ẁ",Ẅ:"Ẅ",Ŵ:"Ŵ",Ẇ:"Ẇ",Ẍ:"Ẍ",Ẋ:"Ẋ",Ý:"Ý",Ỳ:"Ỳ",Ÿ:"Ÿ",Ỹ:"Ỹ",Ȳ:"Ȳ",Ŷ:"Ŷ",Ẏ:"Ẏ",Ź:"Ź",Ž:"Ž",Ẑ:"Ẑ",Ż:"Ż",ά:"ά",ὰ:"ὰ",ᾱ:"ᾱ",ᾰ:"ᾰ",έ:"έ",ὲ:"ὲ",ή:"ή",ὴ:"ὴ",ί:"ί",ὶ:"ὶ",ϊ:"ϊ",ΐ:"ΐ",ῒ:"ῒ",ῑ:"ῑ",ῐ:"ῐ",ό:"ό",ὸ:"ὸ",ύ:"ύ",ὺ:"ὺ",ϋ:"ϋ",ΰ:"ΰ",ῢ:"ῢ",ῡ:"ῡ",ῠ:"ῠ",ώ:"ώ",ὼ:"ὼ",Ύ:"Ύ",Ὺ:"Ὺ",Ϋ:"Ϋ",Ῡ:"Ῡ",Ῠ:"Ῠ",Ώ:"Ώ",Ὼ:"Ὼ"};let K2=class D0{constructor(t,r){this.mode=void 0,this.gullet=void 0,this.settings=void 0,this.leftrightDepth=void 0,this.nextToken=void 0,this.mode="math",this.gullet=new Y9(t,r,this.mode),this.settings=r,this.leftrightDepth=0}expect(t,r){if(r===void 0&&(r=!0),this.fetch().text!==t)throw new te("Expected '"+t+"', got '"+this.fetch().text+"'",this.fetch());r&&this.consume()}consume(){this.nextToken=null}fetch(){return this.nextToken==null&&(this.nextToken=this.gullet.expandNextToken()),this.nextToken}switchMode(t){this.mode=t,this.gullet.switchMode(t)}parse(){this.settings.globalGroup||this.gullet.beginGroup(),this.settings.colorIsTextColor&&this.gullet.macros.set("\\color","\\textcolor");try{var t=this.parseExpression(!1);return this.expect("EOF"),this.settings.globalGroup||this.gullet.endGroup(),t}finally{this.gullet.endGroups()}}subparse(t){var r=this.nextToken;this.consume(),this.gullet.pushToken(new qr("}")),this.gullet.pushTokens(t);var n=this.parseExpression(!1);return this.expect("}"),this.nextToken=r,n}parseExpression(t,r){for(var n=[];;){this.mode==="math"&&this.consumeSpaces();var i=this.fetch();if(D0.endOfExpression.indexOf(i.text)!==-1||r&&i.text===r||t&&On[i.text]&&On[i.text].infix)break;var a=this.parseAtom(r);if(a){if(a.type==="internal")continue}else break;n.push(a)}return this.mode==="text"&&this.formLigatures(n),this.handleInfixNodes(n)}handleInfixNodes(t){for(var r=-1,n,i=0;i<t.length;i++)if(t[i].type==="infix"){if(r!==-1)throw new te("only one infix operator per group",t[i].token);r=i,n=t[i].replaceWith}if(r!==-1&&n){var a,o,s=t.slice(0,r),u=t.slice(r+1);s.length===1&&s[0].type==="ordgroup"?a=s[0]:a={type:"ordgroup",mode:this.mode,body:s},u.length===1&&u[0].type==="ordgroup"?o=u[0]:o={type:"ordgroup",mode:this.mode,body:u};var l;return n==="\\\\abovefrac"?l=this.callFunction(n,[a,t[r],o],[]):l=this.callFunction(n,[a,o],[]),[l]}else return t}handleSupSubscript(t){var r=this.fetch(),n=r.text;this.consume(),this.consumeSpaces();var i=this.parseGroup(t);if(!i)throw new te("Expected group after '"+n+"'",r);return i}formatUnsupportedCmd(t){for(var r=[],n=0;n<t.length;n++)r.push({type:"textord",mode:"text",text:t[n]});var i={type:"text",mode:this.mode,body:r},a={type:"color",mode:this.mode,color:this.settings.errorColor,body:[i]};return a}parseAtom(t){var r=this.parseGroup("atom",t);if(this.mode==="text")return r;for(var n,i;;){this.consumeSpaces();var a=this.fetch();if(a.text==="\\limits"||a.text==="\\nolimits"){if(r&&r.type==="op"){var o=a.text==="\\limits";r.limits=o,r.alwaysHandleSupSub=!0}else if(r&&r.type==="operatorname")r.alwaysHandleSupSub&&(r.limits=a.text==="\\limits");else throw new te("Limit controls must follow a math operator",a);this.consume()}else if(a.text==="^"){if(n)throw new te("Double superscript",a);n=this.handleSupSubscript("superscript")}else if(a.text==="_"){if(i)throw new te("Double subscript",a);i=this.handleSupSubscript("subscript")}else if(a.text==="'"){if(n)throw new te("Double superscript",a);var s={type:"textord",mode:this.mode,text:"\\prime"},u=[s];for(this.consume();this.fetch().text==="'";)u.push(s),this.consume();this.fetch().text==="^"&&u.push(this.handleSupSubscript("superscript")),n={type:"ordgroup",mode:this.mode,body:u}}else if(Ao[a.text]){var l=Ao[a.text],c=b1.test(a.text);for(this.consume();;){var f=this.fetch().text;if(!Ao[f]||b1.test(f)!==c)break;this.consume(),l+=Ao[f]}var d=new D0(l,this.settings).parse();c?i={type:"ordgroup",mode:"math",body:d}:n={type:"ordgroup",mode:"math",body:d}}else break}return n||i?{type:"supsub",mode:this.mode,base:r,sup:n,sub:i}:r}parseFunction(t,r){var n=this.fetch(),i=n.text,a=On[i];if(!a)return null;if(this.consume(),r&&r!=="atom"&&!a.allowedInArgument)throw new te("Got function '"+i+"' with no arguments"+(r?" as "+r:""),n);if(this.mode==="text"&&!a.allowedInText)throw new te("Can't use function '"+i+"' in text mode",n);if(this.mode==="math"&&a.allowedInMath===!1)throw new te("Can't use function '"+i+"' in math mode",n);var{args:o,optArgs:s}=this.parseArguments(i,a);return this.callFunction(i,o,s,n,t)}callFunction(t,r,n,i,a){var o={funcName:t,parser:this,token:i,breakOnTokenText:a},s=On[t];if(s&&s.handler)return s.handler(o,r,n);throw new te("No function handler for "+t)}parseArguments(t,r){var n=r.numArgs+r.numOptionalArgs;if(n===0)return{args:[],optArgs:[]};for(var i=[],a=[],o=0;o<n;o++){var s=r.argTypes&&r.argTypes[o],u=o<r.numOptionalArgs;(r.primitive&&s==null||r.type==="sqrt"&&o===1&&a[0]==null)&&(s="primitive");var l=this.parseGroupOfType("argument to '"+t+"'",s,u);if(u)a.push(l);else if(l!=null)i.push(l);else throw new te("Null argument, please report this as a bug")}return{args:i,optArgs:a}}parseGroupOfType(t,r,n){switch(r){case"color":return this.parseColorGroup(n);case"size":return this.parseSizeGroup(n);case"url":return this.parseUrlGroup(n);case"math":case"text":return this.parseArgumentGroup(n,r);case"hbox":{var i=this.parseArgumentGroup(n,"text");return i!=null?{type:"styling",mode:i.mode,body:[i],style:"text"}:null}case"raw":{var a=this.parseStringGroup("raw",n);return a!=null?{type:"raw",mode:"text",string:a.text}:null}case"primitive":{if(n)throw new te("A primitive argument cannot be optional");var o=this.parseGroup(t);if(o==null)throw new te("Expected group as "+t,this.fetch());return o}case"original":case null:case void 0:return this.parseArgumentGroup(n);default:throw new te("Unknown group type as "+t,this.fetch())}}consumeSpaces(){for(;this.fetch().text===" ";)this.consume()}parseStringGroup(t,r){var n=this.gullet.scanArgument(r);if(n==null)return null;for(var i="",a;(a=this.fetch()).text!=="EOF";)i+=a.text,this.consume();return this.consume(),n.text=i,n}parseRegexGroup(t,r){for(var n=this.fetch(),i=n,a="",o;(o=this.fetch()).text!=="EOF"&&t.test(a+o.text);)i=o,a+=i.text,this.consume();if(a==="")throw new te("Invalid "+r+": '"+n.text+"'",n);return n.range(i,a)}parseColorGroup(t){var r=this.parseStringGroup("color",t);if(r==null)return null;var n=/^(#[a-f0-9]{3}|#?[a-f0-9]{6}|[a-z]+)$/i.exec(r.text);if(!n)throw new te("Invalid color: '"+r.text+"'",r);var i=n[0];return/^[0-9a-f]{6}$/i.test(i)&&(i="#"+i),{type:"color-token",mode:this.mode,color:i}}parseSizeGroup(t){var r,n=!1;if(this.gullet.consumeSpaces(),!t&&this.gullet.future().text!=="{"?r=this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/,"size"):r=this.parseStringGroup("size",t),!r)return null;!t&&r.text.length===0&&(r.text="0pt",n=!0);var i=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(r.text);if(!i)throw new te("Invalid size: '"+r.text+"'",r);var a={number:+(i[1]+i[2]),unit:i[3]};if(!n2(a))throw new te("Invalid unit: '"+a.unit+"'",r);return{type:"size",mode:this.mode,value:a,isBlank:n}}parseUrlGroup(t){this.gullet.lexer.setCatcode("%",13),this.gullet.lexer.setCatcode("~",12);var r=this.parseStringGroup("url",t);if(this.gullet.lexer.setCatcode("%",14),this.gullet.lexer.setCatcode("~",13),r==null)return null;var n=r.text.replace(/\\([#$%&~_^{}])/g,"$1");return{type:"url",mode:this.mode,url:n}}parseArgumentGroup(t,r){var n=this.gullet.scanArgument(t);if(n==null)return null;var i=this.mode;r&&this.switchMode(r),this.gullet.beginGroup();var a=this.parseExpression(!1,"EOF");this.expect("EOF"),this.gullet.endGroup();var o={type:"ordgroup",mode:this.mode,loc:n.loc,body:a};return r&&this.switchMode(i),o}parseGroup(t,r){var n=this.fetch(),i=n.text,a;if(i==="{"||i==="\\begingroup"){this.consume();var o=i==="{"?"}":"\\endgroup";this.gullet.beginGroup();var s=this.parseExpression(!1,o),u=this.fetch();this.expect(o),this.gullet.endGroup(),a={type:"ordgroup",mode:this.mode,loc:Jt.range(n,u),body:s,semisimple:i==="\\begingroup"||void 0}}else if(a=this.parseFunction(r,t)||this.parseSymbol(),a==null&&i[0]==="\\"&&!W2.hasOwnProperty(i)){if(this.settings.throwOnError)throw new te("Undefined control sequence: "+i,n);a=this.formatUnsupportedCmd(i),this.consume()}return a}formLigatures(t){for(var r=t.length-1,n=0;n<r;++n){var i=t[n],a=i.text;a==="-"&&t[n+1].text==="-"&&(n+1<r&&t[n+2].text==="-"?(t.splice(n,3,{type:"textord",mode:"text",loc:Jt.range(i,t[n+2]),text:"---"}),r-=2):(t.splice(n,2,{type:"textord",mode:"text",loc:Jt.range(i,t[n+1]),text:"--"}),r-=1)),(a==="'"||a==="`")&&t[n+1].text===a&&(t.splice(n,2,{type:"textord",mode:"text",loc:Jt.range(i,t[n+1]),text:a+a}),r-=1)}}parseSymbol(){var t=this.fetch(),r=t.text;if(/^\\verb[^a-zA-Z]/.test(r)){this.consume();var n=r.slice(5),i=n.charAt(0)==="*";if(i&&(n=n.slice(1)),n.length<2||n.charAt(0)!==n.slice(-1))throw new te(`\\verb assertion failed --
                    please report what input caused this bug`);return n=n.slice(1,-1),{type:"verb",mode:"text",body:n,star:i}}v1.hasOwnProperty(r[0])&&!tt[this.mode][r[0]]&&(this.settings.strict&&this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Accented Unicode text character "'+r[0]+'" used in math mode',t),r=v1[r[0]]+r.slice(1));var a=G9.exec(r);a&&(r=r.substring(0,a.index),r==="i"?r="ı":r==="j"&&(r="ȷ"));var o;if(tt[this.mode][r]){this.settings.strict&&this.mode==="math"&&_0.indexOf(r)>=0&&this.settings.reportNonstrict("unicodeTextInMathMode",'Latin-1/Unicode text character "'+r[0]+'" used in math mode',t);var s=tt[this.mode][r].group,u=Jt.range(t),l;if(Bx.hasOwnProperty(s)){var c=s;l={type:"atom",mode:this.mode,family:c,loc:u,text:r}}else l={type:s,mode:this.mode,loc:u,text:r};o=l}else if(r.charCodeAt(0)>=128)this.settings.strict&&(r2(r.charCodeAt(0))?this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Unicode text character "'+r[0]+'" used in math mode',t):this.settings.reportNonstrict("unknownSymbol",'Unrecognized Unicode character "'+r[0]+'"'+(" ("+r.charCodeAt(0)+")"),t)),o={type:"textord",mode:"text",loc:Jt.range(t),text:r};else return null;if(this.consume(),a)for(var f=0;f<a[0].length;f++){var d=a[0][f];if(!Nl[d])throw new te("Unknown accent ' "+d+"'",t);var h=Nl[d][this.mode]||Nl[d].text;if(!h)throw new te("Accent "+d+" unsupported in "+this.mode+" mode",t);o={type:"accent",mode:this.mode,loc:Jt.range(t),label:h,isStretchy:!1,isShifty:!0,base:o}}return o}};K2.endOfExpression=["}","\\endgroup","\\end","\\right","&"];var Rf=function(t,r){if(!(typeof t=="string"||t instanceof String))throw new TypeError("KaTeX can only parse string typed expression");var n=new K2(t,r);delete n.gullet.macros.current["\\df@tag"];var i=n.parse();if(delete n.gullet.macros.current["\\current@color"],delete n.gullet.macros.current["\\color"],n.gullet.macros.get("\\df@tag")){if(!r.displayMode)throw new te("\\tag works only in display equations");i=[{type:"tag",mode:"text",body:i,tag:n.subparse([new qr("\\df@tag")])}]}return i},X2=function(t,r,n){r.textContent="";var i=If(t,n).toNode();r.appendChild(i)};typeof document<"u"&&document.compatMode!=="CSS1Compat"&&(typeof console<"u"&&console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."),X2=function(){throw new te("KaTeX doesn't work in quirks mode.")});var Z9=function(t,r){var n=If(t,r).toMarkup();return n},Q9=function(t,r){var n=new pf(r);return Rf(t,n)},Y2=function(t,r,n){if(n.throwOnError||!(t instanceof te))throw t;var i=j.makeSpan(["katex-error"],[new mr(r)]);return i.setAttribute("title",t.toString()),i.setAttribute("style","color:"+n.errorColor),i},If=function(t,r){var n=new pf(r);try{var i=Rf(t,n);return s9(i,t,n)}catch(a){return Y2(a,t,n)}},J9=function(t,r){var n=new pf(r);try{var i=Rf(t,n);return u9(i,t,n)}catch(a){return Y2(a,t,n)}},y1={version:"0.16.9",render:X2,renderToString:Z9,ParseError:te,SETTINGS_SCHEMA:is,__parse:Q9,__renderToDomTree:If,__renderToHTMLTree:J9,__setFontMetrics:Mx,__defineSymbol:b,__defineFunction:ae,__defineMacro:S,__domTree:{Span:Ya,Anchor:bf,SymbolNode:mr,SvgNode:ln,PathNode:In,LineNode:N0}};function eE(e,t){const r=String(e);let n=r.indexOf(t),i=n,a=0,o=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;n!==-1;)n===i?++a>o&&(o=a):a=1,i=n+t.length,n=r.indexOf(t,i);return o}function Pf(e){if(!e._compiled){const t=(e.atBreak?"[\\r\\n][\\t ]*":"")+(e.before?"(?:"+e.before+")":"");e._compiled=new RegExp((t?"("+t+")":"")+(/[|\\{}()[\]^$+*?.-]/.test(e.character)?"\\":"")+e.character+(e.after?"(?:"+e.after+")":""),"g")}return e._compiled}function tE(e,t){return w1(e,t.inConstruct,!0)&&!w1(e,t.notInConstruct,!1)}function w1(e,t,r){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return r;let n=-1;for(;++n<t.length;)if(e.includes(t[n]))return!0;return!1}function Df(e,t,r){const n=(r.before||"")+(t||"")+(r.after||""),i=[],a=[],o={};let s=-1;for(;++s<e.unsafe.length;){const c=e.unsafe[s];if(!tE(e.stack,c))continue;const f=Pf(c);let d;for(;d=f.exec(n);){const h="before"in c||!!c.atBreak,p="after"in c,m=d.index+(h?d[1].length:0);i.includes(m)?(o[m].before&&!h&&(o[m].before=!1),o[m].after&&!p&&(o[m].after=!1)):(i.push(m),o[m]={before:h,after:p})}}i.sort(rE);let u=r.before?r.before.length:0;const l=n.length-(r.after?r.after.length:0);for(s=-1;++s<i.length;){const c=i[s];c<u||c>=l||c+1<l&&i[s+1]===c+1&&o[c].after&&!o[c+1].before&&!o[c+1].after||i[s-1]===c-1&&o[c].before&&!o[c-1].before&&!o[c-1].after||(u!==c&&a.push(x1(n.slice(u,c),"\\")),u=c,/[!-/:-@[-`{-~]/.test(n.charAt(c))&&(!r.encode||!r.encode.includes(n.charAt(c)))?a.push("\\"):(a.push("&#x"+n.charCodeAt(c).toString(16).toUpperCase()+";"),u++))}return a.push(x1(n.slice(u,l),r.after)),a.join("")}function rE(e,t){return e-t}function x1(e,t){const r=/\\(?=[!-/:-@[-`{-~])/g,n=[],i=[],a=e+t;let o=-1,s=0,u;for(;u=r.exec(a);)n.push(u.index);for(;++o<n.length;)s!==n[o]&&i.push(e.slice(s,n[o])),i.push("\\"),s=n[o];return i.push(e.slice(s)),i.join("")}function Qa(e){const t=e||{},r=t.now||{};let n=t.lineShift||0,i=r.line||1,a=r.column||1;return{move:u,current:o,shift:s};function o(){return{now:{line:i,column:a},lineShift:n}}function s(l){n+=l}function u(l){const c=l||"",f=c.split(/\r?\n|\r/g),d=f[f.length-1];return i+=f.length-1,a=f.length===1?a+d.length:1+d.length+n,c}}function nE(){return{enter:{mathFlow:e,mathFlowFenceMeta:t,mathText:a},exit:{mathFlow:i,mathFlowFence:n,mathFlowFenceMeta:r,mathFlowValue:s,mathText:o,mathTextData:s}};function e(u){this.enter({type:"math",meta:null,value:"",data:{hName:"div",hProperties:{className:["math","math-display"]},hChildren:[{type:"text",value:""}]}},u)}function t(){this.buffer()}function r(){const u=this.resume(),l=this.stack[this.stack.length-1];l.meta=u}function n(){this.getData("mathFlowInside")||(this.buffer(),this.setData("mathFlowInside",!0))}function i(u){const l=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),c=this.exit(u);c.value=l,c.data.hChildren[0].value=l,this.setData("mathFlowInside")}function a(u){this.enter({type:"inlineMath",value:"",data:{hName:"span",hProperties:{className:["math","math-inline"]},hChildren:[{type:"text",value:""}]}},u),this.buffer()}function o(u){const l=this.resume(),c=this.exit(u);c.value=l,c.data.hChildren[0].value=l}function s(u){this.config.enter.data.call(this,u),this.config.exit.data.call(this,u)}}function iE(e){let t=(e||{}).singleDollarTextMath;return t==null&&(t=!0),n.peek=i,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:t?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:r,inlineMath:n}};function r(a,o,s,u){const l=a.value||"",c=Qa(u),f="$".repeat(Math.max(eE(l,"$")+1,2)),d=s.enter("mathFlow");let h=c.move(f);if(a.meta){const p=s.enter("mathFlowMeta");h+=c.move(Df(s,a.meta,{before:h,after:`
`,encode:["$"],...c.current()})),p()}return h+=c.move(`
`),l&&(h+=c.move(l+`
`)),h+=c.move(f),d(),h}function n(a,o,s){let u=a.value||"",l=1;for(t||l++;new RegExp("(^|[^$])"+"\\$".repeat(l)+"([^$]|$)").test(u);)l++;const c="$".repeat(l);/[^ \r\n]/.test(u)&&(/^[ \r\n]/.test(u)&&/[ \r\n]$/.test(u)||/^\$|\$$/.test(u))&&(u=" "+u+" ");let f=-1;for(;++f<s.unsafe.length;){const d=s.unsafe[f],h=Pf(d);let p;if(d.atBreak)for(;p=h.exec(u);){let m=p.index;u.codePointAt(m)===10&&u.codePointAt(m-1)===13&&m--,u=u.slice(0,m)+" "+u.slice(p.index+1)}}return c+u+c}function i(){return"$"}}function B$(e={}){const t=this.data();r("micromarkExtensions",rx(e)),r("fromMarkdownExtensions",nE()),r("toMarkdownExtensions",iE(e));function r(n,i){(t[n]?t[n]:t[n]=[]).push(i)}}function aE(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}const oE={}.hasOwnProperty,Z2=function(e,t,r,n){let i,a;typeof t=="string"||t instanceof RegExp?(a=[[t,r]],i=n):(a=t,i=r),i||(i={});const o=ou(i.ignore||[]),s=sE(a);let u=-1;for(;++u<s.length;)Pg(e,"text",l);return e;function l(f,d){let h=-1,p;for(;++h<d.length;){const m=d[h];if(o(m,p?p.children.indexOf(m):void 0,p))return;p=m}if(p)return c(f,d)}function c(f,d){const h=d[d.length-1],p=s[u][0],m=s[u][1];let g=0;const v=h.children.indexOf(f);let w=!1,x=[];p.lastIndex=0;let N=p.exec(f.value);for(;N;){const O=N.index,A={index:N.index,input:N.input,stack:[...d,f]};let D=m(...N,A);if(typeof D=="string"&&(D=D.length>0?{type:"text",value:D}:void 0),D!==!1&&(g!==O&&x.push({type:"text",value:f.value.slice(g,O)}),Array.isArray(D)?x.push(...D):D&&x.push(D),g=O+N[0].length,w=!0),!p.global)break;N=p.exec(f.value)}return w?(g<f.value.length&&x.push({type:"text",value:f.value.slice(g)}),h.children.splice(v,1,...x)):x=[f],v+x.length}};function sE(e){const t=[];if(typeof e!="object")throw new TypeError("Expected array or object as schema");if(Array.isArray(e)){let r=-1;for(;++r<e.length;)t.push([E1(e[r][0]),S1(e[r][1])])}else{let r;for(r in e)oE.call(e,r)&&t.push([E1(r),S1(e[r])])}return t}function E1(e){return typeof e=="string"?new RegExp(aE(e),"g"):e}function S1(e){return typeof e=="function"?e:()=>e}function uE(e){Z2(e,/\r?\n|\r/g,lE)}function lE(){return{type:"break"}}function z$(){return uE}const fi=function(e){if(e==null)return Lf;if(typeof e=="string")return fE(e);if(typeof e=="object")return cE(e);if(typeof e=="function")return Q2(e);throw new Error("Expected function, string, or array as test")};function cE(e){const t=[];let r=-1;for(;++r<e.length;)t[r]=fi(e[r]);return Q2(n);function n(...i){let a=-1;for(;++a<t.length;)if(t[a].call(this,...i))return!0;return!1}}function fE(e){return t;function t(r){return Lf(r)&&r.tagName===e}}function Q2(e){return t;function t(r,...n){return Lf(r)&&!!e.call(this,r,...n)}}function Lf(e){return!!(e&&typeof e=="object"&&e.type==="element"&&typeof e.tagName=="string")}const T1=function(e,t,r){const n=ou(r);if(!e||!e.type||!e.children)throw new Error("Expected parent node");if(typeof t=="number"){if(t<0||t===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")}else if(t=e.children.indexOf(t),t<0)throw new Error("Expected child node or index");for(;++t<e.children.length;)if(n(e.children[t],t,e))return e.children[t];return null},A1=/\n/g,k1=/[\t ]+/g,L0=fi("br"),dE=fi("p"),O1=fi(["th","td"]),N1=fi("tr"),hE=fi(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",vE,yE]),J2=fi(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"]);function pE(e,t={}){const r="children"in e?e.children:[],n=J2(e),i=rb(e,{whitespace:t.whitespace||"normal",breakBefore:!1,breakAfter:!1}),a=[];(e.type==="text"||e.type==="comment")&&a.push(...tb(e,{whitespace:i,breakBefore:!0,breakAfter:!0}));let o=-1;for(;++o<r.length;)a.push(...eb(r[o],e,{whitespace:i,breakBefore:o?void 0:n,breakAfter:o<r.length-1?L0(r[o+1]):n}));const s=[];let u;for(o=-1;++o<a.length;){const l=a[o];typeof l=="number"?u!==void 0&&l>u&&(u=l):l&&(u!==void 0&&u>-1&&s.push(`
`.repeat(u)||" "),u=-1,s.push(l))}return s.join("")}function eb(e,t,r){return e.type==="element"?mE(e,t,r):e.type==="text"?r.whitespace==="normal"?tb(e,r):gE(e):[]}function mE(e,t,r){const n=rb(e,r),i=e.children||[];let a=-1,o=[];if(hE(e))return o;let s,u;for(L0(e)||N1(e)&&T1(t,e,N1)?u=`
`:dE(e)?(s=2,u=2):J2(e)&&(s=1,u=1);++a<i.length;)o=o.concat(eb(i[a],e,{whitespace:n,breakBefore:a?void 0:s,breakAfter:a<i.length-1?L0(i[a+1]):u}));return O1(e)&&T1(t,e,O1)&&o.push("	"),s&&o.unshift(s),u&&o.push(u),o}function tb(e,t){const r=String(e.value),n=[],i=[];let a=0;for(;a<=r.length;){A1.lastIndex=a;const u=A1.exec(r),l=u&&"index"in u?u.index:r.length;n.push(bE(r.slice(a,l).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),a===0?t.breakBefore:!0,l===r.length?t.breakAfter:!0)),a=l+1}let o=-1,s;for(;++o<n.length;)n[o].charCodeAt(n[o].length-1)===8203||o<n.length-1&&n[o+1].charCodeAt(0)===8203?(i.push(n[o]),s=void 0):n[o]?(typeof s=="number"&&i.push(s),i.push(n[o]),s=0):(o===0||o===n.length-1)&&i.push(0);return i}function gE(e){return[String(e.value)]}function bE(e,t,r){const n=[];let i=0,a;for(;i<e.length;){k1.lastIndex=i;const o=k1.exec(e);a=o?o.index:e.length,!i&&!a&&o&&!t&&n.push(""),i!==a&&n.push(e.slice(i,a)),i=o?a+o[0].length:a}return i!==a&&!r&&n.push(""),n.join(" ")}function rb(e,t){if(e.type==="element"){const r=e.properties||{};switch(e.tagName){case"listing":case"plaintext":case"xmp":return"pre";case"nobr":return"nowrap";case"pre":return r.wrap?"pre-wrap":"pre";case"td":case"th":return r.noWrap?"nowrap":t.whitespace;case"textarea":return"pre-wrap"}}return t.whitespace}function vE(e){return!!(e.properties||{}).hidden}function yE(e){return e.tagName==="dialog"&&!(e.properties||{}).open}const _l={html:"http://www.w3.org/1999/xhtml",mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg",xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"},_1=/[#.]/g;function wE(e,t){const r=e||"",n={};let i=0,a,o;for(;i<r.length;){_1.lastIndex=i;const s=_1.exec(r),u=r.slice(i,s?s.index:r.length);u&&(a?a==="#"?n.id=u:Array.isArray(n.className)?n.className.push(u):n.className=[u]:o=u,i+=u.length),s&&(a=s[0],i++)}return{type:"element",tagName:o||t||"div",properties:n,children:[]}}const xE=new Set(["menu","submit","reset","button"]),F0={}.hasOwnProperty;function nb(e,t,r){const n=r&&AE(r);return function(a,o,...s){let u=-1,l;if(a==null)l={type:"root",children:[]},s.unshift(o);else if(l=wE(a,t),l.tagName=l.tagName.toLowerCase(),n&&F0.call(n,l.tagName)&&(l.tagName=n[l.tagName]),EE(o,l.tagName)){let c;for(c in o)F0.call(o,c)&&SE(e,l.properties,c,o[c])}else s.unshift(o);for(;++u<s.length;)B0(l.children,s[u]);return l.type==="element"&&l.tagName==="template"&&(l.content={type:"root",children:l.children},l.children=[]),l}}function EE(e,t){return e==null||typeof e!="object"||Array.isArray(e)?!1:t==="input"||!e.type||typeof e.type!="string"?!0:"children"in e&&Array.isArray(e.children)?!1:t==="button"?xE.has(e.type.toLowerCase()):!("value"in e)}function SE(e,t,r,n){const i=Kg(e,r);let a=-1,o;if(n!=null){if(typeof n=="number"){if(Number.isNaN(n))return;o=n}else typeof n=="boolean"?o=n:typeof n=="string"?i.spaceSeparated?o=Mh(n):i.commaSeparated?o=Rh(n):i.commaOrSpaceSeparated?o=Mh(Rh(n).join(" ")):o=C1(i,i.property,n):Array.isArray(n)?o=n.concat():o=i.property==="style"?TE(n):String(n);if(Array.isArray(o)){const s=[];for(;++a<o.length;)s[a]=C1(i,i.property,o[a]);o=s}i.property==="className"&&Array.isArray(t.className)&&(o=t.className.concat(o)),t[i.property]=o}}function B0(e,t){let r=-1;if(t!=null)if(typeof t=="string"||typeof t=="number")e.push({type:"text",value:String(t)});else if(Array.isArray(t))for(;++r<t.length;)B0(e,t[r]);else if(typeof t=="object"&&"type"in t)t.type==="root"?B0(e,t.children):e.push(t);else throw new Error("Expected node, nodes, or string, got `"+t+"`")}function C1(e,t,r){if(typeof r=="string"){if(e.number&&r&&!Number.isNaN(Number(r)))return Number(r);if((e.boolean||e.overloadedBoolean)&&(r===""||ka(r)===ka(t)))return!0}return r}function TE(e){const t=[];let r;for(r in e)F0.call(e,r)&&t.push([r,e[r]].join(": "));return t.join("; ")}function AE(e){const t={};let r=-1;for(;++r<e.length;)t[e[r].toLowerCase()]=e[r];return t}const kE=nb(Xg,"div"),OE=["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","solidColor","textArea","textPath"],NE=nb(Yg,"g",OE);function _E(e,t){return(e?ib(e,t||{}):void 0)||{type:"root",children:[]}}function ib(e,t){const r=CE(e,t);return r&&t.afterTransform&&t.afterTransform(e,r),r}function CE(e,t){switch(e.nodeType){case 1:return PE(e,t);case 3:return RE(e);case 8:return IE(e);case 9:return M1(e,t);case 10:return ME();case 11:return M1(e,t);default:return}}function M1(e,t){return{type:"root",children:ab(e,t)}}function ME(){return{type:"doctype"}}function RE(e){return{type:"text",value:e.nodeValue||""}}function IE(e){return{type:"comment",value:e.nodeValue||""}}function PE(e,t){const r=e.namespaceURI,n=r===_l.svg?NE:kE,i=r===_l.html?e.tagName.toLowerCase():e.tagName,a=r===_l.html&&i==="template"?e.content:e,o=e.getAttributeNames(),s={};let u=-1;for(;++u<o.length;)s[o[u]]=e.getAttribute(o[u])||"";return n(i,s,ab(a,t))}function ab(e,t){const r=e.childNodes,n=[];let i=-1;for(;++i<r.length;){const a=ib(r[i],t);a!==void 0&&n.push(a)}return n}const DE=new DOMParser;function LE(e,t){const r=t!=null&&t.fragment?FE(e):DE.parseFromString(e,"text/html");return _E(r)}function FE(e){const t=document.createElement("template");return t.innerHTML=e,t.content}const R1=Object.assign,BE="rehype-katex";function $$(e){const t=e||{},r=t.throwOnError||!1;return(n,i)=>{uu(n,"element",a=>{const o=a.properties&&Array.isArray(a.properties.className)?a.properties.className:[],s=o.includes("math-inline"),u=o.includes("math-display");if(!s&&!u)return;const l=pE(a,{whitespace:"pre"});let c;try{c=y1.renderToString(l,R1({},t,{displayMode:u,throwOnError:!0}))}catch(d){const h=d,p=r?"fail":"message",m=[BE,h.name.toLowerCase()].join(":");if(i[p](h.message,a.position,m),h.name!=="ParseError"){a.children=[{type:"element",tagName:"span",properties:{className:["katex-error"],title:String(h),style:"color:"+(t.errorColor||"#cc0000")},children:[{type:"text",value:l}]}];return}c=y1.renderToString(l,R1({},t,{displayMode:u,throwOnError:!1,strict:"ignore"}))}const f=LE(c,{fragment:!0});a.children=f.children})}}const zE={tokenize:VE,partial:!0},ob={tokenize:GE,partial:!0},sb={tokenize:WE,partial:!0},ub={tokenize:KE,partial:!0},$E={tokenize:XE,partial:!0},lb={tokenize:qE,previous:fb},cb={tokenize:jE,previous:db},gn={tokenize:HE,previous:hb},Xr={},UE={text:Xr};let Kn=48;for(;Kn<123;)Xr[Kn]=gn,Kn++,Kn===58?Kn=65:Kn===91&&(Kn=97);Xr[43]=gn;Xr[45]=gn;Xr[46]=gn;Xr[95]=gn;Xr[72]=[gn,cb];Xr[104]=[gn,cb];Xr[87]=[gn,lb];Xr[119]=[gn,lb];function HE(e,t,r){const n=this;let i,a;return o;function o(f){return!z0(f)||!hb.call(n,n.previous)||Ff(n.events)?r(f):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),s(f))}function s(f){return z0(f)?(e.consume(f),s):f===64?(e.consume(f),u):r(f)}function u(f){return f===46?e.check($E,c,l)(f):f===45||f===95||Nt(f)?(a=!0,e.consume(f),u):c(f)}function l(f){return e.consume(f),i=!0,u}function c(f){return a&&i&&Ft(n.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(f)):r(f)}}function qE(e,t,r){const n=this;return i;function i(o){return o!==87&&o!==119||!fb.call(n,n.previous)||Ff(n.events)?r(o):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(zE,e.attempt(ob,e.attempt(sb,a),r),r)(o))}function a(o){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(o)}}function jE(e,t,r){const n=this;let i="",a=!1;return o;function o(f){return(f===72||f===104)&&db.call(n,n.previous)&&!Ff(n.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),i+=String.fromCodePoint(f),e.consume(f),s):r(f)}function s(f){if(Ft(f)&&i.length<5)return i+=String.fromCodePoint(f),e.consume(f),s;if(f===58){const d=i.toLowerCase();if(d==="http"||d==="https")return e.consume(f),u}return r(f)}function u(f){return f===47?(e.consume(f),a?l:(a=!0,u)):r(f)}function l(f){return f===null||Ts(f)||Qe(f)||oi(f)||iu(f)?r(f):e.attempt(ob,e.attempt(sb,c),r)(f)}function c(f){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(f)}}function VE(e,t,r){let n=0;return i;function i(o){return(o===87||o===119)&&n<3?(n++,e.consume(o),i):o===46&&n===3?(e.consume(o),a):r(o)}function a(o){return o===null?r(o):t(o)}}function GE(e,t,r){let n,i,a;return o;function o(l){return l===46||l===95?e.check(ub,u,s)(l):l===null||Qe(l)||oi(l)||l!==45&&iu(l)?u(l):(a=!0,e.consume(l),o)}function s(l){return l===95?n=!0:(i=n,n=void 0),e.consume(l),o}function u(l){return i||n||!a?r(l):t(l)}}function WE(e,t){let r=0,n=0;return i;function i(o){return o===40?(r++,e.consume(o),i):o===41&&n<r?a(o):o===33||o===34||o===38||o===39||o===41||o===42||o===44||o===46||o===58||o===59||o===60||o===63||o===93||o===95||o===126?e.check(ub,t,a)(o):o===null||Qe(o)||oi(o)?t(o):(e.consume(o),i)}function a(o){return o===41&&n++,e.consume(o),i}}function KE(e,t,r){return n;function n(s){return s===33||s===34||s===39||s===41||s===42||s===44||s===46||s===58||s===59||s===63||s===95||s===126?(e.consume(s),n):s===38?(e.consume(s),a):s===93?(e.consume(s),i):s===60||s===null||Qe(s)||oi(s)?t(s):r(s)}function i(s){return s===null||s===40||s===91||Qe(s)||oi(s)?t(s):n(s)}function a(s){return Ft(s)?o(s):r(s)}function o(s){return s===59?(e.consume(s),n):Ft(s)?(e.consume(s),o):r(s)}}function XE(e,t,r){return n;function n(a){return e.consume(a),i}function i(a){return Nt(a)?r(a):t(a)}}function fb(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||Qe(e)}function db(e){return!Ft(e)}function hb(e){return!(e===47||z0(e))}function z0(e){return e===43||e===45||e===46||e===95||Nt(e)}function Ff(e){let t=e.length,r=!1;for(;t--;){const n=e[t][1];if((n.type==="labelLink"||n.type==="labelImage")&&!n._balanced){r=!0;break}if(n._gfmAutolinkLiteralWalkedInto){r=!1;break}}return e.length>0&&!r&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),r}const YE={tokenize:iS,partial:!0};function ZE(){return{document:{91:{tokenize:tS,continuation:{tokenize:rS},exit:nS}},text:{91:{tokenize:eS},93:{add:"after",tokenize:QE,resolveTo:JE}}}}function QE(e,t,r){const n=this;let i=n.events.length;const a=n.parser.gfmFootnotes||(n.parser.gfmFootnotes=[]);let o;for(;i--;){const u=n.events[i][1];if(u.type==="labelImage"){o=u;break}if(u.type==="gfmFootnoteCall"||u.type==="labelLink"||u.type==="label"||u.type==="image"||u.type==="link")break}return s;function s(u){if(!o||!o._balanced)return r(u);const l=Or(n.sliceSerialize({start:o.end,end:n.now()}));return l.codePointAt(0)!==94||!a.includes(l.slice(1))?r(u):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(u),e.exit("gfmFootnoteCallLabelMarker"),t(u))}}function JE(e,t){let r=e.length;for(;r--;)if(e[r][1].type==="labelImage"&&e[r][0]==="enter"){e[r][1];break}e[r+1][1].type="data",e[r+3][1].type="gfmFootnoteCallLabelMarker";const n={type:"gfmFootnoteCall",start:Object.assign({},e[r+3][1].start),end:Object.assign({},e[e.length-1][1].end)},i={type:"gfmFootnoteCallMarker",start:Object.assign({},e[r+3][1].end),end:Object.assign({},e[r+3][1].end)};i.end.column++,i.end.offset++,i.end._bufferIndex++;const a={type:"gfmFootnoteCallString",start:Object.assign({},i.end),end:Object.assign({},e[e.length-1][1].start)},o={type:"chunkString",contentType:"string",start:Object.assign({},a.start),end:Object.assign({},a.end)},s=[e[r+1],e[r+2],["enter",n,t],e[r+3],e[r+4],["enter",i,t],["exit",i,t],["enter",a,t],["enter",o,t],["exit",o,t],["exit",a,t],e[e.length-2],e[e.length-1],["exit",n,t]];return e.splice(r,e.length-r+1,...s),e}function eS(e,t,r){const n=this,i=n.parser.gfmFootnotes||(n.parser.gfmFootnotes=[]);let a=0,o;return s;function s(f){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(f),e.exit("gfmFootnoteCallLabelMarker"),u}function u(f){return f!==94?r(f):(e.enter("gfmFootnoteCallMarker"),e.consume(f),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",l)}function l(f){if(a>999||f===93&&!o||f===null||f===91||Qe(f))return r(f);if(f===93){e.exit("chunkString");const d=e.exit("gfmFootnoteCallString");return i.includes(Or(n.sliceSerialize(d)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(f),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):r(f)}return Qe(f)||(o=!0),a++,e.consume(f),f===92?c:l}function c(f){return f===91||f===92||f===93?(e.consume(f),a++,l):l(f)}}function tS(e,t,r){const n=this,i=n.parser.gfmFootnotes||(n.parser.gfmFootnotes=[]);let a,o=0,s;return u;function u(p){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(p),e.exit("gfmFootnoteDefinitionLabelMarker"),l}function l(p){return p===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(p),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",c):r(p)}function c(p){if(o>999||p===93&&!s||p===null||p===91||Qe(p))return r(p);if(p===93){e.exit("chunkString");const m=e.exit("gfmFootnoteDefinitionLabelString");return a=Or(n.sliceSerialize(m)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(p),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),d}return Qe(p)||(s=!0),o++,e.consume(p),p===92?f:c}function f(p){return p===91||p===92||p===93?(e.consume(p),o++,c):c(p)}function d(p){return p===58?(e.enter("definitionMarker"),e.consume(p),e.exit("definitionMarker"),i.includes(a)||i.push(a),Me(e,h,"gfmFootnoteDefinitionWhitespace")):r(p)}function h(p){return t(p)}}function rS(e,t,r){return e.check(Wa,t,e.attempt(YE,t,r))}function nS(e){e.exit("gfmFootnoteDefinition")}function iS(e,t,r){const n=this;return Me(e,i,"gfmFootnoteDefinitionIndent",4+1);function i(a){const o=n.events[n.events.length-1];return o&&o[1].type==="gfmFootnoteDefinitionIndent"&&o[2].sliceSerialize(o[1],!0).length===4?t(a):r(a)}}function aS(e){let r=(e||{}).singleTilde;const n={tokenize:a,resolveAll:i};return r==null&&(r=!0),{text:{126:n},insideSpan:{null:[n]},attentionMarkers:{null:[126]}};function i(o,s){let u=-1;for(;++u<o.length;)if(o[u][0]==="enter"&&o[u][1].type==="strikethroughSequenceTemporary"&&o[u][1]._close){let l=u;for(;l--;)if(o[l][0]==="exit"&&o[l][1].type==="strikethroughSequenceTemporary"&&o[l][1]._open&&o[u][1].end.offset-o[u][1].start.offset===o[l][1].end.offset-o[l][1].start.offset){o[u][1].type="strikethroughSequence",o[l][1].type="strikethroughSequence";const c={type:"strikethrough",start:Object.assign({},o[l][1].start),end:Object.assign({},o[u][1].end)},f={type:"strikethroughText",start:Object.assign({},o[l][1].end),end:Object.assign({},o[u][1].start)},d=[["enter",c,s],["enter",o[l][1],s],["exit",o[l][1],s],["enter",f,s]],h=s.parser.constructs.insideSpan.null;h&&nr(d,d.length,0,au(h,o.slice(l+1,u),s)),nr(d,d.length,0,[["exit",f,s],["enter",o[u][1],s],["exit",o[u][1],s],["exit",c,s]]),nr(o,l-1,u-l+3,d),u=l+d.length-2;break}}for(u=-1;++u<o.length;)o[u][1].type==="strikethroughSequenceTemporary"&&(o[u][1].type="data");return o}function a(o,s,u){const l=this.previous,c=this.events;let f=0;return d;function d(p){return l===126&&c[c.length-1][1].type!=="characterEscape"?u(p):(o.enter("strikethroughSequenceTemporary"),h(p))}function h(p){const m=As(l);if(p===126)return f>1?u(p):(o.consume(p),f++,h);if(f<2&&!r)return u(p);const g=o.exit("strikethroughSequenceTemporary"),v=As(p);return g._open=!v||v===2&&!!m,g._close=!m||m===2&&!!v,s(p)}}}class oS{constructor(){this.map=[]}add(t,r,n){sS(this,t,r,n)}consume(t){if(this.map.sort((a,o)=>a[0]-o[0]),this.map.length===0)return;let r=this.map.length;const n=[];for(;r>0;)r-=1,n.push(t.slice(this.map[r][0]+this.map[r][1])),n.push(this.map[r][2]),t.length=this.map[r][0];n.push([...t]),t.length=0;let i=n.pop();for(;i;)t.push(...i),i=n.pop();this.map.length=0}}function sS(e,t,r,n){let i=0;if(!(r===0&&n.length===0)){for(;i<e.map.length;){if(e.map[i][0]===t){e.map[i][1]+=r,e.map[i][2].push(...n);return}i+=1}e.map.push([t,r,n])}}function uS(e,t){let r=!1;const n=[];for(;t<e.length;){const i=e[t];if(r){if(i[0]==="enter")i[1].type==="tableContent"&&n.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(i[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const a=n.length-1;n[a]=n[a]==="left"?"center":"right"}}else if(i[1].type==="tableDelimiterRow")break}else i[0]==="enter"&&i[1].type==="tableDelimiterRow"&&(r=!0);t+=1}return n}const lS={flow:{null:{tokenize:cS,resolveAll:fS}}};function cS(e,t,r){const n=this;let i=0,a=0,o;return s;function s(L){let I=n.events.length-1;for(;I>-1;){const F=n.events[I][1].type;if(F==="lineEnding"||F==="linePrefix")I--;else break}const k=I>-1?n.events[I][1].type:null,M=k==="tableHead"||k==="tableRow"?A:u;return M===A&&n.parser.lazy[n.now().line]?r(L):M(L)}function u(L){return e.enter("tableHead"),e.enter("tableRow"),l(L)}function l(L){return L===124||(o=!0,a+=1),c(L)}function c(L){return L===null?r(L):pe(L)?a>1?(a=0,n.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(L),e.exit("lineEnding"),h):r(L):Ie(L)?Me(e,c,"whitespace")(L):(a+=1,o&&(o=!1,i+=1),L===124?(e.enter("tableCellDivider"),e.consume(L),e.exit("tableCellDivider"),o=!0,c):(e.enter("data"),f(L)))}function f(L){return L===null||L===124||Qe(L)?(e.exit("data"),c(L)):(e.consume(L),L===92?d:f)}function d(L){return L===92||L===124?(e.consume(L),f):f(L)}function h(L){return n.interrupt=!1,n.parser.lazy[n.now().line]?r(L):(e.enter("tableDelimiterRow"),o=!1,Ie(L)?Me(e,p,"linePrefix",n.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(L):p(L))}function p(L){return L===45||L===58?g(L):L===124?(o=!0,e.enter("tableCellDivider"),e.consume(L),e.exit("tableCellDivider"),m):O(L)}function m(L){return Ie(L)?Me(e,g,"whitespace")(L):g(L)}function g(L){return L===58?(a+=1,o=!0,e.enter("tableDelimiterMarker"),e.consume(L),e.exit("tableDelimiterMarker"),v):L===45?(a+=1,v(L)):L===null||pe(L)?N(L):O(L)}function v(L){return L===45?(e.enter("tableDelimiterFiller"),w(L)):O(L)}function w(L){return L===45?(e.consume(L),w):L===58?(o=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(L),e.exit("tableDelimiterMarker"),x):(e.exit("tableDelimiterFiller"),x(L))}function x(L){return Ie(L)?Me(e,N,"whitespace")(L):N(L)}function N(L){return L===124?p(L):L===null||pe(L)?!o||i!==a?O(L):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(L)):O(L)}function O(L){return r(L)}function A(L){return e.enter("tableRow"),D(L)}function D(L){return L===124?(e.enter("tableCellDivider"),e.consume(L),e.exit("tableCellDivider"),D):L===null||pe(L)?(e.exit("tableRow"),t(L)):Ie(L)?Me(e,D,"whitespace")(L):(e.enter("data"),H(L))}function H(L){return L===null||L===124||Qe(L)?(e.exit("data"),D(L)):(e.consume(L),L===92?z:H)}function z(L){return L===92||L===124?(e.consume(L),H):H(L)}}function fS(e,t){let r=-1,n=!0,i=0,a=[0,0,0,0],o=[0,0,0,0],s=!1,u=0,l,c,f;const d=new oS;for(;++r<e.length;){const h=e[r],p=h[1];h[0]==="enter"?p.type==="tableHead"?(s=!1,u!==0&&(I1(d,t,u,l,c),c=void 0,u=0),l={type:"table",start:Object.assign({},p.start),end:Object.assign({},p.end)},d.add(r,0,[["enter",l,t]])):p.type==="tableRow"||p.type==="tableDelimiterRow"?(n=!0,f=void 0,a=[0,0,0,0],o=[0,r+1,0,0],s&&(s=!1,c={type:"tableBody",start:Object.assign({},p.start),end:Object.assign({},p.end)},d.add(r,0,[["enter",c,t]])),i=p.type==="tableDelimiterRow"?2:c?3:1):i&&(p.type==="data"||p.type==="tableDelimiterMarker"||p.type==="tableDelimiterFiller")?(n=!1,o[2]===0&&(a[1]!==0&&(o[0]=o[1],f=ko(d,t,a,i,void 0,f),a=[0,0,0,0]),o[2]=r)):p.type==="tableCellDivider"&&(n?n=!1:(a[1]!==0&&(o[0]=o[1],f=ko(d,t,a,i,void 0,f)),a=o,o=[a[1],r,0,0])):p.type==="tableHead"?(s=!0,u=r):p.type==="tableRow"||p.type==="tableDelimiterRow"?(u=r,a[1]!==0?(o[0]=o[1],f=ko(d,t,a,i,r,f)):o[1]!==0&&(f=ko(d,t,o,i,r,f)),i=0):i&&(p.type==="data"||p.type==="tableDelimiterMarker"||p.type==="tableDelimiterFiller")&&(o[3]=r)}for(u!==0&&I1(d,t,u,l,c),d.consume(t.events),r=-1;++r<t.events.length;){const h=t.events[r];h[0]==="enter"&&h[1].type==="table"&&(h[1]._align=uS(t.events,r))}return e}function ko(e,t,r,n,i,a){const o=n===1?"tableHeader":n===2?"tableDelimiter":"tableData",s="tableContent";r[0]!==0&&(a.end=Object.assign({},Ti(t.events,r[0])),e.add(r[0],0,[["exit",a,t]]));const u=Ti(t.events,r[1]);if(a={type:o,start:Object.assign({},u),end:Object.assign({},u)},e.add(r[1],0,[["enter",a,t]]),r[2]!==0){const l=Ti(t.events,r[2]),c=Ti(t.events,r[3]),f={type:s,start:Object.assign({},l),end:Object.assign({},c)};if(e.add(r[2],0,[["enter",f,t]]),n!==2){const d=t.events[r[2]],h=t.events[r[3]];if(d[1].end=Object.assign({},h[1].end),d[1].type="chunkText",d[1].contentType="text",r[3]>r[2]+1){const p=r[2]+1,m=r[3]-r[2]-1;e.add(p,m,[])}}e.add(r[3]+1,0,[["exit",f,t]])}return i!==void 0&&(a.end=Object.assign({},Ti(t.events,i)),e.add(i,0,[["exit",a,t]]),a=void 0),a}function I1(e,t,r,n,i){const a=[],o=Ti(t.events,r);i&&(i.end=Object.assign({},o),a.push(["exit",i,t])),n.end=Object.assign({},o),a.push(["exit",n,t]),e.add(r+1,0,a)}function Ti(e,t){const r=e[t],n=r[0]==="enter"?"start":"end";return r[1][n]}const dS={tokenize:pS},hS={text:{91:dS}};function pS(e,t,r){const n=this;return i;function i(u){return n.previous!==null||!n._gfmTasklistFirstContentOfListItem?r(u):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(u),e.exit("taskListCheckMarker"),a)}function a(u){return Qe(u)?(e.enter("taskListCheckValueUnchecked"),e.consume(u),e.exit("taskListCheckValueUnchecked"),o):u===88||u===120?(e.enter("taskListCheckValueChecked"),e.consume(u),e.exit("taskListCheckValueChecked"),o):r(u)}function o(u){return u===93?(e.enter("taskListCheckMarker"),e.consume(u),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),s):r(u)}function s(u){return pe(u)?t(u):Ie(u)?e.check({tokenize:mS},t,r)(u):r(u)}}function mS(e,t,r){return Me(e,n,"whitespace");function n(i){return i===null?r(i):t(i)}}function gS(e){return gg([UE,ZE(),aS(e),lS,hS])}function P1(e,t){const r=String(e);if(typeof t!="string")throw new TypeError("Expected character");let n=0,i=r.indexOf(t);for(;i!==-1;)n++,i=r.indexOf(t,i+t.length);return n}const Cl="phrasing",Ml=["autolink","link","image","label"],bS={transforms:[TS],enter:{literalAutolink:yS,literalAutolinkEmail:Rl,literalAutolinkHttp:Rl,literalAutolinkWww:Rl},exit:{literalAutolink:SS,literalAutolinkEmail:ES,literalAutolinkHttp:wS,literalAutolinkWww:xS}},vS={unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:Cl,notInConstruct:Ml},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:Cl,notInConstruct:Ml},{character:":",before:"[ps]",after:"\\/",inConstruct:Cl,notInConstruct:Ml}]};function yS(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function Rl(e){this.config.enter.autolinkProtocol.call(this,e)}function wS(e){this.config.exit.autolinkProtocol.call(this,e)}function xS(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.url="http://"+this.sliceSerialize(e)}function ES(e){this.config.exit.autolinkEmail.call(this,e)}function SS(e){this.exit(e)}function TS(e){Z2(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,AS],[/([-.\w+]+)@([-\w]+(?:\.[-\w]+)+)/g,kS]],{ignore:["link","linkReference"]})}function AS(e,t,r,n,i){let a="";if(!pb(i)||(/^w/i.test(t)&&(r=t+r,t="",a="http://"),!OS(r)))return!1;const o=NS(r+n);if(!o[0])return!1;const s={type:"link",title:null,url:a+t+o[0],children:[{type:"text",value:t+o[0]}]};return o[1]?[s,{type:"text",value:o[1]}]:s}function kS(e,t,r,n){return!pb(n,!0)||/[-\d_]$/.test(r)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+r,children:[{type:"text",value:t+"@"+r}]}}function OS(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function NS(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let r=t[0],n=r.indexOf(")");const i=P1(e,"(");let a=P1(e,")");for(;n!==-1&&i>a;)e+=r.slice(0,n+1),r=r.slice(n+1),n=r.indexOf(")"),a++;return[e,r]}function pb(e,t){const r=e.input.charCodeAt(e.index-1);return(e.index===0||oi(r)||iu(r))&&(!t||r!==47)}function mb(e){return e.label||!e.identifier?e.label||"":Og(e.identifier)}function _S(e,t,r){const n=t.indexStack,i=e.children||[],a=t.createTracker(r),o=[];let s=-1;for(n.push(-1);++s<i.length;){const u=i[s];n[n.length-1]=s,o.push(a.move(t.handle(u,e,t,{before:`
`,after:`
`,...a.current()}))),u.type!=="list"&&(t.bulletLastUsed=void 0),s<i.length-1&&o.push(a.move(CS(u,i[s+1],e,t)))}return n.pop(),o.join("")}function CS(e,t,r,n){let i=n.join.length;for(;i--;){const a=n.join[i](e,t,r,n);if(a===!0||a===1)break;if(typeof a=="number")return`
`.repeat(1+a);if(a===!1)return`

<!---->

`}return`

`}const MS=/\r?\n|\r/g;function RS(e,t){const r=[];let n=0,i=0,a;for(;a=MS.exec(e);)o(e.slice(n,a.index)),r.push(a[0]),n=a.index+a[0].length,i++;return o(e.slice(n)),r.join("");function o(s){r.push(t(s,i,!s))}}gb.peek=qS;function IS(){return{enter:{gfmFootnoteDefinition:DS,gfmFootnoteDefinitionLabelString:LS,gfmFootnoteCall:zS,gfmFootnoteCallString:$S},exit:{gfmFootnoteDefinition:BS,gfmFootnoteDefinitionLabelString:FS,gfmFootnoteCall:HS,gfmFootnoteCallString:US}}}function PS(){return{unsafe:[{character:"[",inConstruct:["phrasing","label","reference"]}],handlers:{footnoteDefinition:jS,footnoteReference:gb}}}function DS(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function LS(){this.buffer()}function FS(e){const t=this.resume(),r=this.stack[this.stack.length-1];r.label=t,r.identifier=Or(this.sliceSerialize(e)).toLowerCase()}function BS(e){this.exit(e)}function zS(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function $S(){this.buffer()}function US(e){const t=this.resume(),r=this.stack[this.stack.length-1];r.label=t,r.identifier=Or(this.sliceSerialize(e)).toLowerCase()}function HS(e){this.exit(e)}function gb(e,t,r,n){const i=Qa(n);let a=i.move("[^");const o=r.enter("footnoteReference"),s=r.enter("reference");return a+=i.move(Df(r,mb(e),{...i.current(),before:a,after:"]"})),s(),o(),a+=i.move("]"),a}function qS(){return"["}function jS(e,t,r,n){const i=Qa(n);let a=i.move("[^");const o=r.enter("footnoteDefinition"),s=r.enter("label");return a+=i.move(Df(r,mb(e),{...i.current(),before:a,after:"]"})),s(),a+=i.move("]:"+(e.children&&e.children.length>0?" ":"")),i.shift(4),a+=i.move(RS(_S(e,r,i.current()),VS)),o(),a}function VS(e,t,r){return t===0?e:(r?"":"    ")+e}function bb(e,t,r){const n=t.indexStack,i=e.children||[],a=[];let o=-1,s=r.before;n.push(-1);let u=t.createTracker(r);for(;++o<i.length;){const l=i[o];let c;if(n[n.length-1]=o,o+1<i.length){let f=t.handle.handlers[i[o+1].type];f&&f.peek&&(f=f.peek),c=f?f(i[o+1],e,t,{before:"",after:"",...u.current()}).charAt(0):""}else c=r.after;a.length>0&&(s==="\r"||s===`
`)&&l.type==="html"&&(a[a.length-1]=a[a.length-1].replace(/(\r?\n|\r)$/," "),s=" ",u=t.createTracker(r),u.move(a.join(""))),a.push(u.move(t.handle(l,e,t,{...u.current(),before:s,after:c}))),s=a[a.length-1].slice(-1)}return n.pop(),a.join("")}const GS=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];vb.peek=ZS;const WS={canContainEols:["delete"],enter:{strikethrough:XS},exit:{strikethrough:YS}},KS={unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:GS}],handlers:{delete:vb}};function XS(e){this.enter({type:"delete",children:[]},e)}function YS(e){this.exit(e)}function vb(e,t,r,n){const i=Qa(n),a=r.enter("strikethrough");let o=i.move("~~");return o+=bb(e,r,{...i.current(),before:o,after:"~"}),o+=i.move("~~"),a(),o}function ZS(){return"~"}yb.peek=QS;function yb(e,t,r){let n=e.value||"",i="`",a=-1;for(;new RegExp("(^|[^`])"+i+"([^`]|$)").test(n);)i+="`";for(/[^ \r\n]/.test(n)&&(/^[ \r\n]/.test(n)&&/[ \r\n]$/.test(n)||/^`|`$/.test(n))&&(n=" "+n+" ");++a<r.unsafe.length;){const o=r.unsafe[a],s=Pf(o);let u;if(o.atBreak)for(;u=s.exec(n);){let l=u.index;n.charCodeAt(l)===10&&n.charCodeAt(l-1)===13&&l--,n=n.slice(0,l)+" "+n.slice(u.index+1)}}return i+n+i}function QS(){return"`"}function JS(e,t={}){const r=(t.align||[]).concat(),n=t.stringLength||tT,i=[],a=[],o=[],s=[];let u=0,l=-1;for(;++l<e.length;){const p=[],m=[];let g=-1;for(e[l].length>u&&(u=e[l].length);++g<e[l].length;){const v=eT(e[l][g]);if(t.alignDelimiters!==!1){const w=n(v);m[g]=w,(s[g]===void 0||w>s[g])&&(s[g]=w)}p.push(v)}a[l]=p,o[l]=m}let c=-1;if(typeof r=="object"&&"length"in r)for(;++c<u;)i[c]=D1(r[c]);else{const p=D1(r);for(;++c<u;)i[c]=p}c=-1;const f=[],d=[];for(;++c<u;){const p=i[c];let m="",g="";p===99?(m=":",g=":"):p===108?m=":":p===114&&(g=":");let v=t.alignDelimiters===!1?1:Math.max(1,s[c]-m.length-g.length);const w=m+"-".repeat(v)+g;t.alignDelimiters!==!1&&(v=m.length+v+g.length,v>s[c]&&(s[c]=v),d[c]=v),f[c]=w}a.splice(1,0,f),o.splice(1,0,d),l=-1;const h=[];for(;++l<a.length;){const p=a[l],m=o[l];c=-1;const g=[];for(;++c<u;){const v=p[c]||"";let w="",x="";if(t.alignDelimiters!==!1){const N=s[c]-(m[c]||0),O=i[c];O===114?w=" ".repeat(N):O===99?N%2?(w=" ".repeat(N/2+.5),x=" ".repeat(N/2-.5)):(w=" ".repeat(N/2),x=w):x=" ".repeat(N)}t.delimiterStart!==!1&&!c&&g.push("|"),t.padding!==!1&&!(t.alignDelimiters===!1&&v==="")&&(t.delimiterStart!==!1||c)&&g.push(" "),t.alignDelimiters!==!1&&g.push(w),g.push(v),t.alignDelimiters!==!1&&g.push(x),t.padding!==!1&&g.push(" "),(t.delimiterEnd!==!1||c!==u-1)&&g.push("|")}h.push(t.delimiterEnd===!1?g.join("").replace(/ +$/,""):g.join(""))}return h.join(`
`)}function eT(e){return e==null?"":String(e)}function tT(e){return e.length}function D1(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}const rT={enter:{table:nT,tableData:L1,tableHeader:L1,tableRow:aT},exit:{codeText:oT,table:iT,tableData:Il,tableHeader:Il,tableRow:Il}};function nT(e){const t=e._align;this.enter({type:"table",align:t.map(r=>r==="none"?null:r),children:[]},e),this.setData("inTable",!0)}function iT(e){this.exit(e),this.setData("inTable")}function aT(e){this.enter({type:"tableRow",children:[]},e)}function Il(e){this.exit(e)}function L1(e){this.enter({type:"tableCell",children:[]},e)}function oT(e){let t=this.resume();this.getData("inTable")&&(t=t.replace(/\\([\\|])/g,sT));const r=this.stack[this.stack.length-1];r.value=t,this.exit(e)}function sT(e,t){return t==="|"?t:e}function uT(e){const t=e||{},r=t.tableCellPadding,n=t.tablePipeAlign,i=t.stringLength,a=r?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{table:o,tableRow:s,tableCell:u,inlineCode:d}};function o(h,p,m,g){return l(c(h,m,g),h.align)}function s(h,p,m,g){const v=f(h,m,g),w=l([v]);return w.slice(0,w.indexOf(`
`))}function u(h,p,m,g){const v=m.enter("tableCell"),w=m.enter("phrasing"),x=bb(h,m,{...g,before:a,after:a});return w(),v(),x}function l(h,p){return JS(h,{align:p,alignDelimiters:n,padding:r,stringLength:i})}function c(h,p,m){const g=h.children;let v=-1;const w=[],x=p.enter("table");for(;++v<g.length;)w[v]=f(g[v],p,m);return x(),w}function f(h,p,m){const g=h.children;let v=-1;const w=[],x=p.enter("tableRow");for(;++v<g.length;)w[v]=u(g[v],h,p,m);return x(),w}function d(h,p,m){let g=yb(h,p,m);return m.stack.includes("tableCell")&&(g=g.replace(/\|/g,"\\$&")),g}}function lT(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function cT(e){const t=e.options.listItemIndent||"tab";if(t===1||t==="1")return"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function fT(e,t,r,n){const i=cT(r);let a=r.bulletCurrent||lT(r);t&&t.type==="list"&&t.ordered&&(a=(typeof t.start=="number"&&t.start>-1?t.start:1)+(r.options.incrementListMarker===!1?0:t.children.indexOf(e))+a);let o=a.length+1;(i==="tab"||i==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(o=Math.ceil(o/4)*4);const s=r.createTracker(n);s.move(a+" ".repeat(o-a.length)),s.shift(o);const u=r.enter("listItem"),l=r.indentLines(r.containerFlow(e,s.current()),c);return u(),l;function c(f,d,h){return d?(h?"":" ".repeat(o))+f:(h?a:a+" ".repeat(o-a.length))+f}}const dT={exit:{taskListCheckValueChecked:F1,taskListCheckValueUnchecked:F1,paragraph:pT}},hT={unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:mT}};function F1(e){const t=this.stack[this.stack.length-2];t.checked=e.type==="taskListCheckValueChecked"}function pT(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const r=this.stack[this.stack.length-1],n=r.children[0];if(n&&n.type==="text"){const i=t.children;let a=-1,o;for(;++a<i.length;){const s=i[a];if(s.type==="paragraph"){o=s;break}}o===r&&(n.value=n.value.slice(1),n.value.length===0?r.children.shift():r.position&&n.position&&typeof n.position.start.offset=="number"&&(n.position.start.column++,n.position.start.offset++,r.position.start=Object.assign({},n.position.start)))}}this.exit(e)}function mT(e,t,r,n){const i=e.children[0],a=typeof e.checked=="boolean"&&i&&i.type==="paragraph",o="["+(e.checked?"x":" ")+"] ",s=Qa(n);a&&s.move(o);let u=fT(e,t,r,{...n,...s.current()});return a&&(u=u.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,l)),u;function l(c){return c+o}}function gT(){return[bS,IS(),WS,rT,dT]}function bT(e){return{extensions:[vS,PS(),KS,uT(e),hT]}}function U$(e={}){const t=this.data();r("micromarkExtensions",gS(e)),r("fromMarkdownExtensions",gT()),r("toMarkdownExtensions",bT(e));function r(n,i){(t[n]?t[n]:t[n]=[]).push(i)}}var ce={},$0={exports:{}};(function(e,t){(function(r,n){var i="1.0.37",a="",o="?",s="function",u="undefined",l="object",c="string",f="major",d="model",h="name",p="type",m="vendor",g="version",v="architecture",w="console",x="mobile",N="tablet",O="smarttv",A="wearable",D="embedded",H=500,z="Amazon",L="Apple",I="ASUS",k="BlackBerry",M="Browser",F="Chrome",C="Edge",U="Firefox",$="Google",V="Huawei",se="LG",_="Microsoft",oe="Motorola",ne="Opera",T="Samsung",G="Sharp",ee="Sony",le="Xiaomi",we="Zebra",Oe="Facebook",qe="Chromium OS",ve="Mac OS",ct=function(me,Pe){var q={};for(var K in me)Pe[K]&&Pe[K].length%2===0?q[K]=Pe[K].concat(me[K]):q[K]=me[K];return q},ft=function(me){for(var Pe={},q=0;q<me.length;q++)Pe[me[q].toUpperCase()]=me[q];return Pe},_r=function(me,Pe){return typeof me===c?Xt(Pe).indexOf(Xt(me))!==-1:!1},Xt=function(me){return me.toLowerCase()},yn=function(me){return typeof me===c?me.replace(/[^\d\.]/g,a).split(".")[0]:n},Tr=function(me,Pe){if(typeof me===c)return me=me.replace(/^\s\s*/,a),typeof Pe===u?me:me.substring(0,H)},At=function(me,Pe){for(var q=0,K,de,Z,X,J,Ee;q<Pe.length&&!J;){var Ke=Pe[q],Yt=Pe[q+1];for(K=de=0;K<Ke.length&&!J&&Ke[K];)if(J=Ke[K++].exec(me),J)for(Z=0;Z<Yt.length;Z++)Ee=J[++de],X=Yt[Z],typeof X===l&&X.length>0?X.length===2?typeof X[1]==s?this[X[0]]=X[1].call(this,Ee):this[X[0]]=X[1]:X.length===3?typeof X[1]===s&&!(X[1].exec&&X[1].test)?this[X[0]]=Ee?X[1].call(this,Ee,X[2]):n:this[X[0]]=Ee?Ee.replace(X[1],X[2]):n:X.length===4&&(this[X[0]]=Ee?X[3].call(this,Ee.replace(X[1],X[2])):n):this[X]=Ee||n;q+=2}},$t=function(me,Pe){for(var q in Pe)if(typeof Pe[q]===l&&Pe[q].length>0){for(var K=0;K<Pe[q].length;K++)if(_r(Pe[q][K],me))return q===o?n:q}else if(_r(Pe[q],me))return q===o?n:q;return me},Rt={"1.0":"/8",1.2:"/1",1.3:"/3","2.0":"/412","2.0.2":"/416","2.0.3":"/417","2.0.4":"/419","?":"/"},jn={ME:"4.90","NT 3.11":"NT3.51","NT 4.0":"NT4.0",2e3:"NT 5.0",XP:["NT 5.1","NT 5.2"],Vista:"NT 6.0",7:"NT 6.1",8:"NT 6.2",8.1:"NT 6.3",10:["NT 6.4","NT 10.0"],RT:"ARM"},Zr={browser:[[/\b(?:crmo|crios)\/([\w\.]+)/i],[g,[h,"Chrome"]],[/edg(?:e|ios|a)?\/([\w\.]+)/i],[g,[h,"Edge"]],[/(opera mini)\/([-\w\.]+)/i,/(opera [mobiletab]{3,6})\b.+version\/([-\w\.]+)/i,/(opera)(?:.+version\/|[\/ ]+)([\w\.]+)/i],[h,g],[/opios[\/ ]+([\w\.]+)/i],[g,[h,ne+" Mini"]],[/\bopr\/([\w\.]+)/i],[g,[h,ne]],[/\bb[ai]*d(?:uhd|[ub]*[aekoprswx]{5,6})[\/ ]?([\w\.]+)/i],[g,[h,"Baidu"]],[/(kindle)\/([\w\.]+)/i,/(lunascape|maxthon|netfront|jasmine|blazer)[\/ ]?([\w\.]*)/i,/(avant|iemobile|slim)\s?(?:browser)?[\/ ]?([\w\.]*)/i,/(?:ms|\()(ie) ([\w\.]+)/i,/(flock|rockmelt|midori|epiphany|silk|skyfire|bolt|iron|vivaldi|iridium|phantomjs|bowser|quark|qupzilla|falkon|rekonq|puffin|brave|whale(?!.+naver)|qqbrowserlite|qq|duckduckgo)\/([-\w\.]+)/i,/(heytap|ovi)browser\/([\d\.]+)/i,/(weibo)__([\d\.]+)/i],[h,g],[/(?:\buc? ?browser|(?:juc.+)ucweb)[\/ ]?([\w\.]+)/i],[g,[h,"UC"+M]],[/microm.+\bqbcore\/([\w\.]+)/i,/\bqbcore\/([\w\.]+).+microm/i,/micromessenger\/([\w\.]+)/i],[g,[h,"WeChat"]],[/konqueror\/([\w\.]+)/i],[g,[h,"Konqueror"]],[/trident.+rv[: ]([\w\.]{1,9})\b.+like gecko/i],[g,[h,"IE"]],[/ya(?:search)?browser\/([\w\.]+)/i],[g,[h,"Yandex"]],[/slbrowser\/([\w\.]+)/i],[g,[h,"Smart Lenovo "+M]],[/(avast|avg)\/([\w\.]+)/i],[[h,/(.+)/,"$1 Secure "+M],g],[/\bfocus\/([\w\.]+)/i],[g,[h,U+" Focus"]],[/\bopt\/([\w\.]+)/i],[g,[h,ne+" Touch"]],[/coc_coc\w+\/([\w\.]+)/i],[g,[h,"Coc Coc"]],[/dolfin\/([\w\.]+)/i],[g,[h,"Dolphin"]],[/coast\/([\w\.]+)/i],[g,[h,ne+" Coast"]],[/miuibrowser\/([\w\.]+)/i],[g,[h,"MIUI "+M]],[/fxios\/([-\w\.]+)/i],[g,[h,U]],[/\bqihu|(qi?ho?o?|360)browser/i],[[h,"360 "+M]],[/(oculus|sailfish|huawei|vivo)browser\/([\w\.]+)/i],[[h,/(.+)/,"$1 "+M],g],[/samsungbrowser\/([\w\.]+)/i],[g,[h,T+" Internet"]],[/(comodo_dragon)\/([\w\.]+)/i],[[h,/_/g," "],g],[/metasr[\/ ]?([\d\.]+)/i],[g,[h,"Sogou Explorer"]],[/(sogou)mo\w+\/([\d\.]+)/i],[[h,"Sogou Mobile"],g],[/(electron)\/([\w\.]+) safari/i,/(tesla)(?: qtcarbrowser|\/(20\d\d\.[-\w\.]+))/i,/m?(qqbrowser|2345Explorer)[\/ ]?([\w\.]+)/i],[h,g],[/(lbbrowser)/i,/\[(linkedin)app\]/i],[h],[/((?:fban\/fbios|fb_iab\/fb4a)(?!.+fbav)|;fbav\/([\w\.]+);)/i],[[h,Oe],g],[/(Klarna)\/([\w\.]+)/i,/(kakao(?:talk|story))[\/ ]([\w\.]+)/i,/(naver)\(.*?(\d+\.[\w\.]+).*\)/i,/safari (line)\/([\w\.]+)/i,/\b(line)\/([\w\.]+)\/iab/i,/(alipay)client\/([\w\.]+)/i,/(chromium|instagram|snapchat)[\/ ]([-\w\.]+)/i],[h,g],[/\bgsa\/([\w\.]+) .*safari\//i],[g,[h,"GSA"]],[/musical_ly(?:.+app_?version\/|_)([\w\.]+)/i],[g,[h,"TikTok"]],[/headlesschrome(?:\/([\w\.]+)| )/i],[g,[h,F+" Headless"]],[/ wv\).+(chrome)\/([\w\.]+)/i],[[h,F+" WebView"],g],[/droid.+ version\/([\w\.]+)\b.+(?:mobile safari|safari)/i],[g,[h,"Android "+M]],[/(chrome|omniweb|arora|[tizenoka]{5} ?browser)\/v?([\w\.]+)/i],[h,g],[/version\/([\w\.\,]+) .*mobile\/\w+ (safari)/i],[g,[h,"Mobile Safari"]],[/version\/([\w(\.|\,)]+) .*(mobile ?safari|safari)/i],[g,h],[/webkit.+?(mobile ?safari|safari)(\/[\w\.]+)/i],[h,[g,$t,Rt]],[/(webkit|khtml)\/([\w\.]+)/i],[h,g],[/(navigator|netscape\d?)\/([-\w\.]+)/i],[[h,"Netscape"],g],[/mobile vr; rv:([\w\.]+)\).+firefox/i],[g,[h,U+" Reality"]],[/ekiohf.+(flow)\/([\w\.]+)/i,/(swiftfox)/i,/(icedragon|iceweasel|camino|chimera|fennec|maemo browser|minimo|conkeror|klar)[\/ ]?([\w\.\+]+)/i,/(seamonkey|k-meleon|icecat|iceape|firebird|phoenix|palemoon|basilisk|waterfox)\/([-\w\.]+)$/i,/(firefox)\/([\w\.]+)/i,/(mozilla)\/([\w\.]+) .+rv\:.+gecko\/\d+/i,/(polaris|lynx|dillo|icab|doris|amaya|w3m|netsurf|sleipnir|obigo|mosaic|(?:go|ice|up)[\. ]?browser)[-\/ ]?v?([\w\.]+)/i,/(links) \(([\w\.]+)/i,/panasonic;(viera)/i],[h,g],[/(cobalt)\/([\w\.]+)/i],[h,[g,/master.|lts./,""]]],cpu:[[/(?:(amd|x(?:(?:86|64)[-_])?|wow|win)64)[;\)]/i],[[v,"amd64"]],[/(ia32(?=;))/i],[[v,Xt]],[/((?:i[346]|x)86)[;\)]/i],[[v,"ia32"]],[/\b(aarch64|arm(v?8e?l?|_?64))\b/i],[[v,"arm64"]],[/\b(arm(?:v[67])?ht?n?[fl]p?)\b/i],[[v,"armhf"]],[/windows (ce|mobile); ppc;/i],[[v,"arm"]],[/((?:ppc|powerpc)(?:64)?)(?: mac|;|\))/i],[[v,/ower/,a,Xt]],[/(sun4\w)[;\)]/i],[[v,"sparc"]],[/((?:avr32|ia64(?=;))|68k(?=\))|\barm(?=v(?:[1-7]|[5-7]1)l?|;|eabi)|(?=atmel )avr|(?:irix|mips|sparc)(?:64)?\b|pa-risc)/i],[[v,Xt]]],device:[[/\b(sch-i[89]0\d|shw-m380s|sm-[ptx]\w{2,4}|gt-[pn]\d{2,4}|sgh-t8[56]9|nexus 10)/i],[d,[m,T],[p,N]],[/\b((?:s[cgp]h|gt|sm)-\w+|sc[g-]?[\d]+a?|galaxy nexus)/i,/samsung[- ]([-\w]+)/i,/sec-(sgh\w+)/i],[d,[m,T],[p,x]],[/(?:\/|\()(ip(?:hone|od)[\w, ]*)(?:\/|;)/i],[d,[m,L],[p,x]],[/\((ipad);[-\w\),; ]+apple/i,/applecoremedia\/[\w\.]+ \((ipad)/i,/\b(ipad)\d\d?,\d\d?[;\]].+ios/i],[d,[m,L],[p,N]],[/(macintosh);/i],[d,[m,L]],[/\b(sh-?[altvz]?\d\d[a-ekm]?)/i],[d,[m,G],[p,x]],[/\b((?:ag[rs][23]?|bah2?|sht?|btv)-a?[lw]\d{2})\b(?!.+d\/s)/i],[d,[m,V],[p,N]],[/(?:huawei|honor)([-\w ]+)[;\)]/i,/\b(nexus 6p|\w{2,4}e?-[atu]?[ln][\dx][012359c][adn]?)\b(?!.+d\/s)/i],[d,[m,V],[p,x]],[/\b(poco[\w ]+|m2\d{3}j\d\d[a-z]{2})(?: bui|\))/i,/\b; (\w+) build\/hm\1/i,/\b(hm[-_ ]?note?[_ ]?(?:\d\w)?) bui/i,/\b(redmi[\-_ ]?(?:note|k)?[\w_ ]+)(?: bui|\))/i,/oid[^\)]+; (m?[12][0-389][01]\w{3,6}[c-y])( bui|; wv|\))/i,/\b(mi[-_ ]?(?:a\d|one|one[_ ]plus|note lte|max|cc)?[_ ]?(?:\d?\w?)[_ ]?(?:plus|se|lite)?)(?: bui|\))/i],[[d,/_/g," "],[m,le],[p,x]],[/oid[^\)]+; (2\d{4}(283|rpbf)[cgl])( bui|\))/i,/\b(mi[-_ ]?(?:pad)(?:[\w_ ]+))(?: bui|\))/i],[[d,/_/g," "],[m,le],[p,N]],[/; (\w+) bui.+ oppo/i,/\b(cph[12]\d{3}|p(?:af|c[al]|d\w|e[ar])[mt]\d0|x9007|a101op)\b/i],[d,[m,"OPPO"],[p,x]],[/vivo (\w+)(?: bui|\))/i,/\b(v[12]\d{3}\w?[at])(?: bui|;)/i],[d,[m,"Vivo"],[p,x]],[/\b(rmx[1-3]\d{3})(?: bui|;|\))/i],[d,[m,"Realme"],[p,x]],[/\b(milestone|droid(?:[2-4x]| (?:bionic|x2|pro|razr))?:?( 4g)?)\b[\w ]+build\//i,/\bmot(?:orola)?[- ](\w*)/i,/((?:moto[\w\(\) ]+|xt\d{3,4}|nexus 6)(?= bui|\)))/i],[d,[m,oe],[p,x]],[/\b(mz60\d|xoom[2 ]{0,2}) build\//i],[d,[m,oe],[p,N]],[/((?=lg)?[vl]k\-?\d{3}) bui| 3\.[-\w; ]{10}lg?-([06cv9]{3,4})/i],[d,[m,se],[p,N]],[/(lm(?:-?f100[nv]?|-[\w\.]+)(?= bui|\))|nexus [45])/i,/\blg[-e;\/ ]+((?!browser|netcast|android tv)\w+)/i,/\blg-?([\d\w]+) bui/i],[d,[m,se],[p,x]],[/(ideatab[-\w ]+)/i,/lenovo ?(s[56]000[-\w]+|tab(?:[\w ]+)|yt[-\d\w]{6}|tb[-\d\w]{6})/i],[d,[m,"Lenovo"],[p,N]],[/(?:maemo|nokia).*(n900|lumia \d+)/i,/nokia[-_ ]?([-\w\.]*)/i],[[d,/_/g," "],[m,"Nokia"],[p,x]],[/(pixel c)\b/i],[d,[m,$],[p,N]],[/droid.+; (pixel[\daxl ]{0,6})(?: bui|\))/i],[d,[m,$],[p,x]],[/droid.+ (a?\d[0-2]{2}so|[c-g]\d{4}|so[-gl]\w+|xq-a\w[4-7][12])(?= bui|\).+chrome\/(?![1-6]{0,1}\d\.))/i],[d,[m,ee],[p,x]],[/sony tablet [ps]/i,/\b(?:sony)?sgp\w+(?: bui|\))/i],[[d,"Xperia Tablet"],[m,ee],[p,N]],[/ (kb2005|in20[12]5|be20[12][59])\b/i,/(?:one)?(?:plus)? (a\d0\d\d)(?: b|\))/i],[d,[m,"OnePlus"],[p,x]],[/(alexa)webm/i,/(kf[a-z]{2}wi|aeo[c-r]{2})( bui|\))/i,/(kf[a-z]+)( bui|\)).+silk\//i],[d,[m,z],[p,N]],[/((?:sd|kf)[0349hijorstuw]+)( bui|\)).+silk\//i],[[d,/(.+)/g,"Fire Phone $1"],[m,z],[p,x]],[/(playbook);[-\w\),; ]+(rim)/i],[d,m,[p,N]],[/\b((?:bb[a-f]|st[hv])100-\d)/i,/\(bb10; (\w+)/i],[d,[m,k],[p,x]],[/(?:\b|asus_)(transfo[prime ]{4,10} \w+|eeepc|slider \w+|nexus 7|padfone|p00[cj])/i],[d,[m,I],[p,N]],[/ (z[bes]6[027][012][km][ls]|zenfone \d\w?)\b/i],[d,[m,I],[p,x]],[/(nexus 9)/i],[d,[m,"HTC"],[p,N]],[/(htc)[-;_ ]{1,2}([\w ]+(?=\)| bui)|\w+)/i,/(zte)[- ]([\w ]+?)(?: bui|\/|\))/i,/(alcatel|geeksphone|nexian|panasonic(?!(?:;|\.))|sony(?!-bra))[-_ ]?([-\w]*)/i],[m,[d,/_/g," "],[p,x]],[/droid.+; ([ab][1-7]-?[0178a]\d\d?)/i],[d,[m,"Acer"],[p,N]],[/droid.+; (m[1-5] note) bui/i,/\bmz-([-\w]{2,})/i],[d,[m,"Meizu"],[p,x]],[/; ((?:power )?armor(?:[\w ]{0,8}))(?: bui|\))/i],[d,[m,"Ulefone"],[p,x]],[/(blackberry|benq|palm(?=\-)|sonyericsson|acer|asus|dell|meizu|motorola|polytron|infinix|tecno)[-_ ]?([-\w]*)/i,/(hp) ([\w ]+\w)/i,/(asus)-?(\w+)/i,/(microsoft); (lumia[\w ]+)/i,/(lenovo)[-_ ]?([-\w]+)/i,/(jolla)/i,/(oppo) ?([\w ]+) bui/i],[m,d,[p,x]],[/(kobo)\s(ereader|touch)/i,/(archos) (gamepad2?)/i,/(hp).+(touchpad(?!.+tablet)|tablet)/i,/(kindle)\/([\w\.]+)/i,/(nook)[\w ]+build\/(\w+)/i,/(dell) (strea[kpr\d ]*[\dko])/i,/(le[- ]+pan)[- ]+(\w{1,9}) bui/i,/(trinity)[- ]*(t\d{3}) bui/i,/(gigaset)[- ]+(q\w{1,9}) bui/i,/(vodafone) ([\w ]+)(?:\)| bui)/i],[m,d,[p,N]],[/(surface duo)/i],[d,[m,_],[p,N]],[/droid [\d\.]+; (fp\du?)(?: b|\))/i],[d,[m,"Fairphone"],[p,x]],[/(u304aa)/i],[d,[m,"AT&T"],[p,x]],[/\bsie-(\w*)/i],[d,[m,"Siemens"],[p,x]],[/\b(rct\w+) b/i],[d,[m,"RCA"],[p,N]],[/\b(venue[\d ]{2,7}) b/i],[d,[m,"Dell"],[p,N]],[/\b(q(?:mv|ta)\w+) b/i],[d,[m,"Verizon"],[p,N]],[/\b(?:barnes[& ]+noble |bn[rt])([\w\+ ]*) b/i],[d,[m,"Barnes & Noble"],[p,N]],[/\b(tm\d{3}\w+) b/i],[d,[m,"NuVision"],[p,N]],[/\b(k88) b/i],[d,[m,"ZTE"],[p,N]],[/\b(nx\d{3}j) b/i],[d,[m,"ZTE"],[p,x]],[/\b(gen\d{3}) b.+49h/i],[d,[m,"Swiss"],[p,x]],[/\b(zur\d{3}) b/i],[d,[m,"Swiss"],[p,N]],[/\b((zeki)?tb.*\b) b/i],[d,[m,"Zeki"],[p,N]],[/\b([yr]\d{2}) b/i,/\b(dragon[- ]+touch |dt)(\w{5}) b/i],[[m,"Dragon Touch"],d,[p,N]],[/\b(ns-?\w{0,9}) b/i],[d,[m,"Insignia"],[p,N]],[/\b((nxa|next)-?\w{0,9}) b/i],[d,[m,"NextBook"],[p,N]],[/\b(xtreme\_)?(v(1[045]|2[015]|[3469]0|7[05])) b/i],[[m,"Voice"],d,[p,x]],[/\b(lvtel\-)?(v1[12]) b/i],[[m,"LvTel"],d,[p,x]],[/\b(ph-1) /i],[d,[m,"Essential"],[p,x]],[/\b(v(100md|700na|7011|917g).*\b) b/i],[d,[m,"Envizen"],[p,N]],[/\b(trio[-\w\. ]+) b/i],[d,[m,"MachSpeed"],[p,N]],[/\btu_(1491) b/i],[d,[m,"Rotor"],[p,N]],[/(shield[\w ]+) b/i],[d,[m,"Nvidia"],[p,N]],[/(sprint) (\w+)/i],[m,d,[p,x]],[/(kin\.[onetw]{3})/i],[[d,/\./g," "],[m,_],[p,x]],[/droid.+; (cc6666?|et5[16]|mc[239][23]x?|vc8[03]x?)\)/i],[d,[m,we],[p,N]],[/droid.+; (ec30|ps20|tc[2-8]\d[kx])\)/i],[d,[m,we],[p,x]],[/smart-tv.+(samsung)/i],[m,[p,O]],[/hbbtv.+maple;(\d+)/i],[[d,/^/,"SmartTV"],[m,T],[p,O]],[/(nux; netcast.+smarttv|lg (netcast\.tv-201\d|android tv))/i],[[m,se],[p,O]],[/(apple) ?tv/i],[m,[d,L+" TV"],[p,O]],[/crkey/i],[[d,F+"cast"],[m,$],[p,O]],[/droid.+aft(\w+)( bui|\))/i],[d,[m,z],[p,O]],[/\(dtv[\);].+(aquos)/i,/(aquos-tv[\w ]+)\)/i],[d,[m,G],[p,O]],[/(bravia[\w ]+)( bui|\))/i],[d,[m,ee],[p,O]],[/(mitv-\w{5}) bui/i],[d,[m,le],[p,O]],[/Hbbtv.*(technisat) (.*);/i],[m,d,[p,O]],[/\b(roku)[\dx]*[\)\/]((?:dvp-)?[\d\.]*)/i,/hbbtv\/\d+\.\d+\.\d+ +\([\w\+ ]*; *([\w\d][^;]*);([^;]*)/i],[[m,Tr],[d,Tr],[p,O]],[/\b(android tv|smart[- ]?tv|opera tv|tv; rv:)\b/i],[[p,O]],[/(ouya)/i,/(nintendo) ([wids3utch]+)/i],[m,d,[p,w]],[/droid.+; (shield) bui/i],[d,[m,"Nvidia"],[p,w]],[/(playstation [345portablevi]+)/i],[d,[m,ee],[p,w]],[/\b(xbox(?: one)?(?!; xbox))[\); ]/i],[d,[m,_],[p,w]],[/((pebble))app/i],[m,d,[p,A]],[/(watch)(?: ?os[,\/]|\d,\d\/)[\d\.]+/i],[d,[m,L],[p,A]],[/droid.+; (glass) \d/i],[d,[m,$],[p,A]],[/droid.+; (wt63?0{2,3})\)/i],[d,[m,we],[p,A]],[/(quest( 2| pro)?)/i],[d,[m,Oe],[p,A]],[/(tesla)(?: qtcarbrowser|\/[-\w\.]+)/i],[m,[p,D]],[/(aeobc)\b/i],[d,[m,z],[p,D]],[/droid .+?; ([^;]+?)(?: bui|; wv\)|\) applew).+? mobile safari/i],[d,[p,x]],[/droid .+?; ([^;]+?)(?: bui|\) applew).+?(?! mobile) safari/i],[d,[p,N]],[/\b((tablet|tab)[;\/]|focus\/\d(?!.+mobile))/i],[[p,N]],[/(phone|mobile(?:[;\/]| [ \w\/\.]*safari)|pda(?=.+windows ce))/i],[[p,x]],[/(android[-\w\. ]{0,9});.+buil/i],[d,[m,"Generic"]]],engine:[[/windows.+ edge\/([\w\.]+)/i],[g,[h,C+"HTML"]],[/webkit\/537\.36.+chrome\/(?!27)([\w\.]+)/i],[g,[h,"Blink"]],[/(presto)\/([\w\.]+)/i,/(webkit|trident|netfront|netsurf|amaya|lynx|w3m|goanna)\/([\w\.]+)/i,/ekioh(flow)\/([\w\.]+)/i,/(khtml|tasman|links)[\/ ]\(?([\w\.]+)/i,/(icab)[\/ ]([23]\.[\d\.]+)/i,/\b(libweb)/i],[h,g],[/rv\:([\w\.]{1,9})\b.+(gecko)/i],[g,h]],os:[[/microsoft (windows) (vista|xp)/i],[h,g],[/(windows (?:phone(?: os)?|mobile))[\/ ]?([\d\.\w ]*)/i],[h,[g,$t,jn]],[/windows nt 6\.2; (arm)/i,/windows[\/ ]?([ntce\d\. ]+\w)(?!.+xbox)/i,/(?:win(?=3|9|n)|win 9x )([nt\d\.]+)/i],[[g,$t,jn],[h,"Windows"]],[/ip[honead]{2,4}\b(?:.*os ([\w]+) like mac|; opera)/i,/(?:ios;fbsv\/|iphone.+ios[\/ ])([\d\.]+)/i,/cfnetwork\/.+darwin/i],[[g,/_/g,"."],[h,"iOS"]],[/(mac os x) ?([\w\. ]*)/i,/(macintosh|mac_powerpc\b)(?!.+haiku)/i],[[h,ve],[g,/_/g,"."]],[/droid ([\w\.]+)\b.+(android[- ]x86|harmonyos)/i],[g,h],[/(android|webos|qnx|bada|rim tablet os|maemo|meego|sailfish)[-\/ ]?([\w\.]*)/i,/(blackberry)\w*\/([\w\.]*)/i,/(tizen|kaios)[\/ ]([\w\.]+)/i,/\((series40);/i],[h,g],[/\(bb(10);/i],[g,[h,k]],[/(?:symbian ?os|symbos|s60(?=;)|series60)[-\/ ]?([\w\.]*)/i],[g,[h,"Symbian"]],[/mozilla\/[\d\.]+ \((?:mobile|tablet|tv|mobile; [\w ]+); rv:.+ gecko\/([\w\.]+)/i],[g,[h,U+" OS"]],[/web0s;.+rt(tv)/i,/\b(?:hp)?wos(?:browser)?\/([\w\.]+)/i],[g,[h,"webOS"]],[/watch(?: ?os[,\/]|\d,\d\/)([\d\.]+)/i],[g,[h,"watchOS"]],[/crkey\/([\d\.]+)/i],[g,[h,F+"cast"]],[/(cros) [\w]+(?:\)| ([\w\.]+)\b)/i],[[h,qe],g],[/panasonic;(viera)/i,/(netrange)mmh/i,/(nettv)\/(\d+\.[\w\.]+)/i,/(nintendo|playstation) ([wids345portablevuch]+)/i,/(xbox); +xbox ([^\);]+)/i,/\b(joli|palm)\b ?(?:os)?\/?([\w\.]*)/i,/(mint)[\/\(\) ]?(\w*)/i,/(mageia|vectorlinux)[; ]/i,/([kxln]?ubuntu|debian|suse|opensuse|gentoo|arch(?= linux)|slackware|fedora|mandriva|centos|pclinuxos|red ?hat|zenwalk|linpus|raspbian|plan 9|minix|risc os|contiki|deepin|manjaro|elementary os|sabayon|linspire)(?: gnu\/linux)?(?: enterprise)?(?:[- ]linux)?(?:-gnu)?[-\/ ]?(?!chrom|package)([-\w\.]*)/i,/(hurd|linux) ?([\w\.]*)/i,/(gnu) ?([\w\.]*)/i,/\b([-frentopcghs]{0,5}bsd|dragonfly)[\/ ]?(?!amd|[ix346]{1,2}86)([\w\.]*)/i,/(haiku) (\w+)/i],[h,g],[/(sunos) ?([\w\.\d]*)/i],[[h,"Solaris"],g],[/((?:open)?solaris)[-\/ ]?([\w\.]*)/i,/(aix) ((\d)(?=\.|\)| )[\w\.])*/i,/\b(beos|os\/2|amigaos|morphos|openvms|fuchsia|hp-ux|serenityos)/i,/(unix) ?([\w\.]*)/i],[h,g]]},ye=function(me,Pe){if(typeof me===l&&(Pe=me,me=n),!(this instanceof ye))return new ye(me,Pe).getResult();var q=typeof r!==u&&r.navigator?r.navigator:n,K=me||(q&&q.userAgent?q.userAgent:a),de=q&&q.userAgentData?q.userAgentData:n,Z=Pe?ct(Zr,Pe):Zr,X=q&&q.userAgent==K;return this.getBrowser=function(){var J={};return J[h]=n,J[g]=n,At.call(J,K,Z.browser),J[f]=yn(J[g]),X&&q&&q.brave&&typeof q.brave.isBrave==s&&(J[h]="Brave"),J},this.getCPU=function(){var J={};return J[v]=n,At.call(J,K,Z.cpu),J},this.getDevice=function(){var J={};return J[m]=n,J[d]=n,J[p]=n,At.call(J,K,Z.device),X&&!J[p]&&de&&de.mobile&&(J[p]=x),X&&J[d]=="Macintosh"&&q&&typeof q.standalone!==u&&q.maxTouchPoints&&q.maxTouchPoints>2&&(J[d]="iPad",J[p]=N),J},this.getEngine=function(){var J={};return J[h]=n,J[g]=n,At.call(J,K,Z.engine),J},this.getOS=function(){var J={};return J[h]=n,J[g]=n,At.call(J,K,Z.os),X&&!J[h]&&de&&de.platform!="Unknown"&&(J[h]=de.platform.replace(/chrome os/i,qe).replace(/macos/i,ve)),J},this.getResult=function(){return{ua:this.getUA(),browser:this.getBrowser(),engine:this.getEngine(),os:this.getOS(),device:this.getDevice(),cpu:this.getCPU()}},this.getUA=function(){return K},this.setUA=function(J){return K=typeof J===c&&J.length>H?Tr(J,H):J,this},this.setUA(K),this};ye.VERSION=i,ye.BROWSER=ft([h,g,f]),ye.CPU=ft([v]),ye.DEVICE=ft([d,m,p,w,x,O,N,A,D]),ye.ENGINE=ye.OS=ft([h,g]),e.exports&&(t=e.exports=ye),t.UAParser=ye;var Ar=typeof r!==u&&(r.jQuery||r.Zepto);if(Ar&&!Ar.ua){var ut=new ye;Ar.ua=ut.getResult(),Ar.ua.get=function(){return ut.getUA()},Ar.ua.set=function(me){ut.setUA(me);var Pe=ut.getResult();for(var q in Pe)Ar.ua[q]=Pe[q]}}})(typeof window=="object"?window:xe)})($0,$0.exports);var vT=$0.exports;Object.defineProperty(ce,"__esModule",{value:!0});function yT(e){return e&&typeof e=="object"&&"default"in e?e.default:e}var _t=eu,rt=yT(_t),wb=vT,Fn=new wb,Mt=Fn.getBrowser(),wT=Fn.getCPU(),or=Fn.getDevice(),Bf=Fn.getEngine(),Bn=Fn.getOS(),Ja=Fn.getUA(),xb=function(t){return Fn.setUA(t)},eo=function(t){if(!t){console.error("No userAgent string was provided");return}var r=new wb(t);return{UA:r,browser:r.getBrowser(),cpu:r.getCPU(),device:r.getDevice(),engine:r.getEngine(),os:r.getOS(),ua:r.getUA(),setUserAgent:function(i){return r.setUA(i)}}},Eb=Object.freeze({ClientUAInstance:Fn,browser:Mt,cpu:wT,device:or,engine:Bf,os:Bn,ua:Ja,setUa:xb,parseUserAgent:eo});function B1(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter(function(i){return Object.getOwnPropertyDescriptor(e,i).enumerable})),r.push.apply(r,n)}return r}function xT(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?arguments[t]:{};t%2?B1(Object(r),!0).forEach(function(n){TT(e,n,r[n])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):B1(Object(r)).forEach(function(n){Object.defineProperty(e,n,Object.getOwnPropertyDescriptor(r,n))})}return e}function va(e){"@babel/helpers - typeof";return typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?va=function(t){return typeof t}:va=function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},va(e)}function ET(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function z1(e,t){for(var r=0;r<t.length;r++){var n=t[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}function ST(e,t,r){return t&&z1(e.prototype,t),r&&z1(e,r),e}function TT(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}function U0(){return U0=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},U0.apply(this,arguments)}function AT(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&q0(e,t)}function H0(e){return H0=Object.setPrototypeOf?Object.getPrototypeOf:function(r){return r.__proto__||Object.getPrototypeOf(r)},H0(e)}function q0(e,t){return q0=Object.setPrototypeOf||function(n,i){return n.__proto__=i,n},q0(e,t)}function kT(e,t){if(e==null)return{};var r={},n=Object.keys(e),i,a;for(a=0;a<n.length;a++)i=n[a],!(t.indexOf(i)>=0)&&(r[i]=e[i]);return r}function wr(e,t){if(e==null)return{};var r=kT(e,t),n,i;if(Object.getOwnPropertySymbols){var a=Object.getOwnPropertySymbols(e);for(i=0;i<a.length;i++)n=a[i],!(t.indexOf(n)>=0)&&Object.prototype.propertyIsEnumerable.call(e,n)&&(r[n]=e[n])}return r}function os(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function OT(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return os(e)}function NT(e,t){return _T(e)||CT(e,t)||MT(e,t)||RT()}function _T(e){if(Array.isArray(e))return e}function CT(e,t){var r=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(r!=null){var n=[],i=!0,a=!1,o,s;try{for(r=r.call(e);!(i=(o=r.next()).done)&&(n.push(o.value),!(t&&n.length===t));i=!0);}catch(u){a=!0,s=u}finally{try{!i&&r.return!=null&&r.return()}finally{if(a)throw s}}return n}}function MT(e,t){if(e){if(typeof e=="string")return $1(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);if(r==="Object"&&e.constructor&&(r=e.constructor.name),r==="Map"||r==="Set")return Array.from(e);if(r==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return $1(e,t)}}function $1(e,t){(t==null||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function RT(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}var Ot={Mobile:"mobile",Tablet:"tablet",SmartTv:"smarttv",Console:"console",Wearable:"wearable",Embedded:"embedded",Browser:void 0},Wt={Chrome:"Chrome",Firefox:"Firefox",Opera:"Opera",Yandex:"Yandex",Safari:"Safari",InternetExplorer:"Internet Explorer",Edge:"Edge",Chromium:"Chromium",Ie:"IE",MobileSafari:"Mobile Safari",EdgeChromium:"Edge Chromium",MIUI:"MIUI Browser",SamsungBrowser:"Samsung Browser"},ta={IOS:"iOS",Android:"Android",WindowsPhone:"Windows Phone",Windows:"Windows",MAC_OS:"Mac OS"},IT={isMobile:!1,isTablet:!1,isBrowser:!1,isSmartTV:!1,isConsole:!1,isWearable:!1},PT=function(t){switch(t){case Ot.Mobile:return{isMobile:!0};case Ot.Tablet:return{isTablet:!0};case Ot.SmartTv:return{isSmartTV:!0};case Ot.Console:return{isConsole:!0};case Ot.Wearable:return{isWearable:!0};case Ot.Browser:return{isBrowser:!0};case Ot.Embedded:return{isEmbedded:!0};default:return IT}},DT=function(t){return xb(t)},Ae=function(t){var r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"none";return t||r},zf=function(){return typeof window<"u"&&(window.navigator||navigator)?window.navigator||navigator:!1},$f=function(t){var r=zf();return r&&r.platform&&(r.platform.indexOf(t)!==-1||r.platform==="MacIntel"&&r.maxTouchPoints>1&&!window.MSStream)},LT=function(t,r,n,i,a){return{isBrowser:t,browserMajorVersion:Ae(r.major),browserFullVersion:Ae(r.version),browserName:Ae(r.name),engineName:Ae(n.name),engineVersion:Ae(n.version),osName:Ae(i.name),osVersion:Ae(i.version),userAgent:Ae(a)}},U1=function(t,r,n,i){return xT({},t,{vendor:Ae(r.vendor),model:Ae(r.model),os:Ae(n.name),osVersion:Ae(n.version),ua:Ae(i)})},FT=function(t,r,n,i){return{isSmartTV:t,engineName:Ae(r.name),engineVersion:Ae(r.version),osName:Ae(n.name),osVersion:Ae(n.version),userAgent:Ae(i)}},BT=function(t,r,n,i){return{isConsole:t,engineName:Ae(r.name),engineVersion:Ae(r.version),osName:Ae(n.name),osVersion:Ae(n.version),userAgent:Ae(i)}},zT=function(t,r,n,i){return{isWearable:t,engineName:Ae(r.name),engineVersion:Ae(r.version),osName:Ae(n.name),osVersion:Ae(n.version),userAgent:Ae(i)}},$T=function(t,r,n,i,a){return{isEmbedded:t,vendor:Ae(r.vendor),model:Ae(r.model),engineName:Ae(n.name),engineVersion:Ae(n.version),osName:Ae(i.name),osVersion:Ae(i.version),userAgent:Ae(a)}};function UT(e){var t=e?eo(e):Eb,r=t.device,n=t.browser,i=t.engine,a=t.os,o=t.ua,s=PT(r.type),u=s.isBrowser,l=s.isMobile,c=s.isTablet,f=s.isSmartTV,d=s.isConsole,h=s.isWearable,p=s.isEmbedded;if(u)return LT(u,n,i,a,o);if(f)return FT(f,i,a,o);if(d)return BT(d,i,a,o);if(l||c)return U1(s,r,a,o);if(h)return zT(h,i,a,o);if(p)return $T(p,r,i,a,o)}var Sb=function(t){var r=t.type;return r===Ot.Mobile},Tb=function(t){var r=t.type;return r===Ot.Tablet},Ab=function(t){var r=t.type;return r===Ot.Mobile||r===Ot.Tablet},kb=function(t){var r=t.type;return r===Ot.SmartTv},Rs=function(t){var r=t.type;return r===Ot.Browser},Ob=function(t){var r=t.type;return r===Ot.Wearable},Nb=function(t){var r=t.type;return r===Ot.Console},_b=function(t){var r=t.type;return r===Ot.Embedded},Cb=function(t){var r=t.vendor;return Ae(r)},Mb=function(t){var r=t.model;return Ae(r)},Rb=function(t){var r=t.type;return Ae(r,"browser")},Ib=function(t){var r=t.name;return r===ta.Android},Pb=function(t){var r=t.name;return r===ta.Windows},Db=function(t){var r=t.name;return r===ta.MAC_OS},Lb=function(t){var r=t.name;return r===ta.WindowsPhone},Fb=function(t){var r=t.name;return r===ta.IOS},Bb=function(t){var r=t.version;return Ae(r)},zb=function(t){var r=t.name;return Ae(r)},$b=function(t){var r=t.name;return r===Wt.Chrome},Ub=function(t){var r=t.name;return r===Wt.Firefox},Hb=function(t){var r=t.name;return r===Wt.Chromium},Is=function(t){var r=t.name;return r===Wt.Edge},qb=function(t){var r=t.name;return r===Wt.Yandex},jb=function(t){var r=t.name;return r===Wt.Safari||r===Wt.MobileSafari},Vb=function(t){var r=t.name;return r===Wt.MobileSafari},Gb=function(t){var r=t.name;return r===Wt.Opera},Wb=function(t){var r=t.name;return r===Wt.InternetExplorer||r===Wt.Ie},Kb=function(t){var r=t.name;return r===Wt.MIUI},Xb=function(t){var r=t.name;return r===Wt.SamsungBrowser},Yb=function(t){var r=t.version;return Ae(r)},Zb=function(t){var r=t.major;return Ae(r)},Qb=function(t){var r=t.name;return Ae(r)},Jb=function(t){var r=t.name;return Ae(r)},e4=function(t){var r=t.version;return Ae(r)},t4=function(){var t=zf(),r=t&&t.userAgent&&t.userAgent.toLowerCase();return typeof r=="string"?/electron/.test(r):!1},Pi=function(t){return typeof t=="string"&&t.indexOf("Edg/")!==-1},r4=function(){var t=zf();return t&&(/iPad|iPhone|iPod/.test(t.platform)||t.platform==="MacIntel"&&t.maxTouchPoints>1)&&!window.MSStream},zr=function(){return $f("iPad")},n4=function(){return $f("iPhone")},i4=function(){return $f("iPod")},a4=function(t){return Ae(t)};function o4(e){var t=e||Eb,r=t.device,n=t.browser,i=t.os,a=t.engine,o=t.ua;return{isSmartTV:kb(r),isConsole:Nb(r),isWearable:Ob(r),isEmbedded:_b(r),isMobileSafari:Vb(n)||zr(),isChromium:Hb(n),isMobile:Ab(r)||zr(),isMobileOnly:Sb(r),isTablet:Tb(r)||zr(),isBrowser:Rs(r),isDesktop:Rs(r),isAndroid:Ib(i),isWinPhone:Lb(i),isIOS:Fb(i)||zr(),isChrome:$b(n),isFirefox:Ub(n),isSafari:jb(n),isOpera:Gb(n),isIE:Wb(n),osVersion:Bb(i),osName:zb(i),fullBrowserVersion:Yb(n),browserVersion:Zb(n),browserName:Qb(n),mobileVendor:Cb(r),mobileModel:Mb(r),engineName:Jb(a),engineVersion:e4(a),getUA:a4(o),isEdge:Is(n)||Pi(o),isYandex:qb(n),deviceType:Rb(r),isIOS13:r4(),isIPad13:zr(),isIPhone13:n4(),isIPod13:i4(),isElectron:t4(),isEdgeChromium:Pi(o),isLegacyEdge:Is(n)&&!Pi(o),isWindows:Pb(i),isMacOs:Db(i),isMIUI:Kb(n),isSamsungBrowser:Xb(n)}}var s4=kb(or),u4=Nb(or),l4=Ob(or),HT=_b(or),qT=Vb(Mt)||zr(),jT=Hb(Mt),Au=Ab(or)||zr(),c4=Sb(or),f4=Tb(or)||zr(),d4=Rs(or),VT=Rs(or),h4=Ib(Bn),p4=Lb(Bn),m4=Fb(Bn)||zr(),GT=$b(Mt),WT=Ub(Mt),KT=jb(Mt),XT=Gb(Mt),g4=Wb(Mt),YT=Bb(Bn),ZT=zb(Bn),QT=Yb(Mt),JT=Zb(Mt),eA=Qb(Mt),tA=Cb(or),rA=Mb(or),nA=Jb(Bf),iA=e4(Bf),aA=a4(Ja),oA=Is(Mt)||Pi(Ja),sA=qb(Mt),uA=Rb(or),lA=r4(),cA=zr(),fA=n4(),dA=i4(),hA=t4(),pA=Pi(Ja),mA=Is(Mt)&&!Pi(Ja),gA=Pb(Bn),bA=Db(Bn),vA=Kb(Mt),yA=Xb(Mt),wA=function(t){if(!t||typeof t!="string"){console.error("No valid user agent string was provided");return}var r=eo(t),n=r.device,i=r.browser,a=r.os,o=r.engine,s=r.ua;return o4({device:n,browser:i,os:a,engine:o,ua:s})},xA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return h4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},EA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return d4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},SA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return g4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},TA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return m4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},AA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return Au?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},kA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return f4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},OA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return p4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},NA=function(t){var r=t.renderWithFragment,n=t.children;t.viewClassName,t.style;var i=wr(t,["renderWithFragment","children","viewClassName","style"]);return c4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},_A=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return s4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},CA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return u4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},MA=function(t){var r=t.renderWithFragment,n=t.children,i=wr(t,["renderWithFragment","children"]);return l4?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",i,n):null},RA=function(t){var r=t.renderWithFragment,n=t.children;t.viewClassName,t.style;var i=t.condition,a=wr(t,["renderWithFragment","children","viewClassName","style","condition"]);return i?r?rt.createElement(_t.Fragment,null,n):rt.createElement("div",a,n):null};function IA(e){return function(t){AT(r,t);function r(n){var i;return ET(this,r),i=OT(this,H0(r).call(this,n)),i.isEventListenerAdded=!1,i.handleOrientationChange=i.handleOrientationChange.bind(os(i)),i.onOrientationChange=i.onOrientationChange.bind(os(i)),i.onPageLoad=i.onPageLoad.bind(os(i)),i.state={isLandscape:!1,isPortrait:!1},i}return ST(r,[{key:"handleOrientationChange",value:function(){this.isEventListenerAdded||(this.isEventListenerAdded=!0);var i=window.innerWidth>window.innerHeight?90:0;this.setState({isPortrait:i===0,isLandscape:i===90})}},{key:"onOrientationChange",value:function(){this.handleOrientationChange()}},{key:"onPageLoad",value:function(){this.handleOrientationChange()}},{key:"componentDidMount",value:function(){(typeof window>"u"?"undefined":va(window))!==void 0&&Au&&(this.isEventListenerAdded?window.removeEventListener("load",this.onPageLoad,!1):(this.handleOrientationChange(),window.addEventListener("load",this.onPageLoad,!1)),window.addEventListener("resize",this.onOrientationChange,!1))}},{key:"componentWillUnmount",value:function(){window.removeEventListener("resize",this.onOrientationChange,!1)}},{key:"render",value:function(){return rt.createElement(e,U0({},this.props,{isLandscape:this.state.isLandscape,isPortrait:this.state.isPortrait}))}}]),r}(rt.Component)}function PA(){var e=_t.useState(function(){var a=window.innerWidth>window.innerHeight?90:0;return{isPortrait:a===0,isLandscape:a===90,orientation:a===0?"portrait":"landscape"}}),t=NT(e,2),r=t[0],n=t[1],i=_t.useCallback(function(){var a=window.innerWidth>window.innerHeight?90:0,o={isPortrait:a===0,isLandscape:a===90,orientation:a===0?"portrait":"landscape"};r.orientation!==o.orientation&&n(o)},[r.orientation]);return _t.useEffect(function(){return(typeof window>"u"?"undefined":va(window))!==void 0&&Au&&(i(),window.addEventListener("load",i,!1),window.addEventListener("resize",i,!1)),function(){window.removeEventListener("resize",i,!1),window.removeEventListener("load",i,!1)}},[i]),r}function b4(e){var t=e||window.navigator.userAgent;return eo(t)}function DA(e){var t=e||window.navigator.userAgent,r=b4(t),n=o4(r);return[n,r]}ce.AndroidView=xA;ce.BrowserTypes=Wt;ce.BrowserView=EA;ce.ConsoleView=CA;ce.CustomView=RA;ce.IEView=SA;ce.IOSView=TA;ce.MobileOnlyView=NA;ce.MobileView=AA;ce.OsTypes=ta;ce.SmartTVView=_A;ce.TabletView=kA;ce.WearableView=MA;ce.WinPhoneView=OA;ce.browserName=eA;ce.browserVersion=JT;ce.deviceDetect=UT;ce.deviceType=uA;ce.engineName=nA;ce.engineVersion=iA;ce.fullBrowserVersion=QT;ce.getSelectorsByUserAgent=wA;ce.getUA=aA;ce.isAndroid=h4;ce.isBrowser=d4;ce.isChrome=GT;ce.isChromium=jT;ce.isConsole=u4;ce.isDesktop=VT;ce.isEdge=oA;ce.isEdgeChromium=pA;ce.isElectron=hA;ce.isEmbedded=HT;ce.isFirefox=WT;ce.isIE=g4;ce.isIOS=m4;ce.isIOS13=lA;ce.isIPad13=cA;ce.isIPhone13=fA;ce.isIPod13=dA;ce.isLegacyEdge=mA;ce.isMIUI=vA;ce.isMacOs=bA;var LA=ce.isMobile=Au;ce.isMobileOnly=c4;ce.isMobileSafari=qT;ce.isOpera=XT;ce.isSafari=KT;ce.isSamsungBrowser=yA;ce.isSmartTV=s4;ce.isTablet=f4;ce.isWearable=l4;ce.isWinPhone=p4;ce.isWindows=gA;ce.isYandex=sA;ce.mobileModel=rA;ce.mobileVendor=tA;ce.osName=ZT;ce.osVersion=YT;ce.parseUserAgent=eo;ce.setUserAgent=DT;ce.useDeviceData=b4;ce.useDeviceSelectors=DA;ce.useMobileOrientation=PA;ce.withOrientationChange=IA;function Ps(){return Ps=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},Ps.apply(this,arguments)}function Uf(e,t){if(e==null)return{};var r={},n=Object.keys(e),i,a;for(a=0;a<n.length;a++)i=n[a],!(t.indexOf(i)>=0)&&(r[i]=e[i]);return r}function j0(e,t){return j0=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,i){return n.__proto__=i,n},j0(e,t)}function v4(e,t){e.prototype=Object.create(t.prototype),e.prototype.constructor=e,j0(e,t)}function FA(e,t){return e.classList?!!t&&e.classList.contains(t):(" "+(e.className.baseVal||e.className)+" ").indexOf(" "+t+" ")!==-1}function BA(e,t){e.classList?e.classList.add(t):FA(e,t)||(typeof e.className=="string"?e.className=e.className+" "+t:e.setAttribute("class",(e.className&&e.className.baseVal||"")+" "+t))}function H1(e,t){return e.replace(new RegExp("(^|\\s)"+t+"(?:\\s|$)","g"),"$1").replace(/\s+/g," ").replace(/^\s*|\s*$/g,"")}function zA(e,t){e.classList?e.classList.remove(t):typeof e.className=="string"?e.className=H1(e.className,t):e.setAttribute("class",H1(e.className&&e.className.baseVal||"",t))}const q1={disabled:!1},y4=React.createContext(null);var w4=function(t){return t.scrollTop},fa="unmounted",Yn="exited",Zn="entering",Ai="entered",V0="exiting",bn=function(e){v4(t,e);function t(n,i){var a;a=e.call(this,n,i)||this;var o=i,s=o&&!o.isMounting?n.enter:n.appear,u;return a.appearStatus=null,n.in?s?(u=Yn,a.appearStatus=Zn):u=Ai:n.unmountOnExit||n.mountOnEnter?u=fa:u=Yn,a.state={status:u},a.nextCallback=null,a}t.getDerivedStateFromProps=function(i,a){var o=i.in;return o&&a.status===fa?{status:Yn}:null};var r=t.prototype;return r.componentDidMount=function(){this.updateStatus(!0,this.appearStatus)},r.componentDidUpdate=function(i){var a=null;if(i!==this.props){var o=this.state.status;this.props.in?o!==Zn&&o!==Ai&&(a=Zn):(o===Zn||o===Ai)&&(a=V0)}this.updateStatus(!1,a)},r.componentWillUnmount=function(){this.cancelNextCallback()},r.getTimeouts=function(){var i=this.props.timeout,a,o,s;return a=o=s=i,i!=null&&typeof i!="number"&&(a=i.exit,o=i.enter,s=i.appear!==void 0?i.appear:o),{exit:a,enter:o,appear:s}},r.updateStatus=function(i,a){if(i===void 0&&(i=!1),a!==null)if(this.cancelNextCallback(),a===Zn){if(this.props.unmountOnExit||this.props.mountOnEnter){var o=this.props.nodeRef?this.props.nodeRef.current:ReactDOM.findDOMNode(this);o&&w4(o)}this.performEnter(i)}else this.performExit();else this.props.unmountOnExit&&this.state.status===Yn&&this.setState({status:fa})},r.performEnter=function(i){var a=this,o=this.props.enter,s=this.context?this.context.isMounting:i,u=this.props.nodeRef?[s]:[ReactDOM.findDOMNode(this),s],l=u[0],c=u[1],f=this.getTimeouts(),d=s?f.appear:f.enter;if(!i&&!o||q1.disabled){this.safeSetState({status:Ai},function(){a.props.onEntered(l)});return}this.props.onEnter(l,c),this.safeSetState({status:Zn},function(){a.props.onEntering(l,c),a.onTransitionEnd(d,function(){a.safeSetState({status:Ai},function(){a.props.onEntered(l,c)})})})},r.performExit=function(){var i=this,a=this.props.exit,o=this.getTimeouts(),s=this.props.nodeRef?void 0:ReactDOM.findDOMNode(this);if(!a||q1.disabled){this.safeSetState({status:Yn},function(){i.props.onExited(s)});return}this.props.onExit(s),this.safeSetState({status:V0},function(){i.props.onExiting(s),i.onTransitionEnd(o.exit,function(){i.safeSetState({status:Yn},function(){i.props.onExited(s)})})})},r.cancelNextCallback=function(){this.nextCallback!==null&&(this.nextCallback.cancel(),this.nextCallback=null)},r.safeSetState=function(i,a){a=this.setNextCallback(a),this.setState(i,a)},r.setNextCallback=function(i){var a=this,o=!0;return this.nextCallback=function(s){o&&(o=!1,a.nextCallback=null,i(s))},this.nextCallback.cancel=function(){o=!1},this.nextCallback},r.onTransitionEnd=function(i,a){this.setNextCallback(a);var o=this.props.nodeRef?this.props.nodeRef.current:ReactDOM.findDOMNode(this),s=i==null&&!this.props.addEndListener;if(!o||s){setTimeout(this.nextCallback,0);return}if(this.props.addEndListener){var u=this.props.nodeRef?[this.nextCallback]:[o,this.nextCallback],l=u[0],c=u[1];this.props.addEndListener(l,c)}i!=null&&setTimeout(this.nextCallback,i)},r.render=function(){var i=this.state.status;if(i===fa)return null;var a=this.props,o=a.children;a.in,a.mountOnEnter,a.unmountOnExit,a.appear,a.enter,a.exit,a.timeout,a.addEndListener,a.onEnter,a.onEntering,a.onEntered,a.onExit,a.onExiting,a.onExited,a.nodeRef;var s=Uf(a,["children","in","mountOnEnter","unmountOnExit","appear","enter","exit","timeout","addEndListener","onEnter","onEntering","onEntered","onExit","onExiting","onExited","nodeRef"]);return React.createElement(y4.Provider,{value:null},typeof o=="function"?o(i,s):React.cloneElement(React.Children.only(o),s))},t}(React.Component);bn.contextType=y4;bn.propTypes={};function bi(){}bn.defaultProps={in:!1,mountOnEnter:!1,unmountOnExit:!1,appear:!1,enter:!0,exit:!0,onEnter:bi,onEntering:bi,onEntered:bi,onExit:bi,onExiting:bi,onExited:bi};bn.UNMOUNTED=fa;bn.EXITED=Yn;bn.ENTERING=Zn;bn.ENTERED=Ai;bn.EXITING=V0;const $A=bn;var UA=function(t,r){return t&&r&&r.split(" ").forEach(function(n){return BA(t,n)})},Pl=function(t,r){return t&&r&&r.split(" ").forEach(function(n){return zA(t,n)})},Hf=function(e){v4(t,e);function t(){for(var n,i=arguments.length,a=new Array(i),o=0;o<i;o++)a[o]=arguments[o];return n=e.call.apply(e,[this].concat(a))||this,n.appliedClasses={appear:{},enter:{},exit:{}},n.onEnter=function(s,u){var l=n.resolveArguments(s,u),c=l[0],f=l[1];n.removeClasses(c,"exit"),n.addClass(c,f?"appear":"enter","base"),n.props.onEnter&&n.props.onEnter(s,u)},n.onEntering=function(s,u){var l=n.resolveArguments(s,u),c=l[0],f=l[1],d=f?"appear":"enter";n.addClass(c,d,"active"),n.props.onEntering&&n.props.onEntering(s,u)},n.onEntered=function(s,u){var l=n.resolveArguments(s,u),c=l[0],f=l[1],d=f?"appear":"enter";n.removeClasses(c,d),n.addClass(c,d,"done"),n.props.onEntered&&n.props.onEntered(s,u)},n.onExit=function(s){var u=n.resolveArguments(s),l=u[0];n.removeClasses(l,"appear"),n.removeClasses(l,"enter"),n.addClass(l,"exit","base"),n.props.onExit&&n.props.onExit(s)},n.onExiting=function(s){var u=n.resolveArguments(s),l=u[0];n.addClass(l,"exit","active"),n.props.onExiting&&n.props.onExiting(s)},n.onExited=function(s){var u=n.resolveArguments(s),l=u[0];n.removeClasses(l,"exit"),n.addClass(l,"exit","done"),n.props.onExited&&n.props.onExited(s)},n.resolveArguments=function(s,u){return n.props.nodeRef?[n.props.nodeRef.current,s]:[s,u]},n.getClassNames=function(s){var u=n.props.classNames,l=typeof u=="string",c=l&&u?u+"-":"",f=l?""+c+s:u[s],d=l?f+"-active":u[s+"Active"],h=l?f+"-done":u[s+"Done"];return{baseClassName:f,activeClassName:d,doneClassName:h}},n}var r=t.prototype;return r.addClass=function(i,a,o){var s=this.getClassNames(a)[o+"ClassName"],u=this.getClassNames("enter"),l=u.doneClassName;a==="appear"&&o==="done"&&l&&(s+=" "+l),o==="active"&&i&&w4(i),s&&(this.appliedClasses[a][o]=s,UA(i,s))},r.removeClasses=function(i,a){var o=this.appliedClasses[a],s=o.base,u=o.active,l=o.done;this.appliedClasses[a]={},s&&Pl(i,s),u&&Pl(i,u),l&&Pl(i,l)},r.render=function(){var i=this.props;i.classNames;var a=Uf(i,["classNames"]);return React.createElement($A,Ps({},a,{onEnter:this.onEnter,onEntered:this.onEntered,onEntering:this.onEntering,onExit:this.onExit,onExiting:this.onExiting,onExited:this.onExited}))},t}(React.Component);Hf.defaultProps={classNames:""};Hf.propTypes={};const HA=Hf;function to(e,t){var r={};for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&t.indexOf(n)<0&&(r[n]=e[n]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var i=0,n=Object.getOwnPropertySymbols(e);i<n.length;i++)t.indexOf(n[i])<0&&Object.prototype.propertyIsEnumerable.call(e,n[i])&&(r[n[i]]=e[n[i]]);return r}const qA=(e,t)=>LA?{onTouchEnd:t||e}:{onClick:e||t},jA=(e,t)=>{var{btnType:r,size:n,className:i,children:a,type:o="button",status:s,onClick:u,onTouchEnd:l}=e,c=to(e,["btnType","size","className","children","type","status","onClick","onTouchEnd"]);const f=vt(i,"sea-lion-core-button",r&&`sea-lion-core-button-${r}`,n&&`sea-lion-core-button-${n}`,s&&`sea-lion-core-button-${s}`);return he.jsx("button",Object.assign({ref:t,className:f,type:o},qA(u,l),c,{children:a}))},VA=React.forwardRef(jA),GA=(e,t)=>{const{className:r,btnType:n,size:i,status:a,disabled:o=!1,pure:s=!1,children:u}=e,l=to(e,["className","btnType","size","status","disabled","pure","children"]),c=vt(r,"seal-button",o&&"seal-button-disabled",{[`seal-button-${n}`]:!!n,[`seal-button-${i}`]:!!i,[`seal-button-${a}`]:!!a}),f=s?"":c;return he.jsx(VA,Object.assign({ref:t,className:f,btnType:n,size:i,status:a,disabled:o},l,{children:u}))},ss=React.forwardRef(GA);var x4={exports:{}},je={};/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var j1;function WA(){if(j1)return je;j1=1;var e=typeof Symbol=="function"&&Symbol.for,t=e?Symbol.for("react.element"):60103,r=e?Symbol.for("react.portal"):60106,n=e?Symbol.for("react.fragment"):60107,i=e?Symbol.for("react.strict_mode"):60108,a=e?Symbol.for("react.profiler"):60114,o=e?Symbol.for("react.provider"):60109,s=e?Symbol.for("react.context"):60110,u=e?Symbol.for("react.async_mode"):60111,l=e?Symbol.for("react.concurrent_mode"):60111,c=e?Symbol.for("react.forward_ref"):60112,f=e?Symbol.for("react.suspense"):60113,d=e?Symbol.for("react.suspense_list"):60120,h=e?Symbol.for("react.memo"):60115,p=e?Symbol.for("react.lazy"):60116,m=e?Symbol.for("react.block"):60121,g=e?Symbol.for("react.fundamental"):60117,v=e?Symbol.for("react.responder"):60118,w=e?Symbol.for("react.scope"):60119;function x(O){if(typeof O=="object"&&O!==null){var A=O.$$typeof;switch(A){case t:switch(O=O.type,O){case u:case l:case n:case a:case i:case f:return O;default:switch(O=O&&O.$$typeof,O){case s:case c:case p:case h:case o:return O;default:return A}}case r:return A}}}function N(O){return x(O)===l}return je.AsyncMode=u,je.ConcurrentMode=l,je.ContextConsumer=s,je.ContextProvider=o,je.Element=t,je.ForwardRef=c,je.Fragment=n,je.Lazy=p,je.Memo=h,je.Portal=r,je.Profiler=a,je.StrictMode=i,je.Suspense=f,je.isAsyncMode=function(O){return N(O)||x(O)===u},je.isConcurrentMode=N,je.isContextConsumer=function(O){return x(O)===s},je.isContextProvider=function(O){return x(O)===o},je.isElement=function(O){return typeof O=="object"&&O!==null&&O.$$typeof===t},je.isForwardRef=function(O){return x(O)===c},je.isFragment=function(O){return x(O)===n},je.isLazy=function(O){return x(O)===p},je.isMemo=function(O){return x(O)===h},je.isPortal=function(O){return x(O)===r},je.isProfiler=function(O){return x(O)===a},je.isStrictMode=function(O){return x(O)===i},je.isSuspense=function(O){return x(O)===f},je.isValidElementType=function(O){return typeof O=="string"||typeof O=="function"||O===n||O===l||O===a||O===i||O===f||O===d||typeof O=="object"&&O!==null&&(O.$$typeof===p||O.$$typeof===h||O.$$typeof===o||O.$$typeof===s||O.$$typeof===c||O.$$typeof===g||O.$$typeof===v||O.$$typeof===w||O.$$typeof===m)},je.typeOf=x,je}x4.exports=WA();var KA=x4.exports;function G0(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=[];return React.Children.forEach(e,function(n){n==null&&!t.keepEmpty||(Array.isArray(n)?r=r.concat(G0(n)):KA.isFragment(n)&&n.props?r=r.concat(G0(n.props.children,t)):r.push(n))}),r}var W0={},XA=function(t){};function YA(e,t){}function ZA(e,t){}function QA(){W0={}}function E4(e,t,r){!t&&!W0[r]&&(e(!1,r),W0[r]=!0)}function Nr(e,t){E4(YA,e,t)}function JA(e,t){E4(ZA,e,t)}Nr.preMessage=XA;Nr.resetWarned=QA;Nr.noteOnce=JA;function _a(e){"@babel/helpers - typeof";return _a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},_a(e)}function ek(e,t){if(_a(e)!=="object"||e===null)return e;var r=e[Symbol.toPrimitive];if(r!==void 0){var n=r.call(e,t||"default");if(_a(n)!=="object")return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function tk(e){var t=ek(e,"string");return _a(t)==="symbol"?t:String(t)}function rk(e,t,r){return t=tk(t),t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}function V1(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter(function(i){return Object.getOwnPropertyDescriptor(e,i).enumerable})),r.push.apply(r,n)}return r}function nk(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?arguments[t]:{};t%2?V1(Object(r),!0).forEach(function(n){rk(e,n,r[n])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):V1(Object(r)).forEach(function(n){Object.defineProperty(e,n,Object.getOwnPropertyDescriptor(r,n))})}return e}function Ds(){return Ds=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},Ds.apply(this,arguments)}function ik(e,t){if(e==null)return{};var r={},n=Object.keys(e),i,a;for(a=0;a<n.length;a++)i=n[a],!(t.indexOf(i)>=0)&&(r[i]=e[i]);return r}function qf(e,t){if(e==null)return{};var r=ik(e,t),n,i;if(Object.getOwnPropertySymbols){var a=Object.getOwnPropertySymbols(e);for(i=0;i<a.length;i++)n=a[i],!(t.indexOf(n)>=0)&&Object.prototype.propertyIsEnumerable.call(e,n)&&(r[n]=e[n])}return r}function ir(e){"@babel/helpers - typeof";return ir=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},ir(e)}function ak(e,t){if(ir(e)!=="object"||e===null)return e;var r=e[Symbol.toPrimitive];if(r!==void 0){var n=r.call(e,t||"default");if(ir(n)!=="object")return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function S4(e){var t=ak(e,"string");return ir(t)==="symbol"?t:String(t)}function Ca(e,t,r){return t=S4(t),t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}function G1(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter(function(i){return Object.getOwnPropertyDescriptor(e,i).enumerable})),r.push.apply(r,n)}return r}function $e(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?arguments[t]:{};t%2?G1(Object(r),!0).forEach(function(n){Ca(e,n,r[n])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):G1(Object(r)).forEach(function(n){Object.defineProperty(e,n,Object.getOwnPropertyDescriptor(r,n))})}return e}function K0(e,t){(t==null||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function ok(e){if(Array.isArray(e))return K0(e)}function sk(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function T4(e,t){if(e){if(typeof e=="string")return K0(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);if(r==="Object"&&e.constructor&&(r=e.constructor.name),r==="Map"||r==="Set")return Array.from(e);if(r==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return K0(e,t)}}function uk(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function He(e){return ok(e)||sk(e)||T4(e)||uk()}function jf(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function W1(e,t){for(var r=0;r<t.length;r++){var n=t[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,S4(n.key),n)}}function Vf(e,t,r){return t&&W1(e.prototype,t),r&&W1(e,r),Object.defineProperty(e,"prototype",{writable:!1}),e}function A4(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function X0(e,t){return X0=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,i){return n.__proto__=i,n},X0(e,t)}function lk(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&X0(e,t)}function Ls(e){return Ls=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(r){return r.__proto__||Object.getPrototypeOf(r)},Ls(e)}function ck(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}function fk(e,t){if(t&&(ir(t)==="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return A4(e)}function dk(e){var t=ck();return function(){var n=Ls(e),i;if(t){var a=Ls(this).constructor;i=Reflect.construct(n,arguments,a)}else i=n.apply(this,arguments);return fk(this,i)}}var ri="RC_FORM_INTERNAL_HOOKS",Xe=function(){Nr(!1,"Can not find FormContext. Please make sure you wrap Field under Form.")},zi=React.createContext({getFieldValue:Xe,getFieldsValue:Xe,getFieldError:Xe,getFieldWarning:Xe,getFieldsError:Xe,isFieldsTouched:Xe,isFieldTouched:Xe,isFieldValidating:Xe,isFieldsValidating:Xe,resetFields:Xe,setFields:Xe,setFieldValue:Xe,setFieldsValue:Xe,validateFields:Xe,submit:Xe,getInternalHooks:function(){return Xe(),{dispatch:Xe,initEntityValue:Xe,registerField:Xe,useSubscribe:Xe,setInitialValues:Xe,destroyForm:Xe,setCallbacks:Xe,registerWatch:Xe,getFields:Xe,setValidateMessages:Xe,setPreserve:Xe,getInitialValue:Xe}}});function Y0(e){return e==null?[]:Array.isArray(e)?e:[e]}function dn(){dn=function(){return e};var e={},t=Object.prototype,r=t.hasOwnProperty,n=Object.defineProperty||function(k,M,F){k[M]=F.value},i=typeof Symbol=="function"?Symbol:{},a=i.iterator||"@@iterator",o=i.asyncIterator||"@@asyncIterator",s=i.toStringTag||"@@toStringTag";function u(k,M,F){return Object.defineProperty(k,M,{value:F,enumerable:!0,configurable:!0,writable:!0}),k[M]}try{u({},"")}catch{u=function(F,C,U){return F[C]=U}}function l(k,M,F,C){var U=M&&M.prototype instanceof d?M:d,$=Object.create(U.prototype),V=new z(C||[]);return n($,"_invoke",{value:O(k,F,V)}),$}function c(k,M,F){try{return{type:"normal",arg:k.call(M,F)}}catch(C){return{type:"throw",arg:C}}}e.wrap=l;var f={};function d(){}function h(){}function p(){}var m={};u(m,a,function(){return this});var g=Object.getPrototypeOf,v=g&&g(g(L([])));v&&v!==t&&r.call(v,a)&&(m=v);var w=p.prototype=d.prototype=Object.create(m);function x(k){["next","throw","return"].forEach(function(M){u(k,M,function(F){return this._invoke(M,F)})})}function N(k,M){function F(U,$,V,se){var _=c(k[U],k,$);if(_.type!=="throw"){var oe=_.arg,ne=oe.value;return ne&&ir(ne)=="object"&&r.call(ne,"__await")?M.resolve(ne.__await).then(function(T){F("next",T,V,se)},function(T){F("throw",T,V,se)}):M.resolve(ne).then(function(T){oe.value=T,V(oe)},function(T){return F("throw",T,V,se)})}se(_.arg)}var C;n(this,"_invoke",{value:function($,V){function se(){return new M(function(_,oe){F($,V,_,oe)})}return C=C?C.then(se,se):se()}})}function O(k,M,F){var C="suspendedStart";return function(U,$){if(C==="executing")throw new Error("Generator is already running");if(C==="completed"){if(U==="throw")throw $;return I()}for(F.method=U,F.arg=$;;){var V=F.delegate;if(V){var se=A(V,F);if(se){if(se===f)continue;return se}}if(F.method==="next")F.sent=F._sent=F.arg;else if(F.method==="throw"){if(C==="suspendedStart")throw C="completed",F.arg;F.dispatchException(F.arg)}else F.method==="return"&&F.abrupt("return",F.arg);C="executing";var _=c(k,M,F);if(_.type==="normal"){if(C=F.done?"completed":"suspendedYield",_.arg===f)continue;return{value:_.arg,done:F.done}}_.type==="throw"&&(C="completed",F.method="throw",F.arg=_.arg)}}}function A(k,M){var F=M.method,C=k.iterator[F];if(C===void 0)return M.delegate=null,F==="throw"&&k.iterator.return&&(M.method="return",M.arg=void 0,A(k,M),M.method==="throw")||F!=="return"&&(M.method="throw",M.arg=new TypeError("The iterator does not provide a '"+F+"' method")),f;var U=c(C,k.iterator,M.arg);if(U.type==="throw")return M.method="throw",M.arg=U.arg,M.delegate=null,f;var $=U.arg;return $?$.done?(M[k.resultName]=$.value,M.next=k.nextLoc,M.method!=="return"&&(M.method="next",M.arg=void 0),M.delegate=null,f):$:(M.method="throw",M.arg=new TypeError("iterator result is not an object"),M.delegate=null,f)}function D(k){var M={tryLoc:k[0]};1 in k&&(M.catchLoc=k[1]),2 in k&&(M.finallyLoc=k[2],M.afterLoc=k[3]),this.tryEntries.push(M)}function H(k){var M=k.completion||{};M.type="normal",delete M.arg,k.completion=M}function z(k){this.tryEntries=[{tryLoc:"root"}],k.forEach(D,this),this.reset(!0)}function L(k){if(k){var M=k[a];if(M)return M.call(k);if(typeof k.next=="function")return k;if(!isNaN(k.length)){var F=-1,C=function U(){for(;++F<k.length;)if(r.call(k,F))return U.value=k[F],U.done=!1,U;return U.value=void 0,U.done=!0,U};return C.next=C}}return{next:I}}function I(){return{value:void 0,done:!0}}return h.prototype=p,n(w,"constructor",{value:p,configurable:!0}),n(p,"constructor",{value:h,configurable:!0}),h.displayName=u(p,s,"GeneratorFunction"),e.isGeneratorFunction=function(k){var M=typeof k=="function"&&k.constructor;return!!M&&(M===h||(M.displayName||M.name)==="GeneratorFunction")},e.mark=function(k){return Object.setPrototypeOf?Object.setPrototypeOf(k,p):(k.__proto__=p,u(k,s,"GeneratorFunction")),k.prototype=Object.create(w),k},e.awrap=function(k){return{__await:k}},x(N.prototype),u(N.prototype,o,function(){return this}),e.AsyncIterator=N,e.async=function(k,M,F,C,U){U===void 0&&(U=Promise);var $=new N(l(k,M,F,C),U);return e.isGeneratorFunction(M)?$:$.next().then(function(V){return V.done?V.value:$.next()})},x(w),u(w,s,"Generator"),u(w,a,function(){return this}),u(w,"toString",function(){return"[object Generator]"}),e.keys=function(k){var M=Object(k),F=[];for(var C in M)F.push(C);return F.reverse(),function U(){for(;F.length;){var $=F.pop();if($ in M)return U.value=$,U.done=!1,U}return U.done=!0,U}},e.values=L,z.prototype={constructor:z,reset:function(M){if(this.prev=0,this.next=0,this.sent=this._sent=void 0,this.done=!1,this.delegate=null,this.method="next",this.arg=void 0,this.tryEntries.forEach(H),!M)for(var F in this)F.charAt(0)==="t"&&r.call(this,F)&&!isNaN(+F.slice(1))&&(this[F]=void 0)},stop:function(){this.done=!0;var M=this.tryEntries[0].completion;if(M.type==="throw")throw M.arg;return this.rval},dispatchException:function(M){if(this.done)throw M;var F=this;function C(oe,ne){return V.type="throw",V.arg=M,F.next=oe,ne&&(F.method="next",F.arg=void 0),!!ne}for(var U=this.tryEntries.length-1;U>=0;--U){var $=this.tryEntries[U],V=$.completion;if($.tryLoc==="root")return C("end");if($.tryLoc<=this.prev){var se=r.call($,"catchLoc"),_=r.call($,"finallyLoc");if(se&&_){if(this.prev<$.catchLoc)return C($.catchLoc,!0);if(this.prev<$.finallyLoc)return C($.finallyLoc)}else if(se){if(this.prev<$.catchLoc)return C($.catchLoc,!0)}else{if(!_)throw new Error("try statement without catch or finally");if(this.prev<$.finallyLoc)return C($.finallyLoc)}}}},abrupt:function(M,F){for(var C=this.tryEntries.length-1;C>=0;--C){var U=this.tryEntries[C];if(U.tryLoc<=this.prev&&r.call(U,"finallyLoc")&&this.prev<U.finallyLoc){var $=U;break}}$&&(M==="break"||M==="continue")&&$.tryLoc<=F&&F<=$.finallyLoc&&($=null);var V=$?$.completion:{};return V.type=M,V.arg=F,$?(this.method="next",this.next=$.finallyLoc,f):this.complete(V)},complete:function(M,F){if(M.type==="throw")throw M.arg;return M.type==="break"||M.type==="continue"?this.next=M.arg:M.type==="return"?(this.rval=this.arg=M.arg,this.method="return",this.next="end"):M.type==="normal"&&F&&(this.next=F),f},finish:function(M){for(var F=this.tryEntries.length-1;F>=0;--F){var C=this.tryEntries[F];if(C.finallyLoc===M)return this.complete(C.completion,C.afterLoc),H(C),f}},catch:function(M){for(var F=this.tryEntries.length-1;F>=0;--F){var C=this.tryEntries[F];if(C.tryLoc===M){var U=C.completion;if(U.type==="throw"){var $=U.arg;H(C)}return $}}throw new Error("illegal catch attempt")},delegateYield:function(M,F,C){return this.delegate={iterator:L(M),resultName:F,nextLoc:C},this.method==="next"&&(this.arg=void 0),f}},e}function K1(e,t,r,n,i,a,o){try{var s=e[a](o),u=s.value}catch(l){r(l);return}s.done?t(u):Promise.resolve(u).then(n,i)}function ku(e){return function(){var t=this,r=arguments;return new Promise(function(n,i){var a=e.apply(t,r);function o(u){K1(a,n,i,o,s,"next",u)}function s(u){K1(a,n,i,o,s,"throw",u)}o(void 0)})}}function ni(){return ni=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},ni.apply(this,arguments)}function hk(e,t){e.prototype=Object.create(t.prototype),e.prototype.constructor=e,Ma(e,t)}function Z0(e){return Z0=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(r){return r.__proto__||Object.getPrototypeOf(r)},Z0(e)}function Ma(e,t){return Ma=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,i){return n.__proto__=i,n},Ma(e,t)}function pk(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}function us(e,t,r){return pk()?us=Reflect.construct.bind():us=function(i,a,o){var s=[null];s.push.apply(s,a);var u=Function.bind.apply(i,s),l=new u;return o&&Ma(l,o.prototype),l},us.apply(null,arguments)}function mk(e){return Function.toString.call(e).indexOf("[native code]")!==-1}function Q0(e){var t=typeof Map=="function"?new Map:void 0;return Q0=function(n){if(n===null||!mk(n))return n;if(typeof n!="function")throw new TypeError("Super expression must either be null or a function");if(typeof t<"u"){if(t.has(n))return t.get(n);t.set(n,i)}function i(){return us(n,arguments,Z0(this).constructor)}return i.prototype=Object.create(n.prototype,{constructor:{value:i,enumerable:!1,writable:!0,configurable:!0}}),Ma(i,n)},Q0(e)}var gk=/%[sdj%]/g,bk=function(){};typeof process<"u"&&process.env;function J0(e){if(!e||!e.length)return null;var t={};return e.forEach(function(r){var n=r.field;t[n]=t[n]||[],t[n].push(r)}),t}function rr(e){for(var t=arguments.length,r=new Array(t>1?t-1:0),n=1;n<t;n++)r[n-1]=arguments[n];var i=0,a=r.length;if(typeof e=="function")return e.apply(null,r);if(typeof e=="string"){var o=e.replace(gk,function(s){if(s==="%%")return"%";if(i>=a)return s;switch(s){case"%s":return String(r[i++]);case"%d":return Number(r[i++]);case"%j":try{return JSON.stringify(r[i++])}catch{return"[Circular]"}break;default:return s}});return o}return e}function vk(e){return e==="string"||e==="url"||e==="hex"||e==="email"||e==="date"||e==="pattern"}function wt(e,t){return!!(e==null||t==="array"&&Array.isArray(e)&&!e.length||vk(t)&&typeof e=="string"&&!e)}function yk(e,t,r){var n=[],i=0,a=e.length;function o(s){n.push.apply(n,s||[]),i++,i===a&&r(n)}e.forEach(function(s){t(s,o)})}function X1(e,t,r){var n=0,i=e.length;function a(o){if(o&&o.length){r(o);return}var s=n;n=n+1,s<i?t(e[s],a):r([])}a([])}function wk(e){var t=[];return Object.keys(e).forEach(function(r){t.push.apply(t,e[r]||[])}),t}var Y1=function(e){hk(t,e);function t(r,n){var i;return i=e.call(this,"Async Validation Error")||this,i.errors=r,i.fields=n,i}return t}(Q0(Error));function xk(e,t,r,n,i){if(t.first){var a=new Promise(function(d,h){var p=function(v){return n(v),v.length?h(new Y1(v,J0(v))):d(i)},m=wk(e);X1(m,r,p)});return a.catch(function(d){return d}),a}var o=t.firstFields===!0?Object.keys(e):t.firstFields||[],s=Object.keys(e),u=s.length,l=0,c=[],f=new Promise(function(d,h){var p=function(g){if(c.push.apply(c,g),l++,l===u)return n(c),c.length?h(new Y1(c,J0(c))):d(i)};s.length||(n(c),d(i)),s.forEach(function(m){var g=e[m];o.indexOf(m)!==-1?X1(g,r,p):yk(g,r,p)})});return f.catch(function(d){return d}),f}function Ek(e){return!!(e&&e.message!==void 0)}function Sk(e,t){for(var r=e,n=0;n<t.length;n++){if(r==null)return r;r=r[t[n]]}return r}function Z1(e,t){return function(r){var n;return e.fullFields?n=Sk(t,e.fullFields):n=t[r.field||e.fullField],Ek(r)?(r.field=r.field||e.fullField,r.fieldValue=n,r):{message:typeof r=="function"?r():r,fieldValue:n,field:r.field||e.fullField}}}function Q1(e,t){if(t){for(var r in t)if(t.hasOwnProperty(r)){var n=t[r];typeof n=="object"&&typeof e[r]=="object"?e[r]=ni({},e[r],n):e[r]=n}}return e}var k4=function(t,r,n,i,a,o){t.required&&(!n.hasOwnProperty(t.field)||wt(r,o||t.type))&&i.push(rr(a.messages.required,t.fullField))},Tk=function(t,r,n,i,a){(/^\s+$/.test(r)||r==="")&&i.push(rr(a.messages.whitespace,t.fullField))},Oo,Ak=function(){if(Oo)return Oo;var e="[a-fA-F\\d:]",t=function(N){return N&&N.includeBoundaries?"(?:(?<=\\s|^)(?="+e+")|(?<="+e+")(?=\\s|$))":""},r="(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}",n="[a-fA-F\\d]{1,4}",i=(`
(?:
(?:`+n+":){7}(?:"+n+`|:)|                                    // 1:2:3:4:5:6:7::  1:2:3:4:5:6:7:8
(?:`+n+":){6}(?:"+r+"|:"+n+`|:)|                             // 1:2:3:4:5:6::    1:2:3:4:5:6::8   1:2:3:4:5:6::8  1:2:3:4:5:6::1.2.3.4
(?:`+n+":){5}(?::"+r+"|(?::"+n+`){1,2}|:)|                   // 1:2:3:4:5::      1:2:3:4:5::7:8   1:2:3:4:5::8    1:2:3:4:5::7:1.2.3.4
(?:`+n+":){4}(?:(?::"+n+"){0,1}:"+r+"|(?::"+n+`){1,3}|:)| // 1:2:3:4::        1:2:3:4::6:7:8   1:2:3:4::8      1:2:3:4::6:7:1.2.3.4
(?:`+n+":){3}(?:(?::"+n+"){0,2}:"+r+"|(?::"+n+`){1,4}|:)| // 1:2:3::          1:2:3::5:6:7:8   1:2:3::8        1:2:3::5:6:7:1.2.3.4
(?:`+n+":){2}(?:(?::"+n+"){0,3}:"+r+"|(?::"+n+`){1,5}|:)| // 1:2::            1:2::4:5:6:7:8   1:2::8          1:2::4:5:6:7:1.2.3.4
(?:`+n+":){1}(?:(?::"+n+"){0,4}:"+r+"|(?::"+n+`){1,6}|:)| // 1::              1::3:4:5:6:7:8   1::8            1::3:4:5:6:7:1.2.3.4
(?::(?:(?::`+n+"){0,5}:"+r+"|(?::"+n+`){1,7}|:))             // ::2:3:4:5:6:7:8  ::2:3:4:5:6:7:8  ::8             ::1.2.3.4
)(?:%[0-9a-zA-Z]{1,})?                                             // %eth0            %1
`).replace(/\s*\/\/.*$/gm,"").replace(/\n/g,"").trim(),a=new RegExp("(?:^"+r+"$)|(?:^"+i+"$)"),o=new RegExp("^"+r+"$"),s=new RegExp("^"+i+"$"),u=function(N){return N&&N.exact?a:new RegExp("(?:"+t(N)+r+t(N)+")|(?:"+t(N)+i+t(N)+")","g")};u.v4=function(x){return x&&x.exact?o:new RegExp(""+t(x)+r+t(x),"g")},u.v6=function(x){return x&&x.exact?s:new RegExp(""+t(x)+i+t(x),"g")};var l="(?:(?:[a-z]+:)?//)",c="(?:\\S+(?::\\S*)?@)?",f=u.v4().source,d=u.v6().source,h="(?:(?:[a-z\\u00a1-\\uffff0-9][-_]*)*[a-z\\u00a1-\\uffff0-9]+)",p="(?:\\.(?:[a-z\\u00a1-\\uffff0-9]-*)*[a-z\\u00a1-\\uffff0-9]+)*",m="(?:\\.(?:[a-z\\u00a1-\\uffff]{2,}))",g="(?::\\d{2,5})?",v='(?:[/?#][^\\s"]*)?',w="(?:"+l+"|www\\.)"+c+"(?:localhost|"+f+"|"+d+"|"+h+p+m+")"+g+v;return Oo=new RegExp("(?:^"+w+"$)","i"),Oo},J1={email:/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+\.)+[a-zA-Z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]{2,}))$/,hex:/^#?([a-f0-9]{6}|[a-f0-9]{3})$/i},da={integer:function(t){return da.number(t)&&parseInt(t,10)===t},float:function(t){return da.number(t)&&!da.integer(t)},array:function(t){return Array.isArray(t)},regexp:function(t){if(t instanceof RegExp)return!0;try{return!!new RegExp(t)}catch{return!1}},date:function(t){return typeof t.getTime=="function"&&typeof t.getMonth=="function"&&typeof t.getYear=="function"&&!isNaN(t.getTime())},number:function(t){return isNaN(t)?!1:typeof t=="number"},object:function(t){return typeof t=="object"&&!da.array(t)},method:function(t){return typeof t=="function"},email:function(t){return typeof t=="string"&&t.length<=320&&!!t.match(J1.email)},url:function(t){return typeof t=="string"&&t.length<=2048&&!!t.match(Ak())},hex:function(t){return typeof t=="string"&&!!t.match(J1.hex)}},kk=function(t,r,n,i,a){if(t.required&&r===void 0){k4(t,r,n,i,a);return}var o=["integer","float","array","regexp","object","method","email","number","date","url","hex"],s=t.type;o.indexOf(s)>-1?da[s](r)||i.push(rr(a.messages.types[s],t.fullField,t.type)):s&&typeof r!==t.type&&i.push(rr(a.messages.types[s],t.fullField,t.type))},Ok=function(t,r,n,i,a){var o=typeof t.len=="number",s=typeof t.min=="number",u=typeof t.max=="number",l=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,c=r,f=null,d=typeof r=="number",h=typeof r=="string",p=Array.isArray(r);if(d?f="number":h?f="string":p&&(f="array"),!f)return!1;p&&(c=r.length),h&&(c=r.replace(l,"_").length),o?c!==t.len&&i.push(rr(a.messages[f].len,t.fullField,t.len)):s&&!u&&c<t.min?i.push(rr(a.messages[f].min,t.fullField,t.min)):u&&!s&&c>t.max?i.push(rr(a.messages[f].max,t.fullField,t.max)):s&&u&&(c<t.min||c>t.max)&&i.push(rr(a.messages[f].range,t.fullField,t.min,t.max))},vi="enum",Nk=function(t,r,n,i,a){t[vi]=Array.isArray(t[vi])?t[vi]:[],t[vi].indexOf(r)===-1&&i.push(rr(a.messages[vi],t.fullField,t[vi].join(", ")))},_k=function(t,r,n,i,a){if(t.pattern){if(t.pattern instanceof RegExp)t.pattern.lastIndex=0,t.pattern.test(r)||i.push(rr(a.messages.pattern.mismatch,t.fullField,r,t.pattern));else if(typeof t.pattern=="string"){var o=new RegExp(t.pattern);o.test(r)||i.push(rr(a.messages.pattern.mismatch,t.fullField,r,t.pattern))}}},Le={required:k4,whitespace:Tk,type:kk,range:Ok,enum:Nk,pattern:_k},Ck=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r,"string")&&!t.required)return n();Le.required(t,r,i,o,a,"string"),wt(r,"string")||(Le.type(t,r,i,o,a),Le.range(t,r,i,o,a),Le.pattern(t,r,i,o,a),t.whitespace===!0&&Le.whitespace(t,r,i,o,a))}n(o)},Mk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&Le.type(t,r,i,o,a)}n(o)},Rk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(r===""&&(r=void 0),wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&(Le.type(t,r,i,o,a),Le.range(t,r,i,o,a))}n(o)},Ik=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&Le.type(t,r,i,o,a)}n(o)},Pk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),wt(r)||Le.type(t,r,i,o,a)}n(o)},Dk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&(Le.type(t,r,i,o,a),Le.range(t,r,i,o,a))}n(o)},Lk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&(Le.type(t,r,i,o,a),Le.range(t,r,i,o,a))}n(o)},Fk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(r==null&&!t.required)return n();Le.required(t,r,i,o,a,"array"),r!=null&&(Le.type(t,r,i,o,a),Le.range(t,r,i,o,a))}n(o)},Bk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&Le.type(t,r,i,o,a)}n(o)},zk="enum",$k=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a),r!==void 0&&Le[zk](t,r,i,o,a)}n(o)},Uk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r,"string")&&!t.required)return n();Le.required(t,r,i,o,a),wt(r,"string")||Le.pattern(t,r,i,o,a)}n(o)},Hk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r,"date")&&!t.required)return n();if(Le.required(t,r,i,o,a),!wt(r,"date")){var u;r instanceof Date?u=r:u=new Date(r),Le.type(t,u,i,o,a),u&&Le.range(t,u.getTime(),i,o,a)}}n(o)},qk=function(t,r,n,i,a){var o=[],s=Array.isArray(r)?"array":typeof r;Le.required(t,r,i,o,a,s),n(o)},Dl=function(t,r,n,i,a){var o=t.type,s=[],u=t.required||!t.required&&i.hasOwnProperty(t.field);if(u){if(wt(r,o)&&!t.required)return n();Le.required(t,r,i,s,a,o),wt(r,o)||Le.type(t,r,i,s,a)}n(s)},jk=function(t,r,n,i,a){var o=[],s=t.required||!t.required&&i.hasOwnProperty(t.field);if(s){if(wt(r)&&!t.required)return n();Le.required(t,r,i,o,a)}n(o)},ya={string:Ck,method:Mk,number:Rk,boolean:Ik,regexp:Pk,integer:Dk,float:Lk,array:Fk,object:Bk,enum:$k,pattern:Uk,date:Hk,url:Dl,hex:Dl,email:Dl,required:qk,any:jk};function ec(){return{default:"Validation error on field %s",required:"%s is required",enum:"%s must be one of %s",whitespace:"%s cannot be empty",date:{format:"%s date %s is invalid for format %s",parse:"%s date could not be parsed, %s is invalid ",invalid:"%s date %s is invalid"},types:{string:"%s is not a %s",method:"%s is not a %s (function)",array:"%s is not an %s",object:"%s is not an %s",number:"%s is not a %s",date:"%s is not a %s",boolean:"%s is not a %s",integer:"%s is not an %s",float:"%s is not a %s",regexp:"%s is not a valid %s",email:"%s is not a valid %s",url:"%s is not a valid %s",hex:"%s is not a valid %s"},string:{len:"%s must be exactly %s characters",min:"%s must be at least %s characters",max:"%s cannot be longer than %s characters",range:"%s must be between %s and %s characters"},number:{len:"%s must equal %s",min:"%s cannot be less than %s",max:"%s cannot be greater than %s",range:"%s must be between %s and %s"},array:{len:"%s must be exactly %s in length",min:"%s cannot be less than %s in length",max:"%s cannot be greater than %s in length",range:"%s must be between %s and %s in length"},pattern:{mismatch:"%s value %s does not match pattern %s"},clone:function(){var t=JSON.parse(JSON.stringify(this));return t.clone=this.clone,t}}}var tc=ec(),ro=function(){function e(r){this.rules=null,this._messages=tc,this.define(r)}var t=e.prototype;return t.define=function(n){var i=this;if(!n)throw new Error("Cannot configure a schema with no rules");if(typeof n!="object"||Array.isArray(n))throw new Error("Rules must be an object");this.rules={},Object.keys(n).forEach(function(a){var o=n[a];i.rules[a]=Array.isArray(o)?o:[o]})},t.messages=function(n){return n&&(this._messages=Q1(ec(),n)),this._messages},t.validate=function(n,i,a){var o=this;i===void 0&&(i={}),a===void 0&&(a=function(){});var s=n,u=i,l=a;if(typeof u=="function"&&(l=u,u={}),!this.rules||Object.keys(this.rules).length===0)return l&&l(null,s),Promise.resolve(s);function c(m){var g=[],v={};function w(N){if(Array.isArray(N)){var O;g=(O=g).concat.apply(O,N)}else g.push(N)}for(var x=0;x<m.length;x++)w(m[x]);g.length?(v=J0(g),l(g,v)):l(null,s)}if(u.messages){var f=this.messages();f===tc&&(f=ec()),Q1(f,u.messages),u.messages=f}else u.messages=this.messages();var d={},h=u.keys||Object.keys(this.rules);h.forEach(function(m){var g=o.rules[m],v=s[m];g.forEach(function(w){var x=w;typeof x.transform=="function"&&(s===n&&(s=ni({},s)),v=s[m]=x.transform(v)),typeof x=="function"?x={validator:x}:x=ni({},x),x.validator=o.getValidationMethod(x),x.validator&&(x.field=m,x.fullField=x.fullField||m,x.type=o.getType(x),d[m]=d[m]||[],d[m].push({rule:x,value:v,source:s,field:m}))})});var p={};return xk(d,u,function(m,g){var v=m.rule,w=(v.type==="object"||v.type==="array")&&(typeof v.fields=="object"||typeof v.defaultField=="object");w=w&&(v.required||!v.required&&m.value),v.field=m.field;function x(A,D){return ni({},D,{fullField:v.fullField+"."+A,fullFields:v.fullFields?[].concat(v.fullFields,[A]):[A]})}function N(A){A===void 0&&(A=[]);var D=Array.isArray(A)?A:[A];!u.suppressWarning&&D.length&&e.warning("async-validator:",D),D.length&&v.message!==void 0&&(D=[].concat(v.message));var H=D.map(Z1(v,s));if(u.first&&H.length)return p[v.field]=1,g(H);if(!w)g(H);else{if(v.required&&!m.value)return v.message!==void 0?H=[].concat(v.message).map(Z1(v,s)):u.error&&(H=[u.error(v,rr(u.messages.required,v.field))]),g(H);var z={};v.defaultField&&Object.keys(m.value).map(function(k){z[k]=v.defaultField}),z=ni({},z,m.rule.fields);var L={};Object.keys(z).forEach(function(k){var M=z[k],F=Array.isArray(M)?M:[M];L[k]=F.map(x.bind(null,k))});var I=new e(L);I.messages(u.messages),m.rule.options&&(m.rule.options.messages=u.messages,m.rule.options.error=u.error),I.validate(m.value,m.rule.options||u,function(k){var M=[];H&&H.length&&M.push.apply(M,H),k&&k.length&&M.push.apply(M,k),g(M.length?M:null)})}}var O;if(v.asyncValidator)O=v.asyncValidator(v,m.value,N,m.source,u);else if(v.validator){try{O=v.validator(v,m.value,N,m.source,u)}catch(A){console.error==null||console.error(A),u.suppressValidatorError||setTimeout(function(){throw A},0),N(A.message)}O===!0?N():O===!1?N(typeof v.message=="function"?v.message(v.fullField||v.field):v.message||(v.fullField||v.field)+" fails"):O instanceof Array?N(O):O instanceof Error&&N(O.message)}O&&O.then&&O.then(function(){return N()},function(A){return N(A)})},function(m){c(m)},s)},t.getType=function(n){if(n.type===void 0&&n.pattern instanceof RegExp&&(n.type="pattern"),typeof n.validator!="function"&&n.type&&!ya.hasOwnProperty(n.type))throw new Error(rr("Unknown rule type %s",n.type));return n.type||"string"},t.getValidationMethod=function(n){if(typeof n.validator=="function")return n.validator;var i=Object.keys(n),a=i.indexOf("message");return a!==-1&&i.splice(a,1),i.length===1&&i[0]==="required"?ya.required:ya[this.getType(n)]||void 0},e}();ro.register=function(t,r){if(typeof r!="function")throw new Error("Cannot register a validator by type, validator is not a function");ya[t]=r};ro.warning=bk;ro.messages=tc;ro.validators=ya;var Zt="'${name}' is not a valid ${type}",O4={default:"Validation error on field '${name}'",required:"'${name}' is required",enum:"'${name}' must be one of [${enum}]",whitespace:"'${name}' cannot be empty",date:{format:"'${name}' is invalid for format date",parse:"'${name}' could not be parsed as date",invalid:"'${name}' is invalid date"},types:{string:Zt,method:Zt,array:Zt,object:Zt,number:Zt,date:Zt,boolean:Zt,integer:Zt,float:Zt,regexp:Zt,email:Zt,url:Zt,hex:Zt},string:{len:"'${name}' must be exactly ${len} characters",min:"'${name}' must be at least ${min} characters",max:"'${name}' cannot be longer than ${max} characters",range:"'${name}' must be between ${min} and ${max} characters"},number:{len:"'${name}' must equal ${len}",min:"'${name}' cannot be less than ${min}",max:"'${name}' cannot be greater than ${max}",range:"'${name}' must be between ${min} and ${max}"},array:{len:"'${name}' must be exactly ${len} in length",min:"'${name}' cannot be less than ${min} in length",max:"'${name}' cannot be greater than ${max} in length",range:"'${name}' must be between ${min} and ${max} in length"},pattern:{mismatch:"'${name}' does not match pattern ${pattern}"}};function N4(e,t){for(var r=e,n=0;n<t.length;n+=1){if(r==null)return;r=r[t[n]]}return r}function rc(e,t){(t==null||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Vk(e){if(Array.isArray(e))return rc(e)}function _4(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function C4(e,t){if(e){if(typeof e=="string")return rc(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);if(r==="Object"&&e.constructor&&(r=e.constructor.name),r==="Map"||r==="Set")return Array.from(e);if(r==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return rc(e,t)}}function Gk(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Wk(e){return Vk(e)||_4(e)||C4(e)||Gk()}function Kk(e){if(Array.isArray(e))return e}function Xk(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Yk(e){return Kk(e)||_4(e)||C4(e)||Xk()}function M4(e,t,r,n){if(!t.length)return r;var i=Yk(t),a=i[0],o=i.slice(1),s;return!e&&typeof a=="number"?s=[]:Array.isArray(e)?s=Wk(e):s=nk({},e),n&&r===void 0&&o.length===1?delete s[a][o[0]]:s[a]=M4(s[a],o,r,n),s}function Zk(e,t,r){var n=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1;return t.length&&n&&r===void 0&&!N4(e,t.slice(0,-1))?e:M4(e,t,r,n)}function Ou(e){return Array.isArray(e)?Jk(e):ir(e)==="object"&&e!==null?Qk(e):e}function Qk(e){if(Object.getPrototypeOf(e)===Object.prototype){var t={};for(var r in e)t[r]=Ou(e[r]);return t}return e}function Jk(e){return e.map(function(t){return Ou(t)})}function ht(e){return Y0(e)}function Nn(e,t){var r=N4(e,t);return r}function Tn(e,t,r){var n=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1,i=Zk(e,t,r,n);return i}function ep(e,t){var r={};return t.forEach(function(n){var i=Nn(e,n);r=Tn(r,n,i)}),r}function wa(e,t){return e&&e.some(function(r){return I4(r,t)})}function tp(e){return ir(e)==="object"&&e!==null&&Object.getPrototypeOf(e)===Object.prototype}function R4(e,t){var r=Array.isArray(e)?He(e):$e({},e);return t&&Object.keys(t).forEach(function(n){var i=r[n],a=t[n],o=tp(i)&&tp(a);r[n]=o?R4(i,a||{}):Ou(a)}),r}function ls(e){for(var t=arguments.length,r=new Array(t>1?t-1:0),n=1;n<t;n++)r[n-1]=arguments[n];return r.reduce(function(i,a){return R4(i,a)},e)}function I4(e,t){return!e||!t||e.length!==t.length?!1:e.every(function(r,n){return t[n]===r})}function eO(e,t){if(e===t)return!0;if(!e&&t||e&&!t||!e||!t||ir(e)!=="object"||ir(t)!=="object")return!1;var r=Object.keys(e),n=Object.keys(t),i=new Set([].concat(r,n));return He(i).every(function(a){var o=e[a],s=t[a];return typeof o=="function"&&typeof s=="function"?!0:o===s})}function tO(e){var t=arguments.length<=1?void 0:arguments[1];return t&&t.target&&ir(t.target)==="object"&&e in t.target?t.target[e]:t}function rp(e,t,r){var n=e.length;if(t<0||t>=n||r<0||r>=n)return e;var i=e[t],a=t-r;return a>0?[].concat(He(e.slice(0,r)),[i],He(e.slice(r,t)),He(e.slice(t+1,n))):a<0?[].concat(He(e.slice(0,t)),He(e.slice(t+1,r+1)),[i],He(e.slice(r+1,n))):e}var rO=ro;function nO(e,t){return e.replace(/\$\{\w+\}/g,function(r){var n=r.slice(2,-1);return t[n]})}var np="CODE_LOGIC_ERROR";function nc(e,t,r,n,i){return ic.apply(this,arguments)}function ic(){return ic=ku(dn().mark(function e(t,r,n,i,a){var o,s,u,l,c,f,d,h,p;return dn().wrap(function(g){for(;;)switch(g.prev=g.next){case 0:return o=$e({},n),delete o.ruleIndex,o.validator&&(s=o.validator,o.validator=function(){try{return s.apply(void 0,arguments)}catch(v){return console.error(v),Promise.reject(np)}}),u=null,o&&o.type==="array"&&o.defaultField&&(u=o.defaultField,delete o.defaultField),l=new rO(Ca({},t,[o])),c=ls({},O4,i.validateMessages),l.messages(c),f=[],g.prev=9,g.next=12,Promise.resolve(l.validate(Ca({},t,r),$e({},i)));case 12:g.next=17;break;case 14:g.prev=14,g.t0=g.catch(9),g.t0.errors&&(f=g.t0.errors.map(function(v,w){var x=v.message,N=x===np?c.default:x;return React.isValidElement(N)?React.cloneElement(N,{key:"error_".concat(w)}):N}));case 17:if(!(!f.length&&u)){g.next=22;break}return g.next=20,Promise.all(r.map(function(v,w){return nc("".concat(t,".").concat(w),v,u,i,a)}));case 20:return d=g.sent,g.abrupt("return",d.reduce(function(v,w){return[].concat(He(v),He(w))},[]));case 22:return h=$e($e({},n),{},{name:t,enum:(n.enum||[]).join(", ")},a),p=f.map(function(v){return typeof v=="string"?nO(v,h):v}),g.abrupt("return",p);case 25:case"end":return g.stop()}},e,null,[[9,14]])})),ic.apply(this,arguments)}function iO(e,t,r,n,i,a){var o=e.join("."),s=r.map(function(c,f){var d=c.validator,h=$e($e({},c),{},{ruleIndex:f});return d&&(h.validator=function(p,m,g){var v=!1,w=function(){for(var O=arguments.length,A=new Array(O),D=0;D<O;D++)A[D]=arguments[D];Promise.resolve().then(function(){Nr(!v,"Your validator function has already return a promise. `callback` will be ignored."),v||g.apply(void 0,A)})},x=d(p,m,w);v=x&&typeof x.then=="function"&&typeof x.catch=="function",Nr(v,"`callback` is deprecated. Please return a promise instead."),v&&x.then(function(){g()}).catch(function(N){g(N||" ")})}),h}).sort(function(c,f){var d=c.warningOnly,h=c.ruleIndex,p=f.warningOnly,m=f.ruleIndex;return!!d==!!p?h-m:d?1:-1}),u;if(i===!0)u=new Promise(function(){var c=ku(dn().mark(function f(d,h){var p,m,g;return dn().wrap(function(w){for(;;)switch(w.prev=w.next){case 0:p=0;case 1:if(!(p<s.length)){w.next=12;break}return m=s[p],w.next=5,nc(o,t,m,n,a);case 5:if(g=w.sent,!g.length){w.next=9;break}return h([{errors:g,rule:m}]),w.abrupt("return");case 9:p+=1,w.next=1;break;case 12:d([]);case 13:case"end":return w.stop()}},f)}));return function(f,d){return c.apply(this,arguments)}}());else{var l=s.map(function(c){return nc(o,t,c,n,a).then(function(f){return{errors:f,rule:c}})});u=(i?oO(l):aO(l)).then(function(c){return Promise.reject(c)})}return u.catch(function(c){return c}),u}function aO(e){return ac.apply(this,arguments)}function ac(){return ac=ku(dn().mark(function e(t){return dn().wrap(function(n){for(;;)switch(n.prev=n.next){case 0:return n.abrupt("return",Promise.all(t).then(function(i){var a,o=(a=[]).concat.apply(a,He(i));return o}));case 1:case"end":return n.stop()}},e)})),ac.apply(this,arguments)}function oO(e){return oc.apply(this,arguments)}function oc(){return oc=ku(dn().mark(function e(t){var r;return dn().wrap(function(i){for(;;)switch(i.prev=i.next){case 0:return r=0,i.abrupt("return",new Promise(function(a){t.forEach(function(o){o.then(function(s){s.errors.length&&a([s]),r+=1,r===t.length&&a([])})})}));case 2:case"end":return i.stop()}},e)})),oc.apply(this,arguments)}var sO=["name"],ur=[];function ip(e,t,r,n,i,a){return typeof e=="function"?e(t,r,"source"in a?{source:a.source}:{}):n!==i}var Gf=function(e){lk(r,e);var t=dk(r);function r(n){var i;if(jf(this,r),i=t.call(this,n),i.state={resetCount:0},i.cancelRegisterFunc=null,i.mounted=!1,i.touched=!1,i.dirty=!1,i.validatePromise=null,i.prevValidating=void 0,i.errors=ur,i.warnings=ur,i.cancelRegister=function(){var u=i.props,l=u.preserve,c=u.isListField,f=u.name;i.cancelRegisterFunc&&i.cancelRegisterFunc(c,l,ht(f)),i.cancelRegisterFunc=null},i.getNamePath=function(){var u=i.props,l=u.name,c=u.fieldContext,f=c.prefixName,d=f===void 0?[]:f;return l!==void 0?[].concat(He(d),He(l)):[]},i.getRules=function(){var u=i.props,l=u.rules,c=l===void 0?[]:l,f=u.fieldContext;return c.map(function(d){return typeof d=="function"?d(f):d})},i.refresh=function(){i.mounted&&i.setState(function(u){var l=u.resetCount;return{resetCount:l+1}})},i.triggerMetaEvent=function(u){var l=i.props.onMetaChange;l==null||l($e($e({},i.getMeta()),{},{destroy:u}))},i.onStoreChange=function(u,l,c){var f=i.props,d=f.shouldUpdate,h=f.dependencies,p=h===void 0?[]:h,m=f.onReset,g=c.store,v=i.getNamePath(),w=i.getValue(u),x=i.getValue(g),N=l&&wa(l,v);switch(c.type==="valueUpdate"&&c.source==="external"&&w!==x&&(i.touched=!0,i.dirty=!0,i.validatePromise=null,i.errors=ur,i.warnings=ur,i.triggerMetaEvent()),c.type){case"reset":if(!l||N){i.touched=!1,i.dirty=!1,i.validatePromise=null,i.errors=ur,i.warnings=ur,i.triggerMetaEvent(),m==null||m(),i.refresh();return}break;case"remove":{if(d){i.reRender();return}break}case"setField":{if(N){var O=c.data;"touched"in O&&(i.touched=O.touched),"validating"in O&&!("originRCField"in O)&&(i.validatePromise=O.validating?Promise.resolve([]):null),"errors"in O&&(i.errors=O.errors||ur),"warnings"in O&&(i.warnings=O.warnings||ur),i.dirty=!0,i.triggerMetaEvent(),i.reRender();return}if(d&&!v.length&&ip(d,u,g,w,x,c)){i.reRender();return}break}case"dependenciesUpdate":{var A=p.map(ht);if(A.some(function(D){return wa(c.relatedFields,D)})){i.reRender();return}break}default:if(N||(!p.length||v.length||d)&&ip(d,u,g,w,x,c)){i.reRender();return}break}d===!0&&i.reRender()},i.validateRules=function(u){var l=i.getNamePath(),c=i.getValue(),f=Promise.resolve().then(function(){if(!i.mounted)return[];var d=i.props,h=d.validateFirst,p=h===void 0?!1:h,m=d.messageVariables,g=u||{},v=g.triggerName,w=i.getRules();v&&(w=w.filter(function(N){return N}).filter(function(N){var O=N.validateTrigger;if(!O)return!0;var A=Y0(O);return A.includes(v)}));var x=iO(l,c,w,u,p,m);return x.catch(function(N){return N}).then(function(){var N=arguments.length>0&&arguments[0]!==void 0?arguments[0]:ur;if(i.validatePromise===f){var O;i.validatePromise=null;var A=[],D=[];(O=N.forEach)===null||O===void 0||O.call(N,function(H){var z=H.rule.warningOnly,L=H.errors,I=L===void 0?ur:L;z?D.push.apply(D,He(I)):A.push.apply(A,He(I))}),i.errors=A,i.warnings=D,i.triggerMetaEvent(),i.reRender()}}),x});return i.validatePromise=f,i.dirty=!0,i.errors=ur,i.warnings=ur,i.triggerMetaEvent(),i.reRender(),f},i.isFieldValidating=function(){return!!i.validatePromise},i.isFieldTouched=function(){return i.touched},i.isFieldDirty=function(){if(i.dirty||i.props.initialValue!==void 0)return!0;var u=i.props.fieldContext,l=u.getInternalHooks(ri),c=l.getInitialValue;return c(i.getNamePath())!==void 0},i.getErrors=function(){return i.errors},i.getWarnings=function(){return i.warnings},i.isListField=function(){return i.props.isListField},i.isList=function(){return i.props.isList},i.isPreserve=function(){return i.props.preserve},i.getMeta=function(){i.prevValidating=i.isFieldValidating();var u={touched:i.isFieldTouched(),validating:i.prevValidating,errors:i.errors,warnings:i.warnings,name:i.getNamePath()};return u},i.getOnlyChild=function(u){if(typeof u=="function"){var l=i.getMeta();return $e($e({},i.getOnlyChild(u(i.getControlled(),l,i.props.fieldContext))),{},{isFunction:!0})}var c=G0(u);return c.length!==1||!React.isValidElement(c[0])?{child:c,isFunction:!1}:{child:c[0],isFunction:!1}},i.getValue=function(u){var l=i.props.fieldContext.getFieldsValue,c=i.getNamePath();return Nn(u||l(!0),c)},i.getControlled=function(){var u=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},l=i.props,c=l.trigger,f=l.validateTrigger,d=l.getValueFromEvent,h=l.normalize,p=l.valuePropName,m=l.getValueProps,g=l.fieldContext,v=f!==void 0?f:g.validateTrigger,w=i.getNamePath(),x=g.getInternalHooks,N=g.getFieldsValue,O=x(ri),A=O.dispatch,D=i.getValue(),H=m||function(k){return Ca({},p,k)},z=u[c],L=$e($e({},u),H(D));L[c]=function(){i.touched=!0,i.dirty=!0,i.triggerMetaEvent();for(var k,M=arguments.length,F=new Array(M),C=0;C<M;C++)F[C]=arguments[C];d?k=d.apply(void 0,F):k=tO.apply(void 0,[p].concat(F)),h&&(k=h(k,D,N(!0))),A({type:"updateValue",namePath:w,value:k}),z&&z.apply(void 0,F)};var I=Y0(v||[]);return I.forEach(function(k){var M=L[k];L[k]=function(){M&&M.apply(void 0,arguments);var F=i.props.rules;F&&F.length&&A({type:"validateField",namePath:w,triggerName:k})}}),L},n.fieldContext){var a=n.fieldContext.getInternalHooks,o=a(ri),s=o.initEntityValue;s(A4(i))}return i}return Vf(r,[{key:"componentDidMount",value:function(){var i=this.props,a=i.shouldUpdate,o=i.fieldContext;if(this.mounted=!0,o){var s=o.getInternalHooks,u=s(ri),l=u.registerField;this.cancelRegisterFunc=l(this)}a===!0&&this.reRender()}},{key:"componentWillUnmount",value:function(){this.cancelRegister(),this.triggerMetaEvent(!0),this.mounted=!1}},{key:"reRender",value:function(){this.mounted&&this.forceUpdate()}},{key:"render",value:function(){var i=this.state.resetCount,a=this.props.children,o=this.getOnlyChild(a),s=o.child,u=o.isFunction,l;return u?l=s:React.isValidElement(s)?l=React.cloneElement(s,this.getControlled(s.props)):(Nr(!s,"`children` of Field is not validate ReactElement."),l=s),React.createElement(React.Fragment,{key:i},l)}}]),r}(React.Component);Gf.contextType=zi;Gf.defaultProps={trigger:"onChange",valuePropName:"value"};function P4(e){var t=e.name,r=qf(e,sO),n=React.useContext(zi),i=t!==void 0?ht(t):void 0,a="keep";return r.isListField||(a="_".concat((i||[]).join("_"))),React.createElement(Gf,Ds({key:a,name:i},r,{fieldContext:n}))}var uO=React.createContext(null),lO=function(t){var r=t.name,n=t.initialValue,i=t.children,a=t.rules,o=t.validateTrigger,s=React.useContext(zi),u=React.useRef({keys:[],id:0}),l=u.current,c=React.useMemo(function(){var p=ht(s.prefixName)||[];return[].concat(He(p),He(ht(r)))},[s.prefixName,r]),f=React.useMemo(function(){return $e($e({},s),{},{prefixName:c})},[s,c]),d=React.useMemo(function(){return{getKey:function(m){var g=c.length,v=m[g];return[l.keys[v],m.slice(g+1)]}}},[c]);if(typeof i!="function")return Nr(!1,"Form.List only accepts function as children."),null;var h=function(m,g,v){var w=v.source;return w==="internal"?!1:m!==g};return React.createElement(uO.Provider,{value:d},React.createElement(zi.Provider,{value:f},React.createElement(P4,{name:[],shouldUpdate:h,rules:a,validateTrigger:o,initialValue:n,isList:!0},function(p,m){var g=p.value,v=g===void 0?[]:g,w=p.onChange,x=s.getFieldValue,N=function(){var H=x(c||[]);return H||[]},O={add:function(H,z){var L=N();z>=0&&z<=L.length?(l.keys=[].concat(He(l.keys.slice(0,z)),[l.id],He(l.keys.slice(z))),w([].concat(He(L.slice(0,z)),[H],He(L.slice(z))))):(l.keys=[].concat(He(l.keys),[l.id]),w([].concat(He(L),[H]))),l.id+=1},remove:function(H){var z=N(),L=new Set(Array.isArray(H)?H:[H]);L.size<=0||(l.keys=l.keys.filter(function(I,k){return!L.has(k)}),w(z.filter(function(I,k){return!L.has(k)})))},move:function(H,z){if(H!==z){var L=N();H<0||H>=L.length||z<0||z>=L.length||(l.keys=rp(l.keys,H,z),w(rp(L,H,z)))}}},A=v||[];return Array.isArray(A)||(A=[]),i(A.map(function(D,H){var z=l.keys[H];return z===void 0&&(l.keys[H]=l.id,z=l.keys[H],l.id+=1),{name:H,key:z,isListField:!0}}),O,m)})))};function cO(e){if(Array.isArray(e))return e}function fO(e,t){var r=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(r!=null){var n,i,a,o,s=[],u=!0,l=!1;try{if(a=(r=r.call(e)).next,t===0){if(Object(r)!==r)return;u=!1}else for(;!(u=(n=a.call(r)).done)&&(s.push(n.value),s.length!==t);u=!0);}catch(c){l=!0,i=c}finally{try{if(!u&&r.return!=null&&(o=r.return(),Object(o)!==o))return}finally{if(l)throw i}}return s}}function dO(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Ra(e,t){return cO(e)||fO(e,t)||T4(e,t)||dO()}function hO(e){var t=!1,r=e.length,n=[];return e.length?new Promise(function(i,a){e.forEach(function(o,s){o.catch(function(u){return t=!0,u}).then(function(u){r-=1,n[s]=u,!(r>0)&&(t&&a(n),i(n))})})}):Promise.resolve([])}var D4="__@field_split__";function Ll(e){return e.map(function(t){return"".concat(ir(t),":").concat(t)}).join(D4)}var yi=function(){function e(){jf(this,e),this.kvs=new Map}return Vf(e,[{key:"set",value:function(r,n){this.kvs.set(Ll(r),n)}},{key:"get",value:function(r){return this.kvs.get(Ll(r))}},{key:"update",value:function(r,n){var i=this.get(r),a=n(i);a?this.set(r,a):this.delete(r)}},{key:"delete",value:function(r){this.kvs.delete(Ll(r))}},{key:"map",value:function(r){return He(this.kvs.entries()).map(function(n){var i=Ra(n,2),a=i[0],o=i[1],s=a.split(D4);return r({key:s.map(function(u){var l=u.match(/^([^:]*):(.*)$/),c=Ra(l,3),f=c[1],d=c[2];return f==="number"?Number(d):d}),value:o})})}},{key:"toJSON",value:function(){var r={};return this.map(function(n){var i=n.key,a=n.value;return r[i.join(".")]=a,null}),r}}]),e}(),pO=["name","errors"],mO=Vf(function e(t){var r=this;jf(this,e),this.formHooked=!1,this.forceRootUpdate=void 0,this.subscribable=!0,this.store={},this.fieldEntities=[],this.initialValues={},this.callbacks={},this.validateMessages=null,this.preserve=null,this.lastValidatePromise=null,this.getForm=function(){return{getFieldValue:r.getFieldValue,getFieldsValue:r.getFieldsValue,getFieldError:r.getFieldError,getFieldWarning:r.getFieldWarning,getFieldsError:r.getFieldsError,isFieldsTouched:r.isFieldsTouched,isFieldTouched:r.isFieldTouched,isFieldValidating:r.isFieldValidating,isFieldsValidating:r.isFieldsValidating,resetFields:r.resetFields,setFields:r.setFields,setFieldValue:r.setFieldValue,setFieldsValue:r.setFieldsValue,validateFields:r.validateFields,submit:r.submit,_init:!0,getInternalHooks:r.getInternalHooks}},this.getInternalHooks=function(n){return n===ri?(r.formHooked=!0,{dispatch:r.dispatch,initEntityValue:r.initEntityValue,registerField:r.registerField,useSubscribe:r.useSubscribe,setInitialValues:r.setInitialValues,destroyForm:r.destroyForm,setCallbacks:r.setCallbacks,setValidateMessages:r.setValidateMessages,getFields:r.getFields,setPreserve:r.setPreserve,getInitialValue:r.getInitialValue,registerWatch:r.registerWatch}):(Nr(!1,"`getInternalHooks` is internal usage. Should not call directly."),null)},this.useSubscribe=function(n){r.subscribable=n},this.prevWithoutPreserves=null,this.setInitialValues=function(n,i){if(r.initialValues=n||{},i){var a,o=ls({},n,r.store);(a=r.prevWithoutPreserves)===null||a===void 0||a.map(function(s){var u=s.key;o=Tn(o,u,Nn(n,u))}),r.prevWithoutPreserves=null,r.updateStore(o)}},this.destroyForm=function(){var n=new yi;r.getFieldEntities(!0).forEach(function(i){r.isMergedPreserve(i.isPreserve())||n.set(i.getNamePath(),!0)}),r.prevWithoutPreserves=n},this.getInitialValue=function(n){var i=Nn(r.initialValues,n);return n.length?Ou(i):i},this.setCallbacks=function(n){r.callbacks=n},this.setValidateMessages=function(n){r.validateMessages=n},this.setPreserve=function(n){r.preserve=n},this.watchList=[],this.registerWatch=function(n){return r.watchList.push(n),function(){r.watchList=r.watchList.filter(function(i){return i!==n})}},this.notifyWatch=function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];if(r.watchList.length){var i=r.getFieldsValue();r.watchList.forEach(function(a){a(i,n)})}},this.timeoutId=null,this.warningUnhooked=function(){},this.updateStore=function(n){r.store=n},this.getFieldEntities=function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1;return n?r.fieldEntities.filter(function(i){return i.getNamePath().length}):r.fieldEntities},this.getFieldsMap=function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1,i=new yi;return r.getFieldEntities(n).forEach(function(a){var o=a.getNamePath();i.set(o,a)}),i},this.getFieldEntitiesForNamePathList=function(n){if(!n)return r.getFieldEntities(!0);var i=r.getFieldsMap(!0);return n.map(function(a){var o=ht(a);return i.get(o)||{INVALIDATE_NAME_PATH:ht(a)}})},this.getFieldsValue=function(n,i){if(r.warningUnhooked(),n===!0&&!i)return r.store;var a=r.getFieldEntitiesForNamePathList(Array.isArray(n)?n:null),o=[];return a.forEach(function(s){var u,l="INVALIDATE_NAME_PATH"in s?s.INVALIDATE_NAME_PATH:s.getNamePath();if(!(!n&&(!((u=s.isListField)===null||u===void 0)&&u.call(s))))if(!i)o.push(l);else{var c="getMeta"in s?s.getMeta():null;i(c)&&o.push(l)}}),ep(r.store,o.map(ht))},this.getFieldValue=function(n){r.warningUnhooked();var i=ht(n);return Nn(r.store,i)},this.getFieldsError=function(n){r.warningUnhooked();var i=r.getFieldEntitiesForNamePathList(n);return i.map(function(a,o){return a&&!("INVALIDATE_NAME_PATH"in a)?{name:a.getNamePath(),errors:a.getErrors(),warnings:a.getWarnings()}:{name:ht(n[o]),errors:[],warnings:[]}})},this.getFieldError=function(n){r.warningUnhooked();var i=ht(n),a=r.getFieldsError([i])[0];return a.errors},this.getFieldWarning=function(n){r.warningUnhooked();var i=ht(n),a=r.getFieldsError([i])[0];return a.warnings},this.isFieldsTouched=function(){r.warningUnhooked();for(var n=arguments.length,i=new Array(n),a=0;a<n;a++)i[a]=arguments[a];var o=i[0],s=i[1],u,l=!1;i.length===0?u=null:i.length===1?Array.isArray(o)?(u=o.map(ht),l=!1):(u=null,l=o):(u=o.map(ht),l=s);var c=r.getFieldEntities(!0),f=function(g){return g.isFieldTouched()};if(!u)return l?c.every(f):c.some(f);var d=new yi;u.forEach(function(m){d.set(m,[])}),c.forEach(function(m){var g=m.getNamePath();u.forEach(function(v){v.every(function(w,x){return g[x]===w})&&d.update(v,function(w){return[].concat(He(w),[m])})})});var h=function(g){return g.some(f)},p=d.map(function(m){var g=m.value;return g});return l?p.every(h):p.some(h)},this.isFieldTouched=function(n){return r.warningUnhooked(),r.isFieldsTouched([n])},this.isFieldsValidating=function(n){r.warningUnhooked();var i=r.getFieldEntities();if(!n)return i.some(function(o){return o.isFieldValidating()});var a=n.map(ht);return i.some(function(o){var s=o.getNamePath();return wa(a,s)&&o.isFieldValidating()})},this.isFieldValidating=function(n){return r.warningUnhooked(),r.isFieldsValidating([n])},this.resetWithFieldInitialValue=function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},i=new yi,a=r.getFieldEntities(!0);a.forEach(function(u){var l=u.props.initialValue,c=u.getNamePath();if(l!==void 0){var f=i.get(c)||new Set;f.add({entity:u,value:l}),i.set(c,f)}});var o=function(l){l.forEach(function(c){var f=c.props.initialValue;if(f!==void 0){var d=c.getNamePath(),h=r.getInitialValue(d);if(h!==void 0)Nr(!1,"Form already set 'initialValues' with path '".concat(d.join("."),"'. Field can not overwrite it."));else{var p=i.get(d);if(p&&p.size>1)Nr(!1,"Multiple Field with path '".concat(d.join("."),"' set 'initialValue'. Can not decide which one to pick."));else if(p){var m=r.getFieldValue(d);(!n.skipExist||m===void 0)&&r.updateStore(Tn(r.store,d,He(p)[0].value))}}}})},s;n.entities?s=n.entities:n.namePathList?(s=[],n.namePathList.forEach(function(u){var l=i.get(u);if(l){var c;(c=s).push.apply(c,He(He(l).map(function(f){return f.entity})))}})):s=a,o(s)},this.resetFields=function(n){r.warningUnhooked();var i=r.store;if(!n){r.updateStore(ls({},r.initialValues)),r.resetWithFieldInitialValue(),r.notifyObservers(i,null,{type:"reset"}),r.notifyWatch();return}var a=n.map(ht);a.forEach(function(o){var s=r.getInitialValue(o);r.updateStore(Tn(r.store,o,s))}),r.resetWithFieldInitialValue({namePathList:a}),r.notifyObservers(i,a,{type:"reset"}),r.notifyWatch(a)},this.setFields=function(n){r.warningUnhooked();var i=r.store,a=[];n.forEach(function(o){var s=o.name;o.errors;var u=qf(o,pO),l=ht(s);a.push(l),"value"in u&&r.updateStore(Tn(r.store,l,u.value)),r.notifyObservers(i,[l],{type:"setField",data:o})}),r.notifyWatch(a)},this.getFields=function(){var n=r.getFieldEntities(!0),i=n.map(function(a){var o=a.getNamePath(),s=a.getMeta(),u=$e($e({},s),{},{name:o,value:r.getFieldValue(o)});return Object.defineProperty(u,"originRCField",{value:!0}),u});return i},this.initEntityValue=function(n){var i=n.props.initialValue;if(i!==void 0){var a=n.getNamePath(),o=Nn(r.store,a);o===void 0&&r.updateStore(Tn(r.store,a,i))}},this.isMergedPreserve=function(n){var i=n!==void 0?n:r.preserve;return i??!0},this.registerField=function(n){r.fieldEntities.push(n);var i=n.getNamePath();if(r.notifyWatch([i]),n.props.initialValue!==void 0){var a=r.store;r.resetWithFieldInitialValue({entities:[n],skipExist:!0}),r.notifyObservers(a,[n.getNamePath()],{type:"valueUpdate",source:"internal"})}return function(o,s){var u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];if(r.fieldEntities=r.fieldEntities.filter(function(f){return f!==n}),!r.isMergedPreserve(s)&&(!o||u.length>1)){var l=o?void 0:r.getInitialValue(i);if(i.length&&r.getFieldValue(i)!==l&&r.fieldEntities.every(function(f){return!I4(f.getNamePath(),i)})){var c=r.store;r.updateStore(Tn(c,i,l,!0)),r.notifyObservers(c,[i],{type:"remove"}),r.triggerDependenciesUpdate(c,i)}}r.notifyWatch([i])}},this.dispatch=function(n){switch(n.type){case"updateValue":{var i=n.namePath,a=n.value;r.updateValue(i,a);break}case"validateField":{var o=n.namePath,s=n.triggerName;r.validateFields([o],{triggerName:s});break}}},this.notifyObservers=function(n,i,a){if(r.subscribable){var o=$e($e({},a),{},{store:r.getFieldsValue(!0)});r.getFieldEntities().forEach(function(s){var u=s.onStoreChange;u(n,i,o)})}else r.forceRootUpdate()},this.triggerDependenciesUpdate=function(n,i){var a=r.getDependencyChildrenFields(i);return a.length&&r.validateFields(a),r.notifyObservers(n,a,{type:"dependenciesUpdate",relatedFields:[i].concat(He(a))}),a},this.updateValue=function(n,i){var a=ht(n),o=r.store;r.updateStore(Tn(r.store,a,i)),r.notifyObservers(o,[a],{type:"valueUpdate",source:"internal"}),r.notifyWatch([a]);var s=r.triggerDependenciesUpdate(o,a),u=r.callbacks.onValuesChange;if(u){var l=ep(r.store,[a]);u(l,r.getFieldsValue())}r.triggerOnFieldsChange([a].concat(He(s)))},this.setFieldsValue=function(n){r.warningUnhooked();var i=r.store;if(n){var a=ls(r.store,n);r.updateStore(a)}r.notifyObservers(i,null,{type:"valueUpdate",source:"external"}),r.notifyWatch()},this.setFieldValue=function(n,i){r.setFields([{name:n,value:i}])},this.getDependencyChildrenFields=function(n){var i=new Set,a=[],o=new yi;r.getFieldEntities().forEach(function(u){var l=u.props.dependencies;(l||[]).forEach(function(c){var f=ht(c);o.update(f,function(){var d=arguments.length>0&&arguments[0]!==void 0?arguments[0]:new Set;return d.add(u),d})})});var s=function u(l){var c=o.get(l)||new Set;c.forEach(function(f){if(!i.has(f)){i.add(f);var d=f.getNamePath();f.isFieldDirty()&&d.length&&(a.push(d),u(d))}})};return s(n),a},this.triggerOnFieldsChange=function(n,i){var a=r.callbacks.onFieldsChange;if(a){var o=r.getFields();if(i){var s=new yi;i.forEach(function(l){var c=l.name,f=l.errors;s.set(c,f)}),o.forEach(function(l){l.errors=s.get(l.name)||l.errors})}var u=o.filter(function(l){var c=l.name;return wa(n,c)});a(u,o)}},this.validateFields=function(n,i){r.warningUnhooked();var a=!!n,o=a?n.map(ht):[],s=[];r.getFieldEntities(!0).forEach(function(c){if(a||o.push(c.getNamePath()),i!=null&&i.recursive&&a){var f=c.getNamePath();f.every(function(p,m){return n[m]===p||n[m]===void 0})&&o.push(f)}if(!(!c.props.rules||!c.props.rules.length)){var d=c.getNamePath();if(!a||wa(o,d)){var h=c.validateRules($e({validateMessages:$e($e({},O4),r.validateMessages)},i));s.push(h.then(function(){return{name:d,errors:[],warnings:[]}}).catch(function(p){var m,g=[],v=[];return(m=p.forEach)===null||m===void 0||m.call(p,function(w){var x=w.rule.warningOnly,N=w.errors;x?v.push.apply(v,He(N)):g.push.apply(g,He(N))}),g.length?Promise.reject({name:d,errors:g,warnings:v}):{name:d,errors:g,warnings:v}}))}}});var u=hO(s);r.lastValidatePromise=u,u.catch(function(c){return c}).then(function(c){var f=c.map(function(d){var h=d.name;return h});r.notifyObservers(r.store,f,{type:"validateFinish"}),r.triggerOnFieldsChange(f,c)});var l=u.then(function(){return r.lastValidatePromise===u?Promise.resolve(r.getFieldsValue(o)):Promise.reject([])}).catch(function(c){var f=c.filter(function(d){return d&&d.errors.length});return Promise.reject({values:r.getFieldsValue(o),errorFields:f,outOfDate:r.lastValidatePromise!==u})});return l.catch(function(c){return c}),l},this.submit=function(){r.warningUnhooked(),r.validateFields().then(function(n){var i=r.callbacks.onFinish;if(i)try{i(n)}catch(a){console.error(a)}}).catch(function(n){var i=r.callbacks.onFinishFailed;i&&i(n)})},this.forceRootUpdate=t});function L4(e){var t=React.useRef(),r=React.useState({}),n=Ra(r,2),i=n[1];if(!t.current)if(e)t.current=e;else{var a=function(){i({})},o=new mO(a);t.current=o.getForm()}return[t.current]}var sc=React.createContext({triggerFormChange:function(){},triggerFormFinish:function(){},registerForm:function(){},unregisterForm:function(){}}),gO=function(t){var r=t.validateMessages,n=t.onFormChange,i=t.onFormFinish,a=t.children,o=React.useContext(sc),s=React.useRef({});return React.createElement(sc.Provider,{value:$e($e({},o),{},{validateMessages:$e($e({},o.validateMessages),r),triggerFormChange:function(l,c){n&&n(l,{changedFields:c,forms:s.current}),o.triggerFormChange(l,c)},triggerFormFinish:function(l,c){i&&i(l,{values:c,forms:s.current}),o.triggerFormFinish(l,c)},registerForm:function(l,c){l&&(s.current=$e($e({},s.current),{},Ca({},l,c))),o.registerForm(l,c)},unregisterForm:function(l){var c=$e({},s.current);delete c[l],s.current=c,o.unregisterForm(l)}})},a)},bO=["name","initialValues","fields","form","preserve","children","component","validateMessages","validateTrigger","onValuesChange","onFieldsChange","onFinish","onFinishFailed"],vO=function(t,r){var n=t.name,i=t.initialValues,a=t.fields,o=t.form,s=t.preserve,u=t.children,l=t.component,c=l===void 0?"form":l,f=t.validateMessages,d=t.validateTrigger,h=d===void 0?"onChange":d,p=t.onValuesChange,m=t.onFieldsChange,g=t.onFinish,v=t.onFinishFailed,w=qf(t,bO),x=React.useContext(sc),N=L4(o),O=Ra(N,1),A=O[0],D=A.getInternalHooks(ri),H=D.useSubscribe,z=D.setInitialValues,L=D.setCallbacks,I=D.setValidateMessages,k=D.setPreserve,M=D.destroyForm;React.useImperativeHandle(r,function(){return A}),React.useEffect(function(){return x.registerForm(n,A),function(){x.unregisterForm(n)}},[x,A,n]),I($e($e({},x.validateMessages),f)),L({onValuesChange:p,onFieldsChange:function(ne){if(x.triggerFormChange(n,ne),m){for(var T=arguments.length,G=new Array(T>1?T-1:0),ee=1;ee<T;ee++)G[ee-1]=arguments[ee];m.apply(void 0,[ne].concat(G))}},onFinish:function(ne){x.triggerFormFinish(n,ne),g&&g(ne)},onFinishFailed:v}),k(s);var F=React.useRef(null);z(i,!F.current),F.current||(F.current=!0),React.useEffect(function(){return M},[]);var C,U=typeof u=="function";if(U){var $=A.getFieldsValue(!0);C=u($,A)}else C=u;H(!U);var V=React.useRef();React.useEffect(function(){eO(V.current||[],a||[])||A.setFields(a||[]),V.current=a},[a,A]);var se=React.useMemo(function(){return $e($e({},A),{},{validateTrigger:h})},[A,h]),_=React.createElement(zi.Provider,{value:se},C);return c===!1?_:React.createElement(c,Ds({},w,{onSubmit:function(ne){ne.preventDefault(),ne.stopPropagation(),A.submit()},onReset:function(ne){var T;ne.preventDefault(),A.resetFields(),(T=w.onReset)===null||T===void 0||T.call(w,ne)}}),_)};function ap(e){try{return JSON.stringify(e)}catch{return Math.random()}}function yO(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];var n=t[0],i=n===void 0?[]:n,a=t[1],o=React.useState(),s=Ra(o,2),u=s[0],l=s[1],c=React.useMemo(function(){return ap(u)},[u]),f=React.useRef(c);f.current=c;var d=React.useContext(zi),h=a||d,p=h&&h._init,m=ht(i),g=React.useRef(m);return g.current=m,React.useEffect(function(){if(p){var v=h.getFieldsValue,w=h.getInternalHooks,x=w(ri),N=x.registerWatch,O=N(function(D){var H=Nn(D,g.current),z=ap(H);f.current!==z&&(f.current=z,l(H))}),A=Nn(v(),g.current);return l(A),O}},[p]),u}var wO=React.forwardRef(vO),no=wO;no.FormProvider=gO;no.Field=P4;no.List=lO;no.useForm=L4;no.useWatch=yO;var xO=function(t,r){return r||(t?"ant-".concat(t):"ant")},EO=React.createContext({getPrefixCls:xO});EO.Consumer;const Di=({icon:e,color:t,fontSize:r,style:n,className:i})=>{const a=vt(i,e,"iconfont");return he.jsx("i",{className:a,style:Object.assign({display:"inline-block",color:`${t&&t}`,fontSize:`${r&&r}`},n)})};React.createContext({latestIndex:0,horizontalSize:0,verticalSize:0});function SO(e,t){typeof e=="function"?e(t):typeof e=="object"&&e&&"current"in e&&(e.current=t)}function TO(...e){const t=e.filter(r=>r);return t.length<=1?t[0]:r=>{e.forEach(n=>{SO(n,r)})}}const AO=function(e){const t=function(r){const n=r.type;return(n==="DOMMouseScroll"||n==="mousewheel")&&(r.delta=r.wheelDelta?r.wheelDelta/120:-(r.detail||0)/3),r.srcElement&&!r.target&&(r.target=r.srcElement),!r.preventDefault&&r.returnValue!==void 0&&(r.preventDefault=function(){r.returnValue=!1}),r};return e.addEventListener?function(r,n,i,a){n==="mousewheel"&&document.mozFullScreen!==void 0&&(n="DOMMouseScroll");const o=function(s){i.call(this,t(s))};return r.addEventListener(n,o,a||!1),function(){r.removeEventListener(n,o,a)}}:e.attachEvent?function(r,n,i){const a=function(o){o=o||e.event,i.call(r,t(o))};return r.attachEvent(`on${n}`,a),function(){r.detachEvent(`on${n}`,a)}}:()=>{}}(window);var Fs;(function(e){e[e.hoz=1]="hoz",e[e.ver=2]="ver"})(Fs||(Fs={}));const kO={tabExtraGap:10,direction:Fs.hoz},OO={x:0,y:0},NO=(e,t=Object.assign({},kO))=>{const[r,n]=React.useState(OO),[i,a]=React.useState(!1),o=React.useRef(0),s=React.useRef(null),{tabExtraGap:u,direction:l}=t;return React.useEffect(()=>{const c=h=>{h.preventDefault();const p=h.delta*30,m=h.delta*30;n(g=>{let v=g.x-p;v>0?v=0:v<o.current&&(v=o.current);const w=g.y-m;return Fs.hoz,{x:0,y:0}})};let f=null;return(()=>{if(s.current){const h=s.current.clientWidth,p=s.current.parentNode.clientWidth;h>=p&&(o.current=p-h,f=AO(s.current,"mousewheel",c,{passive:!1})),a(p<h+u)}})(),()=>{typeof f=="function"&&f()}},[r,e]),{position:r,scrollRef:s,isExpandContainer:i}};function op(e){const t=React.useRef();return t.current=e,React.useCallback((...n)=>{var i;return(i=t.current)===null||i===void 0?void 0:i.call(t,...n)},[])}function _O(){return!!(typeof window<"u"&&window.document&&window.document.createElement)}const sp=_O()?React.useLayoutEffect:React.useEffect,CO=(e,t)=>{const r=React.useRef(!0);sp(()=>e(r.current),t),sp(()=>(r.current=!1,()=>{r.current=!0}),[])},up=(e,t)=>{CO(r=>{if(!r)return e()},t)};function lp(e){const t=React.useRef(!1),[r,n]=React.useState(e);React.useEffect(()=>(t.current=!1,()=>{t.current=!0}),[]);function i(a,o){o&&t.current||n(a)}return[r,i]}function Fl(e){return e!==void 0}function F4(e,t){const{defaultValue:r,value:n,onChange:i,postState:a}=t||{},[o,s]=lp(()=>Fl(n)?n:Fl(r)?typeof r=="function"?r():r:typeof e=="function"?e():e),u=n!==void 0?n:o,l=a?a(u):u,c=op(i),[f,d]=lp([u]);up(()=>{const p=f[0];o!==p&&c(o,p)},[f]),up(()=>{Fl(n)||s(n)},[n]);const h=op((p,m)=>{s(p,m),d([u],m)});return[l,h]}const MO=(e,t)=>{var{defaultValue:r,value:n,onChange:i,onPressEnter:a,onKeyDown:o,disabled:s=!1,prepend:u,append:l,prefix:c,suffix:f,id:d,className:h,inputWrapperClassName:p,inputClassName:m,prefixCls:g="seal"}=e,v=to(e,["defaultValue","value","onChange","onPressEnter","onKeyDown","disabled","prepend","append","prefix","suffix","id","className","inputWrapperClassName","inputClassName","prefixCls"]);const[w,x]=F4("",{value:n,defaultValue:r}),N=vt(h,`${g}-input-group`),O=vt(`${g}-input-inner-container`,p,{[`${g}-input-inner-affix-container`]:c||f,[`${g}-input-inner-container-disabled`]:s}),A=vt(m,`${g}-inner-input`),D=z=>{i==null||i(z),x(z.target.value)},H=z=>{z.key==="Enter"&&a&&a(z),o==null||o(z)};return he.jsxs("span",Object.assign({id:d,className:N},{children:[u&&he.jsx("span",Object.assign({className:`${g}-input-prepend`},{children:u})),he.jsxs("span",Object.assign({className:O},{children:[c&&he.jsx("span",Object.assign({className:`${g}-input-prefix`},{children:c})),he.jsx("input",Object.assign({className:A,type:"text",ref:t,value:w,onChange:D,onKeyDown:H,disabled:s},v)),f&&he.jsx("span",Object.assign({className:`${g}-input-suffix`},{children:f}))]})),l&&he.jsx("span",Object.assign({className:`${g}-input-append`},{children:l}))]}))},RO=React.forwardRef(MO),H$=RO;var IO={locale:"zh-CN",pagination:{jump_prev_five:"向前5页",jump_next_five:"向后5页",jump_to:"跳至",page:"页"}};React.createContext({locale:IO});const PO=({children:e,wrapperId:t="react-portal-wrapper"})=>{const[r,n]=React.useState(null);return React.useLayoutEffect(()=>{let i=document.getElementById(t),a=!1;if(!i){const o=document.createElement("div");document.body.appendChild(o),i=o,a=!0}return n(i),()=>{a&&i.parentNode&&i.parentNode.removeChild(i)}},[t]),r===null?null:ReactDOM.createPortal(e,r)},Ni={messageList:[],messageWrapper:null,destroy(){this.messageWrapper&&!this.messageWrapper.children.length&&(this.messageWrapper.parentNode.removeChild(this.messageWrapper),this.messageWrapper=null,this.messageList=[])},open(e,t=()=>document.body){this.messageList.push(e),this.messageWrapper||(this.messageWrapper=document.createElement("div"),this.messageWrapper.classList.add("seal-message-root-wrapper"),t().appendChild(this.messageWrapper)),ReactDOM.render(this.messageList.map(r=>r),this.messageWrapper)}},DO={success:"icon-CheckCircleFilled",error:"icon-CloseCircleFilled",warning:"icon-InfoFilled",info:"icon-InfoFilled",loading:"icon-RefreshOutlined"},No=(e,t)=>{const{title:r,children:n,icon:i,content:a,type:o="success",duration:s=5,className:u,style:l,closable:c=!1,maxCount:f=10,onClose:d=()=>null}=e,[h,p]=React.useState(!0),m=vt("seal-message-icon",o==="loading"&&"seal-message-loading"),g=vt("seal-message-wrapper",`seal-message-${o}`,o,u);return setTimeout(()=>{d(),p(!1),Ni.destroy()},s*1e3),!h||Ni.messageList.length>=f?null:he.jsx("div",{children:he.jsxs("div",Object.assign({className:g,style:l},{children:[i||he.jsx(Di,{icon:DO[o],className:m}),he.jsx("span",Object.assign({className:"seal-message-title"},{children:n||r})),c&&he.jsx("div",Object.assign({className:"seal-message-close",onClick:d},{children:he.jsx(Di,{icon:"icon-cuowu1"})}))]}))})},_o=(e,t)=>{if(typeof e=="string")return{type:t,title:e};if(typeof e=="object"){const{title:r}=e;return Object.assign({type:t,title:r==null?void 0:r.toString()},e)}return{type:t,title:""}},q$={success(e){const t=_o(e,"success");Ni.open(he.jsx(No,Object.assign({},t)))},warning(e){const t=_o(e,"warning");Ni.open(he.jsx(No,Object.assign({},t)))},info(e){const t=_o(e,"info");Ni.open(he.jsx(No,Object.assign({},t)))},error(e){const t=_o(e,"error");Ni.open(he.jsx(No,Object.assign({},t)))}},LO=e=>{const{children:t,title:r,closeable:n=!0,showIcon:i=!0,icon:a,closeIcon:o,okText:s,cancelText:u,footer:l,width:c=400,style:f,className:d,loading:h=!1,loadingIcon:p,onOk:m=()=>null,onCancel:g=()=>null,onClose:v=()=>null}=e,w=vt("seal-modal-icon"),x=vt("seal-modal-card",d),N=a||he.jsx(Di,{icon:"icon-InfoFilled",className:w}),O=o||he.jsx(ss,Object.assign({btnType:"icon",onClick:v},{children:he.jsx(Di,{icon:"icon-cuowu1",style:{fontSize:24,cursor:"pointer"}})})),A=l||he.jsxs("div",Object.assign({className:"seal-modal-footer"},{children:[he.jsx(ss,Object.assign({btnType:"secondary",onClick:()=>{g(),v()},style:{marginRight:12}},{children:u||"取消"})),he.jsx(ss,Object.assign({btnType:"primary",disabled:h,onClick:()=>{m(),v()}},{children:h?he.jsxs(he.Fragment,{children:[p||he.jsx(Di,{icon:"icon-RefreshOutlined",className:"spin"}),s||"确认"]}):s}))]}));return React.useEffect(()=>{const D=H=>H.key==="Escape"?v():null;return document.body.addEventListener("keydown",D),()=>{document.body.removeEventListener("keydown",D)}},[v]),he.jsxs("div",Object.assign({className:x,style:Object.assign({width:c},f)},{children:[i&&N,he.jsxs("div",Object.assign({className:"seal-modal-right"},{children:[he.jsxs("div",Object.assign({className:"seal-modal-header"},{children:[he.jsx("div",Object.assign({className:"seal-modal-title"},{children:r})),n&&O]})),he.jsx("div",Object.assign({className:"seal-modal-content"},{children:t})),A]}))]}))},j$=e=>{const{open:t,className:r,maskClosable:n=!0,onClose:i=()=>null}=e,a=React.useRef(null),o=vt("seal-modal-wrapper",r);return he.jsx(PO,{children:he.jsx(HA,Object.assign({in:t,timeout:{entry:200,exit:0},unmountOnExit:!0,classNames:"seal-modal-animation",nodeRef:a},{children:he.jsxs("div",Object.assign({className:"seal-modal-root",ref:a},{children:[n&&he.jsx("div",{className:"seal-modal-mask",onClick:i}),he.jsx(LO,Object.assign({},e,{className:o}))]}))}))})},FO=e=>{var{children:t,itemKey:r,editable:n,type:i="text",style:a,className:o,active:s,disabled:u,onClick:l,onDelBtnClick:c,onMounted:f}=e,d=to(e,["children","itemKey","editable","type","style","className","active","disabled","onClick","onDelBtnClick","onMounted"]);const h=React.useRef(null),p=vt(o,"seal-tab-item",s&&"seal-tab-item-active",u&&"seal-tab-item-active",`seal-tab-${i}`),m=g=>{const v=h.current.clientWidth,w=h.current.offsetLeft,x={width:v,left:w,itemKey:r};n&&c(x)===!1||l(x,g)};return React.useEffect(()=>{if(h.current&&r!==void 0&&typeof f=="function"){const g=h.current.clientWidth,v=h.current.offsetLeft;f({width:g,left:v,itemKey:r})}},[r]),he.jsx("div",Object.assign({className:p,ref:h,style:a,onClick:m},d,{children:t}))},BO={tabs:[],prefixCls:""},zO=React.createContext(BO),$O=({x:e,y:t})=>({transform:`translate(${e}px, ${t}px)`}),cp=({onClick:e,isEmpty:t})=>{const r=vt("seal-tabs-extra-btn",t&&"seal-tabs-empty-extra-btn");return he.jsx(ss,Object.assign({btnType:"icon",onClick:e,className:r},{children:he.jsx(Di,{icon:"icon-PlusOutlined"})}))},UO=({className:e,defaultActiveKey:t,items:r,editable:n,style:i,id:a,onChange:o=f=>{},onTabExtraClick:s=()=>{},onTabItemClick:u=(f,d,h)=>{},onTabItemDelClick:l=f=>{}},c)=>{const[f,d]=React.useState(t),h=React.useRef(""),[p,m]=React.useState([]),[g,v]=React.useState({width:0,left:0,itemKey:""}),{position:w,scrollRef:x,isExpandContainer:N}=NO(r),O=vt(e,"seal-tabs"),A=vt("seal-tabs-container",N&&"seal-tabs-near-extra"),D=()=>{h.current="add",s()},H=(k,M)=>{d(k.itemKey);const F=r.find(C=>C.key===k.itemKey);u(F,r,M),o(k.itemKey)},z=k=>{m(M=>[...M,k])};React.useEffect(()=>{const k=p.find(M=>M.itemKey===f);k&&v(k)},[f,p]),React.useEffect(()=>{if(typeof o=="function"){if(!r.find(M=>M.key===f)&&r.length>0){const M=r[r.length-1];d(M.key),o(M.key)}h.current=""}},[r,o,f]);const L=React.useMemo(()=>({tabs:[],prefixCls:""}),[]),I=r.length===0;return he.jsx(zO.Provider,Object.assign({value:L},{children:he.jsx("div",Object.assign({className:O,id:a,ref:c},{children:he.jsxs("div",Object.assign({className:"seal-tabs-nav"},{children:[he.jsx("div",Object.assign({className:A},{children:he.jsxs("div",Object.assign({className:"seal-tabs-list",ref:x,style:$O(w)},{children:[r.map(k=>he.jsx("div",Object.assign({className:"seal-tab-item-wrapper"},{children:he.jsx(FO,Object.assign({active:f===k.key,itemKey:k.key,editable:n,onClick:H,onMounted:z},{children:k.label}))}),k.key)),n&&!N&&he.jsx(cp,{isEmpty:I,onClick:D}),!I&&he.jsx("div",{className:"seal-tabs-ink-bar",style:{width:g.width,left:g.left}})]}))})),n&&N&&he.jsx(cp,{isEmpty:I,onClick:D})]}))}))}))};React.forwardRef(UO);React.createContext({currentIndex:0,initial:0,size:"default",status:"process",labelPlacement:"horizontal",direction:"horizontal",progressDot:!1,onChange:e=>null});const Co=6,HO=({title:e,position:t="top",prefixCls:r="seal",className:n,arrowClassName:i,contentClassName:a,theme:o={},style:s},u)=>{const l=vt(n,`${r}-tooltip`,`${r}-tooltip-${t}`),c=vt(i,`${r}-tooltip-arrow`),f=vt(a,`${r}-tooltip-content`),d=o.background,h=d?{background:d}:{};return he.jsxs("div",Object.assign({className:l,ref:u,style:Object.assign(Object.assign({},o),s)},{children:[he.jsx("div",{className:c,style:h}),he.jsx("div",Object.assign({className:f},{children:e}))]}))},qO=React.forwardRef(HO),jO=(e,t,r)=>{if(!e||!t)return{top:0,left:0,width:0,height:0};const n=(e.height-t.height)/2,i=(e.width-t.width)/2;let a=0,o=0;const s=t.width,u=t.height;switch(r){case"top":a=e.top-t.height-Co,o=e.left+i;break;case"right":a=e.top+n,o=e.left+e.width+Co;break;case"bottom":a=e.top+e.height+Co,o=e.left+i;break;default:a=e.top+n,o=e.left-t.width-Co}return{top:a,left:o,width:s,height:u}},VO=(e,t,r)=>{const i=window.innerWidth,a=0,o=window.innerHeight,s=e.top-a>t.height,u=o-e.bottom>t.height,l=e.left-0>t.width,c=i-e.right>t.width;return r==="top"?s?"top":"bottom":r==="bottom"?u?"bottom":"top":r==="left"?l?"left":"right":r==="right"?c?"right":"left":r},GO=(e,t)=>{const{onMouseEnter:r,onMouseLeave:n,onMouseMove:i}=e;return{onMouseEnter:(...u)=>{r==null||r(...u),t.onMouseEnter(...u)},onMouseLeave:(...u)=>{n==null||n(...u),t.onMouseLeave(...u)},onMouseMove:(...u)=>{i==null||i(...u),t.onMouseMove(...u)}}},V$=e=>{var{open:t,title:r,position:n="top",autoPosition:i=!1,getPopupContainer:a=()=>document.body,mouseLeaveDelay:o=30,children:s}=e,u=to(e,["open","title","position","autoPosition","getPopupContainer","mouseLeaveDelay","children"]);const[l,c]=F4(!1,{value:t,defaultValue:!1}),[f,d]=React.useState({top:0,left:0,width:0,height:0}),[h,p]=React.useState(n),m=React.Children.only(s),g=React.useRef(null),v=React.useRef(null),w=React.useRef(null),x=()=>{c(!0)},N=()=>{c(!0)},O=()=>{w.current&&clearTimeout(w.current),w.current=setTimeout(()=>{c(!1)},o)},A=m.ref,D=GO(m.props,{onMouseEnter:x,onMouseMove:N,onMouseLeave:O}),H=Object.assign({ref:TO(g,A)},D),z=React.cloneElement(m,H);React.useEffect(()=>{if(l&&g.current){const k=g.current.getBoundingClientRect(),M=v.current.getBoundingClientRect(),F=i?VO(k,M,n):n,C=jO(k,M,F);d(C),p(F)}else d({top:-99999,left:-99999,width:0,height:0})},[l,n,i]);const L=Object.assign({title:r,position:h},u),I={position:"fixed",top:f.top,left:f.left};return he.jsxs(he.Fragment,{children:[z,l&&ReactDOM.createPortal(he.jsx("div",Object.assign({className:vt("seal-tooltip-wrapper",l&&"seal-toolip-wrapper-open"),style:I},D,{children:he.jsx(qO,Object.assign({},L,{ref:v}))})),a())]})},WO=React.createContext(null);WO.Provider;function KO(e,t){if(e==null)return{};var r=Uf(e,t),n,i;if(Object.getOwnPropertySymbols){var a=Object.getOwnPropertySymbols(e);for(i=0;i<a.length;i++)n=a[i],!(t.indexOf(n)>=0)&&Object.prototype.propertyIsEnumerable.call(e,n)&&(r[n]=e[n])}return r}function uc(e,t){(t==null||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function XO(e){if(Array.isArray(e))return uc(e)}function YO(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function ZO(e,t){if(e){if(typeof e=="string")return uc(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);if(r==="Object"&&e.constructor&&(r=e.constructor.name),r==="Map"||r==="Set")return Array.from(e);if(r==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r))return uc(e,t)}}function QO(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function JO(e){return XO(e)||YO(e)||ZO(e)||QO()}function Ia(e){"@babel/helpers - typeof";return Ia=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Ia(e)}function eN(e,t){if(Ia(e)!="object"||!e)return e;var r=e[Symbol.toPrimitive];if(r!==void 0){var n=r.call(e,t||"default");if(Ia(n)!="object")return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function tN(e){var t=eN(e,"string");return Ia(t)=="symbol"?t:String(t)}function B4(e,t,r){return t=tN(t),t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}function fp(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter(function(i){return Object.getOwnPropertyDescriptor(e,i).enumerable})),r.push.apply(r,n)}return r}function _i(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?arguments[t]:{};t%2?fp(Object(r),!0).forEach(function(n){B4(e,n,r[n])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):fp(Object(r)).forEach(function(n){Object.defineProperty(e,n,Object.getOwnPropertyDescriptor(r,n))})}return e}function rN(e){var t=e.length;if(t===0||t===1)return e;if(t===2)return[e[0],e[1],"".concat(e[0],".").concat(e[1]),"".concat(e[1],".").concat(e[0])];if(t===3)return[e[0],e[1],e[2],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0])];if(t>=4)return[e[0],e[1],e[2],e[3],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[2],".").concat(e[3]),"".concat(e[3],".").concat(e[0]),"".concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[0]),"".concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[3],".").concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[2],".").concat(e[1],".").concat(e[0])]}var Bl={};function nN(e){if(e.length===0||e.length===1)return e;var t=e.join(".");return Bl[t]||(Bl[t]=rN(e)),Bl[t]}function iN(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=arguments.length>2?arguments[2]:void 0,n=e.filter(function(a){return a!=="token"}),i=nN(n);return i.reduce(function(a,o){return _i(_i({},a),r[o])},t)}function dp(e){return e.join(" ")}function aN(e,t){var r=0;return function(n){return r+=1,n.map(function(i,a){return z4({node:i,stylesheet:e,useInlineStyles:t,key:"code-segment-".concat(r,"-").concat(a)})})}}function z4(e){var t=e.node,r=e.stylesheet,n=e.style,i=n===void 0?{}:n,a=e.useInlineStyles,o=e.key,s=t.properties,u=t.type,l=t.tagName,c=t.value;if(u==="text")return c;if(l){var f=aN(r,a),d;if(!a)d=_i(_i({},s),{},{className:dp(s.className)});else{var h=Object.keys(r).reduce(function(v,w){return w.split(".").forEach(function(x){v.includes(x)||v.push(x)}),v},[]),p=s.className&&s.className.includes("token")?["token"]:[],m=s.className&&p.concat(s.className.filter(function(v){return!h.includes(v)}));d=_i(_i({},s),{},{className:dp(m)||void 0,style:iN(s.className,Object.assign({},s.style,i),r)})}var g=f(t.children);return React.createElement(l,Ps({key:o},d),g)}}const oN=function(e,t){var r=e.listLanguages();return r.indexOf(t)!==-1};var sN=["language","children","style","customStyle","codeTagProps","useInlineStyles","showLineNumbers","showInlineLineNumbers","startingLineNumber","lineNumberContainerStyle","lineNumberStyle","wrapLines","wrapLongLines","lineProps","renderer","PreTag","CodeTag","code","astGenerator"];function hp(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter(function(i){return Object.getOwnPropertyDescriptor(e,i).enumerable})),r.push.apply(r,n)}return r}function Lr(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?arguments[t]:{};t%2?hp(Object(r),!0).forEach(function(n){B4(e,n,r[n])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):hp(Object(r)).forEach(function(n){Object.defineProperty(e,n,Object.getOwnPropertyDescriptor(r,n))})}return e}var uN=/\n/g;function lN(e){return e.match(uN)}function cN(e){var t=e.lines,r=e.startingLineNumber,n=e.style;return t.map(function(i,a){var o=a+r;return React.createElement("span",{key:"line-".concat(a),className:"react-syntax-highlighter-line-number",style:typeof n=="function"?n(o):n},"".concat(o,`
`))})}function fN(e){var t=e.codeString,r=e.codeStyle,n=e.containerStyle,i=n===void 0?{float:"left",paddingRight:"10px"}:n,a=e.numberStyle,o=a===void 0?{}:a,s=e.startingLineNumber;return React.createElement("code",{style:Object.assign({},r,i)},cN({lines:t.replace(/\n$/,"").split(`
`),style:o,startingLineNumber:s}))}function dN(e){return"".concat(e.toString().length,".25em")}function $4(e,t){return{type:"element",tagName:"span",properties:{key:"line-number--".concat(e),className:["comment","linenumber","react-syntax-highlighter-line-number"],style:t},children:[{type:"text",value:e}]}}function U4(e,t,r){var n={display:"inline-block",minWidth:dN(r),paddingRight:"1em",textAlign:"right",userSelect:"none"},i=typeof e=="function"?e(t):e,a=Lr(Lr({},n),i);return a}function cs(e){var t=e.children,r=e.lineNumber,n=e.lineNumberStyle,i=e.largestLineNumber,a=e.showInlineLineNumbers,o=e.lineProps,s=o===void 0?{}:o,u=e.className,l=u===void 0?[]:u,c=e.showLineNumbers,f=e.wrapLongLines,d=typeof s=="function"?s(r):s;if(d.className=l,r&&a){var h=U4(n,r,i);t.unshift($4(r,h))}return f&c&&(d.style=Lr(Lr({},d.style),{},{display:"flex"})),{type:"element",tagName:"span",properties:d,children:t}}function H4(e){for(var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[],n=0;n<e.length;n++){var i=e[n];if(i.type==="text")r.push(cs({children:[i],className:JO(new Set(t))}));else if(i.children){var a=t.concat(i.properties.className);H4(i.children,a).forEach(function(o){return r.push(o)})}}return r}function hN(e,t,r,n,i,a,o,s,u){var l,c=H4(e.value),f=[],d=-1,h=0;function p(O,A){var D=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return cs({children:O,lineNumber:A,lineNumberStyle:s,largestLineNumber:o,showInlineLineNumbers:i,lineProps:r,className:D,showLineNumbers:n,wrapLongLines:u})}function m(O,A){if(n&&A&&i){var D=U4(s,A,o);O.unshift($4(A,D))}return O}function g(O,A){var D=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return t||D.length>0?p(O,A,D):m(O,A)}for(var v=function(){var A=c[h],D=A.children[0].value,H=lN(D);if(H){var z=D.split(`
`);z.forEach(function(L,I){var k=n&&f.length+a,M={type:"text",value:"".concat(L,`
`)};if(I===0){var F=c.slice(d+1,h).concat(cs({children:[M],className:A.properties.className})),C=g(F,k);f.push(C)}else if(I===z.length-1){var U=c[h+1]&&c[h+1].children&&c[h+1].children[0],$={type:"text",value:"".concat(L)};if(U){var V=cs({children:[$],className:A.properties.className});c.splice(h+1,0,V)}else{var se=[$],_=g(se,k,A.properties.className);f.push(_)}}else{var oe=[M],ne=g(oe,k,A.properties.className);f.push(ne)}}),d=h}h++};h<c.length;)v();if(d!==c.length-1){var w=c.slice(d+1,c.length);if(w&&w.length){var x=n&&f.length+a,N=g(w,x);f.push(N)}}return t?f:(l=[]).concat.apply(l,f)}function pN(e){var t=e.rows,r=e.stylesheet,n=e.useInlineStyles;return t.map(function(i,a){return z4({node:i,stylesheet:r,useInlineStyles:n,key:"code-segement".concat(a)})})}function q4(e){return e&&typeof e.highlightAuto<"u"}function mN(e){var t=e.astGenerator,r=e.language,n=e.code,i=e.defaultCodeValue;if(q4(t)){var a=oN(t,r);return r==="text"?{value:i,language:"text"}:a?t.highlight(r,n):t.highlightAuto(n)}try{return r&&r!=="text"?{value:t.highlight(n,r)}:{value:i}}catch{return{value:i}}}function gN(e,t){return function(n){var i=n.language,a=n.children,o=n.style,s=o===void 0?t:o,u=n.customStyle,l=u===void 0?{}:u,c=n.codeTagProps,f=c===void 0?{className:i?"language-".concat(i):void 0,style:Lr(Lr({},s['code[class*="language-"]']),s['code[class*="language-'.concat(i,'"]')])}:c,d=n.useInlineStyles,h=d===void 0?!0:d,p=n.showLineNumbers,m=p===void 0?!1:p,g=n.showInlineLineNumbers,v=g===void 0?!0:g,w=n.startingLineNumber,x=w===void 0?1:w,N=n.lineNumberContainerStyle,O=n.lineNumberStyle,A=O===void 0?{}:O,D=n.wrapLines,H=n.wrapLongLines,z=H===void 0?!1:H,L=n.lineProps,I=L===void 0?{}:L,k=n.renderer,M=n.PreTag,F=M===void 0?"pre":M,C=n.CodeTag,U=C===void 0?"code":C,$=n.code,V=$===void 0?(Array.isArray(a)?a[0]:a)||"":$,se=n.astGenerator,_=KO(n,sN);se=se||e;var oe=m?React.createElement(fN,{containerStyle:N,codeStyle:f.style||{},numberStyle:A,startingLineNumber:x,codeString:V}):null,ne=s.hljs||s['pre[class*="language-"]']||{backgroundColor:"#fff"},T=q4(se)?"hljs":"prismjs",G=h?Object.assign({},_,{style:Object.assign({},ne,l)}):Object.assign({},_,{className:_.className?"".concat(T," ").concat(_.className):T,style:Object.assign({},l)});if(z?f.style=Lr(Lr({},f.style),{},{whiteSpace:"pre-wrap"}):f.style=Lr(Lr({},f.style),{},{whiteSpace:"pre"}),!se)return React.createElement(F,G,oe,React.createElement(U,f,V));(D===void 0&&k||z)&&(D=!0),k=k||pN;var ee=[{type:"text",value:V}],le=mN({astGenerator:se,language:i,code:V,defaultCodeValue:ee});le.language===null&&(le.value=ee);var we=le.value.length+x,Oe=hN(le,D,I,m,v,x,we,A,z);return React.createElement(F,G,React.createElement(U,f,!v&&oe,k({rows:Oe,stylesheet:s,useInlineStyles:h})))}}var di={};function Wf(e){return e instanceof Map?e.clear=e.delete=e.set=function(){throw new Error("map is read-only")}:e instanceof Set&&(e.add=e.clear=e.delete=function(){throw new Error("set is read-only")}),Object.freeze(e),Object.getOwnPropertyNames(e).forEach(function(t){var r=e[t];typeof r=="object"&&!Object.isFrozen(r)&&Wf(r)}),e}var j4=Wf,bN=Wf;j4.default=bN;class pp{constructor(t){t.data===void 0&&(t.data={}),this.data=t.data,this.isMatchIgnored=!1}ignoreMatch(){this.isMatchIgnored=!0}}function Li(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;")}function _n(e,...t){const r=Object.create(null);for(const n in e)r[n]=e[n];return t.forEach(function(n){for(const i in n)r[i]=n[i]}),r}const vN="</span>",mp=e=>!!e.kind;class yN{constructor(t,r){this.buffer="",this.classPrefix=r.classPrefix,t.walk(this)}addText(t){this.buffer+=Li(t)}openNode(t){if(!mp(t))return;let r=t.kind;t.sublanguage||(r=`${this.classPrefix}${r}`),this.span(r)}closeNode(t){mp(t)&&(this.buffer+=vN)}value(){return this.buffer}span(t){this.buffer+=`<span class="${t}">`}}class Kf{constructor(){this.rootNode={children:[]},this.stack=[this.rootNode]}get top(){return this.stack[this.stack.length-1]}get root(){return this.rootNode}add(t){this.top.children.push(t)}openNode(t){const r={kind:t,children:[]};this.add(r),this.stack.push(r)}closeNode(){if(this.stack.length>1)return this.stack.pop()}closeAllNodes(){for(;this.closeNode(););}toJSON(){return JSON.stringify(this.rootNode,null,4)}walk(t){return this.constructor._walk(t,this.rootNode)}static _walk(t,r){return typeof r=="string"?t.addText(r):r.children&&(t.openNode(r),r.children.forEach(n=>this._walk(t,n)),t.closeNode(r)),t}static _collapse(t){typeof t!="string"&&t.children&&(t.children.every(r=>typeof r=="string")?t.children=[t.children.join("")]:t.children.forEach(r=>{Kf._collapse(r)}))}}class wN extends Kf{constructor(t){super(),this.options=t}addKeyword(t,r){t!==""&&(this.openNode(r),this.addText(t),this.closeNode())}addText(t){t!==""&&this.add(t)}addSublanguage(t,r){const n=t.root;n.kind=r,n.sublanguage=!0,this.add(n)}toHTML(){return new yN(this,this.options).value()}finalize(){return!0}}function xN(e){return new RegExp(e.replace(/[-/\\^$*+?.()|[\]{}]/g,"\\$&"),"m")}function Pa(e){return e?typeof e=="string"?e:e.source:null}function EN(...e){return e.map(r=>Pa(r)).join("")}function SN(...e){return"("+e.map(r=>Pa(r)).join("|")+")"}function TN(e){return new RegExp(e.toString()+"|").exec("").length-1}function AN(e,t){const r=e&&e.exec(t);return r&&r.index===0}const kN=/\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./;function ON(e,t="|"){let r=0;return e.map(n=>{r+=1;const i=r;let a=Pa(n),o="";for(;a.length>0;){const s=kN.exec(a);if(!s){o+=a;break}o+=a.substring(0,s.index),a=a.substring(s.index+s[0].length),s[0][0]==="\\"&&s[1]?o+="\\"+String(Number(s[1])+i):(o+=s[0],s[0]==="("&&r++)}return o}).map(n=>`(${n})`).join(t)}const NN=/\b\B/,V4="[a-zA-Z]\\w*",Xf="[a-zA-Z_]\\w*",Yf="\\b\\d+(\\.\\d+)?",G4="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",W4="\\b(0b[01]+)",_N="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",CN=(e={})=>{const t=/^#![ ]*\//;return e.binary&&(e.begin=EN(t,/.*\b/,e.binary,/\b.*/)),_n({className:"meta",begin:t,end:/$/,relevance:0,"on:begin":(r,n)=>{r.index!==0&&n.ignoreMatch()}},e)},Da={begin:"\\\\[\\s\\S]",relevance:0},MN={className:"string",begin:"'",end:"'",illegal:"\\n",contains:[Da]},RN={className:"string",begin:'"',end:'"',illegal:"\\n",contains:[Da]},K4={begin:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},Nu=function(e,t,r={}){const n=_n({className:"comment",begin:e,end:t,contains:[]},r);return n.contains.push(K4),n.contains.push({className:"doctag",begin:"(?:TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):",relevance:0}),n},IN=Nu("//","$"),PN=Nu("/\\*","\\*/"),DN=Nu("#","$"),LN={className:"number",begin:Yf,relevance:0},FN={className:"number",begin:G4,relevance:0},BN={className:"number",begin:W4,relevance:0},zN={className:"number",begin:Yf+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},$N={begin:/(?=\/[^/\n]*\/)/,contains:[{className:"regexp",begin:/\//,end:/\/[gimuy]*/,illegal:/\n/,contains:[Da,{begin:/\[/,end:/\]/,relevance:0,contains:[Da]}]}]},UN={className:"title",begin:V4,relevance:0},HN={className:"title",begin:Xf,relevance:0},qN={begin:"\\.\\s*"+Xf,relevance:0},jN=function(e){return Object.assign(e,{"on:begin":(t,r)=>{r.data._beginMatch=t[1]},"on:end":(t,r)=>{r.data._beginMatch!==t[1]&&r.ignoreMatch()}})};var Mo=Object.freeze({__proto__:null,MATCH_NOTHING_RE:NN,IDENT_RE:V4,UNDERSCORE_IDENT_RE:Xf,NUMBER_RE:Yf,C_NUMBER_RE:G4,BINARY_NUMBER_RE:W4,RE_STARTERS_RE:_N,SHEBANG:CN,BACKSLASH_ESCAPE:Da,APOS_STRING_MODE:MN,QUOTE_STRING_MODE:RN,PHRASAL_WORDS_MODE:K4,COMMENT:Nu,C_LINE_COMMENT_MODE:IN,C_BLOCK_COMMENT_MODE:PN,HASH_COMMENT_MODE:DN,NUMBER_MODE:LN,C_NUMBER_MODE:FN,BINARY_NUMBER_MODE:BN,CSS_NUMBER_MODE:zN,REGEXP_MODE:$N,TITLE_MODE:UN,UNDERSCORE_TITLE_MODE:HN,METHOD_GUARD:qN,END_SAME_AS_BEGIN:jN});function VN(e,t){e.input[e.index-1]==="."&&t.ignoreMatch()}function GN(e,t){t&&e.beginKeywords&&(e.begin="\\b("+e.beginKeywords.split(" ").join("|")+")(?!\\.)(?=\\b|\\s)",e.__beforeBegin=VN,e.keywords=e.keywords||e.beginKeywords,delete e.beginKeywords,e.relevance===void 0&&(e.relevance=0))}function WN(e,t){Array.isArray(e.illegal)&&(e.illegal=SN(...e.illegal))}function KN(e,t){if(e.match){if(e.begin||e.end)throw new Error("begin & end are not supported with match");e.begin=e.match,delete e.match}}function XN(e,t){e.relevance===void 0&&(e.relevance=1)}const YN=["of","and","for","in","not","or","if","then","parent","list","value"],ZN="keyword";function X4(e,t,r=ZN){const n={};return typeof e=="string"?i(r,e.split(" ")):Array.isArray(e)?i(r,e):Object.keys(e).forEach(function(a){Object.assign(n,X4(e[a],t,a))}),n;function i(a,o){t&&(o=o.map(s=>s.toLowerCase())),o.forEach(function(s){const u=s.split("|");n[u[0]]=[a,QN(u[0],u[1])]})}}function QN(e,t){return t?Number(t):JN(e)?0:1}function JN(e){return YN.includes(e.toLowerCase())}function e_(e,{plugins:t}){function r(s,u){return new RegExp(Pa(s),"m"+(e.case_insensitive?"i":"")+(u?"g":""))}class n{constructor(){this.matchIndexes={},this.regexes=[],this.matchAt=1,this.position=0}addRule(u,l){l.position=this.position++,this.matchIndexes[this.matchAt]=l,this.regexes.push([l,u]),this.matchAt+=TN(u)+1}compile(){this.regexes.length===0&&(this.exec=()=>null);const u=this.regexes.map(l=>l[1]);this.matcherRe=r(ON(u),!0),this.lastIndex=0}exec(u){this.matcherRe.lastIndex=this.lastIndex;const l=this.matcherRe.exec(u);if(!l)return null;const c=l.findIndex((d,h)=>h>0&&d!==void 0),f=this.matchIndexes[c];return l.splice(0,c),Object.assign(l,f)}}class i{constructor(){this.rules=[],this.multiRegexes=[],this.count=0,this.lastIndex=0,this.regexIndex=0}getMatcher(u){if(this.multiRegexes[u])return this.multiRegexes[u];const l=new n;return this.rules.slice(u).forEach(([c,f])=>l.addRule(c,f)),l.compile(),this.multiRegexes[u]=l,l}resumingScanAtSamePosition(){return this.regexIndex!==0}considerAll(){this.regexIndex=0}addRule(u,l){this.rules.push([u,l]),l.type==="begin"&&this.count++}exec(u){const l=this.getMatcher(this.regexIndex);l.lastIndex=this.lastIndex;let c=l.exec(u);if(this.resumingScanAtSamePosition()&&!(c&&c.index===this.lastIndex)){const f=this.getMatcher(0);f.lastIndex=this.lastIndex+1,c=f.exec(u)}return c&&(this.regexIndex+=c.position+1,this.regexIndex===this.count&&this.considerAll()),c}}function a(s){const u=new i;return s.contains.forEach(l=>u.addRule(l.begin,{rule:l,type:"begin"})),s.terminatorEnd&&u.addRule(s.terminatorEnd,{type:"end"}),s.illegal&&u.addRule(s.illegal,{type:"illegal"}),u}function o(s,u){const l=s;if(s.isCompiled)return l;[KN].forEach(f=>f(s,u)),e.compilerExtensions.forEach(f=>f(s,u)),s.__beforeBegin=null,[GN,WN,XN].forEach(f=>f(s,u)),s.isCompiled=!0;let c=null;if(typeof s.keywords=="object"&&(c=s.keywords.$pattern,delete s.keywords.$pattern),s.keywords&&(s.keywords=X4(s.keywords,e.case_insensitive)),s.lexemes&&c)throw new Error("ERR: Prefer `keywords.$pattern` to `mode.lexemes`, BOTH are not allowed. (see mode reference) ");return c=c||s.lexemes||/\w+/,l.keywordPatternRe=r(c,!0),u&&(s.begin||(s.begin=/\B|\b/),l.beginRe=r(s.begin),s.endSameAsBegin&&(s.end=s.begin),!s.end&&!s.endsWithParent&&(s.end=/\B|\b/),s.end&&(l.endRe=r(s.end)),l.terminatorEnd=Pa(s.end)||"",s.endsWithParent&&u.terminatorEnd&&(l.terminatorEnd+=(s.end?"|":"")+u.terminatorEnd)),s.illegal&&(l.illegalRe=r(s.illegal)),s.contains||(s.contains=[]),s.contains=[].concat(...s.contains.map(function(f){return t_(f==="self"?s:f)})),s.contains.forEach(function(f){o(f,l)}),s.starts&&o(s.starts,u),l.matcher=a(l),l}if(e.compilerExtensions||(e.compilerExtensions=[]),e.contains&&e.contains.includes("self"))throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");return e.classNameAliases=_n(e.classNameAliases||{}),o(e)}function Y4(e){return e?e.endsWithParent||Y4(e.starts):!1}function t_(e){return e.variants&&!e.cachedVariants&&(e.cachedVariants=e.variants.map(function(t){return _n(e,{variants:null},t)})),e.cachedVariants?e.cachedVariants:Y4(e)?_n(e,{starts:e.starts?_n(e.starts):null}):Object.isFrozen(e)?_n(e):e}var r_="10.7.3";function n_(e){return!!(e||e==="")}function i_(e){const t={props:["language","code","autodetect"],data:function(){return{detectedLanguage:"",unknownLanguage:!1}},computed:{className(){return this.unknownLanguage?"":"hljs "+this.detectedLanguage},highlighted(){if(!this.autoDetect&&!e.getLanguage(this.language))return console.warn(`The language "${this.language}" you specified could not be found.`),this.unknownLanguage=!0,Li(this.code);let n={};return this.autoDetect?(n=e.highlightAuto(this.code),this.detectedLanguage=n.language):(n=e.highlight(this.language,this.code,this.ignoreIllegals),this.detectedLanguage=this.language),n.value},autoDetect(){return!this.language||n_(this.autodetect)},ignoreIllegals(){return!0}},render(n){return n("pre",{},[n("code",{class:this.className,domProps:{innerHTML:this.highlighted}})])}};return{Component:t,VuePlugin:{install(n){n.component("highlightjs",t)}}}}const a_={"after:highlightElement":({el:e,result:t,text:r})=>{const n=gp(e);if(!n.length)return;const i=document.createElement("div");i.innerHTML=t.value,t.value=o_(n,gp(i),r)}};function lc(e){return e.nodeName.toLowerCase()}function gp(e){const t=[];return function r(n,i){for(let a=n.firstChild;a;a=a.nextSibling)a.nodeType===3?i+=a.nodeValue.length:a.nodeType===1&&(t.push({event:"start",offset:i,node:a}),i=r(a,i),lc(a).match(/br|hr|img|input/)||t.push({event:"stop",offset:i,node:a}));return i}(e,0),t}function o_(e,t,r){let n=0,i="";const a=[];function o(){return!e.length||!t.length?e.length?e:t:e[0].offset!==t[0].offset?e[0].offset<t[0].offset?e:t:t[0].event==="start"?e:t}function s(c){function f(d){return" "+d.nodeName+'="'+Li(d.value)+'"'}i+="<"+lc(c)+[].map.call(c.attributes,f).join("")+">"}function u(c){i+="</"+lc(c)+">"}function l(c){(c.event==="start"?s:u)(c.node)}for(;e.length||t.length;){let c=o();if(i+=Li(r.substring(n,c[0].offset)),n=c[0].offset,c===e){a.reverse().forEach(u);do l(c.splice(0,1)[0]),c=o();while(c===e&&c.length&&c[0].offset===n);a.reverse().forEach(s)}else c[0].event==="start"?a.push(c[0].node):a.pop(),l(c.splice(0,1)[0])}return i+Li(r.substr(n))}const bp={},zl=e=>{console.error(e)},vp=(e,...t)=>{console.log(`WARN: ${e}`,...t)},lr=(e,t)=>{bp[`${e}/${t}`]||(console.log(`Deprecated as of ${e}. ${t}`),bp[`${e}/${t}`]=!0)},$l=Li,yp=_n,wp=Symbol("nomatch"),s_=function(e){const t=Object.create(null),r=Object.create(null),n=[];let i=!0;const a=/(^(<[^>]+>|\t|)+|\n)/gm,o="Could not find the language '{}', did you forget to load/include a language module?",s={disableAutodetect:!0,name:"Plain text",contains:[]};let u={noHighlightRe:/^(no-?highlight)$/i,languageDetectRe:/\blang(?:uage)?-([\w-]+)\b/i,classPrefix:"hljs-",tabReplace:null,useBR:!1,languages:null,__emitter:wN};function l(T){return u.noHighlightRe.test(T)}function c(T){let G=T.className+" ";G+=T.parentNode?T.parentNode.className:"";const ee=u.languageDetectRe.exec(G);if(ee){const le=C(ee[1]);return le||(vp(o.replace("{}",ee[1])),vp("Falling back to no-highlight mode for this block.",T)),le?ee[1]:"no-highlight"}return G.split(/\s+/).find(le=>l(le)||C(le))}function f(T,G,ee,le){let we="",Oe="";typeof G=="object"?(we=T,ee=G.ignoreIllegals,Oe=G.language,le=void 0):(lr("10.7.0","highlight(lang, code, ...args) has been deprecated."),lr("10.7.0",`Please use highlight(code, options) instead.
https://github.com/highlightjs/highlight.js/issues/2277`),Oe=T,we=G);const qe={code:we,language:Oe};_("before:highlight",qe);const ve=qe.result?qe.result:d(qe.language,qe.code,ee,le);return ve.code=qe.code,_("after:highlight",ve),ve}function d(T,G,ee,le){function we(Z,X){const J=Rt.case_insensitive?X[0].toLowerCase():X[0];return Object.prototype.hasOwnProperty.call(Z.keywords,J)&&Z.keywords[J]}function Oe(){if(!ye.keywords){ut.addText(me);return}let Z=0;ye.keywordPatternRe.lastIndex=0;let X=ye.keywordPatternRe.exec(me),J="";for(;X;){J+=me.substring(Z,X.index);const Ee=we(ye,X);if(Ee){const[Ke,Yt]=Ee;if(ut.addText(J),J="",Pe+=Yt,Ke.startsWith("_"))J+=X[0];else{const Vn=Rt.classNameAliases[Ke]||Ke;ut.addKeyword(X[0],Vn)}}else J+=X[0];Z=ye.keywordPatternRe.lastIndex,X=ye.keywordPatternRe.exec(me)}J+=me.substr(Z),ut.addText(J)}function qe(){if(me==="")return;let Z=null;if(typeof ye.subLanguage=="string"){if(!t[ye.subLanguage]){ut.addText(me);return}Z=d(ye.subLanguage,me,!0,Ar[ye.subLanguage]),Ar[ye.subLanguage]=Z.top}else Z=p(me,ye.subLanguage.length?ye.subLanguage:null);ye.relevance>0&&(Pe+=Z.relevance),ut.addSublanguage(Z.emitter,Z.language)}function ve(){ye.subLanguage!=null?qe():Oe(),me=""}function ct(Z){return Z.className&&ut.openNode(Rt.classNameAliases[Z.className]||Z.className),ye=Object.create(Z,{parent:{value:ye}}),ye}function ft(Z,X,J){let Ee=AN(Z.endRe,J);if(Ee){if(Z["on:end"]){const Ke=new pp(Z);Z["on:end"](X,Ke),Ke.isMatchIgnored&&(Ee=!1)}if(Ee){for(;Z.endsParent&&Z.parent;)Z=Z.parent;return Z}}if(Z.endsWithParent)return ft(Z.parent,X,J)}function _r(Z){return ye.matcher.regexIndex===0?(me+=Z[0],1):(de=!0,0)}function Xt(Z){const X=Z[0],J=Z.rule,Ee=new pp(J),Ke=[J.__beforeBegin,J["on:begin"]];for(const Yt of Ke)if(Yt&&(Yt(Z,Ee),Ee.isMatchIgnored))return _r(X);return J&&J.endSameAsBegin&&(J.endRe=xN(X)),J.skip?me+=X:(J.excludeBegin&&(me+=X),ve(),!J.returnBegin&&!J.excludeBegin&&(me=X)),ct(J),J.returnBegin?0:X.length}function yn(Z){const X=Z[0],J=G.substr(Z.index),Ee=ft(ye,Z,J);if(!Ee)return wp;const Ke=ye;Ke.skip?me+=X:(Ke.returnEnd||Ke.excludeEnd||(me+=X),ve(),Ke.excludeEnd&&(me=X));do ye.className&&ut.closeNode(),!ye.skip&&!ye.subLanguage&&(Pe+=ye.relevance),ye=ye.parent;while(ye!==Ee.parent);return Ee.starts&&(Ee.endSameAsBegin&&(Ee.starts.endRe=Ee.endRe),ct(Ee.starts)),Ke.returnEnd?0:X.length}function Tr(){const Z=[];for(let X=ye;X!==Rt;X=X.parent)X.className&&Z.unshift(X.className);Z.forEach(X=>ut.openNode(X))}let At={};function $t(Z,X){const J=X&&X[0];if(me+=Z,J==null)return ve(),0;if(At.type==="begin"&&X.type==="end"&&At.index===X.index&&J===""){if(me+=G.slice(X.index,X.index+1),!i){const Ee=new Error("0 width match regex");throw Ee.languageName=T,Ee.badRule=At.rule,Ee}return 1}if(At=X,X.type==="begin")return Xt(X);if(X.type==="illegal"&&!ee){const Ee=new Error('Illegal lexeme "'+J+'" for mode "'+(ye.className||"<unnamed>")+'"');throw Ee.mode=ye,Ee}else if(X.type==="end"){const Ee=yn(X);if(Ee!==wp)return Ee}if(X.type==="illegal"&&J==="")return 1;if(K>1e5&&K>X.index*3)throw new Error("potential infinite loop, way more iterations than matches");return me+=J,J.length}const Rt=C(T);if(!Rt)throw zl(o.replace("{}",T)),new Error('Unknown language: "'+T+'"');const jn=e_(Rt,{plugins:n});let Zr="",ye=le||jn;const Ar={},ut=new u.__emitter(u);Tr();let me="",Pe=0,q=0,K=0,de=!1;try{for(ye.matcher.considerAll();;){K++,de?de=!1:ye.matcher.considerAll(),ye.matcher.lastIndex=q;const Z=ye.matcher.exec(G);if(!Z)break;const X=G.substring(q,Z.index),J=$t(X,Z);q=Z.index+J}return $t(G.substr(q)),ut.closeAllNodes(),ut.finalize(),Zr=ut.toHTML(),{relevance:Math.floor(Pe),value:Zr,language:T,illegal:!1,emitter:ut,top:ye}}catch(Z){if(Z.message&&Z.message.includes("Illegal"))return{illegal:!0,illegalBy:{msg:Z.message,context:G.slice(q-100,q+100),mode:Z.mode},sofar:Zr,relevance:0,value:$l(G),emitter:ut};if(i)return{illegal:!1,relevance:0,value:$l(G),emitter:ut,language:T,top:ye,errorRaised:Z};throw Z}}function h(T){const G={relevance:0,emitter:new u.__emitter(u),value:$l(T),illegal:!1,top:s};return G.emitter.addText(T),G}function p(T,G){G=G||u.languages||Object.keys(t);const ee=h(T),le=G.filter(C).filter($).map(ct=>d(ct,T,!1));le.unshift(ee);const we=le.sort((ct,ft)=>{if(ct.relevance!==ft.relevance)return ft.relevance-ct.relevance;if(ct.language&&ft.language){if(C(ct.language).supersetOf===ft.language)return 1;if(C(ft.language).supersetOf===ct.language)return-1}return 0}),[Oe,qe]=we,ve=Oe;return ve.second_best=qe,ve}function m(T){return u.tabReplace||u.useBR?T.replace(a,G=>G===`
`?u.useBR?"<br>":G:u.tabReplace?G.replace(/\t/g,u.tabReplace):G):T}function g(T,G,ee){const le=G?r[G]:ee;T.classList.add("hljs"),le&&T.classList.add(le)}const v={"before:highlightElement":({el:T})=>{u.useBR&&(T.innerHTML=T.innerHTML.replace(/\n/g,"").replace(/<br[ /]*>/g,`
`))},"after:highlightElement":({result:T})=>{u.useBR&&(T.value=T.value.replace(/\n/g,"<br>"))}},w=/^(<[^>]+>|\t)+/gm,x={"after:highlightElement":({result:T})=>{u.tabReplace&&(T.value=T.value.replace(w,G=>G.replace(/\t/g,u.tabReplace)))}};function N(T){let G=null;const ee=c(T);if(l(ee))return;_("before:highlightElement",{el:T,language:ee}),G=T;const le=G.textContent,we=ee?f(le,{language:ee,ignoreIllegals:!0}):p(le);_("after:highlightElement",{el:T,result:we,text:le}),T.innerHTML=we.value,g(T,ee,we.language),T.result={language:we.language,re:we.relevance,relavance:we.relevance},we.second_best&&(T.second_best={language:we.second_best.language,re:we.second_best.relevance,relavance:we.second_best.relevance})}function O(T){T.useBR&&(lr("10.3.0","'useBR' will be removed entirely in v11.0"),lr("10.3.0","Please see https://github.com/highlightjs/highlight.js/issues/2559")),u=yp(u,T)}const A=()=>{if(A.called)return;A.called=!0,lr("10.6.0","initHighlighting() is deprecated.  Use highlightAll() instead."),document.querySelectorAll("pre code").forEach(N)};function D(){lr("10.6.0","initHighlightingOnLoad() is deprecated.  Use highlightAll() instead."),H=!0}let H=!1;function z(){if(document.readyState==="loading"){H=!0;return}document.querySelectorAll("pre code").forEach(N)}function L(){H&&z()}typeof window<"u"&&window.addEventListener&&window.addEventListener("DOMContentLoaded",L,!1);function I(T,G){let ee=null;try{ee=G(e)}catch(le){if(zl("Language definition for '{}' could not be registered.".replace("{}",T)),i)zl(le);else throw le;ee=s}ee.name||(ee.name=T),t[T]=ee,ee.rawDefinition=G.bind(null,e),ee.aliases&&U(ee.aliases,{languageName:T})}function k(T){delete t[T];for(const G of Object.keys(r))r[G]===T&&delete r[G]}function M(){return Object.keys(t)}function F(T){lr("10.4.0","requireLanguage will be removed entirely in v11."),lr("10.4.0","Please see https://github.com/highlightjs/highlight.js/pull/2844");const G=C(T);if(G)return G;throw new Error("The '{}' language is required, but not loaded.".replace("{}",T))}function C(T){return T=(T||"").toLowerCase(),t[T]||t[r[T]]}function U(T,{languageName:G}){typeof T=="string"&&(T=[T]),T.forEach(ee=>{r[ee.toLowerCase()]=G})}function $(T){const G=C(T);return G&&!G.disableAutodetect}function V(T){T["before:highlightBlock"]&&!T["before:highlightElement"]&&(T["before:highlightElement"]=G=>{T["before:highlightBlock"](Object.assign({block:G.el},G))}),T["after:highlightBlock"]&&!T["after:highlightElement"]&&(T["after:highlightElement"]=G=>{T["after:highlightBlock"](Object.assign({block:G.el},G))})}function se(T){V(T),n.push(T)}function _(T,G){const ee=T;n.forEach(function(le){le[ee]&&le[ee](G)})}function oe(T){return lr("10.2.0","fixMarkup will be removed entirely in v11.0"),lr("10.2.0","Please see https://github.com/highlightjs/highlight.js/issues/2534"),m(T)}function ne(T){return lr("10.7.0","highlightBlock will be removed entirely in v12.0"),lr("10.7.0","Please use highlightElement now."),N(T)}Object.assign(e,{highlight:f,highlightAuto:p,highlightAll:z,fixMarkup:oe,highlightElement:N,highlightBlock:ne,configure:O,initHighlighting:A,initHighlightingOnLoad:D,registerLanguage:I,unregisterLanguage:k,listLanguages:M,getLanguage:C,registerAliases:U,requireLanguage:F,autoDetection:$,inherit:yp,addPlugin:se,vuePlugin:i_(e).VuePlugin}),e.debugMode=function(){i=!1},e.safeMode=function(){i=!0},e.versionString=r_;for(const T in Mo)typeof Mo[T]=="object"&&j4(Mo[T]);return Object.assign(e,Mo),e.addPlugin(v),e.addPlugin(a_),e.addPlugin(x),e};var u_=s_({}),l_=u_,Z4={exports:{}};(function(e){(function(){var t;t=e.exports=i,t.format=i,t.vsprintf=n,typeof console<"u"&&typeof console.log=="function"&&(t.printf=r);function r(){console.log(i.apply(null,arguments))}function n(a,o){return i.apply(null,[a].concat(o))}function i(a){for(var o=1,s=[].slice.call(arguments),u=0,l=a.length,c="",f,d=!1,h,p,m=!1,g,v=function(){return s[o++]},w=function(){for(var x="";/\d/.test(a[u]);)x+=a[u++],f=a[u];return x.length>0?parseInt(x):null};u<l;++u)if(f=a[u],d)switch(d=!1,f=="."?(m=!1,f=a[++u]):f=="0"&&a[u+1]=="."?(m=!0,u+=2,f=a[u]):m=!0,g=w(),f){case"b":c+=parseInt(v(),10).toString(2);break;case"c":h=v(),typeof h=="string"||h instanceof String?c+=h:c+=String.fromCharCode(parseInt(h,10));break;case"d":c+=parseInt(v(),10);break;case"f":p=String(parseFloat(v()).toFixed(g||6)),c+=m?p:p.replace(/^0/,"");break;case"j":c+=JSON.stringify(v());break;case"o":c+="0"+parseInt(v(),10).toString(8);break;case"s":c+=v();break;case"x":c+="0x"+parseInt(v(),10).toString(16);break;case"X":c+="0x"+parseInt(v(),10).toString(16).toUpperCase();break;default:c+=f;break}else f==="%"?d=!0:c+=f;return c}})()})(Z4);var c_=Z4.exports,f_=c_,zn=$n(Error),d_=zn;zn.eval=$n(EvalError);zn.range=$n(RangeError);zn.reference=$n(ReferenceError);zn.syntax=$n(SyntaxError);zn.type=$n(TypeError);zn.uri=$n(URIError);zn.create=$n;function $n(e){return t.displayName=e.displayName||e.name,t;function t(r){return r&&(r=f_.apply(null,arguments)),new e(r)}}var $r=l_,fs=d_;di.highlight=Q4;di.highlightAuto=p_;di.registerLanguage=m_;di.listLanguages=g_;di.registerAlias=b_;vn.prototype.addText=w_;vn.prototype.addKeyword=v_;vn.prototype.addSublanguage=y_;vn.prototype.openNode=x_;vn.prototype.closeNode=E_;vn.prototype.closeAllNodes=J4;vn.prototype.finalize=J4;vn.prototype.toHTML=S_;var h_="hljs-";function Q4(e,t,r){var n=$r.configure({}),i=r||{},a=i.prefix,o;if(typeof e!="string")throw fs("Expected `string` for name, got `%s`",e);if(!$r.getLanguage(e))throw fs("Unknown language: `%s` is not registered",e);if(typeof t!="string")throw fs("Expected `string` for value, got `%s`",t);if(a==null&&(a=h_),$r.configure({__emitter:vn,classPrefix:a}),o=$r.highlight(t,{language:e,ignoreIllegals:!0}),$r.configure(n||{}),o.errorRaised)throw o.errorRaised;return{relevance:o.relevance,language:o.language,value:o.emitter.rootNode.children}}function p_(e,t){var r=t||{},n=r.subset||$r.listLanguages();r.prefix;var i=n.length,a=-1,o,s,u,l;if(typeof e!="string")throw fs("Expected `string` for value, got `%s`",e);for(s={relevance:0,language:null,value:[]},o={relevance:0,language:null,value:[]};++a<i;)l=n[a],$r.getLanguage(l)&&(u=Q4(l,e,t),u.language=l,u.relevance>s.relevance&&(s=u),u.relevance>o.relevance&&(s=o,o=u));return s.language&&(o.secondBest=s),o}function m_(e,t){$r.registerLanguage(e,t)}function g_(){return $r.listLanguages()}function b_(e,t){var r=e,n;t&&(r={},r[e]=t);for(n in r)$r.registerAliases(r[n],{languageName:n})}function vn(e){this.options=e,this.rootNode={children:[]},this.stack=[this.rootNode]}function v_(e,t){this.openNode(t),this.addText(e),this.closeNode()}function y_(e,t){var r=this.stack,n=r[r.length-1],i=e.rootNode.children,a=t?{type:"element",tagName:"span",properties:{className:[t]},children:i}:i;n.children=n.children.concat(a)}function w_(e){var t=this.stack,r,n;e!==""&&(r=t[t.length-1],n=r.children[r.children.length-1],n&&n.type==="text"?n.value+=e:r.children.push({type:"text",value:e}))}function x_(e){var t=this.stack,r=this.options.classPrefix+e,n=t[t.length-1],i={type:"element",tagName:"span",properties:{className:[r]},children:[]};n.children.push(i),t.push(i)}function E_(){this.stack.pop()}function S_(){return""}function J4(){}function T_(e){const t={variants:[e.COMMENT("^[ \\t]*(?=#)","$",{relevance:0,excludeBegin:!0}),e.COMMENT("[;@]","$",{relevance:0}),e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]};return{name:"ARM Assembly",case_insensitive:!0,aliases:["arm"],keywords:{$pattern:"\\.?"+e.IDENT_RE,meta:".2byte .4byte .align .ascii .asciz .balign .byte .code .data .else .end .endif .endm .endr .equ .err .exitm .extern .global .hword .if .ifdef .ifndef .include .irp .long .macro .rept .req .section .set .skip .space .text .word .arm .thumb .code16 .code32 .force_thumb .thumb_func .ltorg ALIAS ALIGN ARM AREA ASSERT ATTR CN CODE CODE16 CODE32 COMMON CP DATA DCB DCD DCDU DCDO DCFD DCFDU DCI DCQ DCQU DCW DCWU DN ELIF ELSE END ENDFUNC ENDIF ENDP ENTRY EQU EXPORT EXPORTAS EXTERN FIELD FILL FUNCTION GBLA GBLL GBLS GET GLOBAL IF IMPORT INCBIN INCLUDE INFO KEEP LCLA LCLL LCLS LTORG MACRO MAP MEND MEXIT NOFP OPT PRESERVE8 PROC QN READONLY RELOC REQUIRE REQUIRE8 RLIST FN ROUT SETA SETL SETS SN SPACE SUBT THUMB THUMBX TTL WHILE WEND ",built_in:"r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 pc lr sp ip sl sb fp a1 a2 a3 a4 v1 v2 v3 v4 v5 v6 v7 v8 f0 f1 f2 f3 f4 f5 f6 f7 p0 p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 c0 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 q0 q1 q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12 q13 q14 q15 cpsr_c cpsr_x cpsr_s cpsr_f cpsr_cx cpsr_cxs cpsr_xs cpsr_xsf cpsr_sf cpsr_cxsf spsr_c spsr_x spsr_s spsr_f spsr_cx spsr_cxs spsr_xs spsr_xsf spsr_sf spsr_cxsf s0 s1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12 s13 s14 s15 s16 s17 s18 s19 s20 s21 s22 s23 s24 s25 s26 s27 s28 s29 s30 s31 d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 {PC} {VAR} {TRUE} {FALSE} {OPT} {CONFIG} {ENDIAN} {CODESIZE} {CPU} {FPU} {ARCHITECTURE} {PCSTOREOFFSET} {ARMASM_VERSION} {INTER} {ROPI} {RWPI} {SWST} {NOSWST} . @"},contains:[{className:"keyword",begin:"\\b(adc|(qd?|sh?|u[qh]?)?add(8|16)?|usada?8|(q|sh?|u[qh]?)?(as|sa)x|and|adrl?|sbc|rs[bc]|asr|b[lx]?|blx|bxj|cbn?z|tb[bh]|bic|bfc|bfi|[su]bfx|bkpt|cdp2?|clz|clrex|cmp|cmn|cpsi[ed]|cps|setend|dbg|dmb|dsb|eor|isb|it[te]{0,3}|lsl|lsr|ror|rrx|ldm(([id][ab])|f[ds])?|ldr((s|ex)?[bhd])?|movt?|mvn|mra|mar|mul|[us]mull|smul[bwt][bt]|smu[as]d|smmul|smmla|mla|umlaal|smlal?([wbt][bt]|d)|mls|smlsl?[ds]|smc|svc|sev|mia([bt]{2}|ph)?|mrr?c2?|mcrr2?|mrs|msr|orr|orn|pkh(tb|bt)|rbit|rev(16|sh)?|sel|[su]sat(16)?|nop|pop|push|rfe([id][ab])?|stm([id][ab])?|str(ex)?[bhd]?|(qd?)?sub|(sh?|q|u[qh]?)?sub(8|16)|[su]xt(a?h|a?b(16)?)|srs([id][ab])?|swpb?|swi|smi|tst|teq|wfe|wfi|yield)(eq|ne|cs|cc|mi|pl|vs|vc|hi|ls|ge|lt|gt|le|al|hs|lo)?[sptrx]?(?=\\s)"},t,e.QUOTE_STRING_MODE,{className:"string",begin:"'",end:"[^\\\\]'",relevance:0},{className:"title",begin:"\\|",end:"\\|",illegal:"\\n",relevance:0},{className:"number",variants:[{begin:"[#$=]?0x[0-9a-f]+"},{begin:"[#$=]?0b[01]+"},{begin:"[#$=]\\d+"},{begin:"\\b\\d+"}],relevance:0},{className:"symbol",variants:[{begin:"^[ \\t]*[a-z_\\.\\$][a-z0-9_\\.\\$]+:"},{begin:"^[a-z_\\.\\$][a-z0-9_\\.\\$]+"},{begin:"[=#]\\w+"}],relevance:0}]}}var A_=T_;const G$=Ce(A_);function e3(e){return e?typeof e=="string"?e:e.source:null}function xp(e){return Jn("(?=",e,")")}function k_(e){return Jn("(",e,")?")}function Jn(...e){return e.map(r=>e3(r)).join("")}function O_(...e){return"("+e.map(r=>e3(r)).join("|")+")"}function N_(e){const t=Jn(/[A-Z_]/,k_(/[A-Z0-9_.-]*:/),/[A-Z0-9_.-]*/),r=/[A-Za-z0-9._:-]+/,n={className:"symbol",begin:/&[a-z]+;|&#[0-9]+;|&#x[a-f0-9]+;/},i={begin:/\s/,contains:[{className:"meta-keyword",begin:/#?[a-z_][a-z1-9_-]+/,illegal:/\n/}]},a=e.inherit(i,{begin:/\(/,end:/\)/}),o=e.inherit(e.APOS_STRING_MODE,{className:"meta-string"}),s=e.inherit(e.QUOTE_STRING_MODE,{className:"meta-string"}),u={endsWithParent:!0,illegal:/</,relevance:0,contains:[{className:"attr",begin:r,relevance:0},{begin:/=\s*/,relevance:0,contains:[{className:"string",endsParent:!0,variants:[{begin:/"/,end:/"/,contains:[n]},{begin:/'/,end:/'/,contains:[n]},{begin:/[^\s"'=<>`]+/}]}]}]};return{name:"HTML, XML",aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist","wsf","svg"],case_insensitive:!0,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,relevance:10,contains:[i,s,o,a,{begin:/\[/,end:/\]/,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,contains:[i,a,s,o]}]}]},e.COMMENT(/<!--/,/-->/,{relevance:10}),{begin:/<!\[CDATA\[/,end:/\]\]>/,relevance:10},n,{className:"meta",begin:/<\?xml/,end:/\?>/,relevance:10},{className:"tag",begin:/<style(?=\s|>)/,end:/>/,keywords:{name:"style"},contains:[u],starts:{end:/<\/style>/,returnEnd:!0,subLanguage:["css","xml"]}},{className:"tag",begin:/<script(?=\s|>)/,end:/>/,keywords:{name:"script"},contains:[u],starts:{end:/<\/script>/,returnEnd:!0,subLanguage:["javascript","handlebars","xml"]}},{className:"tag",begin:/<>|<\/>/},{className:"tag",begin:Jn(/</,xp(Jn(t,O_(/\/>/,/>/,/\s/)))),end:/\/?>/,contains:[{className:"name",begin:t,relevance:0,starts:u}]},{className:"tag",begin:Jn(/<\//,xp(Jn(t,/>/))),contains:[{className:"name",begin:t,relevance:0},{begin:/>/,relevance:0,endsParent:!0}]}]}}var __=N_;const W$=Ce(__);function C_(e){return e?typeof e=="string"?e:e.source:null}function M_(...e){return e.map(r=>C_(r)).join("")}function R_(e){const t={},r={begin:/\$\{/,end:/\}/,contains:["self",{begin:/:-/,contains:[t]}]};Object.assign(t,{className:"variable",variants:[{begin:M_(/\$[\w\d#@][\w\d_]*/,"(?![\\w\\d])(?![$])")},r]});const n={className:"subst",begin:/\$\(/,end:/\)/,contains:[e.BACKSLASH_ESCAPE]},i={begin:/<<-?\s*(?=\w+)/,starts:{contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,className:"string"})]}},a={className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,t,n]};n.contains.push(a);const o={className:"",begin:/\\"/},s={className:"string",begin:/'/,end:/'/},u={begin:/\$\(\(/,end:/\)\)/,contains:[{begin:/\d+#[0-9a-f]+/,className:"number"},e.NUMBER_MODE,t]},l=["fish","bash","zsh","sh","csh","ksh","tcsh","dash","scsh"],c=e.SHEBANG({binary:`(${l.join("|")})`,relevance:10}),f={className:"function",begin:/\w[\w\d_]*\s*\(\s*\)\s*\{/,returnBegin:!0,contains:[e.inherit(e.TITLE_MODE,{begin:/\w[\w\d_]*/})],relevance:0};return{name:"Bash",aliases:["sh","zsh"],keywords:{$pattern:/\b[a-z._-]+\b/,keyword:"if then else elif fi for while in do done case esac function",literal:"true false",built_in:"break cd continue eval exec exit export getopts hash pwd readonly return shift test times trap umask unset alias bind builtin caller command declare echo enable help let local logout mapfile printf read readarray source type typeset ulimit unalias set shopt autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate fc fg float functions getcap getln history integer jobs kill limit log noglob popd print pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof zpty zregexparse zsocket zstyle ztcp"},contains:[c,e.SHEBANG(),f,u,e.HASH_COMMENT_MODE,i,a,o,s,t]}}var I_=R_;const K$=Ce(I_);function P_(e){return e?typeof e=="string"?e:e.source:null}function D_(e){return Zf("(?=",e,")")}function Ro(e){return Zf("(",e,")?")}function Zf(...e){return e.map(r=>P_(r)).join("")}function L_(e){const t=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",n="[a-zA-Z_]\\w*::",i="<[^<>]+>",a="("+r+"|"+Ro(n)+"[a-zA-Z_]\\w*"+Ro(i)+")",o={className:"keyword",begin:"\\b[a-z\\d_]*_t\\b"},s="\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)",u={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+s+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},l={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},c={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{"meta-keyword":"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(u,{className:"meta-string"}),{className:"meta-string",begin:/<.*?>/},t,e.C_BLOCK_COMMENT_MODE]},f={className:"title",begin:Ro(n)+e.IDENT_RE,relevance:0},d=Ro(n)+e.IDENT_RE+"\\s*\\(",p={keyword:"int float while private char char8_t char16_t char32_t catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid wchar_t short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignas alignof constexpr consteval constinit decltype concept co_await co_return co_yield requires noexcept static_assert thread_local restrict final override atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and and_eq bitand bitor compl not not_eq or or_eq xor xor_eq",built_in:"_Bool _Complex _Imaginary",_relevance_hints:["asin","atan2","atan","calloc","ceil","cosh","cos","exit","exp","fabs","floor","fmod","fprintf","fputs","free","frexp","auto_ptr","deque","list","queue","stack","vector","map","set","pair","bitset","multiset","multimap","unordered_set","fscanf","future","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","tolower","toupper","labs","ldexp","log10","log","malloc","realloc","memchr","memcmp","memcpy","memset","modf","pow","printf","putchar","puts","scanf","sinh","sin","snprintf","sprintf","sqrt","sscanf","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","tanh","tan","unordered_map","unordered_multiset","unordered_multimap","priority_queue","make_pair","array","shared_ptr","abort","terminate","abs","acos","vfprintf","vprintf","vsprintf","endl","initializer_list","unique_ptr","complex","imaginary","std","string","wstring","cin","cout","cerr","clog","stdin","stdout","stderr","stringstream","istringstream","ostringstream"],literal:"true false nullptr NULL"},m={className:"function.dispatch",relevance:0,keywords:p,begin:Zf(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!while)/,e.IDENT_RE,D_(/\s*\(/))},g=[m,c,o,t,e.C_BLOCK_COMMENT_MODE,l,u],v={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:p,contains:g.concat([{begin:/\(/,end:/\)/,keywords:p,contains:g.concat(["self"]),relevance:0}]),relevance:0},w={className:"function",begin:"("+a+"[\\*&\\s]+)+"+d,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:p,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:p,relevance:0},{begin:d,returnBegin:!0,contains:[f],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[u,l]},{className:"params",begin:/\(/,end:/\)/,keywords:p,relevance:0,contains:[t,e.C_BLOCK_COMMENT_MODE,u,l,o,{begin:/\(/,end:/\)/,keywords:p,relevance:0,contains:["self",t,e.C_BLOCK_COMMENT_MODE,u,l,o]}]},o,t,e.C_BLOCK_COMMENT_MODE,c]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:p,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(v,w,m,g,[c,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",end:">",keywords:p,contains:["self",o]},{begin:e.IDENT_RE+"::",keywords:p},{className:"class",beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{beginKeywords:"final class struct"},e.TITLE_MODE]}]),exports:{preprocessor:c,strings:u,keywords:p}}}function F_(e){const t=L_(e),r=["c","h"],n=["cc","c++","h++","hpp","hh","hxx","cxx"];return t.disableAutodetect=!0,t.aliases=[],e.getLanguage("c")||t.aliases.push(...r),e.getLanguage("cpp")||t.aliases.push(...n),t}var B_=F_;const X$=Ce(B_);function z_(e){return e?typeof e=="string"?e:e.source:null}function Io(e){return $_("(",e,")?")}function $_(...e){return e.map(r=>z_(r)).join("")}function U_(e){const t=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",n="[a-zA-Z_]\\w*::",i="<[^<>]+>",a="("+r+"|"+Io(n)+"[a-zA-Z_]\\w*"+Io(i)+")",o={className:"keyword",begin:"\\b[a-z\\d_]*_t\\b"},s="\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)",u={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+s+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},l={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},c={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{"meta-keyword":"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(u,{className:"meta-string"}),{className:"meta-string",begin:/<.*?>/},t,e.C_BLOCK_COMMENT_MODE]},f={className:"title",begin:Io(n)+e.IDENT_RE,relevance:0},d=Io(n)+e.IDENT_RE+"\\s*\\(",h={keyword:"int float while private char char8_t char16_t char32_t catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid wchar_t short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignas alignof constexpr consteval constinit decltype concept co_await co_return co_yield requires noexcept static_assert thread_local restrict final override atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and and_eq bitand bitor compl not not_eq or or_eq xor xor_eq",built_in:"std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr _Bool complex _Complex imaginary _Imaginary",literal:"true false nullptr NULL"},p=[c,o,t,e.C_BLOCK_COMMENT_MODE,l,u],m={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:h,contains:p.concat([{begin:/\(/,end:/\)/,keywords:h,contains:p.concat(["self"]),relevance:0}]),relevance:0},g={className:"function",begin:"("+a+"[\\*&\\s]+)+"+d,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:h,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:h,relevance:0},{begin:d,returnBegin:!0,contains:[f],relevance:0},{className:"params",begin:/\(/,end:/\)/,keywords:h,relevance:0,contains:[t,e.C_BLOCK_COMMENT_MODE,u,l,o,{begin:/\(/,end:/\)/,keywords:h,relevance:0,contains:["self",t,e.C_BLOCK_COMMENT_MODE,u,l,o]}]},o,t,e.C_BLOCK_COMMENT_MODE,c]};return{name:"C",aliases:["h"],keywords:h,disableAutodetect:!0,illegal:"</",contains:[].concat(m,g,p,[c,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",end:">",keywords:h,contains:["self",o]},{begin:e.IDENT_RE+"::",keywords:h},{className:"class",beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{beginKeywords:"final class struct"},e.TITLE_MODE]}]),exports:{preprocessor:c,strings:u,keywords:h}}}var H_=U_;const Y$=Ce(H_);function q_(e){return e?typeof e=="string"?e:e.source:null}function j_(e){return Qf("(?=",e,")")}function Po(e){return Qf("(",e,")?")}function Qf(...e){return e.map(r=>q_(r)).join("")}function V_(e){const t=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),r="decltype\\(auto\\)",n="[a-zA-Z_]\\w*::",i="<[^<>]+>",a="("+r+"|"+Po(n)+"[a-zA-Z_]\\w*"+Po(i)+")",o={className:"keyword",begin:"\\b[a-z\\d_]*_t\\b"},s="\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)",u={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+s+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},l={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},c={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{"meta-keyword":"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(u,{className:"meta-string"}),{className:"meta-string",begin:/<.*?>/},t,e.C_BLOCK_COMMENT_MODE]},f={className:"title",begin:Po(n)+e.IDENT_RE,relevance:0},d=Po(n)+e.IDENT_RE+"\\s*\\(",p={keyword:"int float while private char char8_t char16_t char32_t catch import module export virtual operator sizeof dynamic_cast|10 typedef const_cast|10 const for static_cast|10 union namespace unsigned long volatile static protected bool template mutable if public friend do goto auto void enum else break extern using asm case typeid wchar_t short reinterpret_cast|10 default double register explicit signed typename try this switch continue inline delete alignas alignof constexpr consteval constinit decltype concept co_await co_return co_yield requires noexcept static_assert thread_local restrict final override atomic_bool atomic_char atomic_schar atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong atomic_ullong new throw return and and_eq bitand bitor compl not not_eq or or_eq xor xor_eq",built_in:"_Bool _Complex _Imaginary",_relevance_hints:["asin","atan2","atan","calloc","ceil","cosh","cos","exit","exp","fabs","floor","fmod","fprintf","fputs","free","frexp","auto_ptr","deque","list","queue","stack","vector","map","set","pair","bitset","multiset","multimap","unordered_set","fscanf","future","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","tolower","toupper","labs","ldexp","log10","log","malloc","realloc","memchr","memcmp","memcpy","memset","modf","pow","printf","putchar","puts","scanf","sinh","sin","snprintf","sprintf","sqrt","sscanf","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","tanh","tan","unordered_map","unordered_multiset","unordered_multimap","priority_queue","make_pair","array","shared_ptr","abort","terminate","abs","acos","vfprintf","vprintf","vsprintf","endl","initializer_list","unique_ptr","complex","imaginary","std","string","wstring","cin","cout","cerr","clog","stdin","stdout","stderr","stringstream","istringstream","ostringstream"],literal:"true false nullptr NULL"},m={className:"function.dispatch",relevance:0,keywords:p,begin:Qf(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!while)/,e.IDENT_RE,j_(/\s*\(/))},g=[m,c,o,t,e.C_BLOCK_COMMENT_MODE,l,u],v={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:p,contains:g.concat([{begin:/\(/,end:/\)/,keywords:p,contains:g.concat(["self"]),relevance:0}]),relevance:0},w={className:"function",begin:"("+a+"[\\*&\\s]+)+"+d,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:p,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:p,relevance:0},{begin:d,returnBegin:!0,contains:[f],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[u,l]},{className:"params",begin:/\(/,end:/\)/,keywords:p,relevance:0,contains:[t,e.C_BLOCK_COMMENT_MODE,u,l,o,{begin:/\(/,end:/\)/,keywords:p,relevance:0,contains:["self",t,e.C_BLOCK_COMMENT_MODE,u,l,o]}]},o,t,e.C_BLOCK_COMMENT_MODE,c]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:p,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(v,w,m,g,[c,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<",end:">",keywords:p,contains:["self",o]},{begin:e.IDENT_RE+"::",keywords:p},{className:"class",beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{beginKeywords:"final class struct"},e.TITLE_MODE]}]),exports:{preprocessor:c,strings:u,keywords:p}}}var G_=V_;const Z$=Ce(G_);function W_(e){const t=["bool","byte","char","decimal","delegate","double","dynamic","enum","float","int","long","nint","nuint","object","sbyte","short","string","ulong","uint","ushort"],r=["public","private","protected","static","internal","protected","abstract","async","extern","override","unsafe","virtual","new","sealed","partial"],n=["default","false","null","true"],i=["abstract","as","base","break","case","class","const","continue","do","else","event","explicit","extern","finally","fixed","for","foreach","goto","if","implicit","in","interface","internal","is","lock","namespace","new","operator","out","override","params","private","protected","public","readonly","record","ref","return","sealed","sizeof","stackalloc","static","struct","switch","this","throw","try","typeof","unchecked","unsafe","using","virtual","void","volatile","while"],a=["add","alias","and","ascending","async","await","by","descending","equals","from","get","global","group","init","into","join","let","nameof","not","notnull","on","or","orderby","partial","remove","select","set","unmanaged","value|0","var","when","where","with","yield"],o={keyword:i.concat(a),built_in:t,literal:n},s=e.inherit(e.TITLE_MODE,{begin:"[a-zA-Z](\\.?\\w)*"}),u={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},l={className:"string",begin:'@"',end:'"',contains:[{begin:'""'}]},c=e.inherit(l,{illegal:/\n/}),f={className:"subst",begin:/\{/,end:/\}/,keywords:o},d=e.inherit(f,{illegal:/\n/}),h={className:"string",begin:/\$"/,end:'"',illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},e.BACKSLASH_ESCAPE,d]},p={className:"string",begin:/\$@"/,end:'"',contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},f]},m=e.inherit(p,{illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},d]});f.contains=[p,h,l,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,u,e.C_BLOCK_COMMENT_MODE],d.contains=[m,h,c,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,u,e.inherit(e.C_BLOCK_COMMENT_MODE,{illegal:/\n/})];const g={variants:[p,h,l,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},v={begin:"<",end:">",contains:[{beginKeywords:"in out"},s]},w=e.IDENT_RE+"(<"+e.IDENT_RE+"(\\s*,\\s*"+e.IDENT_RE+")*>)?(\\[\\])?",x={begin:"@"+e.IDENT_RE,relevance:0};return{name:"C#",aliases:["cs","c#"],keywords:o,illegal:/::/,contains:[e.COMMENT("///","$",{returnBegin:!0,contains:[{className:"doctag",variants:[{begin:"///",relevance:0},{begin:"<!--|-->"},{begin:"</?",end:">"}]}]}),e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"meta",begin:"#",end:"$",keywords:{"meta-keyword":"if else elif endif define undef warning error line region endregion pragma checksum"}},g,u,{beginKeywords:"class interface",relevance:0,end:/[{;=]/,illegal:/[^\s:,]/,contains:[{beginKeywords:"where class"},s,v,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"namespace",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[s,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"record",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[s,v,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"meta",begin:"^\\s*\\[",excludeBegin:!0,end:"\\]",excludeEnd:!0,contains:[{className:"meta-string",begin:/"/,end:/"/}]},{beginKeywords:"new return throw await else",relevance:0},{className:"function",begin:"("+w+"\\s+)+"+e.IDENT_RE+"\\s*(<.+>\\s*)?\\(",returnBegin:!0,end:/\s*[{;=]/,excludeEnd:!0,keywords:o,contains:[{beginKeywords:r.join(" "),relevance:0},{begin:e.IDENT_RE+"\\s*(<.+>\\s*)?\\(",returnBegin:!0,contains:[e.TITLE_MODE,v],relevance:0},{className:"params",begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:o,relevance:0,contains:[g,u,e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},x]}}var K_=W_;const Q$=Ce(K_),X_=e=>({IMPORTANT:{className:"meta",begin:"!important"},HEXCOLOR:{className:"number",begin:"#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})"},ATTRIBUTE_SELECTOR_MODE:{className:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]}}),Y_=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","p","q","quote","samp","section","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],Z_=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"],Q_=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"],J_=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"],eC=["align-content","align-items","align-self","animation","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-timing-function","auto","backface-visibility","background","background-attachment","background-clip","background-color","background-image","background-origin","background-position","background-repeat","background-size","border","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-decoration-break","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","clear","clip","clip-path","color","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","content","counter-increment","counter-reset","cursor","direction","display","empty-cells","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-size","font-size-adjust","font-smoothing","font-stretch","font-style","font-variant","font-variant-ligatures","font-variation-settings","font-weight","height","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","inherit","initial","justify-content","left","letter-spacing","line-height","list-style","list-style-image","list-style-position","list-style-type","margin","margin-bottom","margin-left","margin-right","margin-top","marks","mask","max-height","max-width","min-height","min-width","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-wrap","overflow-x","overflow-y","padding","padding-bottom","padding-left","padding-right","padding-top","page-break-after","page-break-before","page-break-inside","perspective","perspective-origin","pointer-events","position","quotes","resize","right","src","tab-size","table-layout","text-align","text-align-last","text-decoration","text-decoration-color","text-decoration-line","text-decoration-style","text-indent","text-overflow","text-rendering","text-shadow","text-transform","text-underline-position","top","transform","transform-origin","transform-style","transition","transition-delay","transition-duration","transition-property","transition-timing-function","unicode-bidi","vertical-align","visibility","white-space","widows","width","word-break","word-spacing","word-wrap","z-index"].reverse();function tC(e){return e?typeof e=="string"?e:e.source:null}function rC(e){return nC("(?=",e,")")}function nC(...e){return e.map(r=>tC(r)).join("")}function iC(e){const t=X_(e),r={className:"built_in",begin:/[\w-]+(?=\()/},n={begin:/-(webkit|moz|ms|o)-(?=[a-z])/},i="and or not only",a=/@-?\w[\w]*(-\w+)*/,o="[a-zA-Z-][a-zA-Z0-9_-]*",s=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE];return{name:"CSS",case_insensitive:!0,illegal:/[=|'\$]/,keywords:{keyframePosition:"from to"},classNameAliases:{keyframePosition:"selector-tag"},contains:[e.C_BLOCK_COMMENT_MODE,n,e.CSS_NUMBER_MODE,{className:"selector-id",begin:/#[A-Za-z0-9_-]+/,relevance:0},{className:"selector-class",begin:"\\."+o,relevance:0},t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",variants:[{begin:":("+Q_.join("|")+")"},{begin:"::("+J_.join("|")+")"}]},{className:"attribute",begin:"\\b("+eC.join("|")+")\\b"},{begin:":",end:"[;}]",contains:[t.HEXCOLOR,t.IMPORTANT,e.CSS_NUMBER_MODE,...s,{begin:/(url|data-uri)\(/,end:/\)/,relevance:0,keywords:{built_in:"url data-uri"},contains:[{className:"string",begin:/[^)]/,endsWithParent:!0,excludeEnd:!0}]},r]},{begin:rC(/@/),end:"[{;]",relevance:0,illegal:/:/,contains:[{className:"keyword",begin:a},{begin:/\s/,endsWithParent:!0,excludeEnd:!0,relevance:0,keywords:{$pattern:/[a-z-]+/,keyword:i,attribute:Z_.join(" ")},contains:[{begin:/[a-z-]+(?=:)/,className:"attribute"},...s,e.CSS_NUMBER_MODE]}]},{className:"selector-tag",begin:"\\b("+Y_.join("|")+")\\b"}]}}var aC=iC;const J$=Ce(aC);function oC(e){return e?typeof e=="string"?e:e.source:null}function sC(...e){return e.map(r=>oC(r)).join("")}function uC(e){const t={begin:/<\/?[A-Za-z_]/,end:">",subLanguage:"xml",relevance:0},r={begin:"^[-\\*]{3,}",end:"$"},n={className:"code",variants:[{begin:"(`{3,})[^`](.|\\n)*?\\1`*[ ]*"},{begin:"(~{3,})[^~](.|\\n)*?\\1~*[ ]*"},{begin:"```",end:"```+[ ]*$"},{begin:"~~~",end:"~~~+[ ]*$"},{begin:"`.+?`"},{begin:"(?=^( {4}|\\t))",contains:[{begin:"^( {4}|\\t)",end:"(\\n)$"}],relevance:0}]},i={className:"bullet",begin:"^[ 	]*([*+-]|(\\d+\\.))(?=\\s+)",end:"\\s+",excludeEnd:!0},a={begin:/^\[[^\n]+\]:/,returnBegin:!0,contains:[{className:"symbol",begin:/\[/,end:/\]/,excludeBegin:!0,excludeEnd:!0},{className:"link",begin:/:\s*/,end:/$/,excludeBegin:!0}]},s={variants:[{begin:/\[.+?\]\[.*?\]/,relevance:0},{begin:/\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,relevance:2},{begin:sC(/\[.+?\]\(/,/[A-Za-z][A-Za-z0-9+.-]*/,/:\/\/.*?\)/),relevance:2},{begin:/\[.+?\]\([./?&#].*?\)/,relevance:1},{begin:/\[.+?\]\(.*?\)/,relevance:0}],returnBegin:!0,contains:[{className:"string",relevance:0,begin:"\\[",end:"\\]",excludeBegin:!0,returnEnd:!0},{className:"link",relevance:0,begin:"\\]\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0},{className:"symbol",relevance:0,begin:"\\]\\[",end:"\\]",excludeBegin:!0,excludeEnd:!0}]},u={className:"strong",contains:[],variants:[{begin:/_{2}/,end:/_{2}/},{begin:/\*{2}/,end:/\*{2}/}]},l={className:"emphasis",contains:[],variants:[{begin:/\*(?!\*)/,end:/\*/},{begin:/_(?!_)/,end:/_/,relevance:0}]};u.contains.push(l),l.contains.push(u);let c=[t,s];return u.contains=u.contains.concat(c),l.contains=l.contains.concat(c),c=c.concat(u,l),{name:"Markdown",aliases:["md","mkdown","mkd"],contains:[{className:"section",variants:[{begin:"^#{1,6}",end:"$",contains:c},{begin:"(?=^.+?\\n[=-]{2,}$)",contains:[{begin:"^[=-]*$"},{begin:"^",end:"\\n",contains:c}]}]},t,i,u,l,{className:"quote",begin:"^>\\s+",contains:c,end:"$"},n,r,s,a]}}var lC=uC;const eU=Ce(lC);function cC(e){return{name:"Dockerfile",aliases:["docker"],case_insensitive:!0,keywords:"from maintainer expose env arg user onbuild stopsignal",contains:[e.HASH_COMMENT_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,e.NUMBER_MODE,{beginKeywords:"run cmd entrypoint volume add copy workdir label healthcheck shell",starts:{end:/[^\\]$/,subLanguage:"bash"}}],illegal:"</"}}var fC=cC;const tU=Ce(fC);function dC(e){return e?typeof e=="string"?e:e.source:null}function hC(e){return t3("(?=",e,")")}function t3(...e){return e.map(r=>dC(r)).join("")}function pC(e){const t="([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)",r={keyword:"and then defined module in return redo if BEGIN retry end for self when next until do begin unless END rescue else break undef not super class case require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor __FILE__",built_in:"proc lambda",literal:"true false nil"},n={className:"doctag",begin:"@[A-Za-z]+"},i={begin:"#<",end:">"},a=[e.COMMENT("#","$",{contains:[n]}),e.COMMENT("^=begin","^=end",{contains:[n],relevance:10}),e.COMMENT("^__END__","\\n$")],o={className:"subst",begin:/#\{/,end:/\}/,keywords:r},s={className:"string",contains:[e.BACKSLASH_ESCAPE,o],variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/`/,end:/`/},{begin:/%[qQwWx]?\(/,end:/\)/},{begin:/%[qQwWx]?\[/,end:/\]/},{begin:/%[qQwWx]?\{/,end:/\}/},{begin:/%[qQwWx]?</,end:/>/},{begin:/%[qQwWx]?\//,end:/\//},{begin:/%[qQwWx]?%/,end:/%/},{begin:/%[qQwWx]?-/,end:/-/},{begin:/%[qQwWx]?\|/,end:/\|/},{begin:/\B\?(\\\d{1,3})/},{begin:/\B\?(\\x[A-Fa-f0-9]{1,2})/},{begin:/\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/},{begin:/\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/},{begin:/\B\?\\(c|C-)[\x20-\x7e]/},{begin:/\B\?\\?\S/},{begin:/<<[-~]?'?(\w+)\n(?:[^\n]*\n)*?\s*\1\b/,returnBegin:!0,contains:[{begin:/<<[-~]?'?/},e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,contains:[e.BACKSLASH_ESCAPE,o]})]}]},u="[1-9](_?[0-9])*|0",l="[0-9](_?[0-9])*",c={className:"number",relevance:0,variants:[{begin:`\\b(${u})(\\.(${l}))?([eE][+-]?(${l})|r)?i?\\b`},{begin:"\\b0[dD][0-9](_?[0-9])*r?i?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*r?i?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*r?i?\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b"},{begin:"\\b0(_?[0-7])+r?i?\\b"}]},f={className:"params",begin:"\\(",end:"\\)",endsParent:!0,keywords:r},d=[s,{className:"class",beginKeywords:"class module",end:"$|;",illegal:/=/,contains:[e.inherit(e.TITLE_MODE,{begin:"[A-Za-z_]\\w*(::\\w+)*(\\?|!)?"}),{begin:"<\\s*",contains:[{begin:"("+e.IDENT_RE+"::)?"+e.IDENT_RE,relevance:0}]}].concat(a)},{className:"function",begin:t3(/def\s+/,hC(t+"\\s*(\\(|;|$)")),relevance:0,keywords:"def",end:"$|;",contains:[e.inherit(e.TITLE_MODE,{begin:t}),f].concat(a)},{begin:e.IDENT_RE+"::"},{className:"symbol",begin:e.UNDERSCORE_IDENT_RE+"(!|\\?)?:",relevance:0},{className:"symbol",begin:":(?!\\s)",contains:[s,{begin:t}],relevance:0},c,{className:"variable",begin:"(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"},{className:"params",begin:/\|/,end:/\|/,relevance:0,keywords:r},{begin:"("+e.RE_STARTERS_RE+"|unless)\\s*",keywords:"unless",contains:[{className:"regexp",contains:[e.BACKSLASH_ESCAPE,o],illegal:/\n/,variants:[{begin:"/",end:"/[a-z]*"},{begin:/%r\{/,end:/\}[a-z]*/},{begin:"%r\\(",end:"\\)[a-z]*"},{begin:"%r!",end:"![a-z]*"},{begin:"%r\\[",end:"\\][a-z]*"}]}].concat(i,a),relevance:0}].concat(i,a);o.contains=d,f.contains=d;const h="[>?]>",p="[\\w#]+\\(\\w+\\):\\d+:\\d+>",m="(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>",g=[{begin:/^\s*=>/,starts:{end:"$",contains:d}},{className:"meta",begin:"^("+h+"|"+p+"|"+m+")(?=[ ])",starts:{end:"$",contains:d}}];return a.unshift(i),{name:"Ruby",aliases:["rb","gemspec","podspec","thor","irb"],keywords:r,illegal:/\/\*/,contains:[e.SHEBANG({binary:"ruby"})].concat(g).concat(a).concat(d)}}var mC=pC;const rU=Ce(mC);function gC(e){const t={keyword:"break default func interface select case map struct chan else goto package switch const fallthrough if range type continue for import return var go defer bool byte complex64 complex128 float32 float64 int8 int16 int32 int64 string uint8 uint16 uint32 uint64 int uint uintptr rune",literal:"true false iota nil",built_in:"append cap close complex copy imag len make new panic print println real recover delete"};return{name:"Go",aliases:["golang"],keywords:t,illegal:"</",contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"string",variants:[e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{begin:"`",end:"`"}]},{className:"number",variants:[{begin:e.C_NUMBER_RE+"[i]",relevance:1},e.C_NUMBER_MODE]},{begin:/:=/},{className:"function",beginKeywords:"func",end:"\\s*(\\{|$)",excludeEnd:!0,contains:[e.TITLE_MODE,{className:"params",begin:/\(/,end:/\)/,keywords:t,illegal:/["']/}]}]}}var bC=gC;const nU=Ce(bC);var ki="[0-9](_*[0-9])*",Do=`\\.(${ki})`,Lo="[0-9a-fA-F](_*[0-9a-fA-F])*",vC={className:"number",variants:[{begin:`(\\b(${ki})((${Do})|\\.)?|(${Do}))[eE][+-]?(${ki})[fFdD]?\\b`},{begin:`\\b(${ki})((${Do})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${Do})[fFdD]?\\b`},{begin:`\\b(${ki})[fFdD]\\b`},{begin:`\\b0[xX]((${Lo})\\.?|(${Lo})?\\.(${Lo}))[pP][+-]?(${ki})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${Lo})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function yC(e){var t="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=t+"(<"+t+"(\\s*,\\s*"+t+")*>)?",n="false synchronized int abstract float private char boolean var static null if const for true while long strictfp finally protected import native final void enum else break transient catch instanceof byte super volatile case assert short package default double public try this switch continue throws protected public private module requires exports do",i={className:"meta",begin:"@"+t,contains:[{begin:/\(/,end:/\)/,contains:["self"]}]};const a=vC;return{name:"Java",aliases:["jsp"],keywords:n,illegal:/<\/|#/,contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{begin:/\w+@/,relevance:0},{className:"doctag",begin:"@[A-Za-z]+"}]}),{begin:/import java\.[a-z]+\./,keywords:"import",relevance:2},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{className:"class",beginKeywords:"class interface enum",end:/[{;=]/,excludeEnd:!0,relevance:1,keywords:"class interface enum",illegal:/[:"\[\]]/,contains:[{beginKeywords:"extends implements"},e.UNDERSCORE_TITLE_MODE]},{beginKeywords:"new throw return else",relevance:0},{className:"class",begin:"record\\s+"+e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,excludeEnd:!0,end:/[{;=]/,keywords:n,contains:[{beginKeywords:"record"},{begin:e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,relevance:0,contains:[e.UNDERSCORE_TITLE_MODE]},{className:"params",begin:/\(/,end:/\)/,keywords:n,relevance:0,contains:[e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"function",begin:"("+r+"\\s+)+"+e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:n,contains:[{begin:e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,relevance:0,contains:[e.UNDERSCORE_TITLE_MODE]},{className:"params",begin:/\(/,end:/\)/,keywords:n,relevance:0,contains:[i,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,a,e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},a,i]}}var wC=yC;const iU=Ce(wC),Ep="[A-Za-z$_][0-9A-Za-z$_]*",xC=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends"],EC=["true","false","null","undefined","NaN","Infinity"],SC=["Intl","DataView","Number","Math","Date","String","RegExp","Object","Function","Boolean","Error","Symbol","Set","Map","WeakSet","WeakMap","Proxy","Reflect","JSON","Promise","Float64Array","Int16Array","Int32Array","Int8Array","Uint16Array","Uint32Array","Float32Array","Array","Uint8Array","Uint8ClampedArray","ArrayBuffer","BigInt64Array","BigUint64Array","BigInt"],TC=["EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],AC=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],kC=["arguments","this","super","console","window","document","localStorage","module","global"],OC=[].concat(AC,kC,SC,TC);function NC(e){return e?typeof e=="string"?e:e.source:null}function Sp(e){return cc("(?=",e,")")}function cc(...e){return e.map(r=>NC(r)).join("")}function _C(e){const t=(N,{after:O})=>{const A="</"+N[0].slice(1);return N.input.indexOf(A,O)!==-1},r=Ep,n={begin:"<>",end:"</>"},i={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(N,O)=>{const A=N[0].length+N.index,D=N.input[A];if(D==="<"){O.ignoreMatch();return}D===">"&&(t(N,{after:A})||O.ignoreMatch())}},a={$pattern:Ep,keyword:xC,literal:EC,built_in:OC},o="[0-9](_?[0-9])*",s=`\\.(${o})`,u="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",l={className:"number",variants:[{begin:`(\\b(${u})((${s})|\\.)?|(${s}))[eE][+-]?(${o})\\b`},{begin:`\\b(${u})\\b((${s})\\b|\\.)?|(${s})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},c={className:"subst",begin:"\\$\\{",end:"\\}",keywords:a,contains:[]},f={begin:"html`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,c],subLanguage:"xml"}},d={begin:"css`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,c],subLanguage:"css"}},h={className:"string",begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE,c]},m={className:"comment",variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+",contains:[{className:"type",begin:"\\{",end:"\\}",relevance:0},{className:"variable",begin:r+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]},g=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,f,d,h,l,e.REGEXP_MODE];c.contains=g.concat({begin:/\{/,end:/\}/,keywords:a,contains:["self"].concat(g)});const v=[].concat(m,c.contains),w=v.concat([{begin:/\(/,end:/\)/,keywords:a,contains:["self"].concat(v)}]),x={className:"params",begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:a,contains:w};return{name:"Javascript",aliases:["js","jsx","mjs","cjs"],keywords:a,exports:{PARAMS_CONTAINS:w},illegal:/#(?![$_A-z])/,contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),{label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,f,d,h,m,l,{begin:cc(/[{,\n]\s*/,Sp(cc(/(((\/\/.*$)|(\/\*(\*[^/]|[^*])*\*\/))\s*)*/,r+"\\s*:"))),relevance:0,contains:[{className:"attr",begin:r+Sp("\\s*:"),relevance:0}]},{begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",contains:[m,e.REGEXP_MODE,{className:"function",begin:"(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:a,contains:w}]}]},{begin:/,/,relevance:0},{className:"",begin:/\s/,end:/\s*/,skip:!0},{variants:[{begin:n.begin,end:n.end},{begin:i.begin,"on:begin":i.isTrulyOpeningTag,end:i.end}],subLanguage:"xml",contains:[{begin:i.begin,end:i.end,skip:!0,contains:["self"]}]}],relevance:0},{className:"function",beginKeywords:"function",end:/[{;]/,excludeEnd:!0,keywords:a,contains:["self",e.inherit(e.TITLE_MODE,{begin:r}),x],illegal:/%/},{beginKeywords:"while if switch catch for"},{className:"function",begin:e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,contains:[x,e.inherit(e.TITLE_MODE,{begin:r})]},{variants:[{begin:"\\."+r},{begin:"\\$"+r}],relevance:0},{className:"class",beginKeywords:"class",end:/[{;=]/,excludeEnd:!0,illegal:/[:"[\]]/,contains:[{beginKeywords:"extends"},e.UNDERSCORE_TITLE_MODE]},{begin:/\b(?=constructor)/,end:/[{;]/,excludeEnd:!0,contains:[e.inherit(e.TITLE_MODE,{begin:r}),"self",x]},{begin:"(get|set)\\s+(?="+r+"\\()",end:/\{/,keywords:"get set",contains:[e.inherit(e.TITLE_MODE,{begin:r}),{begin:/\(\)/},x]},{begin:/\$[(.]/}]}}var CC=_C;const aU=Ce(CC);function MC(e){const t={literal:"true false null"},r=[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE],n=[e.QUOTE_STRING_MODE,e.C_NUMBER_MODE],i={end:",",endsWithParent:!0,excludeEnd:!0,contains:n,keywords:t},a={begin:/\{/,end:/\}/,contains:[{className:"attr",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE],illegal:"\\n"},e.inherit(i,{begin:/:/})].concat(r),illegal:"\\S"},o={begin:"\\[",end:"\\]",contains:[e.inherit(i)],illegal:"\\S"};return n.push(a,o),r.forEach(function(s){n.push(s)}),{name:"JSON",contains:n,keywords:t,illegal:"\\S"}}var RC=MC;const oU=Ce(RC);function IC(e){return e?typeof e=="string"?e:e.source:null}function PC(...e){return"("+e.map(r=>IC(r)).join("|")+")"}function DC(e){const t=PC(...["(?:NeedsTeXFormat|RequirePackage|GetIdInfo)","Provides(?:Expl)?(?:Package|Class|File)","(?:DeclareOption|ProcessOptions)","(?:documentclass|usepackage|input|include)","makeat(?:letter|other)","ExplSyntax(?:On|Off)","(?:new|renew|provide)?command","(?:re)newenvironment","(?:New|Renew|Provide|Declare)(?:Expandable)?DocumentCommand","(?:New|Renew|Provide|Declare)DocumentEnvironment","(?:(?:e|g|x)?def|let)","(?:begin|end)","(?:part|chapter|(?:sub){0,2}section|(?:sub)?paragraph)","caption","(?:label|(?:eq|page|name)?ref|(?:paren|foot|super)?cite)","(?:alpha|beta|[Gg]amma|[Dd]elta|(?:var)?epsilon|zeta|eta|[Tt]heta|vartheta)","(?:iota|(?:var)?kappa|[Ll]ambda|mu|nu|[Xx]i|[Pp]i|varpi|(?:var)rho)","(?:[Ss]igma|varsigma|tau|[Uu]psilon|[Pp]hi|varphi|chi|[Pp]si|[Oo]mega)","(?:frac|sum|prod|lim|infty|times|sqrt|leq|geq|left|right|middle|[bB]igg?)","(?:[lr]angle|q?quad|[lcvdi]?dots|d?dot|hat|tilde|bar)"].map(z=>z+"(?![a-zA-Z@:_])")),r=new RegExp(["(?:__)?[a-zA-Z]{2,}_[a-zA-Z](?:_?[a-zA-Z])+:[a-zA-Z]*","[lgc]__?[a-zA-Z](?:_?[a-zA-Z])*_[a-zA-Z]{2,}","[qs]__?[a-zA-Z](?:_?[a-zA-Z])+","use(?:_i)?:[a-zA-Z]*","(?:else|fi|or):","(?:if|cs|exp):w","(?:hbox|vbox):n","::[a-zA-Z]_unbraced","::[a-zA-Z:]"].map(z=>z+"(?![a-zA-Z:_])").join("|")),n=[{begin:/[a-zA-Z@]+/},{begin:/[^a-zA-Z@]?/}],i=[{begin:/\^{6}[0-9a-f]{6}/},{begin:/\^{5}[0-9a-f]{5}/},{begin:/\^{4}[0-9a-f]{4}/},{begin:/\^{3}[0-9a-f]{3}/},{begin:/\^{2}[0-9a-f]{2}/},{begin:/\^{2}[\u0000-\u007f]/}],a={className:"keyword",begin:/\\/,relevance:0,contains:[{endsParent:!0,begin:t},{endsParent:!0,begin:r},{endsParent:!0,variants:i},{endsParent:!0,relevance:0,variants:n}]},o={className:"params",relevance:0,begin:/#+\d?/},s={variants:i},u={className:"built_in",relevance:0,begin:/[$&^_]/},l={className:"meta",begin:"% !TeX",end:"$",relevance:10},c=e.COMMENT("%","$",{relevance:0}),f=[a,o,s,u,l,c],d={begin:/\{/,end:/\}/,relevance:0,contains:["self",...f]},h=e.inherit(d,{relevance:0,endsParent:!0,contains:[d,...f]}),p={begin:/\[/,end:/\]/,endsParent:!0,relevance:0,contains:[d,...f]},m={begin:/\s+/,relevance:0},g=[h],v=[p],w=function(z,L){return{contains:[m],starts:{relevance:0,contains:z,starts:L}}},x=function(z,L){return{begin:"\\\\"+z+"(?![a-zA-Z@:_])",keywords:{$pattern:/\\[a-zA-Z]+/,keyword:"\\"+z},relevance:0,contains:[m],starts:L}},N=function(z,L){return e.inherit({begin:"\\\\begin(?=[ 	]*(\\r?\\n[ 	]*)?\\{"+z+"\\})",keywords:{$pattern:/\\[a-zA-Z]+/,keyword:"\\begin"},relevance:0},w(g,L))},O=(z="string")=>e.END_SAME_AS_BEGIN({className:z,begin:/(.|\r?\n)/,end:/(.|\r?\n)/,excludeBegin:!0,excludeEnd:!0,endsParent:!0}),A=function(z){return{className:"string",end:"(?=\\\\end\\{"+z+"\\})"}},D=(z="string")=>({relevance:0,begin:/\{/,starts:{endsParent:!0,contains:[{className:z,end:/(?=\})/,endsParent:!0,contains:[{begin:/\{/,end:/\}/,relevance:0,contains:["self"]}]}]}}),H=[...["verb","lstinline"].map(z=>x(z,{contains:[O()]})),x("mint",w(g,{contains:[O()]})),x("mintinline",w(g,{contains:[D(),O()]})),x("url",{contains:[D("link"),D("link")]}),x("hyperref",{contains:[D("link")]}),x("href",w(v,{contains:[D("link")]})),...[].concat(...["","\\*"].map(z=>[N("verbatim"+z,A("verbatim"+z)),N("filecontents"+z,w(g,A("filecontents"+z))),...["","B","L"].map(L=>N(L+"Verbatim"+z,w(v,A(L+"Verbatim"+z))))])),N("minted",w(v,w(g,A("minted"))))];return{name:"LaTeX",aliases:["tex"],contains:[...H,...f]}}var LC=DC;const sU=Ce(LC),FC=e=>({IMPORTANT:{className:"meta",begin:"!important"},HEXCOLOR:{className:"number",begin:"#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})"},ATTRIBUTE_SELECTOR_MODE:{className:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]}}),BC=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","p","q","quote","samp","section","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],zC=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"],r3=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"],n3=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"],$C=["align-content","align-items","align-self","animation","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-timing-function","auto","backface-visibility","background","background-attachment","background-clip","background-color","background-image","background-origin","background-position","background-repeat","background-size","border","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-decoration-break","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","clear","clip","clip-path","color","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","content","counter-increment","counter-reset","cursor","direction","display","empty-cells","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-size","font-size-adjust","font-smoothing","font-stretch","font-style","font-variant","font-variant-ligatures","font-variation-settings","font-weight","height","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","inherit","initial","justify-content","left","letter-spacing","line-height","list-style","list-style-image","list-style-position","list-style-type","margin","margin-bottom","margin-left","margin-right","margin-top","marks","mask","max-height","max-width","min-height","min-width","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-wrap","overflow-x","overflow-y","padding","padding-bottom","padding-left","padding-right","padding-top","page-break-after","page-break-before","page-break-inside","perspective","perspective-origin","pointer-events","position","quotes","resize","right","src","tab-size","table-layout","text-align","text-align-last","text-decoration","text-decoration-color","text-decoration-line","text-decoration-style","text-indent","text-overflow","text-rendering","text-shadow","text-transform","text-underline-position","top","transform","transform-origin","transform-style","transition","transition-delay","transition-duration","transition-property","transition-timing-function","unicode-bidi","vertical-align","visibility","white-space","widows","width","word-break","word-spacing","word-wrap","z-index"].reverse(),UC=r3.concat(n3);function HC(e){const t=FC(e),r=UC,n="and or not only",i="[\\w-]+",a="("+i+"|@\\{"+i+"\\})",o=[],s=[],u=function(x){return{className:"string",begin:"~?"+x+".*?"+x}},l=function(x,N,O){return{className:x,begin:N,relevance:O}},c={$pattern:/[a-z-]+/,keyword:n,attribute:zC.join(" ")},f={begin:"\\(",end:"\\)",contains:s,keywords:c,relevance:0};s.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,u("'"),u('"'),e.CSS_NUMBER_MODE,{begin:"(url|data-uri)\\(",starts:{className:"string",end:"[\\)\\n]",excludeEnd:!0}},t.HEXCOLOR,f,l("variable","@@?"+i,10),l("variable","@\\{"+i+"\\}"),l("built_in","~?`[^`]*?`"),{className:"attribute",begin:i+"\\s*:",end:":",returnBegin:!0,excludeEnd:!0},t.IMPORTANT);const d=s.concat({begin:/\{/,end:/\}/,contains:o}),h={beginKeywords:"when",endsWithParent:!0,contains:[{beginKeywords:"and not"}].concat(s)},p={begin:a+"\\s*:",returnBegin:!0,end:/[;}]/,relevance:0,contains:[{begin:/-(webkit|moz|ms|o)-/},{className:"attribute",begin:"\\b("+$C.join("|")+")\\b",end:/(?=:)/,starts:{endsWithParent:!0,illegal:"[<=$]",relevance:0,contains:s}}]},m={className:"keyword",begin:"@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b",starts:{end:"[;{}]",keywords:c,returnEnd:!0,contains:s,relevance:0}},g={className:"variable",variants:[{begin:"@"+i+"\\s*:",relevance:15},{begin:"@"+i}],starts:{end:"[;}]",returnEnd:!0,contains:d}},v={variants:[{begin:"[\\.#:&\\[>]",end:"[;{}]"},{begin:a,end:/\{/}],returnBegin:!0,returnEnd:!0,illegal:`[<='$"]`,relevance:0,contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,h,l("keyword","all\\b"),l("variable","@\\{"+i+"\\}"),{begin:"\\b("+BC.join("|")+")\\b",className:"selector-tag"},l("selector-tag",a+"%?",0),l("selector-id","#"+a),l("selector-class","\\."+a,0),l("selector-tag","&",0),t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",begin:":("+r3.join("|")+")"},{className:"selector-pseudo",begin:"::("+n3.join("|")+")"},{begin:"\\(",end:"\\)",contains:d},{begin:"!important"}]},w={begin:i+`:(:)?(${r.join("|")})`,returnBegin:!0,contains:[v]};return o.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,m,g,w,p,v),{name:"Less",case_insensitive:!0,illegal:`[=>'/<($"]`,contains:o}}var qC=HC;const uU=Ce(qC);function jC(e){return e?typeof e=="string"?e:e.source:null}function Fo(...e){return e.map(r=>jC(r)).join("")}function VC(e){const t=/([-a-zA-Z$._][\w$.-]*)/,r={className:"type",begin:/\bi\d+(?=\s|\b)/},n={className:"operator",relevance:0,begin:/=/},i={className:"punctuation",relevance:0,begin:/,/},a={className:"number",variants:[{begin:/0[xX][a-fA-F0-9]+/},{begin:/-?\d+(?:[.]\d+)?(?:[eE][-+]?\d+(?:[.]\d+)?)?/}],relevance:0},o={className:"symbol",variants:[{begin:/^\s*[a-z]+:/}],relevance:0},s={className:"variable",variants:[{begin:Fo(/%/,t)},{begin:/%\d+/},{begin:/#\d+/}]},u={className:"title",variants:[{begin:Fo(/@/,t)},{begin:/@\d+/},{begin:Fo(/!/,t)},{begin:Fo(/!\d+/,t)},{begin:/!\d+/}]};return{name:"LLVM IR",keywords:"begin end true false declare define global constant private linker_private internal available_externally linkonce linkonce_odr weak weak_odr appending dllimport dllexport common default hidden protected extern_weak external thread_local zeroinitializer undef null to tail target triple datalayout volatile nuw nsw nnan ninf nsz arcp fast exact inbounds align addrspace section alias module asm sideeffect gc dbg linker_private_weak attributes blockaddress initialexec localdynamic localexec prefix unnamed_addr ccc fastcc coldcc x86_stdcallcc x86_fastcallcc arm_apcscc arm_aapcscc arm_aapcs_vfpcc ptx_device ptx_kernel intel_ocl_bicc msp430_intrcc spir_func spir_kernel x86_64_sysvcc x86_64_win64cc x86_thiscallcc cc c signext zeroext inreg sret nounwind noreturn noalias nocapture byval nest readnone readonly inlinehint noinline alwaysinline optsize ssp sspreq noredzone noimplicitfloat naked builtin cold nobuiltin noduplicate nonlazybind optnone returns_twice sanitize_address sanitize_memory sanitize_thread sspstrong uwtable returned type opaque eq ne slt sgt sle sge ult ugt ule uge oeq one olt ogt ole oge ord uno ueq une x acq_rel acquire alignstack atomic catch cleanup filter inteldialect max min monotonic nand personality release seq_cst singlethread umax umin unordered xchg add fadd sub fsub mul fmul udiv sdiv fdiv urem srem frem shl lshr ashr and or xor icmp fcmp phi call trunc zext sext fptrunc fpext uitofp sitofp fptoui fptosi inttoptr ptrtoint bitcast addrspacecast select va_arg ret br switch invoke unwind unreachable indirectbr landingpad resume malloc alloca free load store getelementptr extractelement insertelement shufflevector getresult extractvalue insertvalue atomicrmw cmpxchg fence argmemonly double",contains:[r,e.COMMENT(/;\s*$/,null,{relevance:0}),e.COMMENT(/;/,/$/),e.QUOTE_STRING_MODE,{className:"string",variants:[{begin:/"/,end:/[^\\]"/}]},u,i,n,s,o,a]}}var GC=VC;const lU=Ce(GC);function WC(e){const t="\\[=*\\[",r="\\]=*\\]",n={begin:t,end:r,contains:["self"]},i=[e.COMMENT("--(?!"+t+")","$"),e.COMMENT("--"+t,r,{contains:[n],relevance:10})];return{name:"Lua",keywords:{$pattern:e.UNDERSCORE_IDENT_RE,literal:"true false nil",keyword:"and break do else elseif end for goto if in local not or repeat return then until while",built_in:"_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len __gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall arg self coroutine resume yield status wrap create running debug getupvalue debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv io lines write close flush open output type read stderr stdin input stdout popen tmpfile math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower table setn insert getn foreachi maxn foreach concat sort remove"},contains:i.concat([{className:"function",beginKeywords:"function",end:"\\)",contains:[e.inherit(e.TITLE_MODE,{begin:"([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*"}),{className:"params",begin:"\\(",endsWithParent:!0,contains:i}].concat(i)},e.C_NUMBER_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{className:"string",begin:t,end:r,contains:[n],relevance:5}])}}var KC=WC;const cU=Ce(KC);function XC(e){const t={className:"variable",variants:[{begin:"\\$\\("+e.UNDERSCORE_IDENT_RE+"\\)",contains:[e.BACKSLASH_ESCAPE]},{begin:/\$[@%<?\^\+\*]/}]},r={className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,t]},n={className:"variable",begin:/\$\([\w-]+\s/,end:/\)/,keywords:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},contains:[t]},i={begin:"^"+e.UNDERSCORE_IDENT_RE+"\\s*(?=[:+?]?=)"},a={className:"meta",begin:/^\.PHONY:/,end:/$/,keywords:{$pattern:/[\.\w]+/,"meta-keyword":".PHONY"}},o={className:"section",begin:/^[^\s]+:/,end:/$/,contains:[t]};return{name:"Makefile",aliases:["mk","mak","make"],keywords:{$pattern:/[\w-]+/,keyword:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath"},contains:[e.HASH_COMMENT_MODE,t,r,n,i,a,o]}}var YC=XC;const fU=Ce(YC);function ZC(e){var t="('|\\.')+",r={relevance:0,contains:[{begin:t}]};return{name:"Matlab",keywords:{keyword:"arguments break case catch classdef continue else elseif end enumeration events for function global if methods otherwise parfor persistent properties return spmd switch try while",built_in:"sin sind sinh asin asind asinh cos cosd cosh acos acosd acosh tan tand tanh atan atand atan2 atanh sec secd sech asec asecd asech csc cscd csch acsc acscd acsch cot cotd coth acot acotd acoth hypot exp expm1 log log1p log10 log2 pow2 realpow reallog realsqrt sqrt nthroot nextpow2 abs angle complex conj imag real unwrap isreal cplxpair fix floor ceil round mod rem sign airy besselj bessely besselh besseli besselk beta betainc betaln ellipj ellipke erf erfc erfcx erfinv expint gamma gammainc gammaln psi legendre cross dot factor isprime primes gcd lcm rat rats perms nchoosek factorial cart2sph cart2pol pol2cart sph2cart hsv2rgb rgb2hsv zeros ones eye repmat rand randn linspace logspace freqspace meshgrid accumarray size length ndims numel disp isempty isequal isequalwithequalnans cat reshape diag blkdiag tril triu fliplr flipud flipdim rot90 find sub2ind ind2sub bsxfun ndgrid permute ipermute shiftdim circshift squeeze isscalar isvector ans eps realmax realmin pi i|0 inf nan isnan isinf isfinite j|0 why compan gallery hadamard hankel hilb invhilb magic pascal rosser toeplitz vander wilkinson max min nanmax nanmin mean nanmean type table readtable writetable sortrows sort figure plot plot3 scatter scatter3 cellfun legend intersect ismember procrustes hold num2cell "},illegal:'(//|"|#|/\\*|\\s+/\\w+)',contains:[{className:"function",beginKeywords:"function",end:"$",contains:[e.UNDERSCORE_TITLE_MODE,{className:"params",variants:[{begin:"\\(",end:"\\)"},{begin:"\\[",end:"\\]"}]}]},{className:"built_in",begin:/true|false/,relevance:0,starts:r},{begin:"[a-zA-Z][a-zA-Z_0-9]*"+t,relevance:0},{className:"number",begin:e.C_NUMBER_RE,relevance:0,starts:r},{className:"string",begin:"'",end:"'",contains:[e.BACKSLASH_ESCAPE,{begin:"''"}]},{begin:/\]|\}|\)/,relevance:0,starts:r},{className:"string",begin:'"',end:'"',contains:[e.BACKSLASH_ESCAPE,{begin:'""'}],starts:r},e.COMMENT("^\\s*%\\{\\s*$","^\\s*%\\}\\s*$"),e.COMMENT("%","$")]}}var QC=ZC;const dU=Ce(QC);function JC(e){const t={className:"built_in",begin:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},r=/[a-zA-Z@][a-zA-Z0-9_]*/,n={$pattern:r,keyword:"int float while char export sizeof typedef const struct for union unsigned long volatile static bool mutable if do return goto void enum else break extern asm case short default double register explicit signed typename this switch continue wchar_t inline readonly assign readwrite self @synchronized id typeof nonatomic super unichar IBOutlet IBAction strong weak copy in out inout bycopy byref oneway __strong __weak __block __autoreleasing @private @protected @public @try @property @end @throw @catch @finally @autoreleasepool @synthesize @dynamic @selector @optional @required @encode @package @import @defs @compatibility_alias __bridge __bridge_transfer __bridge_retained __bridge_retain __covariant __contravariant __kindof _Nonnull _Nullable _Null_unspecified __FUNCTION__ __PRETTY_FUNCTION__ __attribute__ getter setter retain unsafe_unretained nonnull nullable null_unspecified null_resettable class instancetype NS_DESIGNATED_INITIALIZER NS_UNAVAILABLE NS_REQUIRES_SUPER NS_RETURNS_INNER_POINTER NS_INLINE NS_AVAILABLE NS_DEPRECATED NS_ENUM NS_OPTIONS NS_SWIFT_UNAVAILABLE NS_ASSUME_NONNULL_BEGIN NS_ASSUME_NONNULL_END NS_REFINED_FOR_SWIFT NS_SWIFT_NAME NS_SWIFT_NOTHROW NS_DURING NS_HANDLER NS_ENDHANDLER NS_VALUERETURN NS_VOIDRETURN",literal:"false true FALSE TRUE nil YES NO NULL",built_in:"BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once"},i={$pattern:r,keyword:"@interface @class @protocol @implementation"};return{name:"Objective-C",aliases:["mm","objc","obj-c","obj-c++","objective-c++"],keywords:n,illegal:"</",contains:[t,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.C_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{className:"string",variants:[{begin:'@"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]}]},{className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{"meta-keyword":"if else elif endif define undef warning error line pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(e.QUOTE_STRING_MODE,{className:"meta-string"}),{className:"meta-string",begin:/<.*?>/,end:/$/,illegal:"\\n"},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"class",begin:"("+i.keyword.split(" ").join("|")+")\\b",end:/(\{|$)/,excludeEnd:!0,keywords:i,contains:[e.UNDERSCORE_TITLE_MODE]},{begin:"\\."+e.UNDERSCORE_IDENT_RE,relevance:0}]}}var eM=JC;const hU=Ce(eM);function tM(e){const t={className:"variable",begin:"\\$+[a-zA-Z_-ÿ][a-zA-Z0-9_-ÿ]*(?![A-Za-z0-9])(?![$])"},r={className:"meta",variants:[{begin:/<\?php/,relevance:10},{begin:/<\?[=]?/},{begin:/\?>/}]},n={className:"subst",variants:[{begin:/\$\w+/},{begin:/\{\$/,end:/\}/}]},i=e.inherit(e.APOS_STRING_MODE,{illegal:null}),a=e.inherit(e.QUOTE_STRING_MODE,{illegal:null,contains:e.QUOTE_STRING_MODE.contains.concat(n)}),o=e.END_SAME_AS_BEGIN({begin:/<<<[ \t]*(\w+)\n/,end:/[ \t]*(\w+)\b/,contains:e.QUOTE_STRING_MODE.contains.concat(n)}),s={className:"string",contains:[e.BACKSLASH_ESCAPE,r],variants:[e.inherit(i,{begin:"b'",end:"'"}),e.inherit(a,{begin:'b"',end:'"'}),a,i,o]},u={className:"number",variants:[{begin:"\\b0b[01]+(?:_[01]+)*\\b"},{begin:"\\b0o[0-7]+(?:_[0-7]+)*\\b"},{begin:"\\b0x[\\da-f]+(?:_[\\da-f]+)*\\b"},{begin:"(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:e[+-]?\\d+)?"}],relevance:0},l={keyword:"__CLASS__ __DIR__ __FILE__ __FUNCTION__ __LINE__ __METHOD__ __NAMESPACE__ __TRAIT__ die echo exit include include_once print require require_once array abstract and as binary bool boolean break callable case catch class clone const continue declare default do double else elseif empty enddeclare endfor endforeach endif endswitch endwhile enum eval extends final finally float for foreach from global goto if implements instanceof insteadof int integer interface isset iterable list match|0 mixed new object or private protected public real return string switch throw trait try unset use var void while xor yield",literal:"false null true",built_in:"Error|0 AppendIterator ArgumentCountError ArithmeticError ArrayIterator ArrayObject AssertionError BadFunctionCallException BadMethodCallException CachingIterator CallbackFilterIterator CompileError Countable DirectoryIterator DivisionByZeroError DomainException EmptyIterator ErrorException Exception FilesystemIterator FilterIterator GlobIterator InfiniteIterator InvalidArgumentException IteratorIterator LengthException LimitIterator LogicException MultipleIterator NoRewindIterator OutOfBoundsException OutOfRangeException OuterIterator OverflowException ParentIterator ParseError RangeException RecursiveArrayIterator RecursiveCachingIterator RecursiveCallbackFilterIterator RecursiveDirectoryIterator RecursiveFilterIterator RecursiveIterator RecursiveIteratorIterator RecursiveRegexIterator RecursiveTreeIterator RegexIterator RuntimeException SeekableIterator SplDoublyLinkedList SplFileInfo SplFileObject SplFixedArray SplHeap SplMaxHeap SplMinHeap SplObjectStorage SplObserver SplObserver SplPriorityQueue SplQueue SplStack SplSubject SplSubject SplTempFileObject TypeError UnderflowException UnexpectedValueException UnhandledMatchError ArrayAccess Closure Generator Iterator IteratorAggregate Serializable Stringable Throwable Traversable WeakReference WeakMap Directory __PHP_Incomplete_Class parent php_user_filter self static stdClass"};return{aliases:["php3","php4","php5","php6","php7","php8"],case_insensitive:!0,keywords:l,contains:[e.HASH_COMMENT_MODE,e.COMMENT("//","$",{contains:[r]}),e.COMMENT("/\\*","\\*/",{contains:[{className:"doctag",begin:"@[A-Za-z]+"}]}),e.COMMENT("__halt_compiler.+?;",!1,{endsWithParent:!0,keywords:"__halt_compiler"}),r,{className:"keyword",begin:/\$this\b/},t,{begin:/(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/},{className:"function",relevance:0,beginKeywords:"fn function",end:/[;{]/,excludeEnd:!0,illegal:"[$%\\[]",contains:[{beginKeywords:"use"},e.UNDERSCORE_TITLE_MODE,{begin:"=>",endsParent:!0},{className:"params",begin:"\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0,keywords:l,contains:["self",t,e.C_BLOCK_COMMENT_MODE,s,u]}]},{className:"class",variants:[{beginKeywords:"enum",illegal:/[($"]/},{beginKeywords:"class interface trait",illegal:/[:($"]/}],relevance:0,end:/\{/,excludeEnd:!0,contains:[{beginKeywords:"extends implements"},e.UNDERSCORE_TITLE_MODE]},{beginKeywords:"namespace",relevance:0,end:";",illegal:/[.']/,contains:[e.UNDERSCORE_TITLE_MODE]},{beginKeywords:"use",relevance:0,end:";",contains:[e.UNDERSCORE_TITLE_MODE]},s,u]}}var rM=tM;const pU=Ce(rM);function nM(e){return e?typeof e=="string"?e:e.source:null}function iM(e){return aM("(?=",e,")")}function aM(...e){return e.map(r=>nM(r)).join("")}function oM(e){const a={$pattern:/[A-Za-z]\w+|__\w+__/,keyword:["and","as","assert","async","await","break","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","in","is","lambda","nonlocal|10","not","or","pass","raise","return","try","while","with","yield"],built_in:["__import__","abs","all","any","ascii","bin","bool","breakpoint","bytearray","bytes","callable","chr","classmethod","compile","complex","delattr","dict","dir","divmod","enumerate","eval","exec","filter","float","format","frozenset","getattr","globals","hasattr","hash","help","hex","id","input","int","isinstance","issubclass","iter","len","list","locals","map","max","memoryview","min","next","object","oct","open","ord","pow","print","property","range","repr","reversed","round","set","setattr","slice","sorted","staticmethod","str","sum","super","tuple","type","vars","zip"],literal:["__debug__","Ellipsis","False","None","NotImplemented","True"],type:["Any","Callable","Coroutine","Dict","List","Literal","Generic","Optional","Sequence","Set","Tuple","Type","Union"]},o={className:"meta",begin:/^(>>>|\.\.\.) /},s={className:"subst",begin:/\{/,end:/\}/,keywords:a,illegal:/#/},u={begin:/\{\{/,relevance:0},l={className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,end:/'''/,contains:[e.BACKSLASH_ESCAPE,o],relevance:10},{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,end:/"""/,contains:[e.BACKSLASH_ESCAPE,o],relevance:10},{begin:/([fF][rR]|[rR][fF]|[fF])'''/,end:/'''/,contains:[e.BACKSLASH_ESCAPE,o,u,s]},{begin:/([fF][rR]|[rR][fF]|[fF])"""/,end:/"""/,contains:[e.BACKSLASH_ESCAPE,o,u,s]},{begin:/([uU]|[rR])'/,end:/'/,relevance:10},{begin:/([uU]|[rR])"/,end:/"/,relevance:10},{begin:/([bB]|[bB][rR]|[rR][bB])'/,end:/'/},{begin:/([bB]|[bB][rR]|[rR][bB])"/,end:/"/},{begin:/([fF][rR]|[rR][fF]|[fF])'/,end:/'/,contains:[e.BACKSLASH_ESCAPE,u,s]},{begin:/([fF][rR]|[rR][fF]|[fF])"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,u,s]},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},c="[0-9](_?[0-9])*",f=`(\\b(${c}))?\\.(${c})|\\b(${c})\\.`,d={className:"number",relevance:0,variants:[{begin:`(\\b(${c})|(${f}))[eE][+-]?(${c})[jJ]?\\b`},{begin:`(${f})[jJ]?`},{begin:"\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?\\b"},{begin:"\\b0[bB](_?[01])+[lL]?\\b"},{begin:"\\b0[oO](_?[0-7])+[lL]?\\b"},{begin:"\\b0[xX](_?[0-9a-fA-F])+[lL]?\\b"},{begin:`\\b(${c})[jJ]\\b`}]},h={className:"comment",begin:iM(/# type:/),end:/$/,keywords:a,contains:[{begin:/# type:/},{begin:/#/,end:/\b\B/,endsWithParent:!0}]},p={className:"params",variants:[{className:"",begin:/\(\s*\)/,skip:!0},{begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:a,contains:["self",o,d,l,e.HASH_COMMENT_MODE]}]};return s.contains=[l,d,o],{name:"Python",aliases:["py","gyp","ipython"],keywords:a,illegal:/(<\/|->|\?)|=>/,contains:[o,d,{begin:/\bself\b/},{beginKeywords:"if",relevance:0},l,h,e.HASH_COMMENT_MODE,{variants:[{className:"function",beginKeywords:"def"},{className:"class",beginKeywords:"class"}],end:/:/,illegal:/[${=;\n,]/,contains:[e.UNDERSCORE_TITLE_MODE,p,{begin:/->/,endsWithParent:!0,keywords:a}]},{className:"meta",begin:/^[\t ]*@/,end:/(?=#)|$/,contains:[d,p,l]}]}}var sM=oM;const mU=Ce(sM);function uM(e){return e?typeof e=="string"?e:e.source:null}function lM(e){return fc("(?=",e,")")}function fc(...e){return e.map(r=>uM(r)).join("")}function cM(e){const t=/(?:(?:[a-zA-Z]|\.[._a-zA-Z])[._a-zA-Z0-9]*)|\.(?!\d)/,r=/[a-zA-Z][a-zA-Z_0-9]*/;return{name:"R",illegal:/->/,keywords:{$pattern:t,keyword:"function if in break next repeat else for while",literal:"NULL NA TRUE FALSE Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 NA_complex_|10",built_in:"LETTERS letters month.abb month.name pi T F abs acos acosh all any anyNA Arg as.call as.character as.complex as.double as.environment as.integer as.logical as.null.default as.numeric as.raw asin asinh atan atanh attr attributes baseenv browser c call ceiling class Conj cos cosh cospi cummax cummin cumprod cumsum digamma dim dimnames emptyenv exp expression floor forceAndCall gamma gc.time globalenv Im interactive invisible is.array is.atomic is.call is.character is.complex is.double is.environment is.expression is.finite is.function is.infinite is.integer is.language is.list is.logical is.matrix is.na is.name is.nan is.null is.numeric is.object is.pairlist is.raw is.recursive is.single is.symbol lazyLoadDBfetch length lgamma list log max min missing Mod names nargs nzchar oldClass on.exit pos.to.env proc.time prod quote range Re rep retracemem return round seq_along seq_len seq.int sign signif sin sinh sinpi sqrt standardGeneric substitute sum switch tan tanh tanpi tracemem trigamma trunc unclass untracemem UseMethod xtfrm"},compilerExtensions:[(n,i)=>{if(!n.beforeMatch)return;if(n.starts)throw new Error("beforeMatch cannot be used with starts");const a=Object.assign({},n);Object.keys(n).forEach(o=>{delete n[o]}),n.begin=fc(a.beforeMatch,lM(a.begin)),n.starts={relevance:0,contains:[Object.assign(a,{endsParent:!0})]},n.relevance=0,delete a.beforeMatch}],contains:[e.COMMENT(/#'/,/$/,{contains:[{className:"doctag",begin:"@examples",starts:{contains:[{begin:/\n/},{begin:/#'\s*(?=@[a-zA-Z]+)/,endsParent:!0},{begin:/#'/,end:/$/,excludeBegin:!0}]}},{className:"doctag",begin:"@param",end:/$/,contains:[{className:"variable",variants:[{begin:t},{begin:/`(?:\\.|[^`\\])+`/}],endsParent:!0}]},{className:"doctag",begin:/@[a-zA-Z]+/},{className:"meta-keyword",begin:/\\[a-zA-Z]+/}]}),e.HASH_COMMENT_MODE,{className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\(/,end:/\)(-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\{/,end:/\}(-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\[/,end:/\](-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\(/,end:/\)(-*)'/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\{/,end:/\}(-*)'/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\[/,end:/\](-*)'/}),{begin:'"',end:'"',relevance:0},{begin:"'",end:"'",relevance:0}]},{className:"number",relevance:0,beforeMatch:/([^a-zA-Z0-9._])/,variants:[{match:/0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/},{match:/0[xX][0-9a-fA-F]+([pP][+-]?\d+)?[Li]?/},{match:/(\d+(\.\d*)?|\.\d+)([eE][+-]?\d+)?[Li]?/}]},{begin:"%",end:"%"},{begin:fc(r,"\\s+<-\\s+")},{begin:"`",end:"`",contains:[{begin:/\\./}]}]}}var fM=cM;const gU=Ce(fM);function dM(e){return{name:"Shell Session",aliases:["console"],contains:[{className:"meta",begin:/^\s{0,3}[/~\w\d[\]()@-]*[>%$#]/,starts:{end:/[^\\](?=\s*$)/,subLanguage:"bash"}}]}}var hM=dM;const bU=Ce(hM);function i3(e){return e?typeof e=="string"?e:e.source:null}function pM(...e){return e.map(r=>i3(r)).join("")}function Ul(...e){return"("+e.map(r=>i3(r)).join("|")+")"}function mM(e){const t=e.COMMENT("--","$"),r={className:"string",variants:[{begin:/'/,end:/'/,contains:[{begin:/''/}]}]},n={begin:/"/,end:/"/,contains:[{begin:/""/}]},i=["true","false","unknown"],a=["double precision","large object","with timezone","without timezone"],o=["bigint","binary","blob","boolean","char","character","clob","date","dec","decfloat","decimal","float","int","integer","interval","nchar","nclob","national","numeric","real","row","smallint","time","timestamp","varchar","varying","varbinary"],s=["add","asc","collation","desc","final","first","last","view"],u=["abs","acos","all","allocate","alter","and","any","are","array","array_agg","array_max_cardinality","as","asensitive","asin","asymmetric","at","atan","atomic","authorization","avg","begin","begin_frame","begin_partition","between","bigint","binary","blob","boolean","both","by","call","called","cardinality","cascaded","case","cast","ceil","ceiling","char","char_length","character","character_length","check","classifier","clob","close","coalesce","collate","collect","column","commit","condition","connect","constraint","contains","convert","copy","corr","corresponding","cos","cosh","count","covar_pop","covar_samp","create","cross","cube","cume_dist","current","current_catalog","current_date","current_default_transform_group","current_path","current_role","current_row","current_schema","current_time","current_timestamp","current_path","current_role","current_transform_group_for_type","current_user","cursor","cycle","date","day","deallocate","dec","decimal","decfloat","declare","default","define","delete","dense_rank","deref","describe","deterministic","disconnect","distinct","double","drop","dynamic","each","element","else","empty","end","end_frame","end_partition","end-exec","equals","escape","every","except","exec","execute","exists","exp","external","extract","false","fetch","filter","first_value","float","floor","for","foreign","frame_row","free","from","full","function","fusion","get","global","grant","group","grouping","groups","having","hold","hour","identity","in","indicator","initial","inner","inout","insensitive","insert","int","integer","intersect","intersection","interval","into","is","join","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","language","large","last_value","lateral","lead","leading","left","like","like_regex","listagg","ln","local","localtime","localtimestamp","log","log10","lower","match","match_number","match_recognize","matches","max","member","merge","method","min","minute","mod","modifies","module","month","multiset","national","natural","nchar","nclob","new","no","none","normalize","not","nth_value","ntile","null","nullif","numeric","octet_length","occurrences_regex","of","offset","old","omit","on","one","only","open","or","order","out","outer","over","overlaps","overlay","parameter","partition","pattern","per","percent","percent_rank","percentile_cont","percentile_disc","period","portion","position","position_regex","power","precedes","precision","prepare","primary","procedure","ptf","range","rank","reads","real","recursive","ref","references","referencing","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","release","result","return","returns","revoke","right","rollback","rollup","row","row_number","rows","running","savepoint","scope","scroll","search","second","seek","select","sensitive","session_user","set","show","similar","sin","sinh","skip","smallint","some","specific","specifictype","sql","sqlexception","sqlstate","sqlwarning","sqrt","start","static","stddev_pop","stddev_samp","submultiset","subset","substring","substring_regex","succeeds","sum","symmetric","system","system_time","system_user","table","tablesample","tan","tanh","then","time","timestamp","timezone_hour","timezone_minute","to","trailing","translate","translate_regex","translation","treat","trigger","trim","trim_array","true","truncate","uescape","union","unique","unknown","unnest","update   ","upper","user","using","value","values","value_of","var_pop","var_samp","varbinary","varchar","varying","versioning","when","whenever","where","width_bucket","window","with","within","without","year"],l=["abs","acos","array_agg","asin","atan","avg","cast","ceil","ceiling","coalesce","corr","cos","cosh","count","covar_pop","covar_samp","cume_dist","dense_rank","deref","element","exp","extract","first_value","floor","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","last_value","lead","listagg","ln","log","log10","lower","max","min","mod","nth_value","ntile","nullif","percent_rank","percentile_cont","percentile_disc","position","position_regex","power","rank","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","row_number","sin","sinh","sqrt","stddev_pop","stddev_samp","substring","substring_regex","sum","tan","tanh","translate","translate_regex","treat","trim","trim_array","unnest","upper","value_of","var_pop","var_samp","width_bucket"],c=["current_catalog","current_date","current_default_transform_group","current_path","current_role","current_schema","current_transform_group_for_type","current_user","session_user","system_time","system_user","current_time","localtime","current_timestamp","localtimestamp"],f=["create table","insert into","primary key","foreign key","not null","alter table","add constraint","grouping sets","on overflow","character set","respect nulls","ignore nulls","nulls first","nulls last","depth first","breadth first"],d=l,h=[...u,...s].filter(w=>!l.includes(w)),p={className:"variable",begin:/@[a-z0-9]+/},m={className:"operator",begin:/[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,relevance:0},g={begin:pM(/\b/,Ul(...d),/\s*\(/),keywords:{built_in:d}};function v(w,{exceptions:x,when:N}={}){const O=N;return x=x||[],w.map(A=>A.match(/\|\d+$/)||x.includes(A)?A:O(A)?`${A}|0`:A)}return{name:"SQL",case_insensitive:!0,illegal:/[{}]|<\//,keywords:{$pattern:/\b[\w\.]+/,keyword:v(h,{when:w=>w.length<3}),literal:i,type:o,built_in:c},contains:[{begin:Ul(...f),keywords:{$pattern:/[\w\.]+/,keyword:h.concat(f),literal:i,type:o}},{className:"type",begin:Ul(...a)},g,p,r,n,e.C_NUMBER_MODE,e.C_BLOCK_COMMENT_MODE,t,m]}}var gM=mM;const vU=Ce(gM);function a3(e){return e?typeof e=="string"?e:e.source:null}function wi(e){return Ze("(?=",e,")")}function Ze(...e){return e.map(r=>a3(r)).join("")}function Pt(...e){return"("+e.map(r=>a3(r)).join("|")+")"}const Jf=e=>Ze(/\b/,e,/\w$/.test(e)?/\b/:/\B/),Tp=["Protocol","Type"].map(Jf),Hl=["init","self"].map(Jf),bM=["Any","Self"],ql=["associatedtype","async","await",/as\?/,/as!/,"as","break","case","catch","class","continue","convenience","default","defer","deinit","didSet","do","dynamic","else","enum","extension","fallthrough",/fileprivate\(set\)/,"fileprivate","final","for","func","get","guard","if","import","indirect","infix",/init\?/,/init!/,"inout",/internal\(set\)/,"internal","in","is","lazy","let","mutating","nonmutating",/open\(set\)/,"open","operator","optional","override","postfix","precedencegroup","prefix",/private\(set\)/,"private","protocol",/public\(set\)/,"public","repeat","required","rethrows","return","set","some","static","struct","subscript","super","switch","throws","throw",/try\?/,/try!/,"try","typealias",/unowned\(safe\)/,/unowned\(unsafe\)/,"unowned","var","weak","where","while","willSet"],Ap=["false","nil","true"],vM=["assignment","associativity","higherThan","left","lowerThan","none","right"],yM=["#colorLiteral","#column","#dsohandle","#else","#elseif","#endif","#error","#file","#fileID","#fileLiteral","#filePath","#function","#if","#imageLiteral","#keyPath","#line","#selector","#sourceLocation","#warn_unqualified_access","#warning"],kp=["abs","all","any","assert","assertionFailure","debugPrint","dump","fatalError","getVaList","isKnownUniquelyReferenced","max","min","numericCast","pointwiseMax","pointwiseMin","precondition","preconditionFailure","print","readLine","repeatElement","sequence","stride","swap","swift_unboxFromSwiftValueWithType","transcode","type","unsafeBitCast","unsafeDowncast","withExtendedLifetime","withUnsafeMutablePointer","withUnsafePointer","withVaList","withoutActuallyEscaping","zip"],o3=Pt(/[/=\-+!*%<>&|^~?]/,/[\u00A1-\u00A7]/,/[\u00A9\u00AB]/,/[\u00AC\u00AE]/,/[\u00B0\u00B1]/,/[\u00B6\u00BB\u00BF\u00D7\u00F7]/,/[\u2016-\u2017]/,/[\u2020-\u2027]/,/[\u2030-\u203E]/,/[\u2041-\u2053]/,/[\u2055-\u205E]/,/[\u2190-\u23FF]/,/[\u2500-\u2775]/,/[\u2794-\u2BFF]/,/[\u2E00-\u2E7F]/,/[\u3001-\u3003]/,/[\u3008-\u3020]/,/[\u3030]/),s3=Pt(o3,/[\u0300-\u036F]/,/[\u1DC0-\u1DFF]/,/[\u20D0-\u20FF]/,/[\uFE00-\uFE0F]/,/[\uFE20-\uFE2F]/),jl=Ze(o3,s3,"*"),u3=Pt(/[a-zA-Z_]/,/[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,/[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,/[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,/[\u1E00-\u1FFF]/,/[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,/[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,/[\u2C00-\u2DFF\u2E80-\u2FFF]/,/[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,/[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,/[\uFE47-\uFEFE\uFF00-\uFFFD]/),Bs=Pt(u3,/\d/,/[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/),tn=Ze(u3,Bs,"*"),Vl=Ze(/[A-Z]/,Bs,"*"),wM=["autoclosure",Ze(/convention\(/,Pt("swift","block","c"),/\)/),"discardableResult","dynamicCallable","dynamicMemberLookup","escaping","frozen","GKInspectable","IBAction","IBDesignable","IBInspectable","IBOutlet","IBSegueAction","inlinable","main","nonobjc","NSApplicationMain","NSCopying","NSManaged",Ze(/objc\(/,tn,/\)/),"objc","objcMembers","propertyWrapper","requires_stored_property_inits","testable","UIApplicationMain","unknown","usableFromInline"],xM=["iOS","iOSApplicationExtension","macOS","macOSApplicationExtension","macCatalyst","macCatalystApplicationExtension","watchOS","watchOSApplicationExtension","tvOS","tvOSApplicationExtension","swift"];function EM(e){const t={match:/\s+/,relevance:0},r=e.COMMENT("/\\*","\\*/",{contains:["self"]}),n=[e.C_LINE_COMMENT_MODE,r],i={className:"keyword",begin:Ze(/\./,wi(Pt(...Tp,...Hl))),end:Pt(...Tp,...Hl),excludeBegin:!0},a={match:Ze(/\./,Pt(...ql)),relevance:0},o=ql.filter(ve=>typeof ve=="string").concat(["_|0"]),s=ql.filter(ve=>typeof ve!="string").concat(bM).map(Jf),u={variants:[{className:"keyword",match:Pt(...s,...Hl)}]},l={$pattern:Pt(/\b\w+/,/#\w+/),keyword:o.concat(yM),literal:Ap},c=[i,a,u],f={match:Ze(/\./,Pt(...kp)),relevance:0},d={className:"built_in",match:Ze(/\b/,Pt(...kp),/(?=\()/)},h=[f,d],p={match:/->/,relevance:0},m={className:"operator",relevance:0,variants:[{match:jl},{match:`\\.(\\.|${s3})+`}]},g=[p,m],v="([0-9]_*)+",w="([0-9a-fA-F]_*)+",x={className:"number",relevance:0,variants:[{match:`\\b(${v})(\\.(${v}))?([eE][+-]?(${v}))?\\b`},{match:`\\b0x(${w})(\\.(${w}))?([pP][+-]?(${v}))?\\b`},{match:/\b0o([0-7]_*)+\b/},{match:/\b0b([01]_*)+\b/}]},N=(ve="")=>({className:"subst",variants:[{match:Ze(/\\/,ve,/[0\\tnr"']/)},{match:Ze(/\\/,ve,/u\{[0-9a-fA-F]{1,8}\}/)}]}),O=(ve="")=>({className:"subst",match:Ze(/\\/,ve,/[\t ]*(?:[\r\n]|\r\n)/)}),A=(ve="")=>({className:"subst",label:"interpol",begin:Ze(/\\/,ve,/\(/),end:/\)/}),D=(ve="")=>({begin:Ze(ve,/"""/),end:Ze(/"""/,ve),contains:[N(ve),O(ve),A(ve)]}),H=(ve="")=>({begin:Ze(ve,/"/),end:Ze(/"/,ve),contains:[N(ve),A(ve)]}),z={className:"string",variants:[D(),D("#"),D("##"),D("###"),H(),H("#"),H("##"),H("###")]},L={match:Ze(/`/,tn,/`/)},I={className:"variable",match:/\$\d+/},k={className:"variable",match:`\\$${Bs}+`},M=[L,I,k],F={match:/(@|#)available/,className:"keyword",starts:{contains:[{begin:/\(/,end:/\)/,keywords:xM,contains:[...g,x,z]}]}},C={className:"keyword",match:Ze(/@/,Pt(...wM))},U={className:"meta",match:Ze(/@/,tn)},$=[F,C,U],V={match:wi(/\b[A-Z]/),relevance:0,contains:[{className:"type",match:Ze(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/,Bs,"+")},{className:"type",match:Vl,relevance:0},{match:/[?!]+/,relevance:0},{match:/\.\.\./,relevance:0},{match:Ze(/\s+&\s+/,wi(Vl)),relevance:0}]},se={begin:/</,end:/>/,keywords:l,contains:[...n,...c,...$,p,V]};V.contains.push(se);const _={match:Ze(tn,/\s*:/),keywords:"_|0",relevance:0},oe={begin:/\(/,end:/\)/,relevance:0,keywords:l,contains:["self",_,...n,...c,...h,...g,x,z,...M,...$,V]},ne={beginKeywords:"func",contains:[{className:"title",match:Pt(L.match,tn,jl),endsParent:!0,relevance:0},t]},T={begin:/</,end:/>/,contains:[...n,V]},G={begin:Pt(wi(Ze(tn,/\s*:/)),wi(Ze(tn,/\s+/,tn,/\s*:/))),end:/:/,relevance:0,contains:[{className:"keyword",match:/\b_\b/},{className:"params",match:tn}]},ee={begin:/\(/,end:/\)/,keywords:l,contains:[G,...n,...c,...g,x,z,...$,V,oe],endsParent:!0,illegal:/["']/},le={className:"function",match:wi(/\bfunc\b/),contains:[ne,T,ee,t],illegal:[/\[/,/%/]},we={className:"function",match:/\b(subscript|init[?!]?)\s*(?=[<(])/,keywords:{keyword:"subscript init init? init!",$pattern:/\w+[?!]?/},contains:[T,ee,t],illegal:/\[|%/},Oe={beginKeywords:"operator",end:e.MATCH_NOTHING_RE,contains:[{className:"title",match:jl,endsParent:!0,relevance:0}]},qe={beginKeywords:"precedencegroup",end:e.MATCH_NOTHING_RE,contains:[{className:"title",match:Vl,relevance:0},{begin:/{/,end:/}/,relevance:0,endsParent:!0,keywords:[...vM,...Ap],contains:[V]}]};for(const ve of z.variants){const ct=ve.contains.find(_r=>_r.label==="interpol");ct.keywords=l;const ft=[...c,...h,...g,x,z,...M];ct.contains=[...ft,{begin:/\(/,end:/\)/,contains:["self",...ft]}]}return{name:"Swift",keywords:l,contains:[...n,le,we,{className:"class",beginKeywords:"struct protocol class extension enum",end:"\\{",excludeEnd:!0,keywords:l,contains:[e.inherit(e.TITLE_MODE,{begin:/[A-Za-z$_][\u00C0-\u02B80-9A-Za-z$_]*/}),...c]},Oe,qe,{beginKeywords:"import",end:/$/,contains:[...n],relevance:0},...c,...h,...g,x,z,...M,...$,V,oe]}}var SM=EM;const yU=Ce(SM);function TM(e){var t="true false yes no null",r="[\\w#;/?:@&=+$,.~*'()[\\]]+",n={className:"attr",variants:[{begin:"\\w[\\w :\\/.-]*:(?=[ 	]|$)"},{begin:'"\\w[\\w :\\/.-]*":(?=[ 	]|$)'},{begin:"'\\w[\\w :\\/.-]*':(?=[ 	]|$)"}]},i={className:"template-variable",variants:[{begin:/\{\{/,end:/\}\}/},{begin:/%\{/,end:/\}/}]},a={className:"string",relevance:0,variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/\S+/}],contains:[e.BACKSLASH_ESCAPE,i]},o=e.inherit(a,{variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/[^\s,{}[\]]+/}]}),s="[0-9]{4}(-[0-9][0-9]){0,2}",u="([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?",l="(\\.[0-9]*)?",c="([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?",f={className:"number",begin:"\\b"+s+u+l+c+"\\b"},d={end:",",endsWithParent:!0,excludeEnd:!0,keywords:t,relevance:0},h={begin:/\{/,end:/\}/,contains:[d],illegal:"\\n",relevance:0},p={begin:"\\[",end:"\\]",contains:[d],illegal:"\\n",relevance:0},m=[n,{className:"meta",begin:"^---\\s*$",relevance:10},{className:"string",begin:"[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*"},{begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:"!\\w+!"+r},{className:"type",begin:"!<"+r+">"},{className:"type",begin:"!"+r},{className:"type",begin:"!!"+r},{className:"meta",begin:"&"+e.UNDERSCORE_IDENT_RE+"$"},{className:"meta",begin:"\\*"+e.UNDERSCORE_IDENT_RE+"$"},{className:"bullet",begin:"-(?=[ ]|$)",relevance:0},e.HASH_COMMENT_MODE,{beginKeywords:t,keywords:{literal:t}},f,{className:"number",begin:e.C_NUMBER_RE+"\\b",relevance:0},h,p,a],g=[...m];return g.pop(),g.push(o),d.contains=g,{name:"YAML",case_insensitive:!0,aliases:["yml"],contains:m}}var AM=TM;const wU=Ce(AM),zs="[A-Za-z$_][0-9A-Za-z$_]*",l3=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends"],c3=["true","false","null","undefined","NaN","Infinity"],kM=["Intl","DataView","Number","Math","Date","String","RegExp","Object","Function","Boolean","Error","Symbol","Set","Map","WeakSet","WeakMap","Proxy","Reflect","JSON","Promise","Float64Array","Int16Array","Int32Array","Int8Array","Uint16Array","Uint32Array","Float32Array","Array","Uint8Array","Uint8ClampedArray","ArrayBuffer","BigInt64Array","BigUint64Array","BigInt"],OM=["EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],NM=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],_M=["arguments","this","super","console","window","document","localStorage","module","global"],f3=[].concat(NM,_M,kM,OM);function CM(e){return e?typeof e=="string"?e:e.source:null}function Op(e){return dc("(?=",e,")")}function dc(...e){return e.map(r=>CM(r)).join("")}function MM(e){const t=(N,{after:O})=>{const A="</"+N[0].slice(1);return N.input.indexOf(A,O)!==-1},r=zs,n={begin:"<>",end:"</>"},i={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(N,O)=>{const A=N[0].length+N.index,D=N.input[A];if(D==="<"){O.ignoreMatch();return}D===">"&&(t(N,{after:A})||O.ignoreMatch())}},a={$pattern:zs,keyword:l3,literal:c3,built_in:f3},o="[0-9](_?[0-9])*",s=`\\.(${o})`,u="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",l={className:"number",variants:[{begin:`(\\b(${u})((${s})|\\.)?|(${s}))[eE][+-]?(${o})\\b`},{begin:`\\b(${u})\\b((${s})\\b|\\.)?|(${s})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},c={className:"subst",begin:"\\$\\{",end:"\\}",keywords:a,contains:[]},f={begin:"html`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,c],subLanguage:"xml"}},d={begin:"css`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,c],subLanguage:"css"}},h={className:"string",begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE,c]},m={className:"comment",variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+",contains:[{className:"type",begin:"\\{",end:"\\}",relevance:0},{className:"variable",begin:r+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]},g=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,f,d,h,l,e.REGEXP_MODE];c.contains=g.concat({begin:/\{/,end:/\}/,keywords:a,contains:["self"].concat(g)});const v=[].concat(m,c.contains),w=v.concat([{begin:/\(/,end:/\)/,keywords:a,contains:["self"].concat(v)}]),x={className:"params",begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:a,contains:w};return{name:"Javascript",aliases:["js","jsx","mjs","cjs"],keywords:a,exports:{PARAMS_CONTAINS:w},illegal:/#(?![$_A-z])/,contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),{label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,f,d,h,m,l,{begin:dc(/[{,\n]\s*/,Op(dc(/(((\/\/.*$)|(\/\*(\*[^/]|[^*])*\*\/))\s*)*/,r+"\\s*:"))),relevance:0,contains:[{className:"attr",begin:r+Op("\\s*:"),relevance:0}]},{begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",contains:[m,e.REGEXP_MODE,{className:"function",begin:"(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:a,contains:w}]}]},{begin:/,/,relevance:0},{className:"",begin:/\s/,end:/\s*/,skip:!0},{variants:[{begin:n.begin,end:n.end},{begin:i.begin,"on:begin":i.isTrulyOpeningTag,end:i.end}],subLanguage:"xml",contains:[{begin:i.begin,end:i.end,skip:!0,contains:["self"]}]}],relevance:0},{className:"function",beginKeywords:"function",end:/[{;]/,excludeEnd:!0,keywords:a,contains:["self",e.inherit(e.TITLE_MODE,{begin:r}),x],illegal:/%/},{beginKeywords:"while if switch catch for"},{className:"function",begin:e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,contains:[x,e.inherit(e.TITLE_MODE,{begin:r})]},{variants:[{begin:"\\."+r},{begin:"\\$"+r}],relevance:0},{className:"class",beginKeywords:"class",end:/[{;=]/,excludeEnd:!0,illegal:/[:"[\]]/,contains:[{beginKeywords:"extends"},e.UNDERSCORE_TITLE_MODE]},{begin:/\b(?=constructor)/,end:/[{;]/,excludeEnd:!0,contains:[e.inherit(e.TITLE_MODE,{begin:r}),"self",x]},{begin:"(get|set)\\s+(?="+r+"\\()",end:/\{/,keywords:"get set",contains:[e.inherit(e.TITLE_MODE,{begin:r}),{begin:/\(\)/},x]},{begin:/\$[(.]/}]}}function RM(e){const t=zs,r={beginKeywords:"namespace",end:/\{/,excludeEnd:!0},n={beginKeywords:"interface",end:/\{/,excludeEnd:!0,keywords:"interface extends"},i={className:"meta",relevance:10,begin:/^\s*['"]use strict['"]/},a=["any","void","number","boolean","string","object","never","enum"],o=["type","namespace","typedef","interface","public","private","protected","implements","declare","abstract","readonly"],s={$pattern:zs,keyword:l3.concat(o),literal:c3,built_in:f3.concat(a)},u={className:"meta",begin:"@"+t},l=(d,h,p)=>{const m=d.contains.findIndex(g=>g.label===h);if(m===-1)throw new Error("can not find mode to replace");d.contains.splice(m,1,p)},c=MM(e);Object.assign(c.keywords,s),c.exports.PARAMS_CONTAINS.push(u),c.contains=c.contains.concat([u,r,n]),l(c,"shebang",e.SHEBANG()),l(c,"use_strict",i);const f=c.contains.find(d=>d.className==="function");return f.relevance=0,Object.assign(c,{name:"TypeScript",aliases:["ts","tsx"]}),c}var IM=RM;const xU=Ce(IM);function d3(e){return e?typeof e=="string"?e:e.source:null}function Bo(...e){return e.map(r=>d3(r)).join("")}function Gl(...e){return"("+e.map(r=>d3(r)).join("|")+")"}function PM(e){const t={className:"string",begin:/"(""|[^/n])"C\b/},r={className:"string",begin:/"/,end:/"/,illegal:/\n/,contains:[{begin:/""/}]},n=/\d{1,2}\/\d{1,2}\/\d{4}/,i=/\d{4}-\d{1,2}-\d{1,2}/,a=/(\d|1[012])(:\d+){0,2} *(AM|PM)/,o=/\d{1,2}(:\d{1,2}){1,2}/,s={className:"literal",variants:[{begin:Bo(/# */,Gl(i,n),/ *#/)},{begin:Bo(/# */,o,/ *#/)},{begin:Bo(/# */,a,/ *#/)},{begin:Bo(/# */,Gl(i,n),/ +/,Gl(a,o),/ *#/)}]},u={className:"number",relevance:0,variants:[{begin:/\b\d[\d_]*((\.[\d_]+(E[+-]?[\d_]+)?)|(E[+-]?[\d_]+))[RFD@!#]?/},{begin:/\b\d[\d_]*((U?[SIL])|[%&])?/},{begin:/&H[\dA-F_]+((U?[SIL])|[%&])?/},{begin:/&O[0-7_]+((U?[SIL])|[%&])?/},{begin:/&B[01_]+((U?[SIL])|[%&])?/}]},l={className:"label",begin:/^\w+:/},c=e.COMMENT(/'''/,/$/,{contains:[{className:"doctag",begin:/<\/?/,end:/>/}]}),f=e.COMMENT(null,/$/,{variants:[{begin:/'/},{begin:/([\t ]|^)REM(?=\s)/}]});return{name:"Visual Basic .NET",aliases:["vb"],case_insensitive:!0,classNameAliases:{label:"symbol"},keywords:{keyword:"addhandler alias aggregate ansi as async assembly auto binary by byref byval call case catch class compare const continue custom declare default delegate dim distinct do each equals else elseif end enum erase error event exit explicit finally for friend from function get global goto group handles if implements imports in inherits interface into iterator join key let lib loop me mid module mustinherit mustoverride mybase myclass namespace narrowing new next notinheritable notoverridable of off on operator option optional order overloads overridable overrides paramarray partial preserve private property protected public raiseevent readonly redim removehandler resume return select set shadows shared skip static step stop structure strict sub synclock take text then throw to try unicode until using when where while widening with withevents writeonly yield",built_in:"addressof and andalso await directcast gettype getxmlnamespace is isfalse isnot istrue like mod nameof new not or orelse trycast typeof xor cbool cbyte cchar cdate cdbl cdec cint clng cobj csbyte cshort csng cstr cuint culng cushort",type:"boolean byte char date decimal double integer long object sbyte short single string uinteger ulong ushort",literal:"true false nothing"},illegal:"//|\\{|\\}|endif|gosub|variant|wend|^\\$ ",contains:[t,r,s,u,l,c,f,{className:"meta",begin:/[\t ]*#(const|disable|else|elseif|enable|end|externalsource|if|region)\b/,end:/$/,keywords:{"meta-keyword":"const disable else elseif enable end externalsource if region then"},contains:[f]}]}}var DM=PM;const EU=Ce(DM);var h3=gN(di,{});h3.registerLanguage=di.registerLanguage;const SU=h3,TU={hljs:{display:"block",background:"white",padding:"0.5em",color:"#333333",overflowX:"auto"},"hljs-comment":{color:"#969896"},"hljs-meta":{color:"#969896"},"hljs-variable":{color:"#df5000"},"hljs-template-variable":{color:"#df5000"},"hljs-strong":{color:"#df5000"},"hljs-emphasis":{color:"#df5000"},"hljs-quote":{color:"#df5000"},"hljs-keyword":{color:"#d73a49"},"hljs-selector-tag":{color:"#d73a49"},"hljs-type":{color:"#d73a49"},"hljs-literal":{color:"#0086b3"},"hljs-symbol":{color:"#0086b3"},"hljs-bullet":{color:"#0086b3"},"hljs-attribute":{color:"#0086b3"},"hljs-section":{color:"#63a35c"},"hljs-name":{color:"#63a35c"},"hljs-tag":{color:"#333333"},"hljs-title":{color:"#6f42c1"},"hljs-attr":{color:"#6f42c1"},"hljs-selector-id":{color:"#6f42c1"},"hljs-selector-class":{color:"#6f42c1"},"hljs-selector-attr":{color:"#6f42c1"},"hljs-selector-pseudo":{color:"#6f42c1"},"hljs-addition":{color:"#55a532",backgroundColor:"#eaffea"},"hljs-deletion":{color:"#bd2c00",backgroundColor:"#ffecec"},"hljs-link":{textDecoration:"underline"},"hljs-number":{color:"#005cc5"},"hljs-string":{color:"#032f62"}},AU={hljs:{display:"block",overflowX:"auto",padding:"0.5em",background:"#272822",color:"#ddd"},"hljs-tag":{color:"#f92672"},"hljs-keyword":{color:"#f92672",fontWeight:"bold"},"hljs-selector-tag":{color:"#f92672",fontWeight:"bold"},"hljs-literal":{color:"#f92672",fontWeight:"bold"},"hljs-strong":{color:"#f92672"},"hljs-name":{color:"#f92672"},"hljs-code":{color:"#66d9ef"},"hljs-class .hljs-title":{color:"white"},"hljs-attribute":{color:"#bf79db"},"hljs-symbol":{color:"#bf79db"},"hljs-regexp":{color:"#bf79db"},"hljs-link":{color:"#bf79db"},"hljs-string":{color:"#a6e22e"},"hljs-bullet":{color:"#a6e22e"},"hljs-subst":{color:"#a6e22e"},"hljs-title":{color:"#a6e22e",fontWeight:"bold"},"hljs-section":{color:"#a6e22e",fontWeight:"bold"},"hljs-emphasis":{color:"#a6e22e"},"hljs-type":{color:"#a6e22e",fontWeight:"bold"},"hljs-built_in":{color:"#a6e22e"},"hljs-builtin-name":{color:"#a6e22e"},"hljs-selector-attr":{color:"#a6e22e"},"hljs-selector-pseudo":{color:"#a6e22e"},"hljs-addition":{color:"#a6e22e"},"hljs-variable":{color:"#a6e22e"},"hljs-template-tag":{color:"#a6e22e"},"hljs-template-variable":{color:"#a6e22e"},"hljs-comment":{color:"#75715e"},"hljs-quote":{color:"#75715e"},"hljs-deletion":{color:"#75715e"},"hljs-meta":{color:"#75715e"},"hljs-doctag":{fontWeight:"bold"},"hljs-selector-id":{fontWeight:"bold"}};function LM(e,t){let r;try{r=e()}catch{return}return{getItem:i=>{var a;const o=u=>u===null?null:JSON.parse(u,t==null?void 0:t.reviver),s=(a=r.getItem(i))!=null?a:null;return s instanceof Promise?s.then(o):o(s)},setItem:(i,a)=>r.setItem(i,JSON.stringify(a,t==null?void 0:t.replacer)),removeItem:i=>r.removeItem(i)}}const La=e=>t=>{try{const r=e(t);return r instanceof Promise?r:{then(n){return La(n)(r)},catch(n){return this}}}catch(r){return{then(n){return this},catch(n){return La(n)(r)}}}},FM=(e,t)=>(r,n,i)=>{let a={getStorage:()=>localStorage,serialize:JSON.stringify,deserialize:JSON.parse,partialize:g=>g,version:0,merge:(g,v)=>({...v,...g}),...t},o=!1;const s=new Set,u=new Set;let l;try{l=a.getStorage()}catch{}if(!l)return e((...g)=>{console.warn(`[zustand persist middleware] Unable to update item '${a.name}', the given storage is currently unavailable.`),r(...g)},n,i);const c=La(a.serialize),f=()=>{const g=a.partialize({...n()});let v;const w=c({state:g,version:a.version}).then(x=>l.setItem(a.name,x)).catch(x=>{v=x});if(v)throw v;return w},d=i.setState;i.setState=(g,v)=>{d(g,v),f()};const h=e((...g)=>{r(...g),f()},n,i);let p;const m=()=>{var g;if(!l)return;o=!1,s.forEach(w=>w(n()));const v=((g=a.onRehydrateStorage)==null?void 0:g.call(a,n()))||void 0;return La(l.getItem.bind(l))(a.name).then(w=>{if(w)return a.deserialize(w)}).then(w=>{if(w)if(typeof w.version=="number"&&w.version!==a.version){if(a.migrate)return a.migrate(w.state,w.version);console.error("State loaded from storage couldn't be migrated since no migrate function was provided")}else return w.state}).then(w=>{var x;return p=a.merge(w,(x=n())!=null?x:h),r(p,!0),f()}).then(()=>{v==null||v(p,void 0),o=!0,u.forEach(w=>w(p))}).catch(w=>{v==null||v(void 0,w)})};return i.persist={setOptions:g=>{a={...a,...g},g.getStorage&&(l=g.getStorage())},clearStorage:()=>{l==null||l.removeItem(a.name)},getOptions:()=>a,rehydrate:()=>m(),hasHydrated:()=>o,onHydrate:g=>(s.add(g),()=>{s.delete(g)}),onFinishHydration:g=>(u.add(g),()=>{u.delete(g)})},m(),p||h},BM=(e,t)=>(r,n,i)=>{let a={storage:LM(()=>localStorage),partialize:m=>m,version:0,merge:(m,g)=>({...g,...m}),...t},o=!1;const s=new Set,u=new Set;let l=a.storage;if(!l)return e((...m)=>{console.warn(`[zustand persist middleware] Unable to update item '${a.name}', the given storage is currently unavailable.`),r(...m)},n,i);const c=()=>{const m=a.partialize({...n()});return l.setItem(a.name,{state:m,version:a.version})},f=i.setState;i.setState=(m,g)=>{f(m,g),c()};const d=e((...m)=>{r(...m),c()},n,i);let h;const p=()=>{var m,g;if(!l)return;o=!1,s.forEach(w=>{var x;return w((x=n())!=null?x:d)});const v=((g=a.onRehydrateStorage)==null?void 0:g.call(a,(m=n())!=null?m:d))||void 0;return La(l.getItem.bind(l))(a.name).then(w=>{if(w)if(typeof w.version=="number"&&w.version!==a.version){if(a.migrate)return a.migrate(w.state,w.version);console.error("State loaded from storage couldn't be migrated since no migrate function was provided")}else return w.state}).then(w=>{var x;return h=a.merge(w,(x=n())!=null?x:d),r(h,!0),c()}).then(()=>{v==null||v(h,void 0),h=n(),o=!0,u.forEach(w=>w(h))}).catch(w=>{v==null||v(void 0,w)})};return i.persist={setOptions:m=>{a={...a,...m},m.storage&&(l=m.storage)},clearStorage:()=>{l==null||l.removeItem(a.name)},getOptions:()=>a,rehydrate:()=>p(),hasHydrated:()=>o,onHydrate:m=>(s.add(m),()=>{s.delete(m)}),onFinishHydration:m=>(u.add(m),()=>{u.delete(m)})},a.skipHydration||p(),h||d},zM=(e,t)=>"getStorage"in t||"serialize"in t||"deserialize"in t?FM(e,t):BM(e,t),kU=zM,Np=e=>{let t;const r=new Set,n=(u,l)=>{const c=typeof u=="function"?u(t):u;if(!Object.is(c,t)){const f=t;t=l??(typeof c!="object"||c===null)?c:Object.assign({},t,c),r.forEach(d=>d(t,f))}},i=()=>t,s={setState:n,getState:i,subscribe:u=>(r.add(u),()=>r.delete(u)),destroy:()=>{r.clear()}};return t=e(n,i,s),s},$M=e=>e?Np(e):Np;var p3={exports:{}},m3={},g3={exports:{}},b3={};/**
 * @license React
 * use-sync-external-store-shim.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var $i=eu;function UM(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var HM=typeof Object.is=="function"?Object.is:UM,qM=$i.useState,jM=$i.useEffect,VM=$i.useLayoutEffect,GM=$i.useDebugValue;function WM(e,t){var r=t(),n=qM({inst:{value:r,getSnapshot:t}}),i=n[0].inst,a=n[1];return VM(function(){i.value=r,i.getSnapshot=t,Wl(i)&&a({inst:i})},[e,r,t]),jM(function(){return Wl(i)&&a({inst:i}),e(function(){Wl(i)&&a({inst:i})})},[e]),GM(r),r}function Wl(e){var t=e.getSnapshot;e=e.value;try{var r=t();return!HM(e,r)}catch{return!0}}function KM(e,t){return t()}var XM=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?KM:WM;b3.useSyncExternalStore=$i.useSyncExternalStore!==void 0?$i.useSyncExternalStore:XM;g3.exports=b3;var YM=g3.exports;/**
 * @license React
 * use-sync-external-store-shim/with-selector.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var _u=eu,ZM=YM;function QM(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var JM=typeof Object.is=="function"?Object.is:QM,eR=ZM.useSyncExternalStore,tR=_u.useRef,rR=_u.useEffect,nR=_u.useMemo,iR=_u.useDebugValue;m3.useSyncExternalStoreWithSelector=function(e,t,r,n,i){var a=tR(null);if(a.current===null){var o={hasValue:!1,value:null};a.current=o}else o=a.current;a=nR(function(){function u(h){if(!l){if(l=!0,c=h,h=n(h),i!==void 0&&o.hasValue){var p=o.value;if(i(p,h))return f=p}return f=h}if(p=f,JM(c,h))return p;var m=n(h);return i!==void 0&&i(p,m)?p:(c=h,f=m)}var l=!1,c,f,d=r===void 0?null:r;return[function(){return u(t())},d===null?void 0:function(){return u(d())}]},[t,r,n,i]);var s=eR(e,a[0],a[1]);return rR(function(){o.hasValue=!0,o.value=s},[s]),iR(s),s};p3.exports=m3;var aR=p3.exports;const oR=Ce(aR),{useDebugValue:sR}=React,{useSyncExternalStoreWithSelector:uR}=oR;function lR(e,t=e.getState,r){const n=uR(e.subscribe,e.getState,e.getServerState||e.getState,t,r);return sR(n),n}const _p=e=>{const t=typeof e=="function"?$M(e):e,r=(n,i)=>lR(t,n,i);return Object.assign(r,t),r},OU=e=>e?_p(e):_p;/*! js-cookie v3.0.5 | MIT */function zo(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)e[n]=r[n]}return e}var cR={read:function(e){return e[0]==='"'&&(e=e.slice(1,-1)),e.replace(/(%[\dA-F]{2})+/gi,decodeURIComponent)},write:function(e){return encodeURIComponent(e).replace(/%(2[346BF]|3[AC-F]|40|5[BDE]|60|7[BCD])/g,decodeURIComponent)}};function hc(e,t){function r(i,a,o){if(!(typeof document>"u")){o=zo({},t,o),typeof o.expires=="number"&&(o.expires=new Date(Date.now()+o.expires*864e5)),o.expires&&(o.expires=o.expires.toUTCString()),i=encodeURIComponent(i).replace(/%(2[346B]|5E|60|7C)/g,decodeURIComponent).replace(/[()]/g,escape);var s="";for(var u in o)o[u]&&(s+="; "+u,o[u]!==!0&&(s+="="+o[u].split(";")[0]));return document.cookie=i+"="+e.write(a,i)+s}}function n(i){if(!(typeof document>"u"||arguments.length&&!i)){for(var a=document.cookie?document.cookie.split("; "):[],o={},s=0;s<a.length;s++){var u=a[s].split("="),l=u.slice(1).join("=");try{var c=decodeURIComponent(u[0]);if(o[c]=e.read(l,c),i===c)break}catch{}}return i?o[i]:o}}return Object.create({set:r,get:n,remove:function(i,a){r(i,"",zo({},a,{expires:-1}))},withAttributes:function(i){return hc(this.converter,zo({},this.attributes,i))},withConverter:function(i){return hc(zo({},this.converter,i),this.attributes)}},{attributes:{value:Object.freeze(t)},converter:{value:Object.freeze(e)}})}var NU=hc(cR,{path:"/"});async function fR(e,t){const r=e.getReader();let n;for(;!(n=await r.read()).done;)t(n.value)}function dR(e){let t,r,n,i=!1;return function(o){t===void 0?(t=o,r=0,n=-1):t=pR(t,o);const s=t.length;let u=0;for(;r<s;){i&&(t[r]===10&&(u=++r),i=!1);let l=-1;for(;r<s&&l===-1;++r)switch(t[r]){case 58:n===-1&&(n=r-u);break;case 13:i=!0;case 10:l=r;break}if(l===-1)break;e(t.subarray(u,l),n),u=r,n=-1}u===s?t=void 0:u!==0&&(t=t.subarray(u),r-=u)}}function hR(e,t,r){let n=Cp();const i=new TextDecoder;return function(o,s){if(o.length===0)e==null||e(n),n=Cp();else if(s>0){const u=i.decode(o.subarray(0,s)),l=s+(o[s+1]===32?2:1),c=i.decode(o.subarray(l));switch(u){case"data":n.data=n.data?n.data+`
`+c:c;break;case"event":n.event=c;break;case"id":t==null||t(n.id=c);break;case"retry":const f=parseInt(c,10);isNaN(f)||r==null||r(n.retry=f);break}}}}function pR(e,t){const r=new Uint8Array(e.length+t.length);return r.set(e),r.set(t,e.length),r}function Cp(){return{data:"",event:"",id:"",retry:void 0}}var mR=globalThis&&globalThis.__rest||function(e,t){var r={};for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&t.indexOf(n)<0&&(r[n]=e[n]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var i=0,n=Object.getOwnPropertySymbols(e);i<n.length;i++)t.indexOf(n[i])<0&&Object.prototype.propertyIsEnumerable.call(e,n[i])&&(r[n[i]]=e[n[i]]);return r};const pc="text/event-stream",gR=1e3,Mp="last-event-id";function _U(e,t){var{signal:r,headers:n,onopen:i,onmessage:a,onclose:o,onerror:s,openWhenHidden:u,fetch:l}=t,c=mR(t,["signal","headers","onopen","onmessage","onclose","onerror","openWhenHidden","fetch"]);return new Promise((f,d)=>{const h=Object.assign({},n);h.accept||(h.accept=pc);let p;function m(){p.abort(),document.hidden||O()}typeof document<"u"&&!u&&document.addEventListener("visibilitychange",m);let g=gR,v=0;function w(){typeof document<"u"&&!u&&document.removeEventListener("visibilitychange",m),clearTimeout(v),p.abort()}r==null||r.addEventListener("abort",()=>{w(),f()});const x=l??fetch,N=i??bR;async function O(){var A;p=new AbortController;try{const D=await x(e,Object.assign(Object.assign({},c),{headers:h,signal:p.signal}));await N(D),await fR(D.body,dR(hR(a,H=>{H?h[Mp]=H:delete h[Mp]},H=>{g=H}))),o==null||o(),w(),f()}catch(D){if(!p.signal.aborted)try{const H=(A=s==null?void 0:s(D))!==null&&A!==void 0?A:g;clearTimeout(v),v=setTimeout(O,H)}catch(H){w(),d(H)}}}O()})}function bR(e){const t=e.headers.get("content-type");if(!(t!=null&&t.startsWith(pc)))throw new Error(`Expected content-type to be ${pc}, Actual: ${t}`)}function v3(e,t){return function(){return e.apply(t,arguments)}}const{toString:vR}=Object.prototype,{getPrototypeOf:ed}=Object,Cu=(e=>t=>{const r=vR.call(t);return e[r]||(e[r]=r.slice(8,-1).toLowerCase())})(Object.create(null)),Yr=e=>(e=e.toLowerCase(),t=>Cu(t)===e),Mu=e=>t=>typeof t===e,{isArray:ra}=Array,Fa=Mu("undefined");function yR(e){return e!==null&&!Fa(e)&&e.constructor!==null&&!Fa(e.constructor)&&pr(e.constructor.isBuffer)&&e.constructor.isBuffer(e)}const y3=Yr("ArrayBuffer");function wR(e){let t;return typeof ArrayBuffer<"u"&&ArrayBuffer.isView?t=ArrayBuffer.isView(e):t=e&&e.buffer&&y3(e.buffer),t}const xR=Mu("string"),pr=Mu("function"),w3=Mu("number"),Ru=e=>e!==null&&typeof e=="object",ER=e=>e===!0||e===!1,ds=e=>{if(Cu(e)!=="object")return!1;const t=ed(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)},SR=Yr("Date"),TR=Yr("File"),AR=Yr("Blob"),kR=Yr("FileList"),OR=e=>Ru(e)&&pr(e.pipe),NR=e=>{let t;return e&&(typeof FormData=="function"&&e instanceof FormData||pr(e.append)&&((t=Cu(e))==="formdata"||t==="object"&&pr(e.toString)&&e.toString()==="[object FormData]"))},_R=Yr("URLSearchParams"),CR=e=>e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"");function io(e,t,{allOwnKeys:r=!1}={}){if(e===null||typeof e>"u")return;let n,i;if(typeof e!="object"&&(e=[e]),ra(e))for(n=0,i=e.length;n<i;n++)t.call(null,e[n],n,e);else{const a=r?Object.getOwnPropertyNames(e):Object.keys(e),o=a.length;let s;for(n=0;n<o;n++)s=a[n],t.call(null,e[s],s,e)}}function x3(e,t){t=t.toLowerCase();const r=Object.keys(e);let n=r.length,i;for(;n-- >0;)if(i=r[n],t===i.toLowerCase())return i;return null}const E3=(()=>typeof globalThis<"u"?globalThis:typeof self<"u"?self:typeof window<"u"?window:global)(),S3=e=>!Fa(e)&&e!==E3;function mc(){const{caseless:e}=S3(this)&&this||{},t={},r=(n,i)=>{const a=e&&x3(t,i)||i;ds(t[a])&&ds(n)?t[a]=mc(t[a],n):ds(n)?t[a]=mc({},n):ra(n)?t[a]=n.slice():t[a]=n};for(let n=0,i=arguments.length;n<i;n++)arguments[n]&&io(arguments[n],r);return t}const MR=(e,t,r,{allOwnKeys:n}={})=>(io(t,(i,a)=>{r&&pr(i)?e[a]=v3(i,r):e[a]=i},{allOwnKeys:n}),e),RR=e=>(e.charCodeAt(0)===65279&&(e=e.slice(1)),e),IR=(e,t,r,n)=>{e.prototype=Object.create(t.prototype,n),e.prototype.constructor=e,Object.defineProperty(e,"super",{value:t.prototype}),r&&Object.assign(e.prototype,r)},PR=(e,t,r,n)=>{let i,a,o;const s={};if(t=t||{},e==null)return t;do{for(i=Object.getOwnPropertyNames(e),a=i.length;a-- >0;)o=i[a],(!n||n(o,e,t))&&!s[o]&&(t[o]=e[o],s[o]=!0);e=r!==!1&&ed(e)}while(e&&(!r||r(e,t))&&e!==Object.prototype);return t},DR=(e,t,r)=>{e=String(e),(r===void 0||r>e.length)&&(r=e.length),r-=t.length;const n=e.indexOf(t,r);return n!==-1&&n===r},LR=e=>{if(!e)return null;if(ra(e))return e;let t=e.length;if(!w3(t))return null;const r=new Array(t);for(;t-- >0;)r[t]=e[t];return r},FR=(e=>t=>e&&t instanceof e)(typeof Uint8Array<"u"&&ed(Uint8Array)),BR=(e,t)=>{const n=(e&&e[Symbol.iterator]).call(e);let i;for(;(i=n.next())&&!i.done;){const a=i.value;t.call(e,a[0],a[1])}},zR=(e,t)=>{let r;const n=[];for(;(r=e.exec(t))!==null;)n.push(r);return n},$R=Yr("HTMLFormElement"),UR=e=>e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(r,n,i){return n.toUpperCase()+i}),Rp=(({hasOwnProperty:e})=>(t,r)=>e.call(t,r))(Object.prototype),HR=Yr("RegExp"),T3=(e,t)=>{const r=Object.getOwnPropertyDescriptors(e),n={};io(r,(i,a)=>{let o;(o=t(i,a,e))!==!1&&(n[a]=o||i)}),Object.defineProperties(e,n)},qR=e=>{T3(e,(t,r)=>{if(pr(e)&&["arguments","caller","callee"].indexOf(r)!==-1)return!1;const n=e[r];if(pr(n)){if(t.enumerable=!1,"writable"in t){t.writable=!1;return}t.set||(t.set=()=>{throw Error("Can not rewrite read-only method '"+r+"'")})}})},jR=(e,t)=>{const r={},n=i=>{i.forEach(a=>{r[a]=!0})};return ra(e)?n(e):n(String(e).split(t)),r},VR=()=>{},GR=(e,t)=>(e=+e,Number.isFinite(e)?e:t),Kl="abcdefghijklmnopqrstuvwxyz",Ip="0123456789",A3={DIGIT:Ip,ALPHA:Kl,ALPHA_DIGIT:Kl+Kl.toUpperCase()+Ip},WR=(e=16,t=A3.ALPHA_DIGIT)=>{let r="";const{length:n}=t;for(;e--;)r+=t[Math.random()*n|0];return r};function KR(e){return!!(e&&pr(e.append)&&e[Symbol.toStringTag]==="FormData"&&e[Symbol.iterator])}const XR=e=>{const t=new Array(10),r=(n,i)=>{if(Ru(n)){if(t.indexOf(n)>=0)return;if(!("toJSON"in n)){t[i]=n;const a=ra(n)?[]:{};return io(n,(o,s)=>{const u=r(o,i+1);!Fa(u)&&(a[s]=u)}),t[i]=void 0,a}}return n};return r(e,0)},YR=Yr("AsyncFunction"),ZR=e=>e&&(Ru(e)||pr(e))&&pr(e.then)&&pr(e.catch),W={isArray:ra,isArrayBuffer:y3,isBuffer:yR,isFormData:NR,isArrayBufferView:wR,isString:xR,isNumber:w3,isBoolean:ER,isObject:Ru,isPlainObject:ds,isUndefined:Fa,isDate:SR,isFile:TR,isBlob:AR,isRegExp:HR,isFunction:pr,isStream:OR,isURLSearchParams:_R,isTypedArray:FR,isFileList:kR,forEach:io,merge:mc,extend:MR,trim:CR,stripBOM:RR,inherits:IR,toFlatObject:PR,kindOf:Cu,kindOfTest:Yr,endsWith:DR,toArray:LR,forEachEntry:BR,matchAll:zR,isHTMLForm:$R,hasOwnProperty:Rp,hasOwnProp:Rp,reduceDescriptors:T3,freezeMethods:qR,toObjectSet:jR,toCamelCase:UR,noop:VR,toFiniteNumber:GR,findKey:x3,global:E3,isContextDefined:S3,ALPHABET:A3,generateString:WR,isSpecCompliantForm:KR,toJSONObject:XR,isAsyncFn:YR,isThenable:ZR};function ze(e,t,r,n,i){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack,this.message=e,this.name="AxiosError",t&&(this.code=t),r&&(this.config=r),n&&(this.request=n),i&&(this.response=i)}W.inherits(ze,Error,{toJSON:function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:W.toJSONObject(this.config),code:this.code,status:this.response&&this.response.status?this.response.status:null}}});const k3=ze.prototype,O3={};["ERR_BAD_OPTION_VALUE","ERR_BAD_OPTION","ECONNABORTED","ETIMEDOUT","ERR_NETWORK","ERR_FR_TOO_MANY_REDIRECTS","ERR_DEPRECATED","ERR_BAD_RESPONSE","ERR_BAD_REQUEST","ERR_CANCELED","ERR_NOT_SUPPORT","ERR_INVALID_URL"].forEach(e=>{O3[e]={value:e}});Object.defineProperties(ze,O3);Object.defineProperty(k3,"isAxiosError",{value:!0});ze.from=(e,t,r,n,i,a)=>{const o=Object.create(k3);return W.toFlatObject(e,o,function(u){return u!==Error.prototype},s=>s!=="isAxiosError"),ze.call(o,e.message,t,r,n,i),o.cause=e,o.name=e.name,a&&Object.assign(o,a),o};const QR=null;function gc(e){return W.isPlainObject(e)||W.isArray(e)}function N3(e){return W.endsWith(e,"[]")?e.slice(0,-2):e}function Pp(e,t,r){return e?e.concat(t).map(function(i,a){return i=N3(i),!r&&a?"["+i+"]":i}).join(r?".":""):t}function JR(e){return W.isArray(e)&&!e.some(gc)}const eI=W.toFlatObject(W,{},null,function(t){return/^is[A-Z]/.test(t)});function Iu(e,t,r){if(!W.isObject(e))throw new TypeError("target must be an object");t=t||new FormData,r=W.toFlatObject(r,{metaTokens:!0,dots:!1,indexes:!1},!1,function(m,g){return!W.isUndefined(g[m])});const n=r.metaTokens,i=r.visitor||c,a=r.dots,o=r.indexes,u=(r.Blob||typeof Blob<"u"&&Blob)&&W.isSpecCompliantForm(t);if(!W.isFunction(i))throw new TypeError("visitor must be a function");function l(p){if(p===null)return"";if(W.isDate(p))return p.toISOString();if(!u&&W.isBlob(p))throw new ze("Blob is not supported. Use a Buffer instead.");return W.isArrayBuffer(p)||W.isTypedArray(p)?u&&typeof Blob=="function"?new Blob([p]):Buffer.from(p):p}function c(p,m,g){let v=p;if(p&&!g&&typeof p=="object"){if(W.endsWith(m,"{}"))m=n?m:m.slice(0,-2),p=JSON.stringify(p);else if(W.isArray(p)&&JR(p)||(W.isFileList(p)||W.endsWith(m,"[]"))&&(v=W.toArray(p)))return m=N3(m),v.forEach(function(x,N){!(W.isUndefined(x)||x===null)&&t.append(o===!0?Pp([m],N,a):o===null?m:m+"[]",l(x))}),!1}return gc(p)?!0:(t.append(Pp(g,m,a),l(p)),!1)}const f=[],d=Object.assign(eI,{defaultVisitor:c,convertValue:l,isVisitable:gc});function h(p,m){if(!W.isUndefined(p)){if(f.indexOf(p)!==-1)throw Error("Circular reference detected in "+m.join("."));f.push(p),W.forEach(p,function(v,w){(!(W.isUndefined(v)||v===null)&&i.call(t,v,W.isString(w)?w.trim():w,m,d))===!0&&h(v,m?m.concat(w):[w])}),f.pop()}}if(!W.isObject(e))throw new TypeError("data must be an object");return h(e),t}function Dp(e){const t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g,function(n){return t[n]})}function td(e,t){this._pairs=[],e&&Iu(e,this,t)}const _3=td.prototype;_3.append=function(t,r){this._pairs.push([t,r])};_3.toString=function(t){const r=t?function(n){return t.call(this,n,Dp)}:Dp;return this._pairs.map(function(i){return r(i[0])+"="+r(i[1])},"").join("&")};function tI(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}function C3(e,t,r){if(!t)return e;const n=r&&r.encode||tI,i=r&&r.serialize;let a;if(i?a=i(t,r):a=W.isURLSearchParams(t)?t.toString():new td(t,r).toString(n),a){const o=e.indexOf("#");o!==-1&&(e=e.slice(0,o)),e+=(e.indexOf("?")===-1?"?":"&")+a}return e}class rI{constructor(){this.handlers=[]}use(t,r,n){return this.handlers.push({fulfilled:t,rejected:r,synchronous:n?n.synchronous:!1,runWhen:n?n.runWhen:null}),this.handlers.length-1}eject(t){this.handlers[t]&&(this.handlers[t]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(t){W.forEach(this.handlers,function(n){n!==null&&t(n)})}}const Lp=rI,M3={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1},nI=typeof URLSearchParams<"u"?URLSearchParams:td,iI=typeof FormData<"u"?FormData:null,aI=typeof Blob<"u"?Blob:null,oI={isBrowser:!0,classes:{URLSearchParams:nI,FormData:iI,Blob:aI},protocols:["http","https","file","blob","url","data"]},R3=typeof window<"u"&&typeof document<"u",sI=(e=>R3&&["ReactNative","NativeScript","NS"].indexOf(e)<0)(typeof navigator<"u"&&navigator.product),uI=(()=>typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope&&typeof self.importScripts=="function")(),lI=Object.freeze(Object.defineProperty({__proto__:null,hasBrowserEnv:R3,hasStandardBrowserEnv:sI,hasStandardBrowserWebWorkerEnv:uI},Symbol.toStringTag,{value:"Module"})),Hr={...lI,...oI};function cI(e,t){return Iu(e,new Hr.classes.URLSearchParams,Object.assign({visitor:function(r,n,i,a){return Hr.isNode&&W.isBuffer(r)?(this.append(n,r.toString("base64")),!1):a.defaultVisitor.apply(this,arguments)}},t))}function fI(e){return W.matchAll(/\w+|\[(\w*)]/g,e).map(t=>t[0]==="[]"?"":t[1]||t[0])}function dI(e){const t={},r=Object.keys(e);let n;const i=r.length;let a;for(n=0;n<i;n++)a=r[n],t[a]=e[a];return t}function I3(e){function t(r,n,i,a){let o=r[a++];if(o==="__proto__")return!0;const s=Number.isFinite(+o),u=a>=r.length;return o=!o&&W.isArray(i)?i.length:o,u?(W.hasOwnProp(i,o)?i[o]=[i[o],n]:i[o]=n,!s):((!i[o]||!W.isObject(i[o]))&&(i[o]=[]),t(r,n,i[o],a)&&W.isArray(i[o])&&(i[o]=dI(i[o])),!s)}if(W.isFormData(e)&&W.isFunction(e.entries)){const r={};return W.forEachEntry(e,(n,i)=>{t(fI(n),i,r,0)}),r}return null}function hI(e,t,r){if(W.isString(e))try{return(t||JSON.parse)(e),W.trim(e)}catch(n){if(n.name!=="SyntaxError")throw n}return(r||JSON.stringify)(e)}const rd={transitional:M3,adapter:["xhr","http"],transformRequest:[function(t,r){const n=r.getContentType()||"",i=n.indexOf("application/json")>-1,a=W.isObject(t);if(a&&W.isHTMLForm(t)&&(t=new FormData(t)),W.isFormData(t))return i&&i?JSON.stringify(I3(t)):t;if(W.isArrayBuffer(t)||W.isBuffer(t)||W.isStream(t)||W.isFile(t)||W.isBlob(t))return t;if(W.isArrayBufferView(t))return t.buffer;if(W.isURLSearchParams(t))return r.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),t.toString();let s;if(a){if(n.indexOf("application/x-www-form-urlencoded")>-1)return cI(t,this.formSerializer).toString();if((s=W.isFileList(t))||n.indexOf("multipart/form-data")>-1){const u=this.env&&this.env.FormData;return Iu(s?{"files[]":t}:t,u&&new u,this.formSerializer)}}return a||i?(r.setContentType("application/json",!1),hI(t)):t}],transformResponse:[function(t){const r=this.transitional||rd.transitional,n=r&&r.forcedJSONParsing,i=this.responseType==="json";if(t&&W.isString(t)&&(n&&!this.responseType||i)){const o=!(r&&r.silentJSONParsing)&&i;try{return JSON.parse(t)}catch(s){if(o)throw s.name==="SyntaxError"?ze.from(s,ze.ERR_BAD_RESPONSE,this,null,this.response):s}}return t}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:Hr.classes.FormData,Blob:Hr.classes.Blob},validateStatus:function(t){return t>=200&&t<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};W.forEach(["delete","get","head","post","put","patch"],e=>{rd.headers[e]={}});const nd=rd,pI=W.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),mI=e=>{const t={};let r,n,i;return e&&e.split(`
`).forEach(function(o){i=o.indexOf(":"),r=o.substring(0,i).trim().toLowerCase(),n=o.substring(i+1).trim(),!(!r||t[r]&&pI[r])&&(r==="set-cookie"?t[r]?t[r].push(n):t[r]=[n]:t[r]=t[r]?t[r]+", "+n:n)}),t},Fp=Symbol("internals");function oa(e){return e&&String(e).trim().toLowerCase()}function hs(e){return e===!1||e==null?e:W.isArray(e)?e.map(hs):String(e)}function gI(e){const t=Object.create(null),r=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let n;for(;n=r.exec(e);)t[n[1]]=n[2];return t}const bI=e=>/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim());function Xl(e,t,r,n,i){if(W.isFunction(n))return n.call(this,t,r);if(i&&(t=r),!!W.isString(t)){if(W.isString(n))return t.indexOf(n)!==-1;if(W.isRegExp(n))return n.test(t)}}function vI(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(t,r,n)=>r.toUpperCase()+n)}function yI(e,t){const r=W.toCamelCase(" "+t);["get","set","has"].forEach(n=>{Object.defineProperty(e,n+r,{value:function(i,a,o){return this[n].call(this,t,i,a,o)},configurable:!0})})}class Pu{constructor(t){t&&this.set(t)}set(t,r,n){const i=this;function a(s,u,l){const c=oa(u);if(!c)throw new Error("header name must be a non-empty string");const f=W.findKey(i,c);(!f||i[f]===void 0||l===!0||l===void 0&&i[f]!==!1)&&(i[f||u]=hs(s))}const o=(s,u)=>W.forEach(s,(l,c)=>a(l,c,u));return W.isPlainObject(t)||t instanceof this.constructor?o(t,r):W.isString(t)&&(t=t.trim())&&!bI(t)?o(mI(t),r):t!=null&&a(r,t,n),this}get(t,r){if(t=oa(t),t){const n=W.findKey(this,t);if(n){const i=this[n];if(!r)return i;if(r===!0)return gI(i);if(W.isFunction(r))return r.call(this,i,n);if(W.isRegExp(r))return r.exec(i);throw new TypeError("parser must be boolean|regexp|function")}}}has(t,r){if(t=oa(t),t){const n=W.findKey(this,t);return!!(n&&this[n]!==void 0&&(!r||Xl(this,this[n],n,r)))}return!1}delete(t,r){const n=this;let i=!1;function a(o){if(o=oa(o),o){const s=W.findKey(n,o);s&&(!r||Xl(n,n[s],s,r))&&(delete n[s],i=!0)}}return W.isArray(t)?t.forEach(a):a(t),i}clear(t){const r=Object.keys(this);let n=r.length,i=!1;for(;n--;){const a=r[n];(!t||Xl(this,this[a],a,t,!0))&&(delete this[a],i=!0)}return i}normalize(t){const r=this,n={};return W.forEach(this,(i,a)=>{const o=W.findKey(n,a);if(o){r[o]=hs(i),delete r[a];return}const s=t?vI(a):String(a).trim();s!==a&&delete r[a],r[s]=hs(i),n[s]=!0}),this}concat(...t){return this.constructor.concat(this,...t)}toJSON(t){const r=Object.create(null);return W.forEach(this,(n,i)=>{n!=null&&n!==!1&&(r[i]=t&&W.isArray(n)?n.join(", "):n)}),r}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([t,r])=>t+": "+r).join(`
`)}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(t){return t instanceof this?t:new this(t)}static concat(t,...r){const n=new this(t);return r.forEach(i=>n.set(i)),n}static accessor(t){const n=(this[Fp]=this[Fp]={accessors:{}}).accessors,i=this.prototype;function a(o){const s=oa(o);n[s]||(yI(i,o),n[s]=!0)}return W.isArray(t)?t.forEach(a):a(t),this}}Pu.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]);W.reduceDescriptors(Pu.prototype,({value:e},t)=>{let r=t[0].toUpperCase()+t.slice(1);return{get:()=>e,set(n){this[r]=n}}});W.freezeMethods(Pu);const un=Pu;function Yl(e,t){const r=this||nd,n=t||r,i=un.from(n.headers);let a=n.data;return W.forEach(e,function(s){a=s.call(r,a,i.normalize(),t?t.status:void 0)}),i.normalize(),a}function P3(e){return!!(e&&e.__CANCEL__)}function ao(e,t,r){ze.call(this,e??"canceled",ze.ERR_CANCELED,t,r),this.name="CanceledError"}W.inherits(ao,ze,{__CANCEL__:!0});function wI(e,t,r){const n=r.config.validateStatus;!r.status||!n||n(r.status)?e(r):t(new ze("Request failed with status code "+r.status,[ze.ERR_BAD_REQUEST,ze.ERR_BAD_RESPONSE][Math.floor(r.status/100)-4],r.config,r.request,r))}const xI=Hr.hasStandardBrowserEnv?{write(e,t,r,n,i,a){const o=[e+"="+encodeURIComponent(t)];W.isNumber(r)&&o.push("expires="+new Date(r).toGMTString()),W.isString(n)&&o.push("path="+n),W.isString(i)&&o.push("domain="+i),a===!0&&o.push("secure"),document.cookie=o.join("; ")},read(e){const t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove(e){this.write(e,"",Date.now()-864e5)}}:{write(){},read(){return null},remove(){}};function EI(e){return/^([a-z][a-z\d+\-.]*:)?\/\//i.test(e)}function SI(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}function D3(e,t){return e&&!EI(t)?SI(e,t):t}const TI=Hr.hasStandardBrowserEnv?function(){const t=/(msie|trident)/i.test(navigator.userAgent),r=document.createElement("a");let n;function i(a){let o=a;return t&&(r.setAttribute("href",o),o=r.href),r.setAttribute("href",o),{href:r.href,protocol:r.protocol?r.protocol.replace(/:$/,""):"",host:r.host,search:r.search?r.search.replace(/^\?/,""):"",hash:r.hash?r.hash.replace(/^#/,""):"",hostname:r.hostname,port:r.port,pathname:r.pathname.charAt(0)==="/"?r.pathname:"/"+r.pathname}}return n=i(window.location.href),function(o){const s=W.isString(o)?i(o):o;return s.protocol===n.protocol&&s.host===n.host}}():function(){return function(){return!0}}();function AI(e){const t=/^([-+\w]{1,25})(:?\/\/|:)/.exec(e);return t&&t[1]||""}function kI(e,t){e=e||10;const r=new Array(e),n=new Array(e);let i=0,a=0,o;return t=t!==void 0?t:1e3,function(u){const l=Date.now(),c=n[a];o||(o=l),r[i]=u,n[i]=l;let f=a,d=0;for(;f!==i;)d+=r[f++],f=f%e;if(i=(i+1)%e,i===a&&(a=(a+1)%e),l-o<t)return;const h=c&&l-c;return h?Math.round(d*1e3/h):void 0}}function Bp(e,t){let r=0;const n=kI(50,250);return i=>{const a=i.loaded,o=i.lengthComputable?i.total:void 0,s=a-r,u=n(s),l=a<=o;r=a;const c={loaded:a,total:o,progress:o?a/o:void 0,bytes:s,rate:u||void 0,estimated:u&&o&&l?(o-a)/u:void 0,event:i};c[t?"download":"upload"]=!0,e(c)}}const OI=typeof XMLHttpRequest<"u",NI=OI&&function(e){return new Promise(function(r,n){let i=e.data;const a=un.from(e.headers).normalize();let{responseType:o,withXSRFToken:s}=e,u;function l(){e.cancelToken&&e.cancelToken.unsubscribe(u),e.signal&&e.signal.removeEventListener("abort",u)}let c;if(W.isFormData(i)){if(Hr.hasStandardBrowserEnv||Hr.hasStandardBrowserWebWorkerEnv)a.setContentType(!1);else if((c=a.getContentType())!==!1){const[m,...g]=c?c.split(";").map(v=>v.trim()).filter(Boolean):[];a.setContentType([m||"multipart/form-data",...g].join("; "))}}let f=new XMLHttpRequest;if(e.auth){const m=e.auth.username||"",g=e.auth.password?unescape(encodeURIComponent(e.auth.password)):"";a.set("Authorization","Basic "+btoa(m+":"+g))}const d=D3(e.baseURL,e.url);f.open(e.method.toUpperCase(),C3(d,e.params,e.paramsSerializer),!0),f.timeout=e.timeout;function h(){if(!f)return;const m=un.from("getAllResponseHeaders"in f&&f.getAllResponseHeaders()),v={data:!o||o==="text"||o==="json"?f.responseText:f.response,status:f.status,statusText:f.statusText,headers:m,config:e,request:f};wI(function(x){r(x),l()},function(x){n(x),l()},v),f=null}if("onloadend"in f?f.onloadend=h:f.onreadystatechange=function(){!f||f.readyState!==4||f.status===0&&!(f.responseURL&&f.responseURL.indexOf("file:")===0)||setTimeout(h)},f.onabort=function(){f&&(n(new ze("Request aborted",ze.ECONNABORTED,e,f)),f=null)},f.onerror=function(){n(new ze("Network Error",ze.ERR_NETWORK,e,f)),f=null},f.ontimeout=function(){let g=e.timeout?"timeout of "+e.timeout+"ms exceeded":"timeout exceeded";const v=e.transitional||M3;e.timeoutErrorMessage&&(g=e.timeoutErrorMessage),n(new ze(g,v.clarifyTimeoutError?ze.ETIMEDOUT:ze.ECONNABORTED,e,f)),f=null},Hr.hasStandardBrowserEnv&&(s&&W.isFunction(s)&&(s=s(e)),s||s!==!1&&TI(d))){const m=e.xsrfHeaderName&&e.xsrfCookieName&&xI.read(e.xsrfCookieName);m&&a.set(e.xsrfHeaderName,m)}i===void 0&&a.setContentType(null),"setRequestHeader"in f&&W.forEach(a.toJSON(),function(g,v){f.setRequestHeader(v,g)}),W.isUndefined(e.withCredentials)||(f.withCredentials=!!e.withCredentials),o&&o!=="json"&&(f.responseType=e.responseType),typeof e.onDownloadProgress=="function"&&f.addEventListener("progress",Bp(e.onDownloadProgress,!0)),typeof e.onUploadProgress=="function"&&f.upload&&f.upload.addEventListener("progress",Bp(e.onUploadProgress)),(e.cancelToken||e.signal)&&(u=m=>{f&&(n(!m||m.type?new ao(null,e,f):m),f.abort(),f=null)},e.cancelToken&&e.cancelToken.subscribe(u),e.signal&&(e.signal.aborted?u():e.signal.addEventListener("abort",u)));const p=AI(d);if(p&&Hr.protocols.indexOf(p)===-1){n(new ze("Unsupported protocol "+p+":",ze.ERR_BAD_REQUEST,e));return}f.send(i||null)})},bc={http:QR,xhr:NI};W.forEach(bc,(e,t)=>{if(e){try{Object.defineProperty(e,"name",{value:t})}catch{}Object.defineProperty(e,"adapterName",{value:t})}});const zp=e=>`- ${e}`,_I=e=>W.isFunction(e)||e===null||e===!1,L3={getAdapter:e=>{e=W.isArray(e)?e:[e];const{length:t}=e;let r,n;const i={};for(let a=0;a<t;a++){r=e[a];let o;if(n=r,!_I(r)&&(n=bc[(o=String(r)).toLowerCase()],n===void 0))throw new ze(`Unknown adapter '${o}'`);if(n)break;i[o||"#"+a]=n}if(!n){const a=Object.entries(i).map(([s,u])=>`adapter ${s} `+(u===!1?"is not supported by the environment":"is not available in the build"));let o=t?a.length>1?`since :
`+a.map(zp).join(`
`):" "+zp(a[0]):"as no adapter specified";throw new ze("There is no suitable adapter to dispatch the request "+o,"ERR_NOT_SUPPORT")}return n},adapters:bc};function Zl(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new ao(null,e)}function $p(e){return Zl(e),e.headers=un.from(e.headers),e.data=Yl.call(e,e.transformRequest),["post","put","patch"].indexOf(e.method)!==-1&&e.headers.setContentType("application/x-www-form-urlencoded",!1),L3.getAdapter(e.adapter||nd.adapter)(e).then(function(n){return Zl(e),n.data=Yl.call(e,e.transformResponse,n),n.headers=un.from(n.headers),n},function(n){return P3(n)||(Zl(e),n&&n.response&&(n.response.data=Yl.call(e,e.transformResponse,n.response),n.response.headers=un.from(n.response.headers))),Promise.reject(n)})}const Up=e=>e instanceof un?e.toJSON():e;function Ui(e,t){t=t||{};const r={};function n(l,c,f){return W.isPlainObject(l)&&W.isPlainObject(c)?W.merge.call({caseless:f},l,c):W.isPlainObject(c)?W.merge({},c):W.isArray(c)?c.slice():c}function i(l,c,f){if(W.isUndefined(c)){if(!W.isUndefined(l))return n(void 0,l,f)}else return n(l,c,f)}function a(l,c){if(!W.isUndefined(c))return n(void 0,c)}function o(l,c){if(W.isUndefined(c)){if(!W.isUndefined(l))return n(void 0,l)}else return n(void 0,c)}function s(l,c,f){if(f in t)return n(l,c);if(f in e)return n(void 0,l)}const u={url:a,method:a,data:a,baseURL:o,transformRequest:o,transformResponse:o,paramsSerializer:o,timeout:o,timeoutMessage:o,withCredentials:o,withXSRFToken:o,adapter:o,responseType:o,xsrfCookieName:o,xsrfHeaderName:o,onUploadProgress:o,onDownloadProgress:o,decompress:o,maxContentLength:o,maxBodyLength:o,beforeRedirect:o,transport:o,httpAgent:o,httpsAgent:o,cancelToken:o,socketPath:o,responseEncoding:o,validateStatus:s,headers:(l,c)=>i(Up(l),Up(c),!0)};return W.forEach(Object.keys(Object.assign({},e,t)),function(c){const f=u[c]||i,d=f(e[c],t[c],c);W.isUndefined(d)&&f!==s||(r[c]=d)}),r}const F3="1.6.5",id={};["object","boolean","number","function","string","symbol"].forEach((e,t)=>{id[e]=function(n){return typeof n===e||"a"+(t<1?"n ":" ")+e}});const Hp={};id.transitional=function(t,r,n){function i(a,o){return"[Axios v"+F3+"] Transitional option '"+a+"'"+o+(n?". "+n:"")}return(a,o,s)=>{if(t===!1)throw new ze(i(o," has been removed"+(r?" in "+r:"")),ze.ERR_DEPRECATED);return r&&!Hp[o]&&(Hp[o]=!0,console.warn(i(o," has been deprecated since v"+r+" and will be removed in the near future"))),t?t(a,o,s):!0}};function CI(e,t,r){if(typeof e!="object")throw new ze("options must be an object",ze.ERR_BAD_OPTION_VALUE);const n=Object.keys(e);let i=n.length;for(;i-- >0;){const a=n[i],o=t[a];if(o){const s=e[a],u=s===void 0||o(s,a,e);if(u!==!0)throw new ze("option "+a+" must be "+u,ze.ERR_BAD_OPTION_VALUE);continue}if(r!==!0)throw new ze("Unknown option "+a,ze.ERR_BAD_OPTION)}}const vc={assertOptions:CI,validators:id},Sn=vc.validators;class $s{constructor(t){this.defaults=t,this.interceptors={request:new Lp,response:new Lp}}request(t,r){typeof t=="string"?(r=r||{},r.url=t):r=t||{},r=Ui(this.defaults,r);const{transitional:n,paramsSerializer:i,headers:a}=r;n!==void 0&&vc.assertOptions(n,{silentJSONParsing:Sn.transitional(Sn.boolean),forcedJSONParsing:Sn.transitional(Sn.boolean),clarifyTimeoutError:Sn.transitional(Sn.boolean)},!1),i!=null&&(W.isFunction(i)?r.paramsSerializer={serialize:i}:vc.assertOptions(i,{encode:Sn.function,serialize:Sn.function},!0)),r.method=(r.method||this.defaults.method||"get").toLowerCase();let o=a&&W.merge(a.common,a[r.method]);a&&W.forEach(["delete","get","head","post","put","patch","common"],p=>{delete a[p]}),r.headers=un.concat(o,a);const s=[];let u=!0;this.interceptors.request.forEach(function(m){typeof m.runWhen=="function"&&m.runWhen(r)===!1||(u=u&&m.synchronous,s.unshift(m.fulfilled,m.rejected))});const l=[];this.interceptors.response.forEach(function(m){l.push(m.fulfilled,m.rejected)});let c,f=0,d;if(!u){const p=[$p.bind(this),void 0];for(p.unshift.apply(p,s),p.push.apply(p,l),d=p.length,c=Promise.resolve(r);f<d;)c=c.then(p[f++],p[f++]);return c}d=s.length;let h=r;for(f=0;f<d;){const p=s[f++],m=s[f++];try{h=p(h)}catch(g){m.call(this,g);break}}try{c=$p.call(this,h)}catch(p){return Promise.reject(p)}for(f=0,d=l.length;f<d;)c=c.then(l[f++],l[f++]);return c}getUri(t){t=Ui(this.defaults,t);const r=D3(t.baseURL,t.url);return C3(r,t.params,t.paramsSerializer)}}W.forEach(["delete","get","head","options"],function(t){$s.prototype[t]=function(r,n){return this.request(Ui(n||{},{method:t,url:r,data:(n||{}).data}))}});W.forEach(["post","put","patch"],function(t){function r(n){return function(a,o,s){return this.request(Ui(s||{},{method:t,headers:n?{"Content-Type":"multipart/form-data"}:{},url:a,data:o}))}}$s.prototype[t]=r(),$s.prototype[t+"Form"]=r(!0)});const ps=$s;class ad{constructor(t){if(typeof t!="function")throw new TypeError("executor must be a function.");let r;this.promise=new Promise(function(a){r=a});const n=this;this.promise.then(i=>{if(!n._listeners)return;let a=n._listeners.length;for(;a-- >0;)n._listeners[a](i);n._listeners=null}),this.promise.then=i=>{let a;const o=new Promise(s=>{n.subscribe(s),a=s}).then(i);return o.cancel=function(){n.unsubscribe(a)},o},t(function(a,o,s){n.reason||(n.reason=new ao(a,o,s),r(n.reason))})}throwIfRequested(){if(this.reason)throw this.reason}subscribe(t){if(this.reason){t(this.reason);return}this._listeners?this._listeners.push(t):this._listeners=[t]}unsubscribe(t){if(!this._listeners)return;const r=this._listeners.indexOf(t);r!==-1&&this._listeners.splice(r,1)}static source(){let t;return{token:new ad(function(i){t=i}),cancel:t}}}const MI=ad;function RI(e){return function(r){return e.apply(null,r)}}function II(e){return W.isObject(e)&&e.isAxiosError===!0}const yc={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511};Object.entries(yc).forEach(([e,t])=>{yc[t]=e});const PI=yc;function B3(e){const t=new ps(e),r=v3(ps.prototype.request,t);return W.extend(r,ps.prototype,t,{allOwnKeys:!0}),W.extend(r,t,null,{allOwnKeys:!0}),r.create=function(i){return B3(Ui(e,i))},r}const gt=B3(nd);gt.Axios=ps;gt.CanceledError=ao;gt.CancelToken=MI;gt.isCancel=P3;gt.VERSION=F3;gt.toFormData=Iu;gt.AxiosError=ze;gt.Cancel=gt.CanceledError;gt.all=function(t){return Promise.all(t)};gt.spread=RI;gt.isAxiosError=II;gt.mergeConfig=Ui;gt.AxiosHeaders=un;gt.formToJSON=e=>I3(W.isHTMLForm(e)?new FormData(e):e);gt.getAdapter=L3.getAdapter;gt.HttpStatusCode=PI;gt.default=gt;const CU=gt;var DI=function(){if(typeof Symbol!="function"||typeof Object.getOwnPropertySymbols!="function")return!1;if(typeof Symbol.iterator=="symbol")return!0;var t={},r=Symbol("test"),n=Object(r);if(typeof r=="string"||Object.prototype.toString.call(r)!=="[object Symbol]"||Object.prototype.toString.call(n)!=="[object Symbol]")return!1;var i=42;t[r]=i;for(r in t)return!1;if(typeof Object.keys=="function"&&Object.keys(t).length!==0||typeof Object.getOwnPropertyNames=="function"&&Object.getOwnPropertyNames(t).length!==0)return!1;var a=Object.getOwnPropertySymbols(t);if(a.length!==1||a[0]!==r||!Object.prototype.propertyIsEnumerable.call(t,r))return!1;if(typeof Object.getOwnPropertyDescriptor=="function"){var o=Object.getOwnPropertyDescriptor(t,r);if(o.value!==i||o.enumerable!==!0)return!1}return!0},qp=typeof Symbol<"u"&&Symbol,LI=DI,FI=function(){return typeof qp!="function"||typeof Symbol!="function"||typeof qp("foo")!="symbol"||typeof Symbol("bar")!="symbol"?!1:LI()},jp={foo:{}},BI=Object,zI=function(){return{__proto__:jp}.foo===jp.foo&&!({__proto__:null}instanceof BI)},$I="Function.prototype.bind called on incompatible ",UI=Object.prototype.toString,HI=Math.max,qI="[object Function]",Vp=function(t,r){for(var n=[],i=0;i<t.length;i+=1)n[i]=t[i];for(var a=0;a<r.length;a+=1)n[a+t.length]=r[a];return n},jI=function(t,r){for(var n=[],i=r||0,a=0;i<t.length;i+=1,a+=1)n[a]=t[i];return n},VI=function(e,t){for(var r="",n=0;n<e.length;n+=1)r+=e[n],n+1<e.length&&(r+=t);return r},GI=function(t){var r=this;if(typeof r!="function"||UI.apply(r)!==qI)throw new TypeError($I+r);for(var n=jI(arguments,1),i,a=function(){if(this instanceof i){var c=r.apply(this,Vp(n,arguments));return Object(c)===c?c:this}return r.apply(t,Vp(n,arguments))},o=HI(0,r.length-n.length),s=[],u=0;u<o;u++)s[u]="$"+u;if(i=Function("binder","return function ("+VI(s,",")+"){ return binder.apply(this,arguments); }")(a),r.prototype){var l=function(){};l.prototype=r.prototype,i.prototype=new l,l.prototype=null}return i},WI=GI,od=Function.prototype.bind||WI,KI=Function.prototype.call,XI=Object.prototype.hasOwnProperty,YI=od,ZI=YI.call(KI,XI),De,Hi=SyntaxError,z3=Function,Fi=TypeError,Ql=function(e){try{return z3('"use strict"; return ('+e+").constructor;")()}catch{}},ii=Object.getOwnPropertyDescriptor;if(ii)try{ii({},"")}catch{ii=null}var Jl=function(){throw new Fi},QI=ii?function(){try{return arguments.callee,Jl}catch{try{return ii(arguments,"callee").get}catch{return Jl}}}():Jl,xi=FI(),JI=zI(),Et=Object.getPrototypeOf||(JI?function(e){return e.__proto__}:null),Oi={},eP=typeof Uint8Array>"u"||!Et?De:Et(Uint8Array),ai={"%AggregateError%":typeof AggregateError>"u"?De:AggregateError,"%Array%":Array,"%ArrayBuffer%":typeof ArrayBuffer>"u"?De:ArrayBuffer,"%ArrayIteratorPrototype%":xi&&Et?Et([][Symbol.iterator]()):De,"%AsyncFromSyncIteratorPrototype%":De,"%AsyncFunction%":Oi,"%AsyncGenerator%":Oi,"%AsyncGeneratorFunction%":Oi,"%AsyncIteratorPrototype%":Oi,"%Atomics%":typeof Atomics>"u"?De:Atomics,"%BigInt%":typeof BigInt>"u"?De:BigInt,"%BigInt64Array%":typeof BigInt64Array>"u"?De:BigInt64Array,"%BigUint64Array%":typeof BigUint64Array>"u"?De:BigUint64Array,"%Boolean%":Boolean,"%DataView%":typeof DataView>"u"?De:DataView,"%Date%":Date,"%decodeURI%":decodeURI,"%decodeURIComponent%":decodeURIComponent,"%encodeURI%":encodeURI,"%encodeURIComponent%":encodeURIComponent,"%Error%":Error,"%eval%":eval,"%EvalError%":EvalError,"%Float32Array%":typeof Float32Array>"u"?De:Float32Array,"%Float64Array%":typeof Float64Array>"u"?De:Float64Array,"%FinalizationRegistry%":typeof FinalizationRegistry>"u"?De:FinalizationRegistry,"%Function%":z3,"%GeneratorFunction%":Oi,"%Int8Array%":typeof Int8Array>"u"?De:Int8Array,"%Int16Array%":typeof Int16Array>"u"?De:Int16Array,"%Int32Array%":typeof Int32Array>"u"?De:Int32Array,"%isFinite%":isFinite,"%isNaN%":isNaN,"%IteratorPrototype%":xi&&Et?Et(Et([][Symbol.iterator]())):De,"%JSON%":typeof JSON=="object"?JSON:De,"%Map%":typeof Map>"u"?De:Map,"%MapIteratorPrototype%":typeof Map>"u"||!xi||!Et?De:Et(new Map()[Symbol.iterator]()),"%Math%":Math,"%Number%":Number,"%Object%":Object,"%parseFloat%":parseFloat,"%parseInt%":parseInt,"%Promise%":typeof Promise>"u"?De:Promise,"%Proxy%":typeof Proxy>"u"?De:Proxy,"%RangeError%":RangeError,"%ReferenceError%":ReferenceError,"%Reflect%":typeof Reflect>"u"?De:Reflect,"%RegExp%":RegExp,"%Set%":typeof Set>"u"?De:Set,"%SetIteratorPrototype%":typeof Set>"u"||!xi||!Et?De:Et(new Set()[Symbol.iterator]()),"%SharedArrayBuffer%":typeof SharedArrayBuffer>"u"?De:SharedArrayBuffer,"%String%":String,"%StringIteratorPrototype%":xi&&Et?Et(""[Symbol.iterator]()):De,"%Symbol%":xi?Symbol:De,"%SyntaxError%":Hi,"%ThrowTypeError%":QI,"%TypedArray%":eP,"%TypeError%":Fi,"%Uint8Array%":typeof Uint8Array>"u"?De:Uint8Array,"%Uint8ClampedArray%":typeof Uint8ClampedArray>"u"?De:Uint8ClampedArray,"%Uint16Array%":typeof Uint16Array>"u"?De:Uint16Array,"%Uint32Array%":typeof Uint32Array>"u"?De:Uint32Array,"%URIError%":URIError,"%WeakMap%":typeof WeakMap>"u"?De:WeakMap,"%WeakRef%":typeof WeakRef>"u"?De:WeakRef,"%WeakSet%":typeof WeakSet>"u"?De:WeakSet};if(Et)try{null.error}catch(e){var tP=Et(Et(e));ai["%Error.prototype%"]=tP}var rP=function e(t){var r;if(t==="%AsyncFunction%")r=Ql("async function () {}");else if(t==="%GeneratorFunction%")r=Ql("function* () {}");else if(t==="%AsyncGeneratorFunction%")r=Ql("async function* () {}");else if(t==="%AsyncGenerator%"){var n=e("%AsyncGeneratorFunction%");n&&(r=n.prototype)}else if(t==="%AsyncIteratorPrototype%"){var i=e("%AsyncGenerator%");i&&Et&&(r=Et(i.prototype))}return ai[t]=r,r},Gp={"%ArrayBufferPrototype%":["ArrayBuffer","prototype"],"%ArrayPrototype%":["Array","prototype"],"%ArrayProto_entries%":["Array","prototype","entries"],"%ArrayProto_forEach%":["Array","prototype","forEach"],"%ArrayProto_keys%":["Array","prototype","keys"],"%ArrayProto_values%":["Array","prototype","values"],"%AsyncFunctionPrototype%":["AsyncFunction","prototype"],"%AsyncGenerator%":["AsyncGeneratorFunction","prototype"],"%AsyncGeneratorPrototype%":["AsyncGeneratorFunction","prototype","prototype"],"%BooleanPrototype%":["Boolean","prototype"],"%DataViewPrototype%":["DataView","prototype"],"%DatePrototype%":["Date","prototype"],"%ErrorPrototype%":["Error","prototype"],"%EvalErrorPrototype%":["EvalError","prototype"],"%Float32ArrayPrototype%":["Float32Array","prototype"],"%Float64ArrayPrototype%":["Float64Array","prototype"],"%FunctionPrototype%":["Function","prototype"],"%Generator%":["GeneratorFunction","prototype"],"%GeneratorPrototype%":["GeneratorFunction","prototype","prototype"],"%Int8ArrayPrototype%":["Int8Array","prototype"],"%Int16ArrayPrototype%":["Int16Array","prototype"],"%Int32ArrayPrototype%":["Int32Array","prototype"],"%JSONParse%":["JSON","parse"],"%JSONStringify%":["JSON","stringify"],"%MapPrototype%":["Map","prototype"],"%NumberPrototype%":["Number","prototype"],"%ObjectPrototype%":["Object","prototype"],"%ObjProto_toString%":["Object","prototype","toString"],"%ObjProto_valueOf%":["Object","prototype","valueOf"],"%PromisePrototype%":["Promise","prototype"],"%PromiseProto_then%":["Promise","prototype","then"],"%Promise_all%":["Promise","all"],"%Promise_reject%":["Promise","reject"],"%Promise_resolve%":["Promise","resolve"],"%RangeErrorPrototype%":["RangeError","prototype"],"%ReferenceErrorPrototype%":["ReferenceError","prototype"],"%RegExpPrototype%":["RegExp","prototype"],"%SetPrototype%":["Set","prototype"],"%SharedArrayBufferPrototype%":["SharedArrayBuffer","prototype"],"%StringPrototype%":["String","prototype"],"%SymbolPrototype%":["Symbol","prototype"],"%SyntaxErrorPrototype%":["SyntaxError","prototype"],"%TypedArrayPrototype%":["TypedArray","prototype"],"%TypeErrorPrototype%":["TypeError","prototype"],"%Uint8ArrayPrototype%":["Uint8Array","prototype"],"%Uint8ClampedArrayPrototype%":["Uint8ClampedArray","prototype"],"%Uint16ArrayPrototype%":["Uint16Array","prototype"],"%Uint32ArrayPrototype%":["Uint32Array","prototype"],"%URIErrorPrototype%":["URIError","prototype"],"%WeakMapPrototype%":["WeakMap","prototype"],"%WeakSetPrototype%":["WeakSet","prototype"]},oo=od,Us=ZI,nP=oo.call(Function.call,Array.prototype.concat),iP=oo.call(Function.apply,Array.prototype.splice),Wp=oo.call(Function.call,String.prototype.replace),Hs=oo.call(Function.call,String.prototype.slice),aP=oo.call(Function.call,RegExp.prototype.exec),oP=/[^%.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|%$))/g,sP=/\\(\\)?/g,uP=function(t){var r=Hs(t,0,1),n=Hs(t,-1);if(r==="%"&&n!=="%")throw new Hi("invalid intrinsic syntax, expected closing `%`");if(n==="%"&&r!=="%")throw new Hi("invalid intrinsic syntax, expected opening `%`");var i=[];return Wp(t,oP,function(a,o,s,u){i[i.length]=s?Wp(u,sP,"$1"):o||a}),i},lP=function(t,r){var n=t,i;if(Us(Gp,n)&&(i=Gp[n],n="%"+i[0]+"%"),Us(ai,n)){var a=ai[n];if(a===Oi&&(a=rP(n)),typeof a>"u"&&!r)throw new Fi("intrinsic "+t+" exists, but is not available. Please file an issue!");return{alias:i,name:n,value:a}}throw new Hi("intrinsic "+t+" does not exist!")},hi=function(t,r){if(typeof t!="string"||t.length===0)throw new Fi("intrinsic name must be a non-empty string");if(arguments.length>1&&typeof r!="boolean")throw new Fi('"allowMissing" argument must be a boolean');if(aP(/^%?[^%]*%?$/,t)===null)throw new Hi("`%` may not be present anywhere but at the beginning and end of the intrinsic name");var n=uP(t),i=n.length>0?n[0]:"",a=lP("%"+i+"%",r),o=a.name,s=a.value,u=!1,l=a.alias;l&&(i=l[0],iP(n,nP([0,1],l)));for(var c=1,f=!0;c<n.length;c+=1){var d=n[c],h=Hs(d,0,1),p=Hs(d,-1);if((h==='"'||h==="'"||h==="`"||p==='"'||p==="'"||p==="`")&&h!==p)throw new Hi("property names with quotes must have matching quotes");if((d==="constructor"||!f)&&(u=!0),i+="."+d,o="%"+i+"%",Us(ai,o))s=ai[o];else if(s!=null){if(!(d in s)){if(!r)throw new Fi("base intrinsic for "+t+" exists, but the property is not available.");return}if(ii&&c+1>=n.length){var m=ii(s,d);f=!!m,f&&"get"in m&&!("originalValue"in m.get)?s=m.get:s=s[d]}else f=Us(s,d),s=s[d];f&&!u&&(ai[o]=s)}}return s},$3={exports:{}},cP=hi,wc=cP("%Object.defineProperty%",!0),xc=function(){if(wc)try{return wc({},"a",{value:1}),!0}catch{return!1}return!1};xc.hasArrayLengthDefineBug=function(){if(!xc())return null;try{return wc([],"length",{value:1}).length!==1}catch{return!0}};var U3=xc,fP=hi,ms=fP("%Object.getOwnPropertyDescriptor%",!0);if(ms)try{ms([],"length")}catch{ms=null}var H3=ms,dP=U3(),sd=hi,xa=dP&&sd("%Object.defineProperty%",!0);if(xa)try{xa({},"a",{value:1})}catch{xa=!1}var hP=sd("%SyntaxError%"),Ei=sd("%TypeError%"),Kp=H3,pP=function(t,r,n){if(!t||typeof t!="object"&&typeof t!="function")throw new Ei("`obj` must be an object or a function`");if(typeof r!="string"&&typeof r!="symbol")throw new Ei("`property` must be a string or a symbol`");if(arguments.length>3&&typeof arguments[3]!="boolean"&&arguments[3]!==null)throw new Ei("`nonEnumerable`, if provided, must be a boolean or null");if(arguments.length>4&&typeof arguments[4]!="boolean"&&arguments[4]!==null)throw new Ei("`nonWritable`, if provided, must be a boolean or null");if(arguments.length>5&&typeof arguments[5]!="boolean"&&arguments[5]!==null)throw new Ei("`nonConfigurable`, if provided, must be a boolean or null");if(arguments.length>6&&typeof arguments[6]!="boolean")throw new Ei("`loose`, if provided, must be a boolean");var i=arguments.length>3?arguments[3]:null,a=arguments.length>4?arguments[4]:null,o=arguments.length>5?arguments[5]:null,s=arguments.length>6?arguments[6]:!1,u=!!Kp&&Kp(t,r);if(xa)xa(t,r,{configurable:o===null&&u?u.configurable:!o,enumerable:i===null&&u?u.enumerable:!i,value:n,writable:a===null&&u?u.writable:!a});else if(s||!i&&!a&&!o)t[r]=n;else throw new hP("This environment does not support defining a property as non-configurable, non-writable, or non-enumerable.")},q3=hi,Xp=pP,mP=U3(),Yp=H3,Zp=q3("%TypeError%"),gP=q3("%Math.floor%"),bP=function(t,r){if(typeof t!="function")throw new Zp("`fn` is not a function");if(typeof r!="number"||r<0||r>4294967295||gP(r)!==r)throw new Zp("`length` must be a positive 32-bit integer");var n=arguments.length>2&&!!arguments[2],i=!0,a=!0;if("length"in t&&Yp){var o=Yp(t,"length");o&&!o.configurable&&(i=!1),o&&!o.writable&&(a=!1)}return(i||a||!n)&&(mP?Xp(t,"length",r,!0,!0):Xp(t,"length",r)),t};(function(e){var t=od,r=hi,n=bP,i=r("%TypeError%"),a=r("%Function.prototype.apply%"),o=r("%Function.prototype.call%"),s=r("%Reflect.apply%",!0)||t.call(o,a),u=r("%Object.defineProperty%",!0),l=r("%Math.max%");if(u)try{u({},"a",{value:1})}catch{u=null}e.exports=function(d){if(typeof d!="function")throw new i("a function is required");var h=s(t,o,arguments);return n(h,1+l(0,d.length-(arguments.length-1)),!0)};var c=function(){return s(t,a,arguments)};u?u(e.exports,"apply",{value:c}):e.exports.apply=c})($3);var vP=$3.exports,j3=hi,V3=vP,yP=V3(j3("String.prototype.indexOf")),wP=function(t,r){var n=j3(t,!!r);return typeof n=="function"&&yP(t,".prototype.")>-1?V3(n):n};const xP={},EP=Object.freeze(Object.defineProperty({__proto__:null,default:xP},Symbol.toStringTag,{value:"Module"})),xr=Wy(EP);var ud=typeof Map=="function"&&Map.prototype,e0=Object.getOwnPropertyDescriptor&&ud?Object.getOwnPropertyDescriptor(Map.prototype,"size"):null,qs=ud&&e0&&typeof e0.get=="function"?e0.get:null,Qp=ud&&Map.prototype.forEach,ld=typeof Set=="function"&&Set.prototype,t0=Object.getOwnPropertyDescriptor&&ld?Object.getOwnPropertyDescriptor(Set.prototype,"size"):null,js=ld&&t0&&typeof t0.get=="function"?t0.get:null,Jp=ld&&Set.prototype.forEach,SP=typeof WeakMap=="function"&&WeakMap.prototype,Ea=SP?WeakMap.prototype.has:null,TP=typeof WeakSet=="function"&&WeakSet.prototype,Sa=TP?WeakSet.prototype.has:null,AP=typeof WeakRef=="function"&&WeakRef.prototype,em=AP?WeakRef.prototype.deref:null,kP=Boolean.prototype.valueOf,OP=Object.prototype.toString,NP=Function.prototype.toString,_P=String.prototype.match,cd=String.prototype.slice,Cn=String.prototype.replace,CP=String.prototype.toUpperCase,tm=String.prototype.toLowerCase,G3=RegExp.prototype.test,rm=Array.prototype.concat,Fr=Array.prototype.join,MP=Array.prototype.slice,nm=Math.floor,Ec=typeof BigInt=="function"?BigInt.prototype.valueOf:null,r0=Object.getOwnPropertySymbols,Sc=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?Symbol.prototype.toString:null,qi=typeof Symbol=="function"&&typeof Symbol.iterator=="object",Ct=typeof Symbol=="function"&&Symbol.toStringTag&&(typeof Symbol.toStringTag===qi||"symbol")?Symbol.toStringTag:null,W3=Object.prototype.propertyIsEnumerable,im=(typeof Reflect=="function"?Reflect.getPrototypeOf:Object.getPrototypeOf)||([].__proto__===Array.prototype?function(e){return e.__proto__}:null);function am(e,t){if(e===1/0||e===-1/0||e!==e||e&&e>-1e3&&e<1e3||G3.call(/e/,t))return t;var r=/[0-9](?=(?:[0-9]{3})+(?![0-9]))/g;if(typeof e=="number"){var n=e<0?-nm(-e):nm(e);if(n!==e){var i=String(n),a=cd.call(t,i.length+1);return Cn.call(i,r,"$&_")+"."+Cn.call(Cn.call(a,/([0-9]{3})/g,"$&_"),/_$/,"")}}return Cn.call(t,r,"$&_")}var Tc=xr,om=Tc.custom,sm=X3(om)?om:null,RP=function e(t,r,n,i){var a=r||{};if(An(a,"quoteStyle")&&a.quoteStyle!=="single"&&a.quoteStyle!=="double")throw new TypeError('option "quoteStyle" must be "single" or "double"');if(An(a,"maxStringLength")&&(typeof a.maxStringLength=="number"?a.maxStringLength<0&&a.maxStringLength!==1/0:a.maxStringLength!==null))throw new TypeError('option "maxStringLength", if provided, must be a positive integer, Infinity, or `null`');var o=An(a,"customInspect")?a.customInspect:!0;if(typeof o!="boolean"&&o!=="symbol")throw new TypeError("option \"customInspect\", if provided, must be `true`, `false`, or `'symbol'`");if(An(a,"indent")&&a.indent!==null&&a.indent!=="	"&&!(parseInt(a.indent,10)===a.indent&&a.indent>0))throw new TypeError('option "indent" must be "\\t", an integer > 0, or `null`');if(An(a,"numericSeparator")&&typeof a.numericSeparator!="boolean")throw new TypeError('option "numericSeparator", if provided, must be `true` or `false`');var s=a.numericSeparator;if(typeof t>"u")return"undefined";if(t===null)return"null";if(typeof t=="boolean")return t?"true":"false";if(typeof t=="string")return Z3(t,a);if(typeof t=="number"){if(t===0)return 1/0/t>0?"0":"-0";var u=String(t);return s?am(t,u):u}if(typeof t=="bigint"){var l=String(t)+"n";return s?am(t,l):l}var c=typeof a.depth>"u"?5:a.depth;if(typeof n>"u"&&(n=0),n>=c&&c>0&&typeof t=="object")return Ac(t)?"[Array]":"[Object]";var f=YP(a,n);if(typeof i>"u")i=[];else if(Y3(i,t)>=0)return"[Circular]";function d(M,F,C){if(F&&(i=MP.call(i),i.push(F)),C){var U={depth:a.depth};return An(a,"quoteStyle")&&(U.quoteStyle=a.quoteStyle),e(M,U,n+1,i)}return e(M,a,n+1,i)}if(typeof t=="function"&&!um(t)){var h=UP(t),p=$o(t,d);return"[Function"+(h?": "+h:" (anonymous)")+"]"+(p.length>0?" { "+Fr.call(p,", ")+" }":"")}if(X3(t)){var m=qi?Cn.call(String(t),/^(Symbol\(.*\))_[^)]*$/,"$1"):Sc.call(t);return typeof t=="object"&&!qi?sa(m):m}if(WP(t)){for(var g="<"+tm.call(String(t.nodeName)),v=t.attributes||[],w=0;w<v.length;w++)g+=" "+v[w].name+"="+K3(IP(v[w].value),"double",a);return g+=">",t.childNodes&&t.childNodes.length&&(g+="..."),g+="</"+tm.call(String(t.nodeName))+">",g}if(Ac(t)){if(t.length===0)return"[]";var x=$o(t,d);return f&&!XP(x)?"["+kc(x,f)+"]":"[ "+Fr.call(x,", ")+" ]"}if(DP(t)){var N=$o(t,d);return!("cause"in Error.prototype)&&"cause"in t&&!W3.call(t,"cause")?"{ ["+String(t)+"] "+Fr.call(rm.call("[cause]: "+d(t.cause),N),", ")+" }":N.length===0?"["+String(t)+"]":"{ ["+String(t)+"] "+Fr.call(N,", ")+" }"}if(typeof t=="object"&&o){if(sm&&typeof t[sm]=="function"&&Tc)return Tc(t,{depth:c-n});if(o!=="symbol"&&typeof t.inspect=="function")return t.inspect()}if(HP(t)){var O=[];return Qp&&Qp.call(t,function(M,F){O.push(d(F,t,!0)+" => "+d(M,t))}),lm("Map",qs.call(t),O,f)}if(VP(t)){var A=[];return Jp&&Jp.call(t,function(M){A.push(d(M,t))}),lm("Set",js.call(t),A,f)}if(qP(t))return n0("WeakMap");if(GP(t))return n0("WeakSet");if(jP(t))return n0("WeakRef");if(FP(t))return sa(d(Number(t)));if(zP(t))return sa(d(Ec.call(t)));if(BP(t))return sa(kP.call(t));if(LP(t))return sa(d(String(t)));if(typeof window<"u"&&t===window)return"{ [object Window] }";if(t===xe)return"{ [object globalThis] }";if(!PP(t)&&!um(t)){var D=$o(t,d),H=im?im(t)===Object.prototype:t instanceof Object||t.constructor===Object,z=t instanceof Object?"":"null prototype",L=!H&&Ct&&Object(t)===t&&Ct in t?cd.call(Un(t),8,-1):z?"Object":"",I=H||typeof t.constructor!="function"?"":t.constructor.name?t.constructor.name+" ":"",k=I+(L||z?"["+Fr.call(rm.call([],L||[],z||[]),": ")+"] ":"");return D.length===0?k+"{}":f?k+"{"+kc(D,f)+"}":k+"{ "+Fr.call(D,", ")+" }"}return String(t)};function K3(e,t,r){var n=(r.quoteStyle||t)==="double"?'"':"'";return n+e+n}function IP(e){return Cn.call(String(e),/"/g,"&quot;")}function Ac(e){return Un(e)==="[object Array]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function PP(e){return Un(e)==="[object Date]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function um(e){return Un(e)==="[object RegExp]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function DP(e){return Un(e)==="[object Error]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function LP(e){return Un(e)==="[object String]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function FP(e){return Un(e)==="[object Number]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function BP(e){return Un(e)==="[object Boolean]"&&(!Ct||!(typeof e=="object"&&Ct in e))}function X3(e){if(qi)return e&&typeof e=="object"&&e instanceof Symbol;if(typeof e=="symbol")return!0;if(!e||typeof e!="object"||!Sc)return!1;try{return Sc.call(e),!0}catch{}return!1}function zP(e){if(!e||typeof e!="object"||!Ec)return!1;try{return Ec.call(e),!0}catch{}return!1}var $P=Object.prototype.hasOwnProperty||function(e){return e in this};function An(e,t){return $P.call(e,t)}function Un(e){return OP.call(e)}function UP(e){if(e.name)return e.name;var t=_P.call(NP.call(e),/^function\s*([\w$]+)/);return t?t[1]:null}function Y3(e,t){if(e.indexOf)return e.indexOf(t);for(var r=0,n=e.length;r<n;r++)if(e[r]===t)return r;return-1}function HP(e){if(!qs||!e||typeof e!="object")return!1;try{qs.call(e);try{js.call(e)}catch{return!0}return e instanceof Map}catch{}return!1}function qP(e){if(!Ea||!e||typeof e!="object")return!1;try{Ea.call(e,Ea);try{Sa.call(e,Sa)}catch{return!0}return e instanceof WeakMap}catch{}return!1}function jP(e){if(!em||!e||typeof e!="object")return!1;try{return em.call(e),!0}catch{}return!1}function VP(e){if(!js||!e||typeof e!="object")return!1;try{js.call(e);try{qs.call(e)}catch{return!0}return e instanceof Set}catch{}return!1}function GP(e){if(!Sa||!e||typeof e!="object")return!1;try{Sa.call(e,Sa);try{Ea.call(e,Ea)}catch{return!0}return e instanceof WeakSet}catch{}return!1}function WP(e){return!e||typeof e!="object"?!1:typeof HTMLElement<"u"&&e instanceof HTMLElement?!0:typeof e.nodeName=="string"&&typeof e.getAttribute=="function"}function Z3(e,t){if(e.length>t.maxStringLength){var r=e.length-t.maxStringLength,n="... "+r+" more character"+(r>1?"s":"");return Z3(cd.call(e,0,t.maxStringLength),t)+n}var i=Cn.call(Cn.call(e,/(['\\])/g,"\\$1"),/[\x00-\x1f]/g,KP);return K3(i,"single",t)}function KP(e){var t=e.charCodeAt(0),r={8:"b",9:"t",10:"n",12:"f",13:"r"}[t];return r?"\\"+r:"\\x"+(t<16?"0":"")+CP.call(t.toString(16))}function sa(e){return"Object("+e+")"}function n0(e){return e+" { ? }"}function lm(e,t,r,n){var i=n?kc(r,n):Fr.call(r,", ");return e+" ("+t+") {"+i+"}"}function XP(e){for(var t=0;t<e.length;t++)if(Y3(e[t],`
`)>=0)return!1;return!0}function YP(e,t){var r;if(e.indent==="	")r="	";else if(typeof e.indent=="number"&&e.indent>0)r=Fr.call(Array(e.indent+1)," ");else return null;return{base:r,prev:Fr.call(Array(t+1),r)}}function kc(e,t){if(e.length===0)return"";var r=`
`+t.prev+t.base;return r+Fr.call(e,","+r)+`
`+t.prev}function $o(e,t){var r=Ac(e),n=[];if(r){n.length=e.length;for(var i=0;i<e.length;i++)n[i]=An(e,i)?t(e[i],e):""}var a=typeof r0=="function"?r0(e):[],o;if(qi){o={};for(var s=0;s<a.length;s++)o["$"+a[s]]=a[s]}for(var u in e)An(e,u)&&(r&&String(Number(u))===u&&u<e.length||qi&&o["$"+u]instanceof Symbol||(G3.call(/[^\w$]/,u)?n.push(t(u,e)+": "+t(e[u],e)):n.push(u+": "+t(e[u],e))));if(typeof r0=="function")for(var l=0;l<a.length;l++)W3.call(e,a[l])&&n.push("["+t(a[l])+"]: "+t(e[a[l]],e));return n}var fd=hi,na=wP,ZP=RP,QP=fd("%TypeError%"),Uo=fd("%WeakMap%",!0),Ho=fd("%Map%",!0),JP=na("WeakMap.prototype.get",!0),eD=na("WeakMap.prototype.set",!0),tD=na("WeakMap.prototype.has",!0),rD=na("Map.prototype.get",!0),nD=na("Map.prototype.set",!0),iD=na("Map.prototype.has",!0),dd=function(e,t){for(var r=e,n;(n=r.next)!==null;r=n)if(n.key===t)return r.next=n.next,n.next=e.next,e.next=n,n},aD=function(e,t){var r=dd(e,t);return r&&r.value},oD=function(e,t,r){var n=dd(e,t);n?n.value=r:e.next={key:t,next:e.next,value:r}},sD=function(e,t){return!!dd(e,t)},uD=function(){var t,r,n,i={assert:function(a){if(!i.has(a))throw new QP("Side channel does not contain "+ZP(a))},get:function(a){if(Uo&&a&&(typeof a=="object"||typeof a=="function")){if(t)return JP(t,a)}else if(Ho){if(r)return rD(r,a)}else if(n)return aD(n,a)},has:function(a){if(Uo&&a&&(typeof a=="object"||typeof a=="function")){if(t)return tD(t,a)}else if(Ho){if(r)return iD(r,a)}else if(n)return sD(n,a);return!1},set:function(a,o){Uo&&a&&(typeof a=="object"||typeof a=="function")?(t||(t=new Uo),eD(t,a,o)):Ho?(r||(r=new Ho),nD(r,a,o)):(n||(n={key:{},next:null}),oD(n,a,o))}};return i},lD=String.prototype.replace,cD=/%20/g,i0={RFC1738:"RFC1738",RFC3986:"RFC3986"},hd={default:i0.RFC3986,formatters:{RFC1738:function(e){return lD.call(e,cD,"+")},RFC3986:function(e){return String(e)}},RFC1738:i0.RFC1738,RFC3986:i0.RFC3986},fD=hd,a0=Object.prototype.hasOwnProperty,ei=Array.isArray,Cr=function(){for(var e=[],t=0;t<256;++t)e.push("%"+((t<16?"0":"")+t.toString(16)).toUpperCase());return e}(),dD=function(t){for(;t.length>1;){var r=t.pop(),n=r.obj[r.prop];if(ei(n)){for(var i=[],a=0;a<n.length;++a)typeof n[a]<"u"&&i.push(n[a]);r.obj[r.prop]=i}}},Q3=function(t,r){for(var n=r&&r.plainObjects?Object.create(null):{},i=0;i<t.length;++i)typeof t[i]<"u"&&(n[i]=t[i]);return n},hD=function e(t,r,n){if(!r)return t;if(typeof r!="object"){if(ei(t))t.push(r);else if(t&&typeof t=="object")(n&&(n.plainObjects||n.allowPrototypes)||!a0.call(Object.prototype,r))&&(t[r]=!0);else return[t,r];return t}if(!t||typeof t!="object")return[t].concat(r);var i=t;return ei(t)&&!ei(r)&&(i=Q3(t,n)),ei(t)&&ei(r)?(r.forEach(function(a,o){if(a0.call(t,o)){var s=t[o];s&&typeof s=="object"&&a&&typeof a=="object"?t[o]=e(s,a,n):t.push(a)}else t[o]=a}),t):Object.keys(r).reduce(function(a,o){var s=r[o];return a0.call(a,o)?a[o]=e(a[o],s,n):a[o]=s,a},i)},pD=function(t,r){return Object.keys(r).reduce(function(n,i){return n[i]=r[i],n},t)},mD=function(e,t,r){var n=e.replace(/\+/g," ");if(r==="iso-8859-1")return n.replace(/%[0-9a-f]{2}/gi,unescape);try{return decodeURIComponent(n)}catch{return n}},gD=function(t,r,n,i,a){if(t.length===0)return t;var o=t;if(typeof t=="symbol"?o=Symbol.prototype.toString.call(t):typeof t!="string"&&(o=String(t)),n==="iso-8859-1")return escape(o).replace(/%u[0-9a-f]{4}/gi,function(c){return"%26%23"+parseInt(c.slice(2),16)+"%3B"});for(var s="",u=0;u<o.length;++u){var l=o.charCodeAt(u);if(l===45||l===46||l===95||l===126||l>=48&&l<=57||l>=65&&l<=90||l>=97&&l<=122||a===fD.RFC1738&&(l===40||l===41)){s+=o.charAt(u);continue}if(l<128){s=s+Cr[l];continue}if(l<2048){s=s+(Cr[192|l>>6]+Cr[128|l&63]);continue}if(l<55296||l>=57344){s=s+(Cr[224|l>>12]+Cr[128|l>>6&63]+Cr[128|l&63]);continue}u+=1,l=65536+((l&1023)<<10|o.charCodeAt(u)&1023),s+=Cr[240|l>>18]+Cr[128|l>>12&63]+Cr[128|l>>6&63]+Cr[128|l&63]}return s},bD=function(t){for(var r=[{obj:{o:t},prop:"o"}],n=[],i=0;i<r.length;++i)for(var a=r[i],o=a.obj[a.prop],s=Object.keys(o),u=0;u<s.length;++u){var l=s[u],c=o[l];typeof c=="object"&&c!==null&&n.indexOf(c)===-1&&(r.push({obj:o,prop:l}),n.push(c))}return dD(r),t},vD=function(t){return Object.prototype.toString.call(t)==="[object RegExp]"},yD=function(t){return!t||typeof t!="object"?!1:!!(t.constructor&&t.constructor.isBuffer&&t.constructor.isBuffer(t))},wD=function(t,r){return[].concat(t,r)},xD=function(t,r){if(ei(t)){for(var n=[],i=0;i<t.length;i+=1)n.push(r(t[i]));return n}return r(t)},J3={arrayToObject:Q3,assign:pD,combine:wD,compact:bD,decode:mD,encode:gD,isBuffer:yD,isRegExp:vD,maybeMap:xD,merge:hD},ev=uD,gs=J3,Ta=hd,ED=Object.prototype.hasOwnProperty,cm={brackets:function(t){return t+"[]"},comma:"comma",indices:function(t,r){return t+"["+r+"]"},repeat:function(t){return t}},an=Array.isArray,SD=Array.prototype.push,tv=function(e,t){SD.apply(e,an(t)?t:[t])},TD=Date.prototype.toISOString,fm=Ta.default,kt={addQueryPrefix:!1,allowDots:!1,charset:"utf-8",charsetSentinel:!1,delimiter:"&",encode:!0,encoder:gs.encode,encodeValuesOnly:!1,format:fm,formatter:Ta.formatters[fm],indices:!1,serializeDate:function(t){return TD.call(t)},skipNulls:!1,strictNullHandling:!1},AD=function(t){return typeof t=="string"||typeof t=="number"||typeof t=="boolean"||typeof t=="symbol"||typeof t=="bigint"},o0={},kD=function e(t,r,n,i,a,o,s,u,l,c,f,d,h,p,m,g){for(var v=t,w=g,x=0,N=!1;(w=w.get(o0))!==void 0&&!N;){var O=w.get(t);if(x+=1,typeof O<"u"){if(O===x)throw new RangeError("Cyclic object value");N=!0}typeof w.get(o0)>"u"&&(x=0)}if(typeof u=="function"?v=u(r,v):v instanceof Date?v=f(v):n==="comma"&&an(v)&&(v=gs.maybeMap(v,function(U){return U instanceof Date?f(U):U})),v===null){if(a)return s&&!p?s(r,kt.encoder,m,"key",d):r;v=""}if(AD(v)||gs.isBuffer(v)){if(s){var A=p?r:s(r,kt.encoder,m,"key",d);return[h(A)+"="+h(s(v,kt.encoder,m,"value",d))]}return[h(r)+"="+h(String(v))]}var D=[];if(typeof v>"u")return D;var H;if(n==="comma"&&an(v))p&&s&&(v=gs.maybeMap(v,s)),H=[{value:v.length>0?v.join(",")||null:void 0}];else if(an(u))H=u;else{var z=Object.keys(v);H=l?z.sort(l):z}for(var L=i&&an(v)&&v.length===1?r+"[]":r,I=0;I<H.length;++I){var k=H[I],M=typeof k=="object"&&typeof k.value<"u"?k.value:v[k];if(!(o&&M===null)){var F=an(v)?typeof n=="function"?n(L,k):L:L+(c?"."+k:"["+k+"]");g.set(t,x);var C=ev();C.set(o0,g),tv(D,e(M,F,n,i,a,o,n==="comma"&&p&&an(v)?null:s,u,l,c,f,d,h,p,m,C))}}return D},OD=function(t){if(!t)return kt;if(t.encoder!==null&&typeof t.encoder<"u"&&typeof t.encoder!="function")throw new TypeError("Encoder has to be a function.");var r=t.charset||kt.charset;if(typeof t.charset<"u"&&t.charset!=="utf-8"&&t.charset!=="iso-8859-1")throw new TypeError("The charset option must be either utf-8, iso-8859-1, or undefined");var n=Ta.default;if(typeof t.format<"u"){if(!ED.call(Ta.formatters,t.format))throw new TypeError("Unknown format option provided.");n=t.format}var i=Ta.formatters[n],a=kt.filter;return(typeof t.filter=="function"||an(t.filter))&&(a=t.filter),{addQueryPrefix:typeof t.addQueryPrefix=="boolean"?t.addQueryPrefix:kt.addQueryPrefix,allowDots:typeof t.allowDots>"u"?kt.allowDots:!!t.allowDots,charset:r,charsetSentinel:typeof t.charsetSentinel=="boolean"?t.charsetSentinel:kt.charsetSentinel,delimiter:typeof t.delimiter>"u"?kt.delimiter:t.delimiter,encode:typeof t.encode=="boolean"?t.encode:kt.encode,encoder:typeof t.encoder=="function"?t.encoder:kt.encoder,encodeValuesOnly:typeof t.encodeValuesOnly=="boolean"?t.encodeValuesOnly:kt.encodeValuesOnly,filter:a,format:n,formatter:i,serializeDate:typeof t.serializeDate=="function"?t.serializeDate:kt.serializeDate,skipNulls:typeof t.skipNulls=="boolean"?t.skipNulls:kt.skipNulls,sort:typeof t.sort=="function"?t.sort:null,strictNullHandling:typeof t.strictNullHandling=="boolean"?t.strictNullHandling:kt.strictNullHandling}},ND=function(e,t){var r=e,n=OD(t),i,a;typeof n.filter=="function"?(a=n.filter,r=a("",r)):an(n.filter)&&(a=n.filter,i=a);var o=[];if(typeof r!="object"||r===null)return"";var s;t&&t.arrayFormat in cm?s=t.arrayFormat:t&&"indices"in t?s=t.indices?"indices":"repeat":s="indices";var u=cm[s];if(t&&"commaRoundTrip"in t&&typeof t.commaRoundTrip!="boolean")throw new TypeError("`commaRoundTrip` must be a boolean, or absent");var l=u==="comma"&&t&&t.commaRoundTrip;i||(i=Object.keys(r)),n.sort&&i.sort(n.sort);for(var c=ev(),f=0;f<i.length;++f){var d=i[f];n.skipNulls&&r[d]===null||tv(o,kD(r[d],d,u,l,n.strictNullHandling,n.skipNulls,n.encode?n.encoder:null,n.filter,n.sort,n.allowDots,n.serializeDate,n.format,n.formatter,n.encodeValuesOnly,n.charset,c))}var h=o.join(n.delimiter),p=n.addQueryPrefix===!0?"?":"";return n.charsetSentinel&&(n.charset==="iso-8859-1"?p+="utf8=%26%2310003%3B&":p+="utf8=%E2%9C%93&"),h.length>0?p+h:""},ji=J3,Oc=Object.prototype.hasOwnProperty,_D=Array.isArray,xt={allowDots:!1,allowPrototypes:!1,allowSparse:!1,arrayLimit:20,charset:"utf-8",charsetSentinel:!1,comma:!1,decoder:ji.decode,delimiter:"&",depth:5,ignoreQueryPrefix:!1,interpretNumericEntities:!1,parameterLimit:1e3,parseArrays:!0,plainObjects:!1,strictNullHandling:!1},CD=function(e){return e.replace(/&#(\d+);/g,function(t,r){return String.fromCharCode(parseInt(r,10))})},rv=function(e,t){return e&&typeof e=="string"&&t.comma&&e.indexOf(",")>-1?e.split(","):e},MD="utf8=%26%2310003%3B",RD="utf8=%E2%9C%93",ID=function(t,r){var n={__proto__:null},i=r.ignoreQueryPrefix?t.replace(/^\?/,""):t,a=r.parameterLimit===1/0?void 0:r.parameterLimit,o=i.split(r.delimiter,a),s=-1,u,l=r.charset;if(r.charsetSentinel)for(u=0;u<o.length;++u)o[u].indexOf("utf8=")===0&&(o[u]===RD?l="utf-8":o[u]===MD&&(l="iso-8859-1"),s=u,u=o.length);for(u=0;u<o.length;++u)if(u!==s){var c=o[u],f=c.indexOf("]="),d=f===-1?c.indexOf("="):f+1,h,p;d===-1?(h=r.decoder(c,xt.decoder,l,"key"),p=r.strictNullHandling?null:""):(h=r.decoder(c.slice(0,d),xt.decoder,l,"key"),p=ji.maybeMap(rv(c.slice(d+1),r),function(m){return r.decoder(m,xt.decoder,l,"value")})),p&&r.interpretNumericEntities&&l==="iso-8859-1"&&(p=CD(p)),c.indexOf("[]=")>-1&&(p=_D(p)?[p]:p),Oc.call(n,h)?n[h]=ji.combine(n[h],p):n[h]=p}return n},PD=function(e,t,r,n){for(var i=n?t:rv(t,r),a=e.length-1;a>=0;--a){var o,s=e[a];if(s==="[]"&&r.parseArrays)o=[].concat(i);else{o=r.plainObjects?Object.create(null):{};var u=s.charAt(0)==="["&&s.charAt(s.length-1)==="]"?s.slice(1,-1):s,l=parseInt(u,10);!r.parseArrays&&u===""?o={0:i}:!isNaN(l)&&s!==u&&String(l)===u&&l>=0&&r.parseArrays&&l<=r.arrayLimit?(o=[],o[l]=i):u!=="__proto__"&&(o[u]=i)}i=o}return i},DD=function(t,r,n,i){if(t){var a=n.allowDots?t.replace(/\.([^.[]+)/g,"[$1]"):t,o=/(\[[^[\]]*])/,s=/(\[[^[\]]*])/g,u=n.depth>0&&o.exec(a),l=u?a.slice(0,u.index):a,c=[];if(l){if(!n.plainObjects&&Oc.call(Object.prototype,l)&&!n.allowPrototypes)return;c.push(l)}for(var f=0;n.depth>0&&(u=s.exec(a))!==null&&f<n.depth;){if(f+=1,!n.plainObjects&&Oc.call(Object.prototype,u[1].slice(1,-1))&&!n.allowPrototypes)return;c.push(u[1])}return u&&c.push("["+a.slice(u.index)+"]"),PD(c,r,n,i)}},LD=function(t){if(!t)return xt;if(t.decoder!==null&&t.decoder!==void 0&&typeof t.decoder!="function")throw new TypeError("Decoder has to be a function.");if(typeof t.charset<"u"&&t.charset!=="utf-8"&&t.charset!=="iso-8859-1")throw new TypeError("The charset option must be either utf-8, iso-8859-1, or undefined");var r=typeof t.charset>"u"?xt.charset:t.charset;return{allowDots:typeof t.allowDots>"u"?xt.allowDots:!!t.allowDots,allowPrototypes:typeof t.allowPrototypes=="boolean"?t.allowPrototypes:xt.allowPrototypes,allowSparse:typeof t.allowSparse=="boolean"?t.allowSparse:xt.allowSparse,arrayLimit:typeof t.arrayLimit=="number"?t.arrayLimit:xt.arrayLimit,charset:r,charsetSentinel:typeof t.charsetSentinel=="boolean"?t.charsetSentinel:xt.charsetSentinel,comma:typeof t.comma=="boolean"?t.comma:xt.comma,decoder:typeof t.decoder=="function"?t.decoder:xt.decoder,delimiter:typeof t.delimiter=="string"||ji.isRegExp(t.delimiter)?t.delimiter:xt.delimiter,depth:typeof t.depth=="number"||t.depth===!1?+t.depth:xt.depth,ignoreQueryPrefix:t.ignoreQueryPrefix===!0,interpretNumericEntities:typeof t.interpretNumericEntities=="boolean"?t.interpretNumericEntities:xt.interpretNumericEntities,parameterLimit:typeof t.parameterLimit=="number"?t.parameterLimit:xt.parameterLimit,parseArrays:t.parseArrays!==!1,plainObjects:typeof t.plainObjects=="boolean"?t.plainObjects:xt.plainObjects,strictNullHandling:typeof t.strictNullHandling=="boolean"?t.strictNullHandling:xt.strictNullHandling}},FD=function(e,t){var r=LD(t);if(e===""||e===null||typeof e>"u")return r.plainObjects?Object.create(null):{};for(var n=typeof e=="string"?ID(e,r):e,i=r.plainObjects?Object.create(null):{},a=Object.keys(n),o=0;o<a.length;++o){var s=a[o],u=DD(s,n[s],r,typeof e=="string");i=ji.merge(i,u,r)}return r.allowSparse===!0?i:ji.compact(i)},BD=ND,zD=FD,$D=hd,UD={formats:$D,parse:zD,stringify:BD};const MU=Ce(UD);var nv={},Ba={},pd={},za={},md={};Object.defineProperty(md,"__esModule",{value:!0});md.default=new Uint16Array('ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map(function(e){return e.charCodeAt(0)}));var gd={};Object.defineProperty(gd,"__esModule",{value:!0});gd.default=new Uint16Array("Ȁaglq	\x1Bɭ\0\0p;䀦os;䀧t;䀾t;䀼uot;䀢".split("").map(function(e){return e.charCodeAt(0)}));var Nc={};(function(e){var t;Object.defineProperty(e,"__esModule",{value:!0}),e.replaceCodePoint=e.fromCodePoint=void 0;var r=new Map([[0,65533],[128,8364],[130,8218],[131,402],[132,8222],[133,8230],[134,8224],[135,8225],[136,710],[137,8240],[138,352],[139,8249],[140,338],[142,381],[145,8216],[146,8217],[147,8220],[148,8221],[149,8226],[150,8211],[151,8212],[152,732],[153,8482],[154,353],[155,8250],[156,339],[158,382],[159,376]]);e.fromCodePoint=(t=String.fromCodePoint)!==null&&t!==void 0?t:function(a){var o="";return a>65535&&(a-=65536,o+=String.fromCharCode(a>>>10&1023|55296),a=56320|a&1023),o+=String.fromCharCode(a),o};function n(a){var o;return a>=55296&&a<=57343||a>1114111?65533:(o=r.get(a))!==null&&o!==void 0?o:a}e.replaceCodePoint=n;function i(a){return(0,e.fromCodePoint)(n(a))}e.default=i})(Nc);(function(e){var t=xe&&xe.__createBinding||(Object.create?function(I,k,M,F){F===void 0&&(F=M);var C=Object.getOwnPropertyDescriptor(k,M);(!C||("get"in C?!k.__esModule:C.writable||C.configurable))&&(C={enumerable:!0,get:function(){return k[M]}}),Object.defineProperty(I,F,C)}:function(I,k,M,F){F===void 0&&(F=M),I[F]=k[M]}),r=xe&&xe.__setModuleDefault||(Object.create?function(I,k){Object.defineProperty(I,"default",{enumerable:!0,value:k})}:function(I,k){I.default=k}),n=xe&&xe.__importStar||function(I){if(I&&I.__esModule)return I;var k={};if(I!=null)for(var M in I)M!=="default"&&Object.prototype.hasOwnProperty.call(I,M)&&t(k,I,M);return r(k,I),k},i=xe&&xe.__importDefault||function(I){return I&&I.__esModule?I:{default:I}};Object.defineProperty(e,"__esModule",{value:!0}),e.decodeXML=e.decodeHTMLStrict=e.decodeHTMLAttribute=e.decodeHTML=e.determineBranch=e.EntityDecoder=e.DecodingMode=e.BinTrieFlags=e.fromCodePoint=e.replaceCodePoint=e.decodeCodePoint=e.xmlDecodeTree=e.htmlDecodeTree=void 0;var a=i(md);e.htmlDecodeTree=a.default;var o=i(gd);e.xmlDecodeTree=o.default;var s=n(Nc);e.decodeCodePoint=s.default;var u=Nc;Object.defineProperty(e,"replaceCodePoint",{enumerable:!0,get:function(){return u.replaceCodePoint}}),Object.defineProperty(e,"fromCodePoint",{enumerable:!0,get:function(){return u.fromCodePoint}});var l;(function(I){I[I.NUM=35]="NUM",I[I.SEMI=59]="SEMI",I[I.EQUALS=61]="EQUALS",I[I.ZERO=48]="ZERO",I[I.NINE=57]="NINE",I[I.LOWER_A=97]="LOWER_A",I[I.LOWER_F=102]="LOWER_F",I[I.LOWER_X=120]="LOWER_X",I[I.LOWER_Z=122]="LOWER_Z",I[I.UPPER_A=65]="UPPER_A",I[I.UPPER_F=70]="UPPER_F",I[I.UPPER_Z=90]="UPPER_Z"})(l||(l={}));var c=32,f;(function(I){I[I.VALUE_LENGTH=49152]="VALUE_LENGTH",I[I.BRANCH_LENGTH=16256]="BRANCH_LENGTH",I[I.JUMP_TABLE=127]="JUMP_TABLE"})(f=e.BinTrieFlags||(e.BinTrieFlags={}));function d(I){return I>=l.ZERO&&I<=l.NINE}function h(I){return I>=l.UPPER_A&&I<=l.UPPER_F||I>=l.LOWER_A&&I<=l.LOWER_F}function p(I){return I>=l.UPPER_A&&I<=l.UPPER_Z||I>=l.LOWER_A&&I<=l.LOWER_Z||d(I)}function m(I){return I===l.EQUALS||p(I)}var g;(function(I){I[I.EntityStart=0]="EntityStart",I[I.NumericStart=1]="NumericStart",I[I.NumericDecimal=2]="NumericDecimal",I[I.NumericHex=3]="NumericHex",I[I.NamedEntity=4]="NamedEntity"})(g||(g={}));var v;(function(I){I[I.Legacy=0]="Legacy",I[I.Strict=1]="Strict",I[I.Attribute=2]="Attribute"})(v=e.DecodingMode||(e.DecodingMode={}));var w=function(){function I(k,M,F){this.decodeTree=k,this.emitCodePoint=M,this.errors=F,this.state=g.EntityStart,this.consumed=1,this.result=0,this.treeIndex=0,this.excess=1,this.decodeMode=v.Strict}return I.prototype.startEntity=function(k){this.decodeMode=k,this.state=g.EntityStart,this.result=0,this.treeIndex=0,this.excess=1,this.consumed=1},I.prototype.write=function(k,M){switch(this.state){case g.EntityStart:return k.charCodeAt(M)===l.NUM?(this.state=g.NumericStart,this.consumed+=1,this.stateNumericStart(k,M+1)):(this.state=g.NamedEntity,this.stateNamedEntity(k,M));case g.NumericStart:return this.stateNumericStart(k,M);case g.NumericDecimal:return this.stateNumericDecimal(k,M);case g.NumericHex:return this.stateNumericHex(k,M);case g.NamedEntity:return this.stateNamedEntity(k,M)}},I.prototype.stateNumericStart=function(k,M){return M>=k.length?-1:(k.charCodeAt(M)|c)===l.LOWER_X?(this.state=g.NumericHex,this.consumed+=1,this.stateNumericHex(k,M+1)):(this.state=g.NumericDecimal,this.stateNumericDecimal(k,M))},I.prototype.addToNumericResult=function(k,M,F,C){if(M!==F){var U=F-M;this.result=this.result*Math.pow(C,U)+parseInt(k.substr(M,U),C),this.consumed+=U}},I.prototype.stateNumericHex=function(k,M){for(var F=M;M<k.length;){var C=k.charCodeAt(M);if(d(C)||h(C))M+=1;else return this.addToNumericResult(k,F,M,16),this.emitNumericEntity(C,3)}return this.addToNumericResult(k,F,M,16),-1},I.prototype.stateNumericDecimal=function(k,M){for(var F=M;M<k.length;){var C=k.charCodeAt(M);if(d(C))M+=1;else return this.addToNumericResult(k,F,M,10),this.emitNumericEntity(C,2)}return this.addToNumericResult(k,F,M,10),-1},I.prototype.emitNumericEntity=function(k,M){var F;if(this.consumed<=M)return(F=this.errors)===null||F===void 0||F.absenceOfDigitsInNumericCharacterReference(this.consumed),0;if(k===l.SEMI)this.consumed+=1;else if(this.decodeMode===v.Strict)return 0;return this.emitCodePoint((0,s.replaceCodePoint)(this.result),this.consumed),this.errors&&(k!==l.SEMI&&this.errors.missingSemicolonAfterCharacterReference(),this.errors.validateNumericCharacterReference(this.result)),this.consumed},I.prototype.stateNamedEntity=function(k,M){for(var F=this.decodeTree,C=F[this.treeIndex],U=(C&f.VALUE_LENGTH)>>14;M<k.length;M++,this.excess++){var $=k.charCodeAt(M);if(this.treeIndex=N(F,C,this.treeIndex+Math.max(1,U),$),this.treeIndex<0)return this.result===0||this.decodeMode===v.Attribute&&(U===0||m($))?0:this.emitNotTerminatedNamedEntity();if(C=F[this.treeIndex],U=(C&f.VALUE_LENGTH)>>14,U!==0){if($===l.SEMI)return this.emitNamedEntityData(this.treeIndex,U,this.consumed+this.excess);this.decodeMode!==v.Strict&&(this.result=this.treeIndex,this.consumed+=this.excess,this.excess=0)}}return-1},I.prototype.emitNotTerminatedNamedEntity=function(){var k,M=this,F=M.result,C=M.decodeTree,U=(C[F]&f.VALUE_LENGTH)>>14;return this.emitNamedEntityData(F,U,this.consumed),(k=this.errors)===null||k===void 0||k.missingSemicolonAfterCharacterReference(),this.consumed},I.prototype.emitNamedEntityData=function(k,M,F){var C=this.decodeTree;return this.emitCodePoint(M===1?C[k]&~f.VALUE_LENGTH:C[k+1],F),M===3&&this.emitCodePoint(C[k+2],F),F},I.prototype.end=function(){var k;switch(this.state){case g.NamedEntity:return this.result!==0&&(this.decodeMode!==v.Attribute||this.result===this.treeIndex)?this.emitNotTerminatedNamedEntity():0;case g.NumericDecimal:return this.emitNumericEntity(0,2);case g.NumericHex:return this.emitNumericEntity(0,3);case g.NumericStart:return(k=this.errors)===null||k===void 0||k.absenceOfDigitsInNumericCharacterReference(this.consumed),0;case g.EntityStart:return 0}},I}();e.EntityDecoder=w;function x(I){var k="",M=new w(I,function(F){return k+=(0,s.fromCodePoint)(F)});return function(C,U){for(var $=0,V=0;(V=C.indexOf("&",V))>=0;){k+=C.slice($,V),M.startEntity(U);var se=M.write(C,V+1);if(se<0){$=V+M.end();break}$=V+se,V=se===0?$+1:$}var _=k+C.slice($);return k="",_}}function N(I,k,M,F){var C=(k&f.BRANCH_LENGTH)>>7,U=k&f.JUMP_TABLE;if(C===0)return U!==0&&F===U?M:-1;if(U){var $=F-U;return $<0||$>=C?-1:I[M+$]-1}for(var V=M,se=V+C-1;V<=se;){var _=V+se>>>1,oe=I[_];if(oe<F)V=_+1;else if(oe>F)se=_-1;else return I[_+C]}return-1}e.determineBranch=N;var O=x(a.default),A=x(o.default);function D(I,k){return k===void 0&&(k=v.Legacy),O(I,k)}e.decodeHTML=D;function H(I){return O(I,v.Attribute)}e.decodeHTMLAttribute=H;function z(I){return O(I,v.Strict)}e.decodeHTMLStrict=z;function L(I){return A(I,v.Strict)}e.decodeXML=L})(za);(function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.QuoteType=void 0;var t=za,r;(function(d){d[d.Tab=9]="Tab",d[d.NewLine=10]="NewLine",d[d.FormFeed=12]="FormFeed",d[d.CarriageReturn=13]="CarriageReturn",d[d.Space=32]="Space",d[d.ExclamationMark=33]="ExclamationMark",d[d.Number=35]="Number",d[d.Amp=38]="Amp",d[d.SingleQuote=39]="SingleQuote",d[d.DoubleQuote=34]="DoubleQuote",d[d.Dash=45]="Dash",d[d.Slash=47]="Slash",d[d.Zero=48]="Zero",d[d.Nine=57]="Nine",d[d.Semi=59]="Semi",d[d.Lt=60]="Lt",d[d.Eq=61]="Eq",d[d.Gt=62]="Gt",d[d.Questionmark=63]="Questionmark",d[d.UpperA=65]="UpperA",d[d.LowerA=97]="LowerA",d[d.UpperF=70]="UpperF",d[d.LowerF=102]="LowerF",d[d.UpperZ=90]="UpperZ",d[d.LowerZ=122]="LowerZ",d[d.LowerX=120]="LowerX",d[d.OpeningSquareBracket=91]="OpeningSquareBracket"})(r||(r={}));var n;(function(d){d[d.Text=1]="Text",d[d.BeforeTagName=2]="BeforeTagName",d[d.InTagName=3]="InTagName",d[d.InSelfClosingTag=4]="InSelfClosingTag",d[d.BeforeClosingTagName=5]="BeforeClosingTagName",d[d.InClosingTagName=6]="InClosingTagName",d[d.AfterClosingTagName=7]="AfterClosingTagName",d[d.BeforeAttributeName=8]="BeforeAttributeName",d[d.InAttributeName=9]="InAttributeName",d[d.AfterAttributeName=10]="AfterAttributeName",d[d.BeforeAttributeValue=11]="BeforeAttributeValue",d[d.InAttributeValueDq=12]="InAttributeValueDq",d[d.InAttributeValueSq=13]="InAttributeValueSq",d[d.InAttributeValueNq=14]="InAttributeValueNq",d[d.BeforeDeclaration=15]="BeforeDeclaration",d[d.InDeclaration=16]="InDeclaration",d[d.InProcessingInstruction=17]="InProcessingInstruction",d[d.BeforeComment=18]="BeforeComment",d[d.CDATASequence=19]="CDATASequence",d[d.InSpecialComment=20]="InSpecialComment",d[d.InCommentLike=21]="InCommentLike",d[d.BeforeSpecialS=22]="BeforeSpecialS",d[d.SpecialStartSequence=23]="SpecialStartSequence",d[d.InSpecialTag=24]="InSpecialTag",d[d.BeforeEntity=25]="BeforeEntity",d[d.BeforeNumericEntity=26]="BeforeNumericEntity",d[d.InNamedEntity=27]="InNamedEntity",d[d.InNumericEntity=28]="InNumericEntity",d[d.InHexEntity=29]="InHexEntity"})(n||(n={}));function i(d){return d===r.Space||d===r.NewLine||d===r.Tab||d===r.FormFeed||d===r.CarriageReturn}function a(d){return d===r.Slash||d===r.Gt||i(d)}function o(d){return d>=r.Zero&&d<=r.Nine}function s(d){return d>=r.LowerA&&d<=r.LowerZ||d>=r.UpperA&&d<=r.UpperZ}function u(d){return d>=r.UpperA&&d<=r.UpperF||d>=r.LowerA&&d<=r.LowerF}var l;(function(d){d[d.NoValue=0]="NoValue",d[d.Unquoted=1]="Unquoted",d[d.Single=2]="Single",d[d.Double=3]="Double"})(l=e.QuoteType||(e.QuoteType={}));var c={Cdata:new Uint8Array([67,68,65,84,65,91]),CdataEnd:new Uint8Array([93,93,62]),CommentEnd:new Uint8Array([45,45,62]),ScriptEnd:new Uint8Array([60,47,115,99,114,105,112,116]),StyleEnd:new Uint8Array([60,47,115,116,121,108,101]),TitleEnd:new Uint8Array([60,47,116,105,116,108,101])},f=function(){function d(h,p){var m=h.xmlMode,g=m===void 0?!1:m,v=h.decodeEntities,w=v===void 0?!0:v;this.cbs=p,this.state=n.Text,this.buffer="",this.sectionStart=0,this.index=0,this.baseState=n.Text,this.isSpecial=!1,this.running=!0,this.offset=0,this.currentSequence=void 0,this.sequenceIndex=0,this.trieIndex=0,this.trieCurrent=0,this.entityResult=0,this.entityExcess=0,this.xmlMode=g,this.decodeEntities=w,this.entityTrie=g?t.xmlDecodeTree:t.htmlDecodeTree}return d.prototype.reset=function(){this.state=n.Text,this.buffer="",this.sectionStart=0,this.index=0,this.baseState=n.Text,this.currentSequence=void 0,this.running=!0,this.offset=0},d.prototype.write=function(h){this.offset+=this.buffer.length,this.buffer=h,this.parse()},d.prototype.end=function(){this.running&&this.finish()},d.prototype.pause=function(){this.running=!1},d.prototype.resume=function(){this.running=!0,this.index<this.buffer.length+this.offset&&this.parse()},d.prototype.getIndex=function(){return this.index},d.prototype.getSectionStart=function(){return this.sectionStart},d.prototype.stateText=function(h){h===r.Lt||!this.decodeEntities&&this.fastForwardTo(r.Lt)?(this.index>this.sectionStart&&this.cbs.ontext(this.sectionStart,this.index),this.state=n.BeforeTagName,this.sectionStart=this.index):this.decodeEntities&&h===r.Amp&&(this.state=n.BeforeEntity)},d.prototype.stateSpecialStartSequence=function(h){var p=this.sequenceIndex===this.currentSequence.length,m=p?a(h):(h|32)===this.currentSequence[this.sequenceIndex];if(!m)this.isSpecial=!1;else if(!p){this.sequenceIndex++;return}this.sequenceIndex=0,this.state=n.InTagName,this.stateInTagName(h)},d.prototype.stateInSpecialTag=function(h){if(this.sequenceIndex===this.currentSequence.length){if(h===r.Gt||i(h)){var p=this.index-this.currentSequence.length;if(this.sectionStart<p){var m=this.index;this.index=p,this.cbs.ontext(this.sectionStart,p),this.index=m}this.isSpecial=!1,this.sectionStart=p+2,this.stateInClosingTagName(h);return}this.sequenceIndex=0}(h|32)===this.currentSequence[this.sequenceIndex]?this.sequenceIndex+=1:this.sequenceIndex===0?this.currentSequence===c.TitleEnd?this.decodeEntities&&h===r.Amp&&(this.state=n.BeforeEntity):this.fastForwardTo(r.Lt)&&(this.sequenceIndex=1):this.sequenceIndex=+(h===r.Lt)},d.prototype.stateCDATASequence=function(h){h===c.Cdata[this.sequenceIndex]?++this.sequenceIndex===c.Cdata.length&&(this.state=n.InCommentLike,this.currentSequence=c.CdataEnd,this.sequenceIndex=0,this.sectionStart=this.index+1):(this.sequenceIndex=0,this.state=n.InDeclaration,this.stateInDeclaration(h))},d.prototype.fastForwardTo=function(h){for(;++this.index<this.buffer.length+this.offset;)if(this.buffer.charCodeAt(this.index-this.offset)===h)return!0;return this.index=this.buffer.length+this.offset-1,!1},d.prototype.stateInCommentLike=function(h){h===this.currentSequence[this.sequenceIndex]?++this.sequenceIndex===this.currentSequence.length&&(this.currentSequence===c.CdataEnd?this.cbs.oncdata(this.sectionStart,this.index,2):this.cbs.oncomment(this.sectionStart,this.index,2),this.sequenceIndex=0,this.sectionStart=this.index+1,this.state=n.Text):this.sequenceIndex===0?this.fastForwardTo(this.currentSequence[0])&&(this.sequenceIndex=1):h!==this.currentSequence[this.sequenceIndex-1]&&(this.sequenceIndex=0)},d.prototype.isTagStartChar=function(h){return this.xmlMode?!a(h):s(h)},d.prototype.startSpecial=function(h,p){this.isSpecial=!0,this.currentSequence=h,this.sequenceIndex=p,this.state=n.SpecialStartSequence},d.prototype.stateBeforeTagName=function(h){if(h===r.ExclamationMark)this.state=n.BeforeDeclaration,this.sectionStart=this.index+1;else if(h===r.Questionmark)this.state=n.InProcessingInstruction,this.sectionStart=this.index+1;else if(this.isTagStartChar(h)){var p=h|32;this.sectionStart=this.index,!this.xmlMode&&p===c.TitleEnd[2]?this.startSpecial(c.TitleEnd,3):this.state=!this.xmlMode&&p===c.ScriptEnd[2]?n.BeforeSpecialS:n.InTagName}else h===r.Slash?this.state=n.BeforeClosingTagName:(this.state=n.Text,this.stateText(h))},d.prototype.stateInTagName=function(h){a(h)&&(this.cbs.onopentagname(this.sectionStart,this.index),this.sectionStart=-1,this.state=n.BeforeAttributeName,this.stateBeforeAttributeName(h))},d.prototype.stateBeforeClosingTagName=function(h){i(h)||(h===r.Gt?this.state=n.Text:(this.state=this.isTagStartChar(h)?n.InClosingTagName:n.InSpecialComment,this.sectionStart=this.index))},d.prototype.stateInClosingTagName=function(h){(h===r.Gt||i(h))&&(this.cbs.onclosetag(this.sectionStart,this.index),this.sectionStart=-1,this.state=n.AfterClosingTagName,this.stateAfterClosingTagName(h))},d.prototype.stateAfterClosingTagName=function(h){(h===r.Gt||this.fastForwardTo(r.Gt))&&(this.state=n.Text,this.baseState=n.Text,this.sectionStart=this.index+1)},d.prototype.stateBeforeAttributeName=function(h){h===r.Gt?(this.cbs.onopentagend(this.index),this.isSpecial?(this.state=n.InSpecialTag,this.sequenceIndex=0):this.state=n.Text,this.baseState=this.state,this.sectionStart=this.index+1):h===r.Slash?this.state=n.InSelfClosingTag:i(h)||(this.state=n.InAttributeName,this.sectionStart=this.index)},d.prototype.stateInSelfClosingTag=function(h){h===r.Gt?(this.cbs.onselfclosingtag(this.index),this.state=n.Text,this.baseState=n.Text,this.sectionStart=this.index+1,this.isSpecial=!1):i(h)||(this.state=n.BeforeAttributeName,this.stateBeforeAttributeName(h))},d.prototype.stateInAttributeName=function(h){(h===r.Eq||a(h))&&(this.cbs.onattribname(this.sectionStart,this.index),this.sectionStart=-1,this.state=n.AfterAttributeName,this.stateAfterAttributeName(h))},d.prototype.stateAfterAttributeName=function(h){h===r.Eq?this.state=n.BeforeAttributeValue:h===r.Slash||h===r.Gt?(this.cbs.onattribend(l.NoValue,this.index),this.state=n.BeforeAttributeName,this.stateBeforeAttributeName(h)):i(h)||(this.cbs.onattribend(l.NoValue,this.index),this.state=n.InAttributeName,this.sectionStart=this.index)},d.prototype.stateBeforeAttributeValue=function(h){h===r.DoubleQuote?(this.state=n.InAttributeValueDq,this.sectionStart=this.index+1):h===r.SingleQuote?(this.state=n.InAttributeValueSq,this.sectionStart=this.index+1):i(h)||(this.sectionStart=this.index,this.state=n.InAttributeValueNq,this.stateInAttributeValueNoQuotes(h))},d.prototype.handleInAttributeValue=function(h,p){h===p||!this.decodeEntities&&this.fastForwardTo(p)?(this.cbs.onattribdata(this.sectionStart,this.index),this.sectionStart=-1,this.cbs.onattribend(p===r.DoubleQuote?l.Double:l.Single,this.index),this.state=n.BeforeAttributeName):this.decodeEntities&&h===r.Amp&&(this.baseState=this.state,this.state=n.BeforeEntity)},d.prototype.stateInAttributeValueDoubleQuotes=function(h){this.handleInAttributeValue(h,r.DoubleQuote)},d.prototype.stateInAttributeValueSingleQuotes=function(h){this.handleInAttributeValue(h,r.SingleQuote)},d.prototype.stateInAttributeValueNoQuotes=function(h){i(h)||h===r.Gt?(this.cbs.onattribdata(this.sectionStart,this.index),this.sectionStart=-1,this.cbs.onattribend(l.Unquoted,this.index),this.state=n.BeforeAttributeName,this.stateBeforeAttributeName(h)):this.decodeEntities&&h===r.Amp&&(this.baseState=this.state,this.state=n.BeforeEntity)},d.prototype.stateBeforeDeclaration=function(h){h===r.OpeningSquareBracket?(this.state=n.CDATASequence,this.sequenceIndex=0):this.state=h===r.Dash?n.BeforeComment:n.InDeclaration},d.prototype.stateInDeclaration=function(h){(h===r.Gt||this.fastForwardTo(r.Gt))&&(this.cbs.ondeclaration(this.sectionStart,this.index),this.state=n.Text,this.sectionStart=this.index+1)},d.prototype.stateInProcessingInstruction=function(h){(h===r.Gt||this.fastForwardTo(r.Gt))&&(this.cbs.onprocessinginstruction(this.sectionStart,this.index),this.state=n.Text,this.sectionStart=this.index+1)},d.prototype.stateBeforeComment=function(h){h===r.Dash?(this.state=n.InCommentLike,this.currentSequence=c.CommentEnd,this.sequenceIndex=2,this.sectionStart=this.index+1):this.state=n.InDeclaration},d.prototype.stateInSpecialComment=function(h){(h===r.Gt||this.fastForwardTo(r.Gt))&&(this.cbs.oncomment(this.sectionStart,this.index,0),this.state=n.Text,this.sectionStart=this.index+1)},d.prototype.stateBeforeSpecialS=function(h){var p=h|32;p===c.ScriptEnd[3]?this.startSpecial(c.ScriptEnd,4):p===c.StyleEnd[3]?this.startSpecial(c.StyleEnd,4):(this.state=n.InTagName,this.stateInTagName(h))},d.prototype.stateBeforeEntity=function(h){this.entityExcess=1,this.entityResult=0,h===r.Number?this.state=n.BeforeNumericEntity:h===r.Amp||(this.trieIndex=0,this.trieCurrent=this.entityTrie[0],this.state=n.InNamedEntity,this.stateInNamedEntity(h))},d.prototype.stateInNamedEntity=function(h){if(this.entityExcess+=1,this.trieIndex=(0,t.determineBranch)(this.entityTrie,this.trieCurrent,this.trieIndex+1,h),this.trieIndex<0){this.emitNamedEntity(),this.index--;return}this.trieCurrent=this.entityTrie[this.trieIndex];var p=this.trieCurrent&t.BinTrieFlags.VALUE_LENGTH;if(p){var m=(p>>14)-1;if(!this.allowLegacyEntity()&&h!==r.Semi)this.trieIndex+=m;else{var g=this.index-this.entityExcess+1;g>this.sectionStart&&this.emitPartial(this.sectionStart,g),this.entityResult=this.trieIndex,this.trieIndex+=m,this.entityExcess=0,this.sectionStart=this.index+1,m===0&&this.emitNamedEntity()}}},d.prototype.emitNamedEntity=function(){if(this.state=this.baseState,this.entityResult!==0){var h=(this.entityTrie[this.entityResult]&t.BinTrieFlags.VALUE_LENGTH)>>14;switch(h){case 1:{this.emitCodePoint(this.entityTrie[this.entityResult]&~t.BinTrieFlags.VALUE_LENGTH);break}case 2:{this.emitCodePoint(this.entityTrie[this.entityResult+1]);break}case 3:this.emitCodePoint(this.entityTrie[this.entityResult+1]),this.emitCodePoint(this.entityTrie[this.entityResult+2])}}},d.prototype.stateBeforeNumericEntity=function(h){(h|32)===r.LowerX?(this.entityExcess++,this.state=n.InHexEntity):(this.state=n.InNumericEntity,this.stateInNumericEntity(h))},d.prototype.emitNumericEntity=function(h){var p=this.index-this.entityExcess-1,m=p+2+ +(this.state===n.InHexEntity);m!==this.index&&(p>this.sectionStart&&this.emitPartial(this.sectionStart,p),this.sectionStart=this.index+Number(h),this.emitCodePoint((0,t.replaceCodePoint)(this.entityResult))),this.state=this.baseState},d.prototype.stateInNumericEntity=function(h){h===r.Semi?this.emitNumericEntity(!0):o(h)?(this.entityResult=this.entityResult*10+(h-r.Zero),this.entityExcess++):(this.allowLegacyEntity()?this.emitNumericEntity(!1):this.state=this.baseState,this.index--)},d.prototype.stateInHexEntity=function(h){h===r.Semi?this.emitNumericEntity(!0):o(h)?(this.entityResult=this.entityResult*16+(h-r.Zero),this.entityExcess++):u(h)?(this.entityResult=this.entityResult*16+((h|32)-r.LowerA+10),this.entityExcess++):(this.allowLegacyEntity()?this.emitNumericEntity(!1):this.state=this.baseState,this.index--)},d.prototype.allowLegacyEntity=function(){return!this.xmlMode&&(this.baseState===n.Text||this.baseState===n.InSpecialTag)},d.prototype.cleanup=function(){this.running&&this.sectionStart!==this.index&&(this.state===n.Text||this.state===n.InSpecialTag&&this.sequenceIndex===0?(this.cbs.ontext(this.sectionStart,this.index),this.sectionStart=this.index):(this.state===n.InAttributeValueDq||this.state===n.InAttributeValueSq||this.state===n.InAttributeValueNq)&&(this.cbs.onattribdata(this.sectionStart,this.index),this.sectionStart=this.index))},d.prototype.shouldContinue=function(){return this.index<this.buffer.length+this.offset&&this.running},d.prototype.parse=function(){for(;this.shouldContinue();){var h=this.buffer.charCodeAt(this.index-this.offset);switch(this.state){case n.Text:{this.stateText(h);break}case n.SpecialStartSequence:{this.stateSpecialStartSequence(h);break}case n.InSpecialTag:{this.stateInSpecialTag(h);break}case n.CDATASequence:{this.stateCDATASequence(h);break}case n.InAttributeValueDq:{this.stateInAttributeValueDoubleQuotes(h);break}case n.InAttributeName:{this.stateInAttributeName(h);break}case n.InCommentLike:{this.stateInCommentLike(h);break}case n.InSpecialComment:{this.stateInSpecialComment(h);break}case n.BeforeAttributeName:{this.stateBeforeAttributeName(h);break}case n.InTagName:{this.stateInTagName(h);break}case n.InClosingTagName:{this.stateInClosingTagName(h);break}case n.BeforeTagName:{this.stateBeforeTagName(h);break}case n.AfterAttributeName:{this.stateAfterAttributeName(h);break}case n.InAttributeValueSq:{this.stateInAttributeValueSingleQuotes(h);break}case n.BeforeAttributeValue:{this.stateBeforeAttributeValue(h);break}case n.BeforeClosingTagName:{this.stateBeforeClosingTagName(h);break}case n.AfterClosingTagName:{this.stateAfterClosingTagName(h);break}case n.BeforeSpecialS:{this.stateBeforeSpecialS(h);break}case n.InAttributeValueNq:{this.stateInAttributeValueNoQuotes(h);break}case n.InSelfClosingTag:{this.stateInSelfClosingTag(h);break}case n.InDeclaration:{this.stateInDeclaration(h);break}case n.BeforeDeclaration:{this.stateBeforeDeclaration(h);break}case n.BeforeComment:{this.stateBeforeComment(h);break}case n.InProcessingInstruction:{this.stateInProcessingInstruction(h);break}case n.InNamedEntity:{this.stateInNamedEntity(h);break}case n.BeforeEntity:{this.stateBeforeEntity(h);break}case n.InHexEntity:{this.stateInHexEntity(h);break}case n.InNumericEntity:{this.stateInNumericEntity(h);break}default:this.stateBeforeNumericEntity(h)}this.index++}this.cleanup()},d.prototype.finish=function(){this.state===n.InNamedEntity&&this.emitNamedEntity(),this.sectionStart<this.index&&this.handleTrailingData(),this.cbs.onend()},d.prototype.handleTrailingData=function(){var h=this.buffer.length+this.offset;this.state===n.InCommentLike?this.currentSequence===c.CdataEnd?this.cbs.oncdata(this.sectionStart,h,0):this.cbs.oncomment(this.sectionStart,h,0):this.state===n.InNumericEntity&&this.allowLegacyEntity()?this.emitNumericEntity(!1):this.state===n.InHexEntity&&this.allowLegacyEntity()?this.emitNumericEntity(!1):this.state===n.InTagName||this.state===n.BeforeAttributeName||this.state===n.BeforeAttributeValue||this.state===n.AfterAttributeName||this.state===n.InAttributeName||this.state===n.InAttributeValueSq||this.state===n.InAttributeValueDq||this.state===n.InAttributeValueNq||this.state===n.InClosingTagName||this.cbs.ontext(this.sectionStart,h)},d.prototype.emitPartial=function(h,p){this.baseState!==n.Text&&this.baseState!==n.InSpecialTag?this.cbs.onattribdata(h,p):this.cbs.ontext(h,p)},d.prototype.emitCodePoint=function(h){this.baseState!==n.Text&&this.baseState!==n.InSpecialTag?this.cbs.onattribentity(h):this.cbs.ontextentity(h)},d}();e.default=f})(pd);var HD=xe&&xe.__createBinding||(Object.create?function(e,t,r,n){n===void 0&&(n=r);var i=Object.getOwnPropertyDescriptor(t,r);(!i||("get"in i?!t.__esModule:i.writable||i.configurable))&&(i={enumerable:!0,get:function(){return t[r]}}),Object.defineProperty(e,n,i)}:function(e,t,r,n){n===void 0&&(n=r),e[n]=t[r]}),qD=xe&&xe.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),jD=xe&&xe.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(e!=null)for(var r in e)r!=="default"&&Object.prototype.hasOwnProperty.call(e,r)&&HD(t,e,r);return qD(t,e),t};Object.defineProperty(Ba,"__esModule",{value:!0});Ba.Parser=void 0;var qo=jD(pd),dm=za,Si=new Set(["input","option","optgroup","select","button","datalist","textarea"]),Ye=new Set(["p"]),hm=new Set(["thead","tbody"]),pm=new Set(["dd","dt"]),mm=new Set(["rt","rp"]),VD=new Map([["tr",new Set(["tr","th","td"])],["th",new Set(["th"])],["td",new Set(["thead","th","td"])],["body",new Set(["head","link","script"])],["li",new Set(["li"])],["p",Ye],["h1",Ye],["h2",Ye],["h3",Ye],["h4",Ye],["h5",Ye],["h6",Ye],["select",Si],["input",Si],["output",Si],["button",Si],["datalist",Si],["textarea",Si],["option",new Set(["option"])],["optgroup",new Set(["optgroup","option"])],["dd",pm],["dt",pm],["address",Ye],["article",Ye],["aside",Ye],["blockquote",Ye],["details",Ye],["div",Ye],["dl",Ye],["fieldset",Ye],["figcaption",Ye],["figure",Ye],["footer",Ye],["form",Ye],["header",Ye],["hr",Ye],["main",Ye],["nav",Ye],["ol",Ye],["pre",Ye],["section",Ye],["table",Ye],["ul",Ye],["rt",mm],["rp",mm],["tbody",hm],["tfoot",hm]]),GD=new Set(["area","base","basefont","br","col","command","embed","frame","hr","img","input","isindex","keygen","link","meta","param","source","track","wbr"]),gm=new Set(["math","svg"]),bm=new Set(["mi","mo","mn","ms","mtext","annotation-xml","foreignobject","desc","title"]),WD=/\s|\//,KD=function(){function e(t,r){r===void 0&&(r={});var n,i,a,o,s;this.options=r,this.startIndex=0,this.endIndex=0,this.openTagStart=0,this.tagname="",this.attribname="",this.attribvalue="",this.attribs=null,this.stack=[],this.foreignContext=[],this.buffers=[],this.bufferOffset=0,this.writeIndex=0,this.ended=!1,this.cbs=t??{},this.lowerCaseTagNames=(n=r.lowerCaseTags)!==null&&n!==void 0?n:!r.xmlMode,this.lowerCaseAttributeNames=(i=r.lowerCaseAttributeNames)!==null&&i!==void 0?i:!r.xmlMode,this.tokenizer=new((a=r.Tokenizer)!==null&&a!==void 0?a:qo.default)(this.options,this),(s=(o=this.cbs).onparserinit)===null||s===void 0||s.call(o,this)}return e.prototype.ontext=function(t,r){var n,i,a=this.getSlice(t,r);this.endIndex=r-1,(i=(n=this.cbs).ontext)===null||i===void 0||i.call(n,a),this.startIndex=r},e.prototype.ontextentity=function(t){var r,n,i=this.tokenizer.getSectionStart();this.endIndex=i-1,(n=(r=this.cbs).ontext)===null||n===void 0||n.call(r,(0,dm.fromCodePoint)(t)),this.startIndex=i},e.prototype.isVoidElement=function(t){return!this.options.xmlMode&&GD.has(t)},e.prototype.onopentagname=function(t,r){this.endIndex=r;var n=this.getSlice(t,r);this.lowerCaseTagNames&&(n=n.toLowerCase()),this.emitOpenTag(n)},e.prototype.emitOpenTag=function(t){var r,n,i,a;this.openTagStart=this.startIndex,this.tagname=t;var o=!this.options.xmlMode&&VD.get(t);if(o)for(;this.stack.length>0&&o.has(this.stack[this.stack.length-1]);){var s=this.stack.pop();(n=(r=this.cbs).onclosetag)===null||n===void 0||n.call(r,s,!0)}this.isVoidElement(t)||(this.stack.push(t),gm.has(t)?this.foreignContext.push(!0):bm.has(t)&&this.foreignContext.push(!1)),(a=(i=this.cbs).onopentagname)===null||a===void 0||a.call(i,t),this.cbs.onopentag&&(this.attribs={})},e.prototype.endOpenTag=function(t){var r,n;this.startIndex=this.openTagStart,this.attribs&&((n=(r=this.cbs).onopentag)===null||n===void 0||n.call(r,this.tagname,this.attribs,t),this.attribs=null),this.cbs.onclosetag&&this.isVoidElement(this.tagname)&&this.cbs.onclosetag(this.tagname,!0),this.tagname=""},e.prototype.onopentagend=function(t){this.endIndex=t,this.endOpenTag(!1),this.startIndex=t+1},e.prototype.onclosetag=function(t,r){var n,i,a,o,s,u;this.endIndex=r;var l=this.getSlice(t,r);if(this.lowerCaseTagNames&&(l=l.toLowerCase()),(gm.has(l)||bm.has(l))&&this.foreignContext.pop(),this.isVoidElement(l))!this.options.xmlMode&&l==="br"&&((i=(n=this.cbs).onopentagname)===null||i===void 0||i.call(n,"br"),(o=(a=this.cbs).onopentag)===null||o===void 0||o.call(a,"br",{},!0),(u=(s=this.cbs).onclosetag)===null||u===void 0||u.call(s,"br",!1));else{var c=this.stack.lastIndexOf(l);if(c!==-1)if(this.cbs.onclosetag)for(var f=this.stack.length-c;f--;)this.cbs.onclosetag(this.stack.pop(),f!==0);else this.stack.length=c;else!this.options.xmlMode&&l==="p"&&(this.emitOpenTag("p"),this.closeCurrentTag(!0))}this.startIndex=r+1},e.prototype.onselfclosingtag=function(t){this.endIndex=t,this.options.xmlMode||this.options.recognizeSelfClosing||this.foreignContext[this.foreignContext.length-1]?(this.closeCurrentTag(!1),this.startIndex=t+1):this.onopentagend(t)},e.prototype.closeCurrentTag=function(t){var r,n,i=this.tagname;this.endOpenTag(t),this.stack[this.stack.length-1]===i&&((n=(r=this.cbs).onclosetag)===null||n===void 0||n.call(r,i,!t),this.stack.pop())},e.prototype.onattribname=function(t,r){this.startIndex=t;var n=this.getSlice(t,r);this.attribname=this.lowerCaseAttributeNames?n.toLowerCase():n},e.prototype.onattribdata=function(t,r){this.attribvalue+=this.getSlice(t,r)},e.prototype.onattribentity=function(t){this.attribvalue+=(0,dm.fromCodePoint)(t)},e.prototype.onattribend=function(t,r){var n,i;this.endIndex=r,(i=(n=this.cbs).onattribute)===null||i===void 0||i.call(n,this.attribname,this.attribvalue,t===qo.QuoteType.Double?'"':t===qo.QuoteType.Single?"'":t===qo.QuoteType.NoValue?void 0:null),this.attribs&&!Object.prototype.hasOwnProperty.call(this.attribs,this.attribname)&&(this.attribs[this.attribname]=this.attribvalue),this.attribvalue=""},e.prototype.getInstructionName=function(t){var r=t.search(WD),n=r<0?t:t.substr(0,r);return this.lowerCaseTagNames&&(n=n.toLowerCase()),n},e.prototype.ondeclaration=function(t,r){this.endIndex=r;var n=this.getSlice(t,r);if(this.cbs.onprocessinginstruction){var i=this.getInstructionName(n);this.cbs.onprocessinginstruction("!".concat(i),"!".concat(n))}this.startIndex=r+1},e.prototype.onprocessinginstruction=function(t,r){this.endIndex=r;var n=this.getSlice(t,r);if(this.cbs.onprocessinginstruction){var i=this.getInstructionName(n);this.cbs.onprocessinginstruction("?".concat(i),"?".concat(n))}this.startIndex=r+1},e.prototype.oncomment=function(t,r,n){var i,a,o,s;this.endIndex=r,(a=(i=this.cbs).oncomment)===null||a===void 0||a.call(i,this.getSlice(t,r-n)),(s=(o=this.cbs).oncommentend)===null||s===void 0||s.call(o),this.startIndex=r+1},e.prototype.oncdata=function(t,r,n){var i,a,o,s,u,l,c,f,d,h;this.endIndex=r;var p=this.getSlice(t,r-n);this.options.xmlMode||this.options.recognizeCDATA?((a=(i=this.cbs).oncdatastart)===null||a===void 0||a.call(i),(s=(o=this.cbs).ontext)===null||s===void 0||s.call(o,p),(l=(u=this.cbs).oncdataend)===null||l===void 0||l.call(u)):((f=(c=this.cbs).oncomment)===null||f===void 0||f.call(c,"[CDATA[".concat(p,"]]")),(h=(d=this.cbs).oncommentend)===null||h===void 0||h.call(d)),this.startIndex=r+1},e.prototype.onend=function(){var t,r;if(this.cbs.onclosetag){this.endIndex=this.startIndex;for(var n=this.stack.length;n>0;this.cbs.onclosetag(this.stack[--n],!0));}(r=(t=this.cbs).onend)===null||r===void 0||r.call(t)},e.prototype.reset=function(){var t,r,n,i;(r=(t=this.cbs).onreset)===null||r===void 0||r.call(t),this.tokenizer.reset(),this.tagname="",this.attribname="",this.attribs=null,this.stack.length=0,this.startIndex=0,this.endIndex=0,(i=(n=this.cbs).onparserinit)===null||i===void 0||i.call(n,this),this.buffers.length=0,this.bufferOffset=0,this.writeIndex=0,this.ended=!1},e.prototype.parseComplete=function(t){this.reset(),this.end(t)},e.prototype.getSlice=function(t,r){for(;t-this.bufferOffset>=this.buffers[0].length;)this.shiftBuffer();for(var n=this.buffers[0].slice(t-this.bufferOffset,r-this.bufferOffset);r-this.bufferOffset>this.buffers[0].length;)this.shiftBuffer(),n+=this.buffers[0].slice(0,r-this.bufferOffset);return n},e.prototype.shiftBuffer=function(){this.bufferOffset+=this.buffers[0].length,this.writeIndex--,this.buffers.shift()},e.prototype.write=function(t){var r,n;if(this.ended){(n=(r=this.cbs).onerror)===null||n===void 0||n.call(r,new Error(".write() after done!"));return}this.buffers.push(t),this.tokenizer.running&&(this.tokenizer.write(t),this.writeIndex++)},e.prototype.end=function(t){var r,n;if(this.ended){(n=(r=this.cbs).onerror)===null||n===void 0||n.call(r,new Error(".end() after done!"));return}t&&this.write(t),this.ended=!0,this.tokenizer.end()},e.prototype.pause=function(){this.tokenizer.pause()},e.prototype.resume=function(){for(this.tokenizer.resume();this.tokenizer.running&&this.writeIndex<this.buffers.length;)this.tokenizer.write(this.buffers[this.writeIndex++]);this.ended&&this.tokenizer.end()},e.prototype.parseChunk=function(t){this.write(t)},e.prototype.done=function(t){this.end(t)},e}();Ba.Parser=KD;var hn={},ia={};(function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.Doctype=e.CDATA=e.Tag=e.Style=e.Script=e.Comment=e.Directive=e.Text=e.Root=e.isTag=e.ElementType=void 0;var t;(function(n){n.Root="root",n.Text="text",n.Directive="directive",n.Comment="comment",n.Script="script",n.Style="style",n.Tag="tag",n.CDATA="cdata",n.Doctype="doctype"})(t=e.ElementType||(e.ElementType={}));function r(n){return n.type===t.Tag||n.type===t.Script||n.type===t.Style}e.isTag=r,e.Root=t.Root,e.Text=t.Text,e.Directive=t.Directive,e.Comment=t.Comment,e.Script=t.Script,e.Style=t.Style,e.Tag=t.Tag,e.CDATA=t.CDATA,e.Doctype=t.Doctype})(ia);var Re={},Hn=xe&&xe.__extends||function(){var e=function(t,r){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(n,i){n.__proto__=i}||function(n,i){for(var a in i)Object.prototype.hasOwnProperty.call(i,a)&&(n[a]=i[a])},e(t,r)};return function(t,r){if(typeof r!="function"&&r!==null)throw new TypeError("Class extends value "+String(r)+" is not a constructor or null");e(t,r);function n(){this.constructor=t}t.prototype=r===null?Object.create(r):(n.prototype=r.prototype,new n)}}(),Aa=xe&&xe.__assign||function(){return Aa=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++){t=arguments[r];for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])}return e},Aa.apply(this,arguments)};Object.defineProperty(Re,"__esModule",{value:!0});Re.cloneNode=Re.hasChildren=Re.isDocument=Re.isDirective=Re.isComment=Re.isText=Re.isCDATA=Re.isTag=Re.Element=Re.Document=Re.CDATA=Re.NodeWithChildren=Re.ProcessingInstruction=Re.Comment=Re.Text=Re.DataNode=Re.Node=void 0;var Vt=ia,bd=function(){function e(){this.parent=null,this.prev=null,this.next=null,this.startIndex=null,this.endIndex=null}return Object.defineProperty(e.prototype,"parentNode",{get:function(){return this.parent},set:function(t){this.parent=t},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"previousSibling",{get:function(){return this.prev},set:function(t){this.prev=t},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"nextSibling",{get:function(){return this.next},set:function(t){this.next=t},enumerable:!1,configurable:!0}),e.prototype.cloneNode=function(t){return t===void 0&&(t=!1),vd(this,t)},e}();Re.Node=bd;var Du=function(e){Hn(t,e);function t(r){var n=e.call(this)||this;return n.data=r,n}return Object.defineProperty(t.prototype,"nodeValue",{get:function(){return this.data},set:function(r){this.data=r},enumerable:!1,configurable:!0}),t}(bd);Re.DataNode=Du;var iv=function(e){Hn(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=Vt.ElementType.Text,r}return Object.defineProperty(t.prototype,"nodeType",{get:function(){return 3},enumerable:!1,configurable:!0}),t}(Du);Re.Text=iv;var av=function(e){Hn(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=Vt.ElementType.Comment,r}return Object.defineProperty(t.prototype,"nodeType",{get:function(){return 8},enumerable:!1,configurable:!0}),t}(Du);Re.Comment=av;var ov=function(e){Hn(t,e);function t(r,n){var i=e.call(this,n)||this;return i.name=r,i.type=Vt.ElementType.Directive,i}return Object.defineProperty(t.prototype,"nodeType",{get:function(){return 1},enumerable:!1,configurable:!0}),t}(Du);Re.ProcessingInstruction=ov;var Lu=function(e){Hn(t,e);function t(r){var n=e.call(this)||this;return n.children=r,n}return Object.defineProperty(t.prototype,"firstChild",{get:function(){var r;return(r=this.children[0])!==null&&r!==void 0?r:null},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"lastChild",{get:function(){return this.children.length>0?this.children[this.children.length-1]:null},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"childNodes",{get:function(){return this.children},set:function(r){this.children=r},enumerable:!1,configurable:!0}),t}(bd);Re.NodeWithChildren=Lu;var sv=function(e){Hn(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=Vt.ElementType.CDATA,r}return Object.defineProperty(t.prototype,"nodeType",{get:function(){return 4},enumerable:!1,configurable:!0}),t}(Lu);Re.CDATA=sv;var uv=function(e){Hn(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=Vt.ElementType.Root,r}return Object.defineProperty(t.prototype,"nodeType",{get:function(){return 9},enumerable:!1,configurable:!0}),t}(Lu);Re.Document=uv;var lv=function(e){Hn(t,e);function t(r,n,i,a){i===void 0&&(i=[]),a===void 0&&(a=r==="script"?Vt.ElementType.Script:r==="style"?Vt.ElementType.Style:Vt.ElementType.Tag);var o=e.call(this,i)||this;return o.name=r,o.attribs=n,o.type=a,o}return Object.defineProperty(t.prototype,"nodeType",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"tagName",{get:function(){return this.name},set:function(r){this.name=r},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"attributes",{get:function(){var r=this;return Object.keys(this.attribs).map(function(n){var i,a;return{name:n,value:r.attribs[n],namespace:(i=r["x-attribsNamespace"])===null||i===void 0?void 0:i[n],prefix:(a=r["x-attribsPrefix"])===null||a===void 0?void 0:a[n]}})},enumerable:!1,configurable:!0}),t}(Lu);Re.Element=lv;function cv(e){return(0,Vt.isTag)(e)}Re.isTag=cv;function fv(e){return e.type===Vt.ElementType.CDATA}Re.isCDATA=fv;function dv(e){return e.type===Vt.ElementType.Text}Re.isText=dv;function hv(e){return e.type===Vt.ElementType.Comment}Re.isComment=hv;function pv(e){return e.type===Vt.ElementType.Directive}Re.isDirective=pv;function mv(e){return e.type===Vt.ElementType.Root}Re.isDocument=mv;function XD(e){return Object.prototype.hasOwnProperty.call(e,"children")}Re.hasChildren=XD;function vd(e,t){t===void 0&&(t=!1);var r;if(dv(e))r=new iv(e.data);else if(hv(e))r=new av(e.data);else if(cv(e)){var n=t?s0(e.children):[],i=new lv(e.name,Aa({},e.attribs),n);n.forEach(function(u){return u.parent=i}),e.namespace!=null&&(i.namespace=e.namespace),e["x-attribsNamespace"]&&(i["x-attribsNamespace"]=Aa({},e["x-attribsNamespace"])),e["x-attribsPrefix"]&&(i["x-attribsPrefix"]=Aa({},e["x-attribsPrefix"])),r=i}else if(fv(e)){var n=t?s0(e.children):[],a=new sv(n);n.forEach(function(l){return l.parent=a}),r=a}else if(mv(e)){var n=t?s0(e.children):[],o=new uv(n);n.forEach(function(l){return l.parent=o}),e["x-mode"]&&(o["x-mode"]=e["x-mode"]),r=o}else if(pv(e)){var s=new ov(e.name,e.data);e["x-name"]!=null&&(s["x-name"]=e["x-name"],s["x-publicId"]=e["x-publicId"],s["x-systemId"]=e["x-systemId"]),r=s}else throw new Error("Not implemented yet: ".concat(e.type));return r.startIndex=e.startIndex,r.endIndex=e.endIndex,e.sourceCodeLocation!=null&&(r.sourceCodeLocation=e.sourceCodeLocation),r}Re.cloneNode=vd;function s0(e){for(var t=e.map(function(n){return vd(n,!0)}),r=1;r<t.length;r++)t[r].prev=t[r-1],t[r-1].next=t[r];return t}(function(e){var t=xe&&xe.__createBinding||(Object.create?function(s,u,l,c){c===void 0&&(c=l);var f=Object.getOwnPropertyDescriptor(u,l);(!f||("get"in f?!u.__esModule:f.writable||f.configurable))&&(f={enumerable:!0,get:function(){return u[l]}}),Object.defineProperty(s,c,f)}:function(s,u,l,c){c===void 0&&(c=l),s[c]=u[l]}),r=xe&&xe.__exportStar||function(s,u){for(var l in s)l!=="default"&&!Object.prototype.hasOwnProperty.call(u,l)&&t(u,s,l)};Object.defineProperty(e,"__esModule",{value:!0}),e.DomHandler=void 0;var n=ia,i=Re;r(Re,e);var a={withStartIndices:!1,withEndIndices:!1,xmlMode:!1},o=function(){function s(u,l,c){this.dom=[],this.root=new i.Document(this.dom),this.done=!1,this.tagStack=[this.root],this.lastNode=null,this.parser=null,typeof l=="function"&&(c=l,l=a),typeof u=="object"&&(l=u,u=void 0),this.callback=u??null,this.options=l??a,this.elementCB=c??null}return s.prototype.onparserinit=function(u){this.parser=u},s.prototype.onreset=function(){this.dom=[],this.root=new i.Document(this.dom),this.done=!1,this.tagStack=[this.root],this.lastNode=null,this.parser=null},s.prototype.onend=function(){this.done||(this.done=!0,this.parser=null,this.handleCallback(null))},s.prototype.onerror=function(u){this.handleCallback(u)},s.prototype.onclosetag=function(){this.lastNode=null;var u=this.tagStack.pop();this.options.withEndIndices&&(u.endIndex=this.parser.endIndex),this.elementCB&&this.elementCB(u)},s.prototype.onopentag=function(u,l){var c=this.options.xmlMode?n.ElementType.Tag:void 0,f=new i.Element(u,l,void 0,c);this.addNode(f),this.tagStack.push(f)},s.prototype.ontext=function(u){var l=this.lastNode;if(l&&l.type===n.ElementType.Text)l.data+=u,this.options.withEndIndices&&(l.endIndex=this.parser.endIndex);else{var c=new i.Text(u);this.addNode(c),this.lastNode=c}},s.prototype.oncomment=function(u){if(this.lastNode&&this.lastNode.type===n.ElementType.Comment){this.lastNode.data+=u;return}var l=new i.Comment(u);this.addNode(l),this.lastNode=l},s.prototype.oncommentend=function(){this.lastNode=null},s.prototype.oncdatastart=function(){var u=new i.Text(""),l=new i.CDATA([u]);this.addNode(l),u.parent=l,this.lastNode=u},s.prototype.oncdataend=function(){this.lastNode=null},s.prototype.onprocessinginstruction=function(u,l){var c=new i.ProcessingInstruction(u,l);this.addNode(c)},s.prototype.handleCallback=function(u){if(typeof this.callback=="function")this.callback(u,this.dom);else if(u)throw u},s.prototype.addNode=function(u){var l=this.tagStack[this.tagStack.length-1],c=l.children[l.children.length-1];this.options.withStartIndices&&(u.startIndex=this.parser.startIndex),this.options.withEndIndices&&(u.endIndex=this.parser.endIndex),l.children.push(u),c&&(u.prev=c,c.next=u),u.parent=l,this.lastNode=null},s}();e.DomHandler=o,e.default=o})(hn);var bs={},er={},so={},gv={},si={},yd={};Object.defineProperty(yd,"__esModule",{value:!0});function jo(e){for(var t=1;t<e.length;t++)e[t][0]+=e[t-1][0]+1;return e}yd.default=new Map(jo([[9,"&Tab;"],[0,"&NewLine;"],[22,"&excl;"],[0,"&quot;"],[0,"&num;"],[0,"&dollar;"],[0,"&percnt;"],[0,"&amp;"],[0,"&apos;"],[0,"&lpar;"],[0,"&rpar;"],[0,"&ast;"],[0,"&plus;"],[0,"&comma;"],[1,"&period;"],[0,"&sol;"],[10,"&colon;"],[0,"&semi;"],[0,{v:"&lt;",n:8402,o:"&nvlt;"}],[0,{v:"&equals;",n:8421,o:"&bne;"}],[0,{v:"&gt;",n:8402,o:"&nvgt;"}],[0,"&quest;"],[0,"&commat;"],[26,"&lbrack;"],[0,"&bsol;"],[0,"&rbrack;"],[0,"&Hat;"],[0,"&lowbar;"],[0,"&DiacriticalGrave;"],[5,{n:106,o:"&fjlig;"}],[20,"&lbrace;"],[0,"&verbar;"],[0,"&rbrace;"],[34,"&nbsp;"],[0,"&iexcl;"],[0,"&cent;"],[0,"&pound;"],[0,"&curren;"],[0,"&yen;"],[0,"&brvbar;"],[0,"&sect;"],[0,"&die;"],[0,"&copy;"],[0,"&ordf;"],[0,"&laquo;"],[0,"&not;"],[0,"&shy;"],[0,"&circledR;"],[0,"&macr;"],[0,"&deg;"],[0,"&PlusMinus;"],[0,"&sup2;"],[0,"&sup3;"],[0,"&acute;"],[0,"&micro;"],[0,"&para;"],[0,"&centerdot;"],[0,"&cedil;"],[0,"&sup1;"],[0,"&ordm;"],[0,"&raquo;"],[0,"&frac14;"],[0,"&frac12;"],[0,"&frac34;"],[0,"&iquest;"],[0,"&Agrave;"],[0,"&Aacute;"],[0,"&Acirc;"],[0,"&Atilde;"],[0,"&Auml;"],[0,"&angst;"],[0,"&AElig;"],[0,"&Ccedil;"],[0,"&Egrave;"],[0,"&Eacute;"],[0,"&Ecirc;"],[0,"&Euml;"],[0,"&Igrave;"],[0,"&Iacute;"],[0,"&Icirc;"],[0,"&Iuml;"],[0,"&ETH;"],[0,"&Ntilde;"],[0,"&Ograve;"],[0,"&Oacute;"],[0,"&Ocirc;"],[0,"&Otilde;"],[0,"&Ouml;"],[0,"&times;"],[0,"&Oslash;"],[0,"&Ugrave;"],[0,"&Uacute;"],[0,"&Ucirc;"],[0,"&Uuml;"],[0,"&Yacute;"],[0,"&THORN;"],[0,"&szlig;"],[0,"&agrave;"],[0,"&aacute;"],[0,"&acirc;"],[0,"&atilde;"],[0,"&auml;"],[0,"&aring;"],[0,"&aelig;"],[0,"&ccedil;"],[0,"&egrave;"],[0,"&eacute;"],[0,"&ecirc;"],[0,"&euml;"],[0,"&igrave;"],[0,"&iacute;"],[0,"&icirc;"],[0,"&iuml;"],[0,"&eth;"],[0,"&ntilde;"],[0,"&ograve;"],[0,"&oacute;"],[0,"&ocirc;"],[0,"&otilde;"],[0,"&ouml;"],[0,"&div;"],[0,"&oslash;"],[0,"&ugrave;"],[0,"&uacute;"],[0,"&ucirc;"],[0,"&uuml;"],[0,"&yacute;"],[0,"&thorn;"],[0,"&yuml;"],[0,"&Amacr;"],[0,"&amacr;"],[0,"&Abreve;"],[0,"&abreve;"],[0,"&Aogon;"],[0,"&aogon;"],[0,"&Cacute;"],[0,"&cacute;"],[0,"&Ccirc;"],[0,"&ccirc;"],[0,"&Cdot;"],[0,"&cdot;"],[0,"&Ccaron;"],[0,"&ccaron;"],[0,"&Dcaron;"],[0,"&dcaron;"],[0,"&Dstrok;"],[0,"&dstrok;"],[0,"&Emacr;"],[0,"&emacr;"],[2,"&Edot;"],[0,"&edot;"],[0,"&Eogon;"],[0,"&eogon;"],[0,"&Ecaron;"],[0,"&ecaron;"],[0,"&Gcirc;"],[0,"&gcirc;"],[0,"&Gbreve;"],[0,"&gbreve;"],[0,"&Gdot;"],[0,"&gdot;"],[0,"&Gcedil;"],[1,"&Hcirc;"],[0,"&hcirc;"],[0,"&Hstrok;"],[0,"&hstrok;"],[0,"&Itilde;"],[0,"&itilde;"],[0,"&Imacr;"],[0,"&imacr;"],[2,"&Iogon;"],[0,"&iogon;"],[0,"&Idot;"],[0,"&imath;"],[0,"&IJlig;"],[0,"&ijlig;"],[0,"&Jcirc;"],[0,"&jcirc;"],[0,"&Kcedil;"],[0,"&kcedil;"],[0,"&kgreen;"],[0,"&Lacute;"],[0,"&lacute;"],[0,"&Lcedil;"],[0,"&lcedil;"],[0,"&Lcaron;"],[0,"&lcaron;"],[0,"&Lmidot;"],[0,"&lmidot;"],[0,"&Lstrok;"],[0,"&lstrok;"],[0,"&Nacute;"],[0,"&nacute;"],[0,"&Ncedil;"],[0,"&ncedil;"],[0,"&Ncaron;"],[0,"&ncaron;"],[0,"&napos;"],[0,"&ENG;"],[0,"&eng;"],[0,"&Omacr;"],[0,"&omacr;"],[2,"&Odblac;"],[0,"&odblac;"],[0,"&OElig;"],[0,"&oelig;"],[0,"&Racute;"],[0,"&racute;"],[0,"&Rcedil;"],[0,"&rcedil;"],[0,"&Rcaron;"],[0,"&rcaron;"],[0,"&Sacute;"],[0,"&sacute;"],[0,"&Scirc;"],[0,"&scirc;"],[0,"&Scedil;"],[0,"&scedil;"],[0,"&Scaron;"],[0,"&scaron;"],[0,"&Tcedil;"],[0,"&tcedil;"],[0,"&Tcaron;"],[0,"&tcaron;"],[0,"&Tstrok;"],[0,"&tstrok;"],[0,"&Utilde;"],[0,"&utilde;"],[0,"&Umacr;"],[0,"&umacr;"],[0,"&Ubreve;"],[0,"&ubreve;"],[0,"&Uring;"],[0,"&uring;"],[0,"&Udblac;"],[0,"&udblac;"],[0,"&Uogon;"],[0,"&uogon;"],[0,"&Wcirc;"],[0,"&wcirc;"],[0,"&Ycirc;"],[0,"&ycirc;"],[0,"&Yuml;"],[0,"&Zacute;"],[0,"&zacute;"],[0,"&Zdot;"],[0,"&zdot;"],[0,"&Zcaron;"],[0,"&zcaron;"],[19,"&fnof;"],[34,"&imped;"],[63,"&gacute;"],[65,"&jmath;"],[142,"&circ;"],[0,"&caron;"],[16,"&breve;"],[0,"&DiacriticalDot;"],[0,"&ring;"],[0,"&ogon;"],[0,"&DiacriticalTilde;"],[0,"&dblac;"],[51,"&DownBreve;"],[127,"&Alpha;"],[0,"&Beta;"],[0,"&Gamma;"],[0,"&Delta;"],[0,"&Epsilon;"],[0,"&Zeta;"],[0,"&Eta;"],[0,"&Theta;"],[0,"&Iota;"],[0,"&Kappa;"],[0,"&Lambda;"],[0,"&Mu;"],[0,"&Nu;"],[0,"&Xi;"],[0,"&Omicron;"],[0,"&Pi;"],[0,"&Rho;"],[1,"&Sigma;"],[0,"&Tau;"],[0,"&Upsilon;"],[0,"&Phi;"],[0,"&Chi;"],[0,"&Psi;"],[0,"&ohm;"],[7,"&alpha;"],[0,"&beta;"],[0,"&gamma;"],[0,"&delta;"],[0,"&epsi;"],[0,"&zeta;"],[0,"&eta;"],[0,"&theta;"],[0,"&iota;"],[0,"&kappa;"],[0,"&lambda;"],[0,"&mu;"],[0,"&nu;"],[0,"&xi;"],[0,"&omicron;"],[0,"&pi;"],[0,"&rho;"],[0,"&sigmaf;"],[0,"&sigma;"],[0,"&tau;"],[0,"&upsi;"],[0,"&phi;"],[0,"&chi;"],[0,"&psi;"],[0,"&omega;"],[7,"&thetasym;"],[0,"&Upsi;"],[2,"&phiv;"],[0,"&piv;"],[5,"&Gammad;"],[0,"&digamma;"],[18,"&kappav;"],[0,"&rhov;"],[3,"&epsiv;"],[0,"&backepsilon;"],[10,"&IOcy;"],[0,"&DJcy;"],[0,"&GJcy;"],[0,"&Jukcy;"],[0,"&DScy;"],[0,"&Iukcy;"],[0,"&YIcy;"],[0,"&Jsercy;"],[0,"&LJcy;"],[0,"&NJcy;"],[0,"&TSHcy;"],[0,"&KJcy;"],[1,"&Ubrcy;"],[0,"&DZcy;"],[0,"&Acy;"],[0,"&Bcy;"],[0,"&Vcy;"],[0,"&Gcy;"],[0,"&Dcy;"],[0,"&IEcy;"],[0,"&ZHcy;"],[0,"&Zcy;"],[0,"&Icy;"],[0,"&Jcy;"],[0,"&Kcy;"],[0,"&Lcy;"],[0,"&Mcy;"],[0,"&Ncy;"],[0,"&Ocy;"],[0,"&Pcy;"],[0,"&Rcy;"],[0,"&Scy;"],[0,"&Tcy;"],[0,"&Ucy;"],[0,"&Fcy;"],[0,"&KHcy;"],[0,"&TScy;"],[0,"&CHcy;"],[0,"&SHcy;"],[0,"&SHCHcy;"],[0,"&HARDcy;"],[0,"&Ycy;"],[0,"&SOFTcy;"],[0,"&Ecy;"],[0,"&YUcy;"],[0,"&YAcy;"],[0,"&acy;"],[0,"&bcy;"],[0,"&vcy;"],[0,"&gcy;"],[0,"&dcy;"],[0,"&iecy;"],[0,"&zhcy;"],[0,"&zcy;"],[0,"&icy;"],[0,"&jcy;"],[0,"&kcy;"],[0,"&lcy;"],[0,"&mcy;"],[0,"&ncy;"],[0,"&ocy;"],[0,"&pcy;"],[0,"&rcy;"],[0,"&scy;"],[0,"&tcy;"],[0,"&ucy;"],[0,"&fcy;"],[0,"&khcy;"],[0,"&tscy;"],[0,"&chcy;"],[0,"&shcy;"],[0,"&shchcy;"],[0,"&hardcy;"],[0,"&ycy;"],[0,"&softcy;"],[0,"&ecy;"],[0,"&yucy;"],[0,"&yacy;"],[1,"&iocy;"],[0,"&djcy;"],[0,"&gjcy;"],[0,"&jukcy;"],[0,"&dscy;"],[0,"&iukcy;"],[0,"&yicy;"],[0,"&jsercy;"],[0,"&ljcy;"],[0,"&njcy;"],[0,"&tshcy;"],[0,"&kjcy;"],[1,"&ubrcy;"],[0,"&dzcy;"],[7074,"&ensp;"],[0,"&emsp;"],[0,"&emsp13;"],[0,"&emsp14;"],[1,"&numsp;"],[0,"&puncsp;"],[0,"&ThinSpace;"],[0,"&hairsp;"],[0,"&NegativeMediumSpace;"],[0,"&zwnj;"],[0,"&zwj;"],[0,"&lrm;"],[0,"&rlm;"],[0,"&dash;"],[2,"&ndash;"],[0,"&mdash;"],[0,"&horbar;"],[0,"&Verbar;"],[1,"&lsquo;"],[0,"&CloseCurlyQuote;"],[0,"&lsquor;"],[1,"&ldquo;"],[0,"&CloseCurlyDoubleQuote;"],[0,"&bdquo;"],[1,"&dagger;"],[0,"&Dagger;"],[0,"&bull;"],[2,"&nldr;"],[0,"&hellip;"],[9,"&permil;"],[0,"&pertenk;"],[0,"&prime;"],[0,"&Prime;"],[0,"&tprime;"],[0,"&backprime;"],[3,"&lsaquo;"],[0,"&rsaquo;"],[3,"&oline;"],[2,"&caret;"],[1,"&hybull;"],[0,"&frasl;"],[10,"&bsemi;"],[7,"&qprime;"],[7,{v:"&MediumSpace;",n:8202,o:"&ThickSpace;"}],[0,"&NoBreak;"],[0,"&af;"],[0,"&InvisibleTimes;"],[0,"&ic;"],[72,"&euro;"],[46,"&tdot;"],[0,"&DotDot;"],[37,"&complexes;"],[2,"&incare;"],[4,"&gscr;"],[0,"&hamilt;"],[0,"&Hfr;"],[0,"&Hopf;"],[0,"&planckh;"],[0,"&hbar;"],[0,"&imagline;"],[0,"&Ifr;"],[0,"&lagran;"],[0,"&ell;"],[1,"&naturals;"],[0,"&numero;"],[0,"&copysr;"],[0,"&weierp;"],[0,"&Popf;"],[0,"&Qopf;"],[0,"&realine;"],[0,"&real;"],[0,"&reals;"],[0,"&rx;"],[3,"&trade;"],[1,"&integers;"],[2,"&mho;"],[0,"&zeetrf;"],[0,"&iiota;"],[2,"&bernou;"],[0,"&Cayleys;"],[1,"&escr;"],[0,"&Escr;"],[0,"&Fouriertrf;"],[1,"&Mellintrf;"],[0,"&order;"],[0,"&alefsym;"],[0,"&beth;"],[0,"&gimel;"],[0,"&daleth;"],[12,"&CapitalDifferentialD;"],[0,"&dd;"],[0,"&ee;"],[0,"&ii;"],[10,"&frac13;"],[0,"&frac23;"],[0,"&frac15;"],[0,"&frac25;"],[0,"&frac35;"],[0,"&frac45;"],[0,"&frac16;"],[0,"&frac56;"],[0,"&frac18;"],[0,"&frac38;"],[0,"&frac58;"],[0,"&frac78;"],[49,"&larr;"],[0,"&ShortUpArrow;"],[0,"&rarr;"],[0,"&darr;"],[0,"&harr;"],[0,"&updownarrow;"],[0,"&nwarr;"],[0,"&nearr;"],[0,"&LowerRightArrow;"],[0,"&LowerLeftArrow;"],[0,"&nlarr;"],[0,"&nrarr;"],[1,{v:"&rarrw;",n:824,o:"&nrarrw;"}],[0,"&Larr;"],[0,"&Uarr;"],[0,"&Rarr;"],[0,"&Darr;"],[0,"&larrtl;"],[0,"&rarrtl;"],[0,"&LeftTeeArrow;"],[0,"&mapstoup;"],[0,"&map;"],[0,"&DownTeeArrow;"],[1,"&hookleftarrow;"],[0,"&hookrightarrow;"],[0,"&larrlp;"],[0,"&looparrowright;"],[0,"&harrw;"],[0,"&nharr;"],[1,"&lsh;"],[0,"&rsh;"],[0,"&ldsh;"],[0,"&rdsh;"],[1,"&crarr;"],[0,"&cularr;"],[0,"&curarr;"],[2,"&circlearrowleft;"],[0,"&circlearrowright;"],[0,"&leftharpoonup;"],[0,"&DownLeftVector;"],[0,"&RightUpVector;"],[0,"&LeftUpVector;"],[0,"&rharu;"],[0,"&DownRightVector;"],[0,"&dharr;"],[0,"&dharl;"],[0,"&RightArrowLeftArrow;"],[0,"&udarr;"],[0,"&LeftArrowRightArrow;"],[0,"&leftleftarrows;"],[0,"&upuparrows;"],[0,"&rightrightarrows;"],[0,"&ddarr;"],[0,"&leftrightharpoons;"],[0,"&Equilibrium;"],[0,"&nlArr;"],[0,"&nhArr;"],[0,"&nrArr;"],[0,"&DoubleLeftArrow;"],[0,"&DoubleUpArrow;"],[0,"&DoubleRightArrow;"],[0,"&dArr;"],[0,"&DoubleLeftRightArrow;"],[0,"&DoubleUpDownArrow;"],[0,"&nwArr;"],[0,"&neArr;"],[0,"&seArr;"],[0,"&swArr;"],[0,"&lAarr;"],[0,"&rAarr;"],[1,"&zigrarr;"],[6,"&larrb;"],[0,"&rarrb;"],[15,"&DownArrowUpArrow;"],[7,"&loarr;"],[0,"&roarr;"],[0,"&hoarr;"],[0,"&forall;"],[0,"&comp;"],[0,{v:"&part;",n:824,o:"&npart;"}],[0,"&exist;"],[0,"&nexist;"],[0,"&empty;"],[1,"&Del;"],[0,"&Element;"],[0,"&NotElement;"],[1,"&ni;"],[0,"&notni;"],[2,"&prod;"],[0,"&coprod;"],[0,"&sum;"],[0,"&minus;"],[0,"&MinusPlus;"],[0,"&dotplus;"],[1,"&Backslash;"],[0,"&lowast;"],[0,"&compfn;"],[1,"&radic;"],[2,"&prop;"],[0,"&infin;"],[0,"&angrt;"],[0,{v:"&ang;",n:8402,o:"&nang;"}],[0,"&angmsd;"],[0,"&angsph;"],[0,"&mid;"],[0,"&nmid;"],[0,"&DoubleVerticalBar;"],[0,"&NotDoubleVerticalBar;"],[0,"&and;"],[0,"&or;"],[0,{v:"&cap;",n:65024,o:"&caps;"}],[0,{v:"&cup;",n:65024,o:"&cups;"}],[0,"&int;"],[0,"&Int;"],[0,"&iiint;"],[0,"&conint;"],[0,"&Conint;"],[0,"&Cconint;"],[0,"&cwint;"],[0,"&ClockwiseContourIntegral;"],[0,"&awconint;"],[0,"&there4;"],[0,"&becaus;"],[0,"&ratio;"],[0,"&Colon;"],[0,"&dotminus;"],[1,"&mDDot;"],[0,"&homtht;"],[0,{v:"&sim;",n:8402,o:"&nvsim;"}],[0,{v:"&backsim;",n:817,o:"&race;"}],[0,{v:"&ac;",n:819,o:"&acE;"}],[0,"&acd;"],[0,"&VerticalTilde;"],[0,"&NotTilde;"],[0,{v:"&eqsim;",n:824,o:"&nesim;"}],[0,"&sime;"],[0,"&NotTildeEqual;"],[0,"&cong;"],[0,"&simne;"],[0,"&ncong;"],[0,"&ap;"],[0,"&nap;"],[0,"&ape;"],[0,{v:"&apid;",n:824,o:"&napid;"}],[0,"&backcong;"],[0,{v:"&asympeq;",n:8402,o:"&nvap;"}],[0,{v:"&bump;",n:824,o:"&nbump;"}],[0,{v:"&bumpe;",n:824,o:"&nbumpe;"}],[0,{v:"&doteq;",n:824,o:"&nedot;"}],[0,"&doteqdot;"],[0,"&efDot;"],[0,"&erDot;"],[0,"&Assign;"],[0,"&ecolon;"],[0,"&ecir;"],[0,"&circeq;"],[1,"&wedgeq;"],[0,"&veeeq;"],[1,"&triangleq;"],[2,"&equest;"],[0,"&ne;"],[0,{v:"&Congruent;",n:8421,o:"&bnequiv;"}],[0,"&nequiv;"],[1,{v:"&le;",n:8402,o:"&nvle;"}],[0,{v:"&ge;",n:8402,o:"&nvge;"}],[0,{v:"&lE;",n:824,o:"&nlE;"}],[0,{v:"&gE;",n:824,o:"&ngE;"}],[0,{v:"&lnE;",n:65024,o:"&lvertneqq;"}],[0,{v:"&gnE;",n:65024,o:"&gvertneqq;"}],[0,{v:"&ll;",n:new Map(jo([[824,"&nLtv;"],[7577,"&nLt;"]]))}],[0,{v:"&gg;",n:new Map(jo([[824,"&nGtv;"],[7577,"&nGt;"]]))}],[0,"&between;"],[0,"&NotCupCap;"],[0,"&nless;"],[0,"&ngt;"],[0,"&nle;"],[0,"&nge;"],[0,"&lesssim;"],[0,"&GreaterTilde;"],[0,"&nlsim;"],[0,"&ngsim;"],[0,"&LessGreater;"],[0,"&gl;"],[0,"&NotLessGreater;"],[0,"&NotGreaterLess;"],[0,"&pr;"],[0,"&sc;"],[0,"&prcue;"],[0,"&sccue;"],[0,"&PrecedesTilde;"],[0,{v:"&scsim;",n:824,o:"&NotSucceedsTilde;"}],[0,"&NotPrecedes;"],[0,"&NotSucceeds;"],[0,{v:"&sub;",n:8402,o:"&NotSubset;"}],[0,{v:"&sup;",n:8402,o:"&NotSuperset;"}],[0,"&nsub;"],[0,"&nsup;"],[0,"&sube;"],[0,"&supe;"],[0,"&NotSubsetEqual;"],[0,"&NotSupersetEqual;"],[0,{v:"&subne;",n:65024,o:"&varsubsetneq;"}],[0,{v:"&supne;",n:65024,o:"&varsupsetneq;"}],[1,"&cupdot;"],[0,"&UnionPlus;"],[0,{v:"&sqsub;",n:824,o:"&NotSquareSubset;"}],[0,{v:"&sqsup;",n:824,o:"&NotSquareSuperset;"}],[0,"&sqsube;"],[0,"&sqsupe;"],[0,{v:"&sqcap;",n:65024,o:"&sqcaps;"}],[0,{v:"&sqcup;",n:65024,o:"&sqcups;"}],[0,"&CirclePlus;"],[0,"&CircleMinus;"],[0,"&CircleTimes;"],[0,"&osol;"],[0,"&CircleDot;"],[0,"&circledcirc;"],[0,"&circledast;"],[1,"&circleddash;"],[0,"&boxplus;"],[0,"&boxminus;"],[0,"&boxtimes;"],[0,"&dotsquare;"],[0,"&RightTee;"],[0,"&dashv;"],[0,"&DownTee;"],[0,"&bot;"],[1,"&models;"],[0,"&DoubleRightTee;"],[0,"&Vdash;"],[0,"&Vvdash;"],[0,"&VDash;"],[0,"&nvdash;"],[0,"&nvDash;"],[0,"&nVdash;"],[0,"&nVDash;"],[0,"&prurel;"],[1,"&LeftTriangle;"],[0,"&RightTriangle;"],[0,{v:"&LeftTriangleEqual;",n:8402,o:"&nvltrie;"}],[0,{v:"&RightTriangleEqual;",n:8402,o:"&nvrtrie;"}],[0,"&origof;"],[0,"&imof;"],[0,"&multimap;"],[0,"&hercon;"],[0,"&intcal;"],[0,"&veebar;"],[1,"&barvee;"],[0,"&angrtvb;"],[0,"&lrtri;"],[0,"&bigwedge;"],[0,"&bigvee;"],[0,"&bigcap;"],[0,"&bigcup;"],[0,"&diam;"],[0,"&sdot;"],[0,"&sstarf;"],[0,"&divideontimes;"],[0,"&bowtie;"],[0,"&ltimes;"],[0,"&rtimes;"],[0,"&leftthreetimes;"],[0,"&rightthreetimes;"],[0,"&backsimeq;"],[0,"&curlyvee;"],[0,"&curlywedge;"],[0,"&Sub;"],[0,"&Sup;"],[0,"&Cap;"],[0,"&Cup;"],[0,"&fork;"],[0,"&epar;"],[0,"&lessdot;"],[0,"&gtdot;"],[0,{v:"&Ll;",n:824,o:"&nLl;"}],[0,{v:"&Gg;",n:824,o:"&nGg;"}],[0,{v:"&leg;",n:65024,o:"&lesg;"}],[0,{v:"&gel;",n:65024,o:"&gesl;"}],[2,"&cuepr;"],[0,"&cuesc;"],[0,"&NotPrecedesSlantEqual;"],[0,"&NotSucceedsSlantEqual;"],[0,"&NotSquareSubsetEqual;"],[0,"&NotSquareSupersetEqual;"],[2,"&lnsim;"],[0,"&gnsim;"],[0,"&precnsim;"],[0,"&scnsim;"],[0,"&nltri;"],[0,"&NotRightTriangle;"],[0,"&nltrie;"],[0,"&NotRightTriangleEqual;"],[0,"&vellip;"],[0,"&ctdot;"],[0,"&utdot;"],[0,"&dtdot;"],[0,"&disin;"],[0,"&isinsv;"],[0,"&isins;"],[0,{v:"&isindot;",n:824,o:"&notindot;"}],[0,"&notinvc;"],[0,"&notinvb;"],[1,{v:"&isinE;",n:824,o:"&notinE;"}],[0,"&nisd;"],[0,"&xnis;"],[0,"&nis;"],[0,"&notnivc;"],[0,"&notnivb;"],[6,"&barwed;"],[0,"&Barwed;"],[1,"&lceil;"],[0,"&rceil;"],[0,"&LeftFloor;"],[0,"&rfloor;"],[0,"&drcrop;"],[0,"&dlcrop;"],[0,"&urcrop;"],[0,"&ulcrop;"],[0,"&bnot;"],[1,"&profline;"],[0,"&profsurf;"],[1,"&telrec;"],[0,"&target;"],[5,"&ulcorn;"],[0,"&urcorn;"],[0,"&dlcorn;"],[0,"&drcorn;"],[2,"&frown;"],[0,"&smile;"],[9,"&cylcty;"],[0,"&profalar;"],[7,"&topbot;"],[6,"&ovbar;"],[1,"&solbar;"],[60,"&angzarr;"],[51,"&lmoustache;"],[0,"&rmoustache;"],[2,"&OverBracket;"],[0,"&bbrk;"],[0,"&bbrktbrk;"],[37,"&OverParenthesis;"],[0,"&UnderParenthesis;"],[0,"&OverBrace;"],[0,"&UnderBrace;"],[2,"&trpezium;"],[4,"&elinters;"],[59,"&blank;"],[164,"&circledS;"],[55,"&boxh;"],[1,"&boxv;"],[9,"&boxdr;"],[3,"&boxdl;"],[3,"&boxur;"],[3,"&boxul;"],[3,"&boxvr;"],[7,"&boxvl;"],[7,"&boxhd;"],[7,"&boxhu;"],[7,"&boxvh;"],[19,"&boxH;"],[0,"&boxV;"],[0,"&boxdR;"],[0,"&boxDr;"],[0,"&boxDR;"],[0,"&boxdL;"],[0,"&boxDl;"],[0,"&boxDL;"],[0,"&boxuR;"],[0,"&boxUr;"],[0,"&boxUR;"],[0,"&boxuL;"],[0,"&boxUl;"],[0,"&boxUL;"],[0,"&boxvR;"],[0,"&boxVr;"],[0,"&boxVR;"],[0,"&boxvL;"],[0,"&boxVl;"],[0,"&boxVL;"],[0,"&boxHd;"],[0,"&boxhD;"],[0,"&boxHD;"],[0,"&boxHu;"],[0,"&boxhU;"],[0,"&boxHU;"],[0,"&boxvH;"],[0,"&boxVh;"],[0,"&boxVH;"],[19,"&uhblk;"],[3,"&lhblk;"],[3,"&block;"],[8,"&blk14;"],[0,"&blk12;"],[0,"&blk34;"],[13,"&square;"],[8,"&blacksquare;"],[0,"&EmptyVerySmallSquare;"],[1,"&rect;"],[0,"&marker;"],[2,"&fltns;"],[1,"&bigtriangleup;"],[0,"&blacktriangle;"],[0,"&triangle;"],[2,"&blacktriangleright;"],[0,"&rtri;"],[3,"&bigtriangledown;"],[0,"&blacktriangledown;"],[0,"&dtri;"],[2,"&blacktriangleleft;"],[0,"&ltri;"],[6,"&loz;"],[0,"&cir;"],[32,"&tridot;"],[2,"&bigcirc;"],[8,"&ultri;"],[0,"&urtri;"],[0,"&lltri;"],[0,"&EmptySmallSquare;"],[0,"&FilledSmallSquare;"],[8,"&bigstar;"],[0,"&star;"],[7,"&phone;"],[49,"&female;"],[1,"&male;"],[29,"&spades;"],[2,"&clubs;"],[1,"&hearts;"],[0,"&diamondsuit;"],[3,"&sung;"],[2,"&flat;"],[0,"&natural;"],[0,"&sharp;"],[163,"&check;"],[3,"&cross;"],[8,"&malt;"],[21,"&sext;"],[33,"&VerticalSeparator;"],[25,"&lbbrk;"],[0,"&rbbrk;"],[84,"&bsolhsub;"],[0,"&suphsol;"],[28,"&LeftDoubleBracket;"],[0,"&RightDoubleBracket;"],[0,"&lang;"],[0,"&rang;"],[0,"&Lang;"],[0,"&Rang;"],[0,"&loang;"],[0,"&roang;"],[7,"&longleftarrow;"],[0,"&longrightarrow;"],[0,"&longleftrightarrow;"],[0,"&DoubleLongLeftArrow;"],[0,"&DoubleLongRightArrow;"],[0,"&DoubleLongLeftRightArrow;"],[1,"&longmapsto;"],[2,"&dzigrarr;"],[258,"&nvlArr;"],[0,"&nvrArr;"],[0,"&nvHarr;"],[0,"&Map;"],[6,"&lbarr;"],[0,"&bkarow;"],[0,"&lBarr;"],[0,"&dbkarow;"],[0,"&drbkarow;"],[0,"&DDotrahd;"],[0,"&UpArrowBar;"],[0,"&DownArrowBar;"],[2,"&Rarrtl;"],[2,"&latail;"],[0,"&ratail;"],[0,"&lAtail;"],[0,"&rAtail;"],[0,"&larrfs;"],[0,"&rarrfs;"],[0,"&larrbfs;"],[0,"&rarrbfs;"],[2,"&nwarhk;"],[0,"&nearhk;"],[0,"&hksearow;"],[0,"&hkswarow;"],[0,"&nwnear;"],[0,"&nesear;"],[0,"&seswar;"],[0,"&swnwar;"],[8,{v:"&rarrc;",n:824,o:"&nrarrc;"}],[1,"&cudarrr;"],[0,"&ldca;"],[0,"&rdca;"],[0,"&cudarrl;"],[0,"&larrpl;"],[2,"&curarrm;"],[0,"&cularrp;"],[7,"&rarrpl;"],[2,"&harrcir;"],[0,"&Uarrocir;"],[0,"&lurdshar;"],[0,"&ldrushar;"],[2,"&LeftRightVector;"],[0,"&RightUpDownVector;"],[0,"&DownLeftRightVector;"],[0,"&LeftUpDownVector;"],[0,"&LeftVectorBar;"],[0,"&RightVectorBar;"],[0,"&RightUpVectorBar;"],[0,"&RightDownVectorBar;"],[0,"&DownLeftVectorBar;"],[0,"&DownRightVectorBar;"],[0,"&LeftUpVectorBar;"],[0,"&LeftDownVectorBar;"],[0,"&LeftTeeVector;"],[0,"&RightTeeVector;"],[0,"&RightUpTeeVector;"],[0,"&RightDownTeeVector;"],[0,"&DownLeftTeeVector;"],[0,"&DownRightTeeVector;"],[0,"&LeftUpTeeVector;"],[0,"&LeftDownTeeVector;"],[0,"&lHar;"],[0,"&uHar;"],[0,"&rHar;"],[0,"&dHar;"],[0,"&luruhar;"],[0,"&ldrdhar;"],[0,"&ruluhar;"],[0,"&rdldhar;"],[0,"&lharul;"],[0,"&llhard;"],[0,"&rharul;"],[0,"&lrhard;"],[0,"&udhar;"],[0,"&duhar;"],[0,"&RoundImplies;"],[0,"&erarr;"],[0,"&simrarr;"],[0,"&larrsim;"],[0,"&rarrsim;"],[0,"&rarrap;"],[0,"&ltlarr;"],[1,"&gtrarr;"],[0,"&subrarr;"],[1,"&suplarr;"],[0,"&lfisht;"],[0,"&rfisht;"],[0,"&ufisht;"],[0,"&dfisht;"],[5,"&lopar;"],[0,"&ropar;"],[4,"&lbrke;"],[0,"&rbrke;"],[0,"&lbrkslu;"],[0,"&rbrksld;"],[0,"&lbrksld;"],[0,"&rbrkslu;"],[0,"&langd;"],[0,"&rangd;"],[0,"&lparlt;"],[0,"&rpargt;"],[0,"&gtlPar;"],[0,"&ltrPar;"],[3,"&vzigzag;"],[1,"&vangrt;"],[0,"&angrtvbd;"],[6,"&ange;"],[0,"&range;"],[0,"&dwangle;"],[0,"&uwangle;"],[0,"&angmsdaa;"],[0,"&angmsdab;"],[0,"&angmsdac;"],[0,"&angmsdad;"],[0,"&angmsdae;"],[0,"&angmsdaf;"],[0,"&angmsdag;"],[0,"&angmsdah;"],[0,"&bemptyv;"],[0,"&demptyv;"],[0,"&cemptyv;"],[0,"&raemptyv;"],[0,"&laemptyv;"],[0,"&ohbar;"],[0,"&omid;"],[0,"&opar;"],[1,"&operp;"],[1,"&olcross;"],[0,"&odsold;"],[1,"&olcir;"],[0,"&ofcir;"],[0,"&olt;"],[0,"&ogt;"],[0,"&cirscir;"],[0,"&cirE;"],[0,"&solb;"],[0,"&bsolb;"],[3,"&boxbox;"],[3,"&trisb;"],[0,"&rtriltri;"],[0,{v:"&LeftTriangleBar;",n:824,o:"&NotLeftTriangleBar;"}],[0,{v:"&RightTriangleBar;",n:824,o:"&NotRightTriangleBar;"}],[11,"&iinfin;"],[0,"&infintie;"],[0,"&nvinfin;"],[4,"&eparsl;"],[0,"&smeparsl;"],[0,"&eqvparsl;"],[5,"&blacklozenge;"],[8,"&RuleDelayed;"],[1,"&dsol;"],[9,"&bigodot;"],[0,"&bigoplus;"],[0,"&bigotimes;"],[1,"&biguplus;"],[1,"&bigsqcup;"],[5,"&iiiint;"],[0,"&fpartint;"],[2,"&cirfnint;"],[0,"&awint;"],[0,"&rppolint;"],[0,"&scpolint;"],[0,"&npolint;"],[0,"&pointint;"],[0,"&quatint;"],[0,"&intlarhk;"],[10,"&pluscir;"],[0,"&plusacir;"],[0,"&simplus;"],[0,"&plusdu;"],[0,"&plussim;"],[0,"&plustwo;"],[1,"&mcomma;"],[0,"&minusdu;"],[2,"&loplus;"],[0,"&roplus;"],[0,"&Cross;"],[0,"&timesd;"],[0,"&timesbar;"],[1,"&smashp;"],[0,"&lotimes;"],[0,"&rotimes;"],[0,"&otimesas;"],[0,"&Otimes;"],[0,"&odiv;"],[0,"&triplus;"],[0,"&triminus;"],[0,"&tritime;"],[0,"&intprod;"],[2,"&amalg;"],[0,"&capdot;"],[1,"&ncup;"],[0,"&ncap;"],[0,"&capand;"],[0,"&cupor;"],[0,"&cupcap;"],[0,"&capcup;"],[0,"&cupbrcap;"],[0,"&capbrcup;"],[0,"&cupcup;"],[0,"&capcap;"],[0,"&ccups;"],[0,"&ccaps;"],[2,"&ccupssm;"],[2,"&And;"],[0,"&Or;"],[0,"&andand;"],[0,"&oror;"],[0,"&orslope;"],[0,"&andslope;"],[1,"&andv;"],[0,"&orv;"],[0,"&andd;"],[0,"&ord;"],[1,"&wedbar;"],[6,"&sdote;"],[3,"&simdot;"],[2,{v:"&congdot;",n:824,o:"&ncongdot;"}],[0,"&easter;"],[0,"&apacir;"],[0,{v:"&apE;",n:824,o:"&napE;"}],[0,"&eplus;"],[0,"&pluse;"],[0,"&Esim;"],[0,"&Colone;"],[0,"&Equal;"],[1,"&ddotseq;"],[0,"&equivDD;"],[0,"&ltcir;"],[0,"&gtcir;"],[0,"&ltquest;"],[0,"&gtquest;"],[0,{v:"&leqslant;",n:824,o:"&nleqslant;"}],[0,{v:"&geqslant;",n:824,o:"&ngeqslant;"}],[0,"&lesdot;"],[0,"&gesdot;"],[0,"&lesdoto;"],[0,"&gesdoto;"],[0,"&lesdotor;"],[0,"&gesdotol;"],[0,"&lap;"],[0,"&gap;"],[0,"&lne;"],[0,"&gne;"],[0,"&lnap;"],[0,"&gnap;"],[0,"&lEg;"],[0,"&gEl;"],[0,"&lsime;"],[0,"&gsime;"],[0,"&lsimg;"],[0,"&gsiml;"],[0,"&lgE;"],[0,"&glE;"],[0,"&lesges;"],[0,"&gesles;"],[0,"&els;"],[0,"&egs;"],[0,"&elsdot;"],[0,"&egsdot;"],[0,"&el;"],[0,"&eg;"],[2,"&siml;"],[0,"&simg;"],[0,"&simlE;"],[0,"&simgE;"],[0,{v:"&LessLess;",n:824,o:"&NotNestedLessLess;"}],[0,{v:"&GreaterGreater;",n:824,o:"&NotNestedGreaterGreater;"}],[1,"&glj;"],[0,"&gla;"],[0,"&ltcc;"],[0,"&gtcc;"],[0,"&lescc;"],[0,"&gescc;"],[0,"&smt;"],[0,"&lat;"],[0,{v:"&smte;",n:65024,o:"&smtes;"}],[0,{v:"&late;",n:65024,o:"&lates;"}],[0,"&bumpE;"],[0,{v:"&PrecedesEqual;",n:824,o:"&NotPrecedesEqual;"}],[0,{v:"&sce;",n:824,o:"&NotSucceedsEqual;"}],[2,"&prE;"],[0,"&scE;"],[0,"&precneqq;"],[0,"&scnE;"],[0,"&prap;"],[0,"&scap;"],[0,"&precnapprox;"],[0,"&scnap;"],[0,"&Pr;"],[0,"&Sc;"],[0,"&subdot;"],[0,"&supdot;"],[0,"&subplus;"],[0,"&supplus;"],[0,"&submult;"],[0,"&supmult;"],[0,"&subedot;"],[0,"&supedot;"],[0,{v:"&subE;",n:824,o:"&nsubE;"}],[0,{v:"&supE;",n:824,o:"&nsupE;"}],[0,"&subsim;"],[0,"&supsim;"],[2,{v:"&subnE;",n:65024,o:"&varsubsetneqq;"}],[0,{v:"&supnE;",n:65024,o:"&varsupsetneqq;"}],[2,"&csub;"],[0,"&csup;"],[0,"&csube;"],[0,"&csupe;"],[0,"&subsup;"],[0,"&supsub;"],[0,"&subsub;"],[0,"&supsup;"],[0,"&suphsub;"],[0,"&supdsub;"],[0,"&forkv;"],[0,"&topfork;"],[0,"&mlcp;"],[8,"&Dashv;"],[1,"&Vdashl;"],[0,"&Barv;"],[0,"&vBar;"],[0,"&vBarv;"],[1,"&Vbar;"],[0,"&Not;"],[0,"&bNot;"],[0,"&rnmid;"],[0,"&cirmid;"],[0,"&midcir;"],[0,"&topcir;"],[0,"&nhpar;"],[0,"&parsim;"],[9,{v:"&parsl;",n:8421,o:"&nparsl;"}],[44343,{n:new Map(jo([[56476,"&Ascr;"],[1,"&Cscr;"],[0,"&Dscr;"],[2,"&Gscr;"],[2,"&Jscr;"],[0,"&Kscr;"],[2,"&Nscr;"],[0,"&Oscr;"],[0,"&Pscr;"],[0,"&Qscr;"],[1,"&Sscr;"],[0,"&Tscr;"],[0,"&Uscr;"],[0,"&Vscr;"],[0,"&Wscr;"],[0,"&Xscr;"],[0,"&Yscr;"],[0,"&Zscr;"],[0,"&ascr;"],[0,"&bscr;"],[0,"&cscr;"],[0,"&dscr;"],[1,"&fscr;"],[1,"&hscr;"],[0,"&iscr;"],[0,"&jscr;"],[0,"&kscr;"],[0,"&lscr;"],[0,"&mscr;"],[0,"&nscr;"],[1,"&pscr;"],[0,"&qscr;"],[0,"&rscr;"],[0,"&sscr;"],[0,"&tscr;"],[0,"&uscr;"],[0,"&vscr;"],[0,"&wscr;"],[0,"&xscr;"],[0,"&yscr;"],[0,"&zscr;"],[52,"&Afr;"],[0,"&Bfr;"],[1,"&Dfr;"],[0,"&Efr;"],[0,"&Ffr;"],[0,"&Gfr;"],[2,"&Jfr;"],[0,"&Kfr;"],[0,"&Lfr;"],[0,"&Mfr;"],[0,"&Nfr;"],[0,"&Ofr;"],[0,"&Pfr;"],[0,"&Qfr;"],[1,"&Sfr;"],[0,"&Tfr;"],[0,"&Ufr;"],[0,"&Vfr;"],[0,"&Wfr;"],[0,"&Xfr;"],[0,"&Yfr;"],[1,"&afr;"],[0,"&bfr;"],[0,"&cfr;"],[0,"&dfr;"],[0,"&efr;"],[0,"&ffr;"],[0,"&gfr;"],[0,"&hfr;"],[0,"&ifr;"],[0,"&jfr;"],[0,"&kfr;"],[0,"&lfr;"],[0,"&mfr;"],[0,"&nfr;"],[0,"&ofr;"],[0,"&pfr;"],[0,"&qfr;"],[0,"&rfr;"],[0,"&sfr;"],[0,"&tfr;"],[0,"&ufr;"],[0,"&vfr;"],[0,"&wfr;"],[0,"&xfr;"],[0,"&yfr;"],[0,"&zfr;"],[0,"&Aopf;"],[0,"&Bopf;"],[1,"&Dopf;"],[0,"&Eopf;"],[0,"&Fopf;"],[0,"&Gopf;"],[1,"&Iopf;"],[0,"&Jopf;"],[0,"&Kopf;"],[0,"&Lopf;"],[0,"&Mopf;"],[1,"&Oopf;"],[3,"&Sopf;"],[0,"&Topf;"],[0,"&Uopf;"],[0,"&Vopf;"],[0,"&Wopf;"],[0,"&Xopf;"],[0,"&Yopf;"],[1,"&aopf;"],[0,"&bopf;"],[0,"&copf;"],[0,"&dopf;"],[0,"&eopf;"],[0,"&fopf;"],[0,"&gopf;"],[0,"&hopf;"],[0,"&iopf;"],[0,"&jopf;"],[0,"&kopf;"],[0,"&lopf;"],[0,"&mopf;"],[0,"&nopf;"],[0,"&oopf;"],[0,"&popf;"],[0,"&qopf;"],[0,"&ropf;"],[0,"&sopf;"],[0,"&topf;"],[0,"&uopf;"],[0,"&vopf;"],[0,"&wopf;"],[0,"&xopf;"],[0,"&yopf;"],[0,"&zopf;"]]))}],[8906,"&fflig;"],[0,"&filig;"],[0,"&fllig;"],[0,"&ffilig;"],[0,"&ffllig;"]]));var Vs={};(function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.escapeText=e.escapeAttribute=e.escapeUTF8=e.escape=e.encodeXML=e.getCodePoint=e.xmlReplacer=void 0,e.xmlReplacer=/["&'<>$\x80-\uFFFF]/g;var t=new Map([[34,"&quot;"],[38,"&amp;"],[39,"&apos;"],[60,"&lt;"],[62,"&gt;"]]);e.getCodePoint=String.prototype.codePointAt!=null?function(i,a){return i.codePointAt(a)}:function(i,a){return(i.charCodeAt(a)&64512)===55296?(i.charCodeAt(a)-55296)*1024+i.charCodeAt(a+1)-56320+65536:i.charCodeAt(a)};function r(i){for(var a="",o=0,s;(s=e.xmlReplacer.exec(i))!==null;){var u=s.index,l=i.charCodeAt(u),c=t.get(l);c!==void 0?(a+=i.substring(o,u)+c,o=u+1):(a+="".concat(i.substring(o,u),"&#x").concat((0,e.getCodePoint)(i,u).toString(16),";"),o=e.xmlReplacer.lastIndex+=+((l&64512)===55296))}return a+i.substr(o)}e.encodeXML=r,e.escape=r;function n(i,a){return function(s){for(var u,l=0,c="";u=i.exec(s);)l!==u.index&&(c+=s.substring(l,u.index)),c+=a.get(u[0].charCodeAt(0)),l=u.index+1;return c+s.substring(l)}}e.escapeUTF8=n(/[&<>'"]/g,t),e.escapeAttribute=n(/["&\u00A0]/g,new Map([[34,"&quot;"],[38,"&amp;"],[160,"&nbsp;"]])),e.escapeText=n(/[&<>\u00A0]/g,new Map([[38,"&amp;"],[60,"&lt;"],[62,"&gt;"],[160,"&nbsp;"]]))})(Vs);var YD=xe&&xe.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(si,"__esModule",{value:!0});si.encodeNonAsciiHTML=si.encodeHTML=void 0;var ZD=YD(yd),bv=Vs,QD=/[\t\n!-,./:-@[-`\f{-}$\x80-\uFFFF]/g;function JD(e){return vv(QD,e)}si.encodeHTML=JD;function eL(e){return vv(bv.xmlReplacer,e)}si.encodeNonAsciiHTML=eL;function vv(e,t){for(var r="",n=0,i;(i=e.exec(t))!==null;){var a=i.index;r+=t.substring(n,a);var o=t.charCodeAt(a),s=ZD.default.get(o);if(typeof s=="object"){if(a+1<t.length){var u=t.charCodeAt(a+1),l=typeof s.n=="number"?s.n===u?s.o:void 0:s.n.get(u);if(l!==void 0){r+=l,n=e.lastIndex+=1;continue}}s=s.v}if(s!==void 0)r+=s,n=a+1;else{var c=(0,bv.getCodePoint)(t,a);r+="&#x".concat(c.toString(16),";"),n=e.lastIndex+=+(c!==o)}}return r+t.substr(n)}(function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.decodeXMLStrict=e.decodeHTML5Strict=e.decodeHTML4Strict=e.decodeHTML5=e.decodeHTML4=e.decodeHTMLAttribute=e.decodeHTMLStrict=e.decodeHTML=e.decodeXML=e.DecodingMode=e.EntityDecoder=e.encodeHTML5=e.encodeHTML4=e.encodeNonAsciiHTML=e.encodeHTML=e.escapeText=e.escapeAttribute=e.escapeUTF8=e.escape=e.encodeXML=e.encode=e.decodeStrict=e.decode=e.EncodingMode=e.EntityLevel=void 0;var t=za,r=si,n=Vs,i;(function(d){d[d.XML=0]="XML",d[d.HTML=1]="HTML"})(i=e.EntityLevel||(e.EntityLevel={}));var a;(function(d){d[d.UTF8=0]="UTF8",d[d.ASCII=1]="ASCII",d[d.Extensive=2]="Extensive",d[d.Attribute=3]="Attribute",d[d.Text=4]="Text"})(a=e.EncodingMode||(e.EncodingMode={}));function o(d,h){h===void 0&&(h=i.XML);var p=typeof h=="number"?h:h.level;if(p===i.HTML){var m=typeof h=="object"?h.mode:void 0;return(0,t.decodeHTML)(d,m)}return(0,t.decodeXML)(d)}e.decode=o;function s(d,h){var p;h===void 0&&(h=i.XML);var m=typeof h=="number"?{level:h}:h;return(p=m.mode)!==null&&p!==void 0||(m.mode=t.DecodingMode.Strict),o(d,m)}e.decodeStrict=s;function u(d,h){h===void 0&&(h=i.XML);var p=typeof h=="number"?{level:h}:h;return p.mode===a.UTF8?(0,n.escapeUTF8)(d):p.mode===a.Attribute?(0,n.escapeAttribute)(d):p.mode===a.Text?(0,n.escapeText)(d):p.level===i.HTML?p.mode===a.ASCII?(0,r.encodeNonAsciiHTML)(d):(0,r.encodeHTML)(d):(0,n.encodeXML)(d)}e.encode=u;var l=Vs;Object.defineProperty(e,"encodeXML",{enumerable:!0,get:function(){return l.encodeXML}}),Object.defineProperty(e,"escape",{enumerable:!0,get:function(){return l.escape}}),Object.defineProperty(e,"escapeUTF8",{enumerable:!0,get:function(){return l.escapeUTF8}}),Object.defineProperty(e,"escapeAttribute",{enumerable:!0,get:function(){return l.escapeAttribute}}),Object.defineProperty(e,"escapeText",{enumerable:!0,get:function(){return l.escapeText}});var c=si;Object.defineProperty(e,"encodeHTML",{enumerable:!0,get:function(){return c.encodeHTML}}),Object.defineProperty(e,"encodeNonAsciiHTML",{enumerable:!0,get:function(){return c.encodeNonAsciiHTML}}),Object.defineProperty(e,"encodeHTML4",{enumerable:!0,get:function(){return c.encodeHTML}}),Object.defineProperty(e,"encodeHTML5",{enumerable:!0,get:function(){return c.encodeHTML}});var f=za;Object.defineProperty(e,"EntityDecoder",{enumerable:!0,get:function(){return f.EntityDecoder}}),Object.defineProperty(e,"DecodingMode",{enumerable:!0,get:function(){return f.DecodingMode}}),Object.defineProperty(e,"decodeXML",{enumerable:!0,get:function(){return f.decodeXML}}),Object.defineProperty(e,"decodeHTML",{enumerable:!0,get:function(){return f.decodeHTML}}),Object.defineProperty(e,"decodeHTMLStrict",{enumerable:!0,get:function(){return f.decodeHTMLStrict}}),Object.defineProperty(e,"decodeHTMLAttribute",{enumerable:!0,get:function(){return f.decodeHTMLAttribute}}),Object.defineProperty(e,"decodeHTML4",{enumerable:!0,get:function(){return f.decodeHTML}}),Object.defineProperty(e,"decodeHTML5",{enumerable:!0,get:function(){return f.decodeHTML}}),Object.defineProperty(e,"decodeHTML4Strict",{enumerable:!0,get:function(){return f.decodeHTMLStrict}}),Object.defineProperty(e,"decodeHTML5Strict",{enumerable:!0,get:function(){return f.decodeHTMLStrict}}),Object.defineProperty(e,"decodeXMLStrict",{enumerable:!0,get:function(){return f.decodeXML}})})(gv);var Vi={};Object.defineProperty(Vi,"__esModule",{value:!0});Vi.attributeNames=Vi.elementNames=void 0;Vi.elementNames=new Map(["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","textPath"].map(function(e){return[e.toLowerCase(),e]}));Vi.attributeNames=new Map(["definitionURL","attributeName","attributeType","baseFrequency","baseProfile","calcMode","clipPathUnits","diffuseConstant","edgeMode","filterUnits","glyphRef","gradientTransform","gradientUnits","kernelMatrix","kernelUnitLength","keyPoints","keySplines","keyTimes","lengthAdjust","limitingConeAngle","markerHeight","markerUnits","markerWidth","maskContentUnits","maskUnits","numOctaves","pathLength","patternContentUnits","patternTransform","patternUnits","pointsAtX","pointsAtY","pointsAtZ","preserveAlpha","preserveAspectRatio","primitiveUnits","refX","refY","repeatCount","repeatDur","requiredExtensions","requiredFeatures","specularConstant","specularExponent","spreadMethod","startOffset","stdDeviation","stitchTiles","surfaceScale","systemLanguage","tableValues","targetX","targetY","textLength","viewBox","viewTarget","xChannelSelector","yChannelSelector","zoomAndPan"].map(function(e){return[e.toLowerCase(),e]}));var Ci=xe&&xe.__assign||function(){return Ci=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++){t=arguments[r];for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])}return e},Ci.apply(this,arguments)},tL=xe&&xe.__createBinding||(Object.create?function(e,t,r,n){n===void 0&&(n=r);var i=Object.getOwnPropertyDescriptor(t,r);(!i||("get"in i?!t.__esModule:i.writable||i.configurable))&&(i={enumerable:!0,get:function(){return t[r]}}),Object.defineProperty(e,n,i)}:function(e,t,r,n){n===void 0&&(n=r),e[n]=t[r]}),rL=xe&&xe.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),nL=xe&&xe.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(e!=null)for(var r in e)r!=="default"&&Object.prototype.hasOwnProperty.call(e,r)&&tL(t,e,r);return rL(t,e),t};Object.defineProperty(so,"__esModule",{value:!0});so.render=void 0;var en=nL(ia),Gs=gv,yv=Vi,iL=new Set(["style","script","xmp","iframe","noembed","noframes","plaintext","noscript"]);function aL(e){return e.replace(/"/g,"&quot;")}function oL(e,t){var r;if(e){var n=((r=t.encodeEntities)!==null&&r!==void 0?r:t.decodeEntities)===!1?aL:t.xmlMode||t.encodeEntities!=="utf8"?Gs.encodeXML:Gs.escapeAttribute;return Object.keys(e).map(function(i){var a,o,s=(a=e[i])!==null&&a!==void 0?a:"";return t.xmlMode==="foreign"&&(i=(o=yv.attributeNames.get(i))!==null&&o!==void 0?o:i),!t.emptyAttrs&&!t.xmlMode&&s===""?i:"".concat(i,'="').concat(n(s),'"')}).join(" ")}}var vm=new Set(["area","base","basefont","br","col","command","embed","frame","hr","img","input","isindex","keygen","link","meta","param","source","track","wbr"]);function Fu(e,t){t===void 0&&(t={});for(var r=("length"in e)?e:[e],n="",i=0;i<r.length;i++)n+=sL(r[i],t);return n}so.render=Fu;so.default=Fu;function sL(e,t){switch(e.type){case en.Root:return Fu(e.children,t);case en.Doctype:case en.Directive:return fL(e);case en.Comment:return pL(e);case en.CDATA:return hL(e);case en.Script:case en.Style:case en.Tag:return cL(e,t);case en.Text:return dL(e,t)}}var uL=new Set(["mi","mo","mn","ms","mtext","annotation-xml","foreignObject","desc","title"]),lL=new Set(["svg","math"]);function cL(e,t){var r;t.xmlMode==="foreign"&&(e.name=(r=yv.elementNames.get(e.name))!==null&&r!==void 0?r:e.name,e.parent&&uL.has(e.parent.name)&&(t=Ci(Ci({},t),{xmlMode:!1}))),!t.xmlMode&&lL.has(e.name)&&(t=Ci(Ci({},t),{xmlMode:"foreign"}));var n="<".concat(e.name),i=oL(e.attribs,t);return i&&(n+=" ".concat(i)),e.children.length===0&&(t.xmlMode?t.selfClosingTags!==!1:t.selfClosingTags&&vm.has(e.name))?(t.xmlMode||(n+=" "),n+="/>"):(n+=">",e.children.length>0&&(n+=Fu(e.children,t)),(t.xmlMode||!vm.has(e.name))&&(n+="</".concat(e.name,">"))),n}function fL(e){return"<".concat(e.data,">")}function dL(e,t){var r,n=e.data||"";return((r=t.encodeEntities)!==null&&r!==void 0?r:t.decodeEntities)!==!1&&!(!t.xmlMode&&e.parent&&iL.has(e.parent.name))&&(n=t.xmlMode||t.encodeEntities!=="utf8"?(0,Gs.encodeXML)(n):(0,Gs.escapeText)(n)),n}function hL(e){return"<![CDATA[".concat(e.children[0].data,"]]>")}function pL(e){return"<!--".concat(e.data,"-->")}var mL=xe&&xe.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(er,"__esModule",{value:!0});er.innerText=er.textContent=er.getText=er.getInnerHTML=er.getOuterHTML=void 0;var jr=hn,gL=mL(so),bL=ia;function wv(e,t){return(0,gL.default)(e,t)}er.getOuterHTML=wv;function vL(e,t){return(0,jr.hasChildren)(e)?e.children.map(function(r){return wv(r,t)}).join(""):""}er.getInnerHTML=vL;function vs(e){return Array.isArray(e)?e.map(vs).join(""):(0,jr.isTag)(e)?e.name==="br"?`
`:vs(e.children):(0,jr.isCDATA)(e)?vs(e.children):(0,jr.isText)(e)?e.data:""}er.getText=vs;function _c(e){return Array.isArray(e)?e.map(_c).join(""):(0,jr.hasChildren)(e)&&!(0,jr.isComment)(e)?_c(e.children):(0,jr.isText)(e)?e.data:""}er.textContent=_c;function Cc(e){return Array.isArray(e)?e.map(Cc).join(""):(0,jr.hasChildren)(e)&&(e.type===bL.ElementType.Tag||(0,jr.isCDATA)(e))?Cc(e.children):(0,jr.isText)(e)?e.data:""}er.innerText=Cc;var St={};Object.defineProperty(St,"__esModule",{value:!0});St.prevElementSibling=St.nextElementSibling=St.getName=St.hasAttrib=St.getAttributeValue=St.getSiblings=St.getParent=St.getChildren=void 0;var wd=hn;function xv(e){return(0,wd.hasChildren)(e)?e.children:[]}St.getChildren=xv;function Ev(e){return e.parent||null}St.getParent=Ev;function yL(e){var t,r,n=Ev(e);if(n!=null)return xv(n);for(var i=[e],a=e.prev,o=e.next;a!=null;)i.unshift(a),t=a,a=t.prev;for(;o!=null;)i.push(o),r=o,o=r.next;return i}St.getSiblings=yL;function wL(e,t){var r;return(r=e.attribs)===null||r===void 0?void 0:r[t]}St.getAttributeValue=wL;function xL(e,t){return e.attribs!=null&&Object.prototype.hasOwnProperty.call(e.attribs,t)&&e.attribs[t]!=null}St.hasAttrib=xL;function EL(e){return e.name}St.getName=EL;function SL(e){for(var t,r=e.next;r!==null&&!(0,wd.isTag)(r);)t=r,r=t.next;return r}St.nextElementSibling=SL;function TL(e){for(var t,r=e.prev;r!==null&&!(0,wd.isTag)(r);)t=r,r=t.prev;return r}St.prevElementSibling=TL;var jt={};Object.defineProperty(jt,"__esModule",{value:!0});jt.prepend=jt.prependChild=jt.append=jt.appendChild=jt.replaceElement=jt.removeElement=void 0;function uo(e){if(e.prev&&(e.prev.next=e.next),e.next&&(e.next.prev=e.prev),e.parent){var t=e.parent.children,r=t.lastIndexOf(e);r>=0&&t.splice(r,1)}e.next=null,e.prev=null,e.parent=null}jt.removeElement=uo;function AL(e,t){var r=t.prev=e.prev;r&&(r.next=t);var n=t.next=e.next;n&&(n.prev=t);var i=t.parent=e.parent;if(i){var a=i.children;a[a.lastIndexOf(e)]=t,e.parent=null}}jt.replaceElement=AL;function kL(e,t){if(uo(t),t.next=null,t.parent=e,e.children.push(t)>1){var r=e.children[e.children.length-2];r.next=t,t.prev=r}else t.prev=null}jt.appendChild=kL;function OL(e,t){uo(t);var r=e.parent,n=e.next;if(t.next=n,t.prev=e,e.next=t,t.parent=r,n){if(n.prev=t,r){var i=r.children;i.splice(i.lastIndexOf(n),0,t)}}else r&&r.children.push(t)}jt.append=OL;function NL(e,t){if(uo(t),t.parent=e,t.prev=null,e.children.unshift(t)!==1){var r=e.children[1];r.prev=t,t.next=r}else t.next=null}jt.prependChild=NL;function _L(e,t){uo(t);var r=e.parent;if(r){var n=r.children;n.splice(n.indexOf(e),0,t)}e.prev&&(e.prev.next=t),t.parent=r,t.prev=e.prev,t.next=e,e.prev=t}jt.prepend=_L;var Lt={};Object.defineProperty(Lt,"__esModule",{value:!0});Lt.findAll=Lt.existsOne=Lt.findOne=Lt.findOneChild=Lt.find=Lt.filter=void 0;var Bu=hn;function CL(e,t,r,n){return r===void 0&&(r=!0),n===void 0&&(n=1/0),Sv(e,Array.isArray(t)?t:[t],r,n)}Lt.filter=CL;function Sv(e,t,r,n){for(var i=[],a=[t],o=[0];;){if(o[0]>=a[0].length){if(o.length===1)return i;a.shift(),o.shift();continue}var s=a[0][o[0]++];if(e(s)&&(i.push(s),--n<=0))return i;r&&(0,Bu.hasChildren)(s)&&s.children.length>0&&(o.unshift(0),a.unshift(s.children))}}Lt.find=Sv;function ML(e,t){return t.find(e)}Lt.findOneChild=ML;function Tv(e,t,r){r===void 0&&(r=!0);for(var n=null,i=0;i<t.length&&!n;i++){var a=t[i];if((0,Bu.isTag)(a))e(a)?n=a:r&&a.children.length>0&&(n=Tv(e,a.children,!0));else continue}return n}Lt.findOne=Tv;function Av(e,t){return t.some(function(r){return(0,Bu.isTag)(r)&&(e(r)||Av(e,r.children))})}Lt.existsOne=Av;function RL(e,t){for(var r=[],n=[t],i=[0];;){if(i[0]>=n[0].length){if(n.length===1)return r;n.shift(),i.shift();continue}var a=n[0][i[0]++];(0,Bu.isTag)(a)&&(e(a)&&r.push(a),a.children.length>0&&(i.unshift(0),n.unshift(a.children)))}}Lt.findAll=RL;var tr={};Object.defineProperty(tr,"__esModule",{value:!0});tr.getElementsByTagType=tr.getElementsByTagName=tr.getElementById=tr.getElements=tr.testElement=void 0;var ti=hn,zu=Lt,Ws={tag_name:function(e){return typeof e=="function"?function(t){return(0,ti.isTag)(t)&&e(t.name)}:e==="*"?ti.isTag:function(t){return(0,ti.isTag)(t)&&t.name===e}},tag_type:function(e){return typeof e=="function"?function(t){return e(t.type)}:function(t){return t.type===e}},tag_contains:function(e){return typeof e=="function"?function(t){return(0,ti.isText)(t)&&e(t.data)}:function(t){return(0,ti.isText)(t)&&t.data===e}}};function kv(e,t){return typeof t=="function"?function(r){return(0,ti.isTag)(r)&&t(r.attribs[e])}:function(r){return(0,ti.isTag)(r)&&r.attribs[e]===t}}function IL(e,t){return function(r){return e(r)||t(r)}}function Ov(e){var t=Object.keys(e).map(function(r){var n=e[r];return Object.prototype.hasOwnProperty.call(Ws,r)?Ws[r](n):kv(r,n)});return t.length===0?null:t.reduce(IL)}function PL(e,t){var r=Ov(e);return r?r(t):!0}tr.testElement=PL;function DL(e,t,r,n){n===void 0&&(n=1/0);var i=Ov(e);return i?(0,zu.filter)(i,t,r,n):[]}tr.getElements=DL;function LL(e,t,r){return r===void 0&&(r=!0),Array.isArray(t)||(t=[t]),(0,zu.findOne)(kv("id",e),t,r)}tr.getElementById=LL;function FL(e,t,r,n){return r===void 0&&(r=!0),n===void 0&&(n=1/0),(0,zu.filter)(Ws.tag_name(e),t,r,n)}tr.getElementsByTagName=FL;function BL(e,t,r,n){return r===void 0&&(r=!0),n===void 0&&(n=1/0),(0,zu.filter)(Ws.tag_type(e),t,r,n)}tr.getElementsByTagType=BL;var Nv={};(function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.uniqueSort=e.compareDocumentPosition=e.DocumentPosition=e.removeSubsets=void 0;var t=hn;function r(o){for(var s=o.length;--s>=0;){var u=o[s];if(s>0&&o.lastIndexOf(u,s-1)>=0){o.splice(s,1);continue}for(var l=u.parent;l;l=l.parent)if(o.includes(l)){o.splice(s,1);break}}return o}e.removeSubsets=r;var n;(function(o){o[o.DISCONNECTED=1]="DISCONNECTED",o[o.PRECEDING=2]="PRECEDING",o[o.FOLLOWING=4]="FOLLOWING",o[o.CONTAINS=8]="CONTAINS",o[o.CONTAINED_BY=16]="CONTAINED_BY"})(n=e.DocumentPosition||(e.DocumentPosition={}));function i(o,s){var u=[],l=[];if(o===s)return 0;for(var c=(0,t.hasChildren)(o)?o:o.parent;c;)u.unshift(c),c=c.parent;for(c=(0,t.hasChildren)(s)?s:s.parent;c;)l.unshift(c),c=c.parent;for(var f=Math.min(u.length,l.length),d=0;d<f&&u[d]===l[d];)d++;if(d===0)return n.DISCONNECTED;var h=u[d-1],p=h.children,m=u[d],g=l[d];return p.indexOf(m)>p.indexOf(g)?h===s?n.FOLLOWING|n.CONTAINED_BY:n.FOLLOWING:h===o?n.PRECEDING|n.CONTAINS:n.PRECEDING}e.compareDocumentPosition=i;function a(o){return o=o.filter(function(s,u,l){return!l.includes(s,u+1)}),o.sort(function(s,u){var l=i(s,u);return l&n.PRECEDING?-1:l&n.FOLLOWING?1:0}),o}e.uniqueSort=a})(Nv);var $u={};Object.defineProperty($u,"__esModule",{value:!0});$u.getFeed=void 0;var zL=er,lo=tr;function $L(e){var t=Ks(VL,e);return t?t.name==="feed"?UL(t):HL(t):null}$u.getFeed=$L;function UL(e){var t,r=e.children,n={type:"atom",items:(0,lo.getElementsByTagName)("entry",r).map(function(o){var s,u=o.children,l={media:_v(u)};qt(l,"id","id",u),qt(l,"title","title",u);var c=(s=Ks("link",u))===null||s===void 0?void 0:s.attribs.href;c&&(l.link=c);var f=Mn("summary",u)||Mn("content",u);f&&(l.description=f);var d=Mn("updated",u);return d&&(l.pubDate=new Date(d)),l})};qt(n,"id","id",r),qt(n,"title","title",r);var i=(t=Ks("link",r))===null||t===void 0?void 0:t.attribs.href;i&&(n.link=i),qt(n,"description","subtitle",r);var a=Mn("updated",r);return a&&(n.updated=new Date(a)),qt(n,"author","email",r,!0),n}function HL(e){var t,r,n=(r=(t=Ks("channel",e.children))===null||t===void 0?void 0:t.children)!==null&&r!==void 0?r:[],i={type:e.name.substr(0,3),id:"",items:(0,lo.getElementsByTagName)("item",e.children).map(function(o){var s=o.children,u={media:_v(s)};qt(u,"id","guid",s),qt(u,"title","title",s),qt(u,"link","link",s),qt(u,"description","description",s);var l=Mn("pubDate",s)||Mn("dc:date",s);return l&&(u.pubDate=new Date(l)),u})};qt(i,"title","title",n),qt(i,"link","link",n),qt(i,"description","description",n);var a=Mn("lastBuildDate",n);return a&&(i.updated=new Date(a)),qt(i,"author","managingEditor",n,!0),i}var qL=["url","type","lang"],jL=["fileSize","bitrate","framerate","samplingrate","channels","duration","height","width"];function _v(e){return(0,lo.getElementsByTagName)("media:content",e).map(function(t){for(var r=t.attribs,n={medium:r.medium,isDefault:!!r.isDefault},i=0,a=qL;i<a.length;i++){var o=a[i];r[o]&&(n[o]=r[o])}for(var s=0,u=jL;s<u.length;s++){var o=u[s];r[o]&&(n[o]=parseInt(r[o],10))}return r.expression&&(n.expression=r.expression),n})}function Ks(e,t){return(0,lo.getElementsByTagName)(e,t,!0,1)[0]}function Mn(e,t,r){return r===void 0&&(r=!1),(0,zL.textContent)((0,lo.getElementsByTagName)(e,t,r,1)).trim()}function qt(e,t,r,n,i){i===void 0&&(i=!1);var a=Mn(r,n,i);a&&(e[t]=a)}function VL(e){return e==="rss"||e==="feed"||e==="rdf:RDF"}(function(e){var t=xe&&xe.__createBinding||(Object.create?function(i,a,o,s){s===void 0&&(s=o);var u=Object.getOwnPropertyDescriptor(a,o);(!u||("get"in u?!a.__esModule:u.writable||u.configurable))&&(u={enumerable:!0,get:function(){return a[o]}}),Object.defineProperty(i,s,u)}:function(i,a,o,s){s===void 0&&(s=o),i[s]=a[o]}),r=xe&&xe.__exportStar||function(i,a){for(var o in i)o!=="default"&&!Object.prototype.hasOwnProperty.call(a,o)&&t(a,i,o)};Object.defineProperty(e,"__esModule",{value:!0}),e.hasChildren=e.isDocument=e.isComment=e.isText=e.isCDATA=e.isTag=void 0,r(er,e),r(St,e),r(jt,e),r(Lt,e),r(tr,e),r(Nv,e),r($u,e);var n=hn;Object.defineProperty(e,"isTag",{enumerable:!0,get:function(){return n.isTag}}),Object.defineProperty(e,"isCDATA",{enumerable:!0,get:function(){return n.isCDATA}}),Object.defineProperty(e,"isText",{enumerable:!0,get:function(){return n.isText}}),Object.defineProperty(e,"isComment",{enumerable:!0,get:function(){return n.isComment}}),Object.defineProperty(e,"isDocument",{enumerable:!0,get:function(){return n.isDocument}}),Object.defineProperty(e,"hasChildren",{enumerable:!0,get:function(){return n.hasChildren}})})(bs);(function(e){var t=xe&&xe.__createBinding||(Object.create?function(v,w,x,N){N===void 0&&(N=x);var O=Object.getOwnPropertyDescriptor(w,x);(!O||("get"in O?!w.__esModule:O.writable||O.configurable))&&(O={enumerable:!0,get:function(){return w[x]}}),Object.defineProperty(v,N,O)}:function(v,w,x,N){N===void 0&&(N=x),v[N]=w[x]}),r=xe&&xe.__setModuleDefault||(Object.create?function(v,w){Object.defineProperty(v,"default",{enumerable:!0,value:w})}:function(v,w){v.default=w}),n=xe&&xe.__importStar||function(v){if(v&&v.__esModule)return v;var w={};if(v!=null)for(var x in v)x!=="default"&&Object.prototype.hasOwnProperty.call(v,x)&&t(w,v,x);return r(w,v),w},i=xe&&xe.__importDefault||function(v){return v&&v.__esModule?v:{default:v}};Object.defineProperty(e,"__esModule",{value:!0}),e.DomUtils=e.parseFeed=e.getFeed=e.ElementType=e.Tokenizer=e.createDomStream=e.parseDOM=e.parseDocument=e.DefaultHandler=e.DomHandler=e.Parser=void 0;var a=Ba,o=Ba;Object.defineProperty(e,"Parser",{enumerable:!0,get:function(){return o.Parser}});var s=hn,u=hn;Object.defineProperty(e,"DomHandler",{enumerable:!0,get:function(){return u.DomHandler}}),Object.defineProperty(e,"DefaultHandler",{enumerable:!0,get:function(){return u.DomHandler}});function l(v,w){var x=new s.DomHandler(void 0,w);return new a.Parser(x,w).end(v),x.root}e.parseDocument=l;function c(v,w){return l(v,w).children}e.parseDOM=c;function f(v,w,x){var N=new s.DomHandler(v,w,x);return new a.Parser(N,w)}e.createDomStream=f;var d=pd;Object.defineProperty(e,"Tokenizer",{enumerable:!0,get:function(){return i(d).default}}),e.ElementType=n(ia);var h=bs,p=bs;Object.defineProperty(e,"getFeed",{enumerable:!0,get:function(){return p.getFeed}});var m={xmlMode:!0};function g(v,w){return w===void 0&&(w=m),(0,h.getFeed)(c(v,w))}e.parseFeed=g,e.DomUtils=n(bs)})(nv);var GL=e=>{if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")},xd={};Object.defineProperty(xd,"__esModule",{value:!0});/*!
 * is-plain-object <https://github.com/jonschlinkert/is-plain-object>
 *
 * Copyright (c) 2014-2017, Jon Schlinkert.
 * Released under the MIT License.
 */function ym(e){return Object.prototype.toString.call(e)==="[object Object]"}function WL(e){var t,r;return ym(e)===!1?!1:(t=e.constructor,t===void 0?!0:(r=t.prototype,!(ym(r)===!1||r.hasOwnProperty("isPrototypeOf")===!1)))}xd.isPlainObject=WL;var KL=function(t){return XL(t)&&!YL(t)};function XL(e){return!!e&&typeof e=="object"}function YL(e){var t=Object.prototype.toString.call(e);return t==="[object RegExp]"||t==="[object Date]"||JL(e)}var ZL=typeof Symbol=="function"&&Symbol.for,QL=ZL?Symbol.for("react.element"):60103;function JL(e){return e.$$typeof===QL}function eF(e){return Array.isArray(e)?[]:{}}function $a(e,t){return t.clone!==!1&&t.isMergeableObject(e)?Gi(eF(e),e,t):e}function tF(e,t,r){return e.concat(t).map(function(n){return $a(n,r)})}function rF(e,t){if(!t.customMerge)return Gi;var r=t.customMerge(e);return typeof r=="function"?r:Gi}function nF(e){return Object.getOwnPropertySymbols?Object.getOwnPropertySymbols(e).filter(function(t){return Object.propertyIsEnumerable.call(e,t)}):[]}function wm(e){return Object.keys(e).concat(nF(e))}function Cv(e,t){try{return t in e}catch{return!1}}function iF(e,t){return Cv(e,t)&&!(Object.hasOwnProperty.call(e,t)&&Object.propertyIsEnumerable.call(e,t))}function aF(e,t,r){var n={};return r.isMergeableObject(e)&&wm(e).forEach(function(i){n[i]=$a(e[i],r)}),wm(t).forEach(function(i){iF(e,i)||(Cv(e,i)&&r.isMergeableObject(t[i])?n[i]=rF(i,r)(e[i],t[i],r):n[i]=$a(t[i],r))}),n}function Gi(e,t,r){r=r||{},r.arrayMerge=r.arrayMerge||tF,r.isMergeableObject=r.isMergeableObject||KL,r.cloneUnlessOtherwiseSpecified=$a;var n=Array.isArray(t),i=Array.isArray(e),a=n===i;return a?n?r.arrayMerge(e,t,r):aF(e,t,r):$a(t,r)}Gi.all=function(t,r){if(!Array.isArray(t))throw new Error("first argument should be an array");return t.reduce(function(n,i){return Gi(n,i,r)},{})};var oF=Gi,sF=oF,Mv={exports:{}};(function(e){(function(t,r){e.exports?e.exports=r():t.parseSrcset=r()})(xe,function(){return function(t){function r(N){return N===" "||N==="	"||N===`
`||N==="\f"||N==="\r"}function n(N){var O,A=N.exec(t.substring(g));if(A)return O=A[0],g+=O.length,O}for(var i=t.length,a=/^[ \t\n\r\u000c]+/,o=/^[, \t\n\r\u000c]+/,s=/^[^ \t\n\r\u000c]+/,u=/[,]+$/,l=/^\d+$/,c=/^-?(?:[0-9]+|[0-9]*\.[0-9]+)(?:[eE][+-]?[0-9]+)?$/,f,d,h,p,m,g=0,v=[];;){if(n(o),g>=i)return v;f=n(s),d=[],f.slice(-1)===","?(f=f.replace(u,""),x()):w()}function w(){for(n(a),h="",p="in descriptor";;){if(m=t.charAt(g),p==="in descriptor")if(r(m))h&&(d.push(h),h="",p="after descriptor");else if(m===","){g+=1,h&&d.push(h),x();return}else if(m==="(")h=h+m,p="in parens";else if(m===""){h&&d.push(h),x();return}else h=h+m;else if(p==="in parens")if(m===")")h=h+m,p="in descriptor";else if(m===""){d.push(h),x();return}else h=h+m;else if(p==="after descriptor"&&!r(m))if(m===""){x();return}else p="in descriptor",g-=1;g+=1}}function x(){var N=!1,O,A,D,H,z={},L,I,k,M,F;for(H=0;H<d.length;H++)L=d[H],I=L[L.length-1],k=L.substring(0,L.length-1),M=parseInt(k,10),F=parseFloat(k),l.test(k)&&I==="w"?((O||A)&&(N=!0),M===0?N=!0:O=M):c.test(k)&&I==="x"?((O||A||D)&&(N=!0),F<0?N=!0:A=F):l.test(k)&&I==="h"?((D||A)&&(N=!0),M===0?N=!0:D=M):N=!0;N?console&&console.log&&console.log("Invalid srcset descriptor found in '"+t+"' at '"+L+"'."):(z.url=f,O&&(z.w=O),A&&(z.d=A),D&&(z.h=D),v.push(z))}}})})(Mv);var uF=Mv.exports,Ed={exports:{}},nt=String,Rv=function(){return{isColorSupported:!1,reset:nt,bold:nt,dim:nt,italic:nt,underline:nt,inverse:nt,hidden:nt,strikethrough:nt,black:nt,red:nt,green:nt,yellow:nt,blue:nt,magenta:nt,cyan:nt,white:nt,gray:nt,bgBlack:nt,bgRed:nt,bgGreen:nt,bgYellow:nt,bgBlue:nt,bgMagenta:nt,bgCyan:nt,bgWhite:nt}};Ed.exports=Rv();Ed.exports.createColors=Rv;var lF=Ed.exports;let xm=lF,Em=xr,Mc=class Iv extends Error{constructor(t,r,n,i,a,o){super(t),this.name="CssSyntaxError",this.reason=t,a&&(this.file=a),i&&(this.source=i),o&&(this.plugin=o),typeof r<"u"&&typeof n<"u"&&(typeof r=="number"?(this.line=r,this.column=n):(this.line=r.line,this.column=r.column,this.endLine=n.line,this.endColumn=n.column)),this.setMessage(),Error.captureStackTrace&&Error.captureStackTrace(this,Iv)}setMessage(){this.message=this.plugin?this.plugin+": ":"",this.message+=this.file?this.file:"<css input>",typeof this.line<"u"&&(this.message+=":"+this.line+":"+this.column),this.message+=": "+this.reason}showSourceCode(t){if(!this.source)return"";let r=this.source;t==null&&(t=xm.isColorSupported),Em&&t&&(r=Em(r));let n=r.split(/\r?\n/),i=Math.max(this.line-3,0),a=Math.min(this.line+2,n.length),o=String(a).length,s,u;if(t){let{bold:l,gray:c,red:f}=xm.createColors(!0);s=d=>l(f(d)),u=d=>c(d)}else s=u=l=>l;return n.slice(i,a).map((l,c)=>{let f=i+1+c,d=" "+(" "+f).slice(-o)+" | ";if(f===this.line){let h=u(d.replace(/\d/g," "))+l.slice(0,this.column-1).replace(/[^\t]/g," ");return s(">")+u(d)+l+`
 `+h+s("^")}return" "+u(d)+l}).join(`
`)}toString(){let t=this.showSourceCode();return t&&(t=`

`+t+`
`),this.name+": "+this.message+t}};var Sd=Mc;Mc.default=Mc;var co={};co.isClean=Symbol("isClean");co.my=Symbol("my");const Sm={after:`
`,beforeClose:`
`,beforeComment:`
`,beforeDecl:`
`,beforeOpen:" ",beforeRule:`
`,colon:": ",commentLeft:" ",commentRight:" ",emptyBody:"",indent:"    ",semicolon:!1};function cF(e){return e[0].toUpperCase()+e.slice(1)}let Rc=class{constructor(t){this.builder=t}atrule(t,r){let n="@"+t.name,i=t.params?this.rawValue(t,"params"):"";if(typeof t.raws.afterName<"u"?n+=t.raws.afterName:i&&(n+=" "),t.nodes)this.block(t,n+i);else{let a=(t.raws.between||"")+(r?";":"");this.builder(n+i+a,t)}}beforeAfter(t,r){let n;t.type==="decl"?n=this.raw(t,null,"beforeDecl"):t.type==="comment"?n=this.raw(t,null,"beforeComment"):r==="before"?n=this.raw(t,null,"beforeRule"):n=this.raw(t,null,"beforeClose");let i=t.parent,a=0;for(;i&&i.type!=="root";)a+=1,i=i.parent;if(n.includes(`
`)){let o=this.raw(t,null,"indent");if(o.length)for(let s=0;s<a;s++)n+=o}return n}block(t,r){let n=this.raw(t,"between","beforeOpen");this.builder(r+n+"{",t,"start");let i;t.nodes&&t.nodes.length?(this.body(t),i=this.raw(t,"after")):i=this.raw(t,"after","emptyBody"),i&&this.builder(i),this.builder("}",t,"end")}body(t){let r=t.nodes.length-1;for(;r>0&&t.nodes[r].type==="comment";)r-=1;let n=this.raw(t,"semicolon");for(let i=0;i<t.nodes.length;i++){let a=t.nodes[i],o=this.raw(a,"before");o&&this.builder(o),this.stringify(a,r!==i||n)}}comment(t){let r=this.raw(t,"left","commentLeft"),n=this.raw(t,"right","commentRight");this.builder("/*"+r+t.text+n+"*/",t)}decl(t,r){let n=this.raw(t,"between","colon"),i=t.prop+n+this.rawValue(t,"value");t.important&&(i+=t.raws.important||" !important"),r&&(i+=";"),this.builder(i,t)}document(t){this.body(t)}raw(t,r,n){let i;if(n||(n=r),r&&(i=t.raws[r],typeof i<"u"))return i;let a=t.parent;if(n==="before"&&(!a||a.type==="root"&&a.first===t||a&&a.type==="document"))return"";if(!a)return Sm[n];let o=t.root();if(o.rawCache||(o.rawCache={}),typeof o.rawCache[n]<"u")return o.rawCache[n];if(n==="before"||n==="after")return this.beforeAfter(t,n);{let s="raw"+cF(n);this[s]?i=this[s](o,t):o.walk(u=>{if(i=u.raws[r],typeof i<"u")return!1})}return typeof i>"u"&&(i=Sm[n]),o.rawCache[n]=i,i}rawBeforeClose(t){let r;return t.walk(n=>{if(n.nodes&&n.nodes.length>0&&typeof n.raws.after<"u")return r=n.raws.after,r.includes(`
`)&&(r=r.replace(/[^\n]+$/,"")),!1}),r&&(r=r.replace(/\S/g,"")),r}rawBeforeComment(t,r){let n;return t.walkComments(i=>{if(typeof i.raws.before<"u")return n=i.raws.before,n.includes(`
`)&&(n=n.replace(/[^\n]+$/,"")),!1}),typeof n>"u"?n=this.raw(r,null,"beforeDecl"):n&&(n=n.replace(/\S/g,"")),n}rawBeforeDecl(t,r){let n;return t.walkDecls(i=>{if(typeof i.raws.before<"u")return n=i.raws.before,n.includes(`
`)&&(n=n.replace(/[^\n]+$/,"")),!1}),typeof n>"u"?n=this.raw(r,null,"beforeRule"):n&&(n=n.replace(/\S/g,"")),n}rawBeforeOpen(t){let r;return t.walk(n=>{if(n.type!=="decl"&&(r=n.raws.between,typeof r<"u"))return!1}),r}rawBeforeRule(t){let r;return t.walk(n=>{if(n.nodes&&(n.parent!==t||t.first!==n)&&typeof n.raws.before<"u")return r=n.raws.before,r.includes(`
`)&&(r=r.replace(/[^\n]+$/,"")),!1}),r&&(r=r.replace(/\S/g,"")),r}rawColon(t){let r;return t.walkDecls(n=>{if(typeof n.raws.between<"u")return r=n.raws.between.replace(/[^\s:]/g,""),!1}),r}rawEmptyBody(t){let r;return t.walk(n=>{if(n.nodes&&n.nodes.length===0&&(r=n.raws.after,typeof r<"u"))return!1}),r}rawIndent(t){if(t.raws.indent)return t.raws.indent;let r;return t.walk(n=>{let i=n.parent;if(i&&i!==t&&i.parent&&i.parent===t&&typeof n.raws.before<"u"){let a=n.raws.before.split(`
`);return r=a[a.length-1],r=r.replace(/\S/g,""),!1}}),r}rawSemicolon(t){let r;return t.walk(n=>{if(n.nodes&&n.nodes.length&&n.last.type==="decl"&&(r=n.raws.semicolon,typeof r<"u"))return!1}),r}rawValue(t,r){let n=t[r],i=t.raws[r];return i&&i.value===n?i.raw:n}root(t){this.body(t),t.raws.after&&this.builder(t.raws.after)}rule(t){this.block(t,this.rawValue(t,"selector")),t.raws.ownSemicolon&&this.builder(t.raws.ownSemicolon,t,"end")}stringify(t,r){if(!this[t.type])throw new Error("Unknown AST node type "+t.type+". Maybe you need to change PostCSS stringifier.");this[t.type](t,r)}};var Pv=Rc;Rc.default=Rc;let fF=Pv;function Ic(e,t){new fF(t).stringify(e)}var Uu=Ic;Ic.default=Ic;let{isClean:Vo,my:dF}=co,hF=Sd,pF=Pv,mF=Uu;function Pc(e,t){let r=new e.constructor;for(let n in e){if(!Object.prototype.hasOwnProperty.call(e,n)||n==="proxyCache")continue;let i=e[n],a=typeof i;n==="parent"&&a==="object"?t&&(r[n]=t):n==="source"?r[n]=i:Array.isArray(i)?r[n]=i.map(o=>Pc(o,r)):(a==="object"&&i!==null&&(i=Pc(i)),r[n]=i)}return r}let Dc=class{constructor(t={}){this.raws={},this[Vo]=!1,this[dF]=!0;for(let r in t)if(r==="nodes"){this.nodes=[];for(let n of t[r])typeof n.clone=="function"?this.append(n.clone()):this.append(n)}else this[r]=t[r]}addToError(t){if(t.postcssNode=this,t.stack&&this.source&&/\n\s{4}at /.test(t.stack)){let r=this.source;t.stack=t.stack.replace(/\n\s{4}at /,`$&${r.input.from}:${r.start.line}:${r.start.column}$&`)}return t}after(t){return this.parent.insertAfter(this,t),this}assign(t={}){for(let r in t)this[r]=t[r];return this}before(t){return this.parent.insertBefore(this,t),this}cleanRaws(t){delete this.raws.before,delete this.raws.after,t||delete this.raws.between}clone(t={}){let r=Pc(this);for(let n in t)r[n]=t[n];return r}cloneAfter(t={}){let r=this.clone(t);return this.parent.insertAfter(this,r),r}cloneBefore(t={}){let r=this.clone(t);return this.parent.insertBefore(this,r),r}error(t,r={}){if(this.source){let{end:n,start:i}=this.rangeBy(r);return this.source.input.error(t,{column:i.column,line:i.line},{column:n.column,line:n.line},r)}return new hF(t)}getProxyProcessor(){return{get(t,r){return r==="proxyOf"?t:r==="root"?()=>t.root().toProxy():t[r]},set(t,r,n){return t[r]===n||(t[r]=n,(r==="prop"||r==="value"||r==="name"||r==="params"||r==="important"||r==="text")&&t.markDirty()),!0}}}markDirty(){if(this[Vo]){this[Vo]=!1;let t=this;for(;t=t.parent;)t[Vo]=!1}}next(){if(!this.parent)return;let t=this.parent.index(this);return this.parent.nodes[t+1]}positionBy(t,r){let n=this.source.start;if(t.index)n=this.positionInside(t.index,r);else if(t.word){r=this.toString();let i=r.indexOf(t.word);i!==-1&&(n=this.positionInside(i,r))}return n}positionInside(t,r){let n=r||this.toString(),i=this.source.start.column,a=this.source.start.line;for(let o=0;o<t;o++)n[o]===`
`?(i=1,a+=1):i+=1;return{column:i,line:a}}prev(){if(!this.parent)return;let t=this.parent.index(this);return this.parent.nodes[t-1]}rangeBy(t){let r={column:this.source.start.column,line:this.source.start.line},n=this.source.end?{column:this.source.end.column+1,line:this.source.end.line}:{column:r.column+1,line:r.line};if(t.word){let i=this.toString(),a=i.indexOf(t.word);a!==-1&&(r=this.positionInside(a,i),n=this.positionInside(a+t.word.length,i))}else t.start?r={column:t.start.column,line:t.start.line}:t.index&&(r=this.positionInside(t.index)),t.end?n={column:t.end.column,line:t.end.line}:t.endIndex?n=this.positionInside(t.endIndex):t.index&&(n=this.positionInside(t.index+1));return(n.line<r.line||n.line===r.line&&n.column<=r.column)&&(n={column:r.column+1,line:r.line}),{end:n,start:r}}raw(t,r){return new pF().raw(this,t,r)}remove(){return this.parent&&this.parent.removeChild(this),this.parent=void 0,this}replaceWith(...t){if(this.parent){let r=this,n=!1;for(let i of t)i===this?n=!0:n?(this.parent.insertAfter(r,i),r=i):this.parent.insertBefore(r,i);n||this.remove()}return this}root(){let t=this;for(;t.parent&&t.parent.type!=="document";)t=t.parent;return t}toJSON(t,r){let n={},i=r==null;r=r||new Map;let a=0;for(let o in this){if(!Object.prototype.hasOwnProperty.call(this,o)||o==="parent"||o==="proxyCache")continue;let s=this[o];if(Array.isArray(s))n[o]=s.map(u=>typeof u=="object"&&u.toJSON?u.toJSON(null,r):u);else if(typeof s=="object"&&s.toJSON)n[o]=s.toJSON(null,r);else if(o==="source"){let u=r.get(s.input);u==null&&(u=a,r.set(s.input,a),a++),n[o]={end:s.end,inputId:u,start:s.start}}else n[o]=s}return i&&(n.inputs=[...r.keys()].map(o=>o.toJSON())),n}toProxy(){return this.proxyCache||(this.proxyCache=new Proxy(this,this.getProxyProcessor())),this.proxyCache}toString(t=mF){t.stringify&&(t=t.stringify);let r="";return t(this,n=>{r+=n}),r}warn(t,r,n){let i={node:this};for(let a in n)i[a]=n[a];return t.warn(r,i)}get proxyOf(){return this}};var Hu=Dc;Dc.default=Dc;let gF=Hu,Lc=class extends gF{constructor(t){t&&typeof t.value<"u"&&typeof t.value!="string"&&(t={...t,value:String(t.value)}),super(t),this.type="decl"}get variable(){return this.prop.startsWith("--")||this.prop[0]==="$"}};var qu=Lc;Lc.default=Lc;let bF="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict",vF=(e,t=21)=>(r=t)=>{let n="",i=r;for(;i--;)n+=e[Math.random()*e.length|0];return n},yF=(e=21)=>{let t="",r=e;for(;r--;)t+=bF[Math.random()*64|0];return t};var wF={nanoid:yF,customAlphabet:vF};let{SourceMapConsumer:Tm,SourceMapGenerator:Am}=xr,{existsSync:xF,readFileSync:EF}=xr,{dirname:u0,join:SF}=xr;function TF(e){return Buffer?Buffer.from(e,"base64").toString():window.atob(e)}let Fc=class{constructor(t,r){if(r.map===!1)return;this.loadAnnotation(t),this.inline=this.startWith(this.annotation,"data:");let n=r.map?r.map.prev:void 0,i=this.loadMap(r.from,n);!this.mapFile&&r.from&&(this.mapFile=r.from),this.mapFile&&(this.root=u0(this.mapFile)),i&&(this.text=i)}consumer(){return this.consumerCache||(this.consumerCache=new Tm(this.text)),this.consumerCache}decodeInline(t){let r=/^data:application\/json;charset=utf-?8;base64,/,n=/^data:application\/json;base64,/,i=/^data:application\/json;charset=utf-?8,/,a=/^data:application\/json,/;if(i.test(t)||a.test(t))return decodeURIComponent(t.substr(RegExp.lastMatch.length));if(r.test(t)||n.test(t))return TF(t.substr(RegExp.lastMatch.length));let o=t.match(/data:application\/json;([^,]+),/)[1];throw new Error("Unsupported source map encoding "+o)}getAnnotationURL(t){return t.replace(/^\/\*\s*# sourceMappingURL=/,"").trim()}isMap(t){return typeof t!="object"?!1:typeof t.mappings=="string"||typeof t._mappings=="string"||Array.isArray(t.sections)}loadAnnotation(t){let r=t.match(/\/\*\s*# sourceMappingURL=/gm);if(!r)return;let n=t.lastIndexOf(r.pop()),i=t.indexOf("*/",n);n>-1&&i>-1&&(this.annotation=this.getAnnotationURL(t.substring(n,i)))}loadFile(t){if(this.root=u0(t),xF(t))return this.mapFile=t,EF(t,"utf-8").toString().trim()}loadMap(t,r){if(r===!1)return!1;if(r){if(typeof r=="string")return r;if(typeof r=="function"){let n=r(t);if(n){let i=this.loadFile(n);if(!i)throw new Error("Unable to load previous source map: "+n.toString());return i}}else{if(r instanceof Tm)return Am.fromSourceMap(r).toString();if(r instanceof Am)return r.toString();if(this.isMap(r))return JSON.stringify(r);throw new Error("Unsupported previous source map format: "+r.toString())}}else{if(this.inline)return this.decodeInline(this.annotation);if(this.annotation){let n=this.annotation;return t&&(n=SF(u0(t),n)),this.loadFile(n)}}}startWith(t,r){return t?t.substr(0,r.length)===r:!1}withContent(){return!!(this.consumer().sourcesContent&&this.consumer().sourcesContent.length>0)}};var Dv=Fc;Fc.default=Fc;let{SourceMapConsumer:AF,SourceMapGenerator:kF}=xr,{fileURLToPath:km,pathToFileURL:Go}=xr,{isAbsolute:Bc,resolve:zc}=xr,{nanoid:OF}=wF,l0=xr,Om=Sd,NF=Dv,c0=Symbol("fromOffsetCache"),_F=!!(AF&&kF),Nm=!!(zc&&Bc),Xs=class{constructor(t,r={}){if(t===null||typeof t>"u"||typeof t=="object"&&!t.toString)throw new Error(`PostCSS received ${t} instead of CSS string`);if(this.css=t.toString(),this.css[0]==="\uFEFF"||this.css[0]===""?(this.hasBOM=!0,this.css=this.css.slice(1)):this.hasBOM=!1,r.from&&(!Nm||/^\w+:\/\//.test(r.from)||Bc(r.from)?this.file=r.from:this.file=zc(r.from)),Nm&&_F){let n=new NF(this.css,r);if(n.text){this.map=n;let i=n.consumer().file;!this.file&&i&&(this.file=this.mapResolve(i))}}this.file||(this.id="<input css "+OF(6)+">"),this.map&&(this.map.file=this.from)}error(t,r,n,i={}){let a,o,s;if(r&&typeof r=="object"){let l=r,c=n;if(typeof l.offset=="number"){let f=this.fromOffset(l.offset);r=f.line,n=f.col}else r=l.line,n=l.column;if(typeof c.offset=="number"){let f=this.fromOffset(c.offset);o=f.line,s=f.col}else o=c.line,s=c.column}else if(!n){let l=this.fromOffset(r);r=l.line,n=l.col}let u=this.origin(r,n,o,s);return u?a=new Om(t,u.endLine===void 0?u.line:{column:u.column,line:u.line},u.endLine===void 0?u.column:{column:u.endColumn,line:u.endLine},u.source,u.file,i.plugin):a=new Om(t,o===void 0?r:{column:n,line:r},o===void 0?n:{column:s,line:o},this.css,this.file,i.plugin),a.input={column:n,endColumn:s,endLine:o,line:r,source:this.css},this.file&&(Go&&(a.input.url=Go(this.file).toString()),a.input.file=this.file),a}fromOffset(t){let r,n;if(this[c0])n=this[c0];else{let a=this.css.split(`
`);n=new Array(a.length);let o=0;for(let s=0,u=a.length;s<u;s++)n[s]=o,o+=a[s].length+1;this[c0]=n}r=n[n.length-1];let i=0;if(t>=r)i=n.length-1;else{let a=n.length-2,o;for(;i<a;)if(o=i+(a-i>>1),t<n[o])a=o-1;else if(t>=n[o+1])i=o+1;else{i=o;break}}return{col:t-n[i]+1,line:i+1}}mapResolve(t){return/^\w+:\/\//.test(t)?t:zc(this.map.consumer().sourceRoot||this.map.root||".",t)}origin(t,r,n,i){if(!this.map)return!1;let a=this.map.consumer(),o=a.originalPositionFor({column:r,line:t});if(!o.source)return!1;let s;typeof n=="number"&&(s=a.originalPositionFor({column:i,line:n}));let u;Bc(o.source)?u=Go(o.source):u=new URL(o.source,this.map.consumer().sourceRoot||Go(this.map.mapFile));let l={column:o.column,endColumn:s&&s.column,endLine:s&&s.line,line:o.line,url:u.toString()};if(u.protocol==="file:")if(km)l.file=km(u);else throw new Error("file: protocol is not available in this PostCSS build");let c=a.sourceContentFor(o.source);return c&&(l.source=c),l}toJSON(){let t={};for(let r of["hasBOM","css","file","id"])this[r]!=null&&(t[r]=this[r]);return this.map&&(t.map={...this.map},t.map.consumerCache&&(t.map.consumerCache=void 0)),t}get from(){return this.file||this.id}};var ju=Xs;Xs.default=Xs;l0&&l0.registerInput&&l0.registerInput(Xs);let{SourceMapConsumer:Lv,SourceMapGenerator:ys}=xr,{dirname:ws,relative:Fv,resolve:Bv,sep:zv}=xr,{pathToFileURL:_m}=xr,CF=ju,MF=!!(Lv&&ys),RF=!!(ws&&Bv&&Fv&&zv),IF=class{constructor(t,r,n,i){this.stringify=t,this.mapOpts=n.map||{},this.root=r,this.opts=n,this.css=i,this.originalCSS=i,this.usesFileUrls=!this.mapOpts.from&&this.mapOpts.absolute,this.memoizedFileURLs=new Map,this.memoizedPaths=new Map,this.memoizedURLs=new Map}addAnnotation(){let t;this.isInline()?t="data:application/json;base64,"+this.toBase64(this.map.toString()):typeof this.mapOpts.annotation=="string"?t=this.mapOpts.annotation:typeof this.mapOpts.annotation=="function"?t=this.mapOpts.annotation(this.opts.to,this.root):t=this.outputFile()+".map";let r=`
`;this.css.includes(`\r
`)&&(r=`\r
`),this.css+=r+"/*# sourceMappingURL="+t+" */"}applyPrevMaps(){for(let t of this.previous()){let r=this.toUrl(this.path(t.file)),n=t.root||ws(t.file),i;this.mapOpts.sourcesContent===!1?(i=new Lv(t.text),i.sourcesContent&&(i.sourcesContent=i.sourcesContent.map(()=>null))):i=t.consumer(),this.map.applySourceMap(i,r,this.toUrl(this.path(n)))}}clearAnnotation(){if(this.mapOpts.annotation!==!1)if(this.root){let t;for(let r=this.root.nodes.length-1;r>=0;r--)t=this.root.nodes[r],t.type==="comment"&&t.text.indexOf("# sourceMappingURL=")===0&&this.root.removeChild(r)}else this.css&&(this.css=this.css.replace(/\n*?\/\*#[\S\s]*?\*\/$/gm,""))}generate(){if(this.clearAnnotation(),RF&&MF&&this.isMap())return this.generateMap();{let t="";return this.stringify(this.root,r=>{t+=r}),[t]}}generateMap(){if(this.root)this.generateString();else if(this.previous().length===1){let t=this.previous()[0].consumer();t.file=this.outputFile(),this.map=ys.fromSourceMap(t)}else this.map=new ys({file:this.outputFile()}),this.map.addMapping({generated:{column:0,line:1},original:{column:0,line:1},source:this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>"});return this.isSourcesContent()&&this.setSourcesContent(),this.root&&this.previous().length>0&&this.applyPrevMaps(),this.isAnnotation()&&this.addAnnotation(),this.isInline()?[this.css]:[this.css,this.map]}generateString(){this.css="",this.map=new ys({file:this.outputFile()});let t=1,r=1,n="<no source>",i={generated:{column:0,line:0},original:{column:0,line:0},source:""},a,o;this.stringify(this.root,(s,u,l)=>{if(this.css+=s,u&&l!=="end"&&(i.generated.line=t,i.generated.column=r-1,u.source&&u.source.start?(i.source=this.sourcePath(u),i.original.line=u.source.start.line,i.original.column=u.source.start.column-1,this.map.addMapping(i)):(i.source=n,i.original.line=1,i.original.column=0,this.map.addMapping(i))),a=s.match(/\n/g),a?(t+=a.length,o=s.lastIndexOf(`
`),r=s.length-o):r+=s.length,u&&l!=="start"){let c=u.parent||{raws:{}};(!(u.type==="decl"||u.type==="atrule"&&!u.nodes)||u!==c.last||c.raws.semicolon)&&(u.source&&u.source.end?(i.source=this.sourcePath(u),i.original.line=u.source.end.line,i.original.column=u.source.end.column-1,i.generated.line=t,i.generated.column=r-2,this.map.addMapping(i)):(i.source=n,i.original.line=1,i.original.column=0,i.generated.line=t,i.generated.column=r-1,this.map.addMapping(i)))}})}isAnnotation(){return this.isInline()?!0:typeof this.mapOpts.annotation<"u"?this.mapOpts.annotation:this.previous().length?this.previous().some(t=>t.annotation):!0}isInline(){if(typeof this.mapOpts.inline<"u")return this.mapOpts.inline;let t=this.mapOpts.annotation;return typeof t<"u"&&t!==!0?!1:this.previous().length?this.previous().some(r=>r.inline):!0}isMap(){return typeof this.opts.map<"u"?!!this.opts.map:this.previous().length>0}isSourcesContent(){return typeof this.mapOpts.sourcesContent<"u"?this.mapOpts.sourcesContent:this.previous().length?this.previous().some(t=>t.withContent()):!0}outputFile(){return this.opts.to?this.path(this.opts.to):this.opts.from?this.path(this.opts.from):"to.css"}path(t){if(this.mapOpts.absolute||t.charCodeAt(0)===60||/^\w+:\/\//.test(t))return t;let r=this.memoizedPaths.get(t);if(r)return r;let n=this.opts.to?ws(this.opts.to):".";typeof this.mapOpts.annotation=="string"&&(n=ws(Bv(n,this.mapOpts.annotation)));let i=Fv(n,t);return this.memoizedPaths.set(t,i),i}previous(){if(!this.previousMaps)if(this.previousMaps=[],this.root)this.root.walk(t=>{if(t.source&&t.source.input.map){let r=t.source.input.map;this.previousMaps.includes(r)||this.previousMaps.push(r)}});else{let t=new CF(this.originalCSS,this.opts);t.map&&this.previousMaps.push(t.map)}return this.previousMaps}setSourcesContent(){let t={};if(this.root)this.root.walk(r=>{if(r.source){let n=r.source.input.from;if(n&&!t[n]){t[n]=!0;let i=this.usesFileUrls?this.toFileUrl(n):this.toUrl(this.path(n));this.map.setSourceContent(i,r.source.input.css)}}});else if(this.css){let r=this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>";this.map.setSourceContent(r,this.css)}}sourcePath(t){return this.mapOpts.from?this.toUrl(this.mapOpts.from):this.usesFileUrls?this.toFileUrl(t.source.input.from):this.toUrl(this.path(t.source.input.from))}toBase64(t){return Buffer?Buffer.from(t).toString("base64"):window.btoa(unescape(encodeURIComponent(t)))}toFileUrl(t){let r=this.memoizedFileURLs.get(t);if(r)return r;if(_m){let n=_m(t).toString();return this.memoizedFileURLs.set(t,n),n}else throw new Error("`map.absolute` option is not available in this PostCSS build")}toUrl(t){let r=this.memoizedURLs.get(t);if(r)return r;zv==="\\"&&(t=t.replace(/\\/g,"/"));let n=encodeURI(t).replace(/[#?]/g,encodeURIComponent);return this.memoizedURLs.set(t,n),n}};var $v=IF;let PF=Hu,$c=class extends PF{constructor(t){super(t),this.type="comment"}};var Vu=$c;$c.default=$c;let{isClean:Uv,my:Hv}=co,qv=qu,jv=Vu,DF=Hu,Vv,Td,Ad,Gv;function Wv(e){return e.map(t=>(t.nodes&&(t.nodes=Wv(t.nodes)),delete t.source,t))}function Kv(e){if(e[Uv]=!1,e.proxyOf.nodes)for(let t of e.proxyOf.nodes)Kv(t)}let pn=class Xv extends DF{append(...t){for(let r of t){let n=this.normalize(r,this.last);for(let i of n)this.proxyOf.nodes.push(i)}return this.markDirty(),this}cleanRaws(t){if(super.cleanRaws(t),this.nodes)for(let r of this.nodes)r.cleanRaws(t)}each(t){if(!this.proxyOf.nodes)return;let r=this.getIterator(),n,i;for(;this.indexes[r]<this.proxyOf.nodes.length&&(n=this.indexes[r],i=t(this.proxyOf.nodes[n],n),i!==!1);)this.indexes[r]+=1;return delete this.indexes[r],i}every(t){return this.nodes.every(t)}getIterator(){this.lastEach||(this.lastEach=0),this.indexes||(this.indexes={}),this.lastEach+=1;let t=this.lastEach;return this.indexes[t]=0,t}getProxyProcessor(){return{get(t,r){return r==="proxyOf"?t:t[r]?r==="each"||typeof r=="string"&&r.startsWith("walk")?(...n)=>t[r](...n.map(i=>typeof i=="function"?(a,o)=>i(a.toProxy(),o):i)):r==="every"||r==="some"?n=>t[r]((i,...a)=>n(i.toProxy(),...a)):r==="root"?()=>t.root().toProxy():r==="nodes"?t.nodes.map(n=>n.toProxy()):r==="first"||r==="last"?t[r].toProxy():t[r]:t[r]},set(t,r,n){return t[r]===n||(t[r]=n,(r==="name"||r==="params"||r==="selector")&&t.markDirty()),!0}}}index(t){return typeof t=="number"?t:(t.proxyOf&&(t=t.proxyOf),this.proxyOf.nodes.indexOf(t))}insertAfter(t,r){let n=this.index(t),i=this.normalize(r,this.proxyOf.nodes[n]).reverse();n=this.index(t);for(let o of i)this.proxyOf.nodes.splice(n+1,0,o);let a;for(let o in this.indexes)a=this.indexes[o],n<a&&(this.indexes[o]=a+i.length);return this.markDirty(),this}insertBefore(t,r){let n=this.index(t),i=n===0?"prepend":!1,a=this.normalize(r,this.proxyOf.nodes[n],i).reverse();n=this.index(t);for(let s of a)this.proxyOf.nodes.splice(n,0,s);let o;for(let s in this.indexes)o=this.indexes[s],n<=o&&(this.indexes[s]=o+a.length);return this.markDirty(),this}normalize(t,r){if(typeof t=="string")t=Wv(Vv(t).nodes);else if(Array.isArray(t)){t=t.slice(0);for(let i of t)i.parent&&i.parent.removeChild(i,"ignore")}else if(t.type==="root"&&this.type!=="document"){t=t.nodes.slice(0);for(let i of t)i.parent&&i.parent.removeChild(i,"ignore")}else if(t.type)t=[t];else if(t.prop){if(typeof t.value>"u")throw new Error("Value field is missed in node creation");typeof t.value!="string"&&(t.value=String(t.value)),t=[new qv(t)]}else if(t.selector)t=[new Td(t)];else if(t.name)t=[new Ad(t)];else if(t.text)t=[new jv(t)];else throw new Error("Unknown node type in node creation");return t.map(i=>(i[Hv]||Xv.rebuild(i),i=i.proxyOf,i.parent&&i.parent.removeChild(i),i[Uv]&&Kv(i),typeof i.raws.before>"u"&&r&&typeof r.raws.before<"u"&&(i.raws.before=r.raws.before.replace(/\S/g,"")),i.parent=this.proxyOf,i))}prepend(...t){t=t.reverse();for(let r of t){let n=this.normalize(r,this.first,"prepend").reverse();for(let i of n)this.proxyOf.nodes.unshift(i);for(let i in this.indexes)this.indexes[i]=this.indexes[i]+n.length}return this.markDirty(),this}push(t){return t.parent=this,this.proxyOf.nodes.push(t),this}removeAll(){for(let t of this.proxyOf.nodes)t.parent=void 0;return this.proxyOf.nodes=[],this.markDirty(),this}removeChild(t){t=this.index(t),this.proxyOf.nodes[t].parent=void 0,this.proxyOf.nodes.splice(t,1);let r;for(let n in this.indexes)r=this.indexes[n],r>=t&&(this.indexes[n]=r-1);return this.markDirty(),this}replaceValues(t,r,n){return n||(n=r,r={}),this.walkDecls(i=>{r.props&&!r.props.includes(i.prop)||r.fast&&!i.value.includes(r.fast)||(i.value=i.value.replace(t,n))}),this.markDirty(),this}some(t){return this.nodes.some(t)}walk(t){return this.each((r,n)=>{let i;try{i=t(r,n)}catch(a){throw r.addToError(a)}return i!==!1&&r.walk&&(i=r.walk(t)),i})}walkAtRules(t,r){return r?t instanceof RegExp?this.walk((n,i)=>{if(n.type==="atrule"&&t.test(n.name))return r(n,i)}):this.walk((n,i)=>{if(n.type==="atrule"&&n.name===t)return r(n,i)}):(r=t,this.walk((n,i)=>{if(n.type==="atrule")return r(n,i)}))}walkComments(t){return this.walk((r,n)=>{if(r.type==="comment")return t(r,n)})}walkDecls(t,r){return r?t instanceof RegExp?this.walk((n,i)=>{if(n.type==="decl"&&t.test(n.prop))return r(n,i)}):this.walk((n,i)=>{if(n.type==="decl"&&n.prop===t)return r(n,i)}):(r=t,this.walk((n,i)=>{if(n.type==="decl")return r(n,i)}))}walkRules(t,r){return r?t instanceof RegExp?this.walk((n,i)=>{if(n.type==="rule"&&t.test(n.selector))return r(n,i)}):this.walk((n,i)=>{if(n.type==="rule"&&n.selector===t)return r(n,i)}):(r=t,this.walk((n,i)=>{if(n.type==="rule")return r(n,i)}))}get first(){if(this.proxyOf.nodes)return this.proxyOf.nodes[0]}get last(){if(this.proxyOf.nodes)return this.proxyOf.nodes[this.proxyOf.nodes.length-1]}};pn.registerParse=e=>{Vv=e};pn.registerRule=e=>{Td=e};pn.registerAtRule=e=>{Ad=e};pn.registerRoot=e=>{Gv=e};var pi=pn;pn.default=pn;pn.rebuild=e=>{e.type==="atrule"?Object.setPrototypeOf(e,Ad.prototype):e.type==="rule"?Object.setPrototypeOf(e,Td.prototype):e.type==="decl"?Object.setPrototypeOf(e,qv.prototype):e.type==="comment"?Object.setPrototypeOf(e,jv.prototype):e.type==="root"&&Object.setPrototypeOf(e,Gv.prototype),e[Hv]=!0,e.nodes&&e.nodes.forEach(t=>{pn.rebuild(t)})};let LF=pi,Yv,Zv,Ua=class extends LF{constructor(t){super({type:"document",...t}),this.nodes||(this.nodes=[])}toResult(t={}){return new Yv(new Zv,this,t).stringify()}};Ua.registerLazyResult=e=>{Yv=e};Ua.registerProcessor=e=>{Zv=e};var kd=Ua;Ua.default=Ua;let Uc=class{constructor(t,r={}){if(this.type="warning",this.text=t,r.node&&r.node.source){let n=r.node.rangeBy(r);this.line=n.start.line,this.column=n.start.column,this.endLine=n.end.line,this.endColumn=n.end.column}for(let n in r)this[n]=r[n]}toString(){return this.node?this.node.error(this.text,{index:this.index,plugin:this.plugin,word:this.word}).message:this.plugin?this.plugin+": "+this.text:this.text}};var Qv=Uc;Uc.default=Uc;let FF=Qv,Hc=class{constructor(t,r,n){this.processor=t,this.messages=[],this.root=r,this.opts=n,this.css=void 0,this.map=void 0}toString(){return this.css}warn(t,r={}){r.plugin||this.lastPlugin&&this.lastPlugin.postcssPlugin&&(r.plugin=this.lastPlugin.postcssPlugin);let n=new FF(t,r);return this.messages.push(n),n}warnings(){return this.messages.filter(t=>t.type==="warning")}get content(){return this.css}};var Od=Hc;Hc.default=Hc;const f0="'".charCodeAt(0),Cm='"'.charCodeAt(0),Wo="\\".charCodeAt(0),Mm="/".charCodeAt(0),Ko=`
`.charCodeAt(0),ua=" ".charCodeAt(0),Xo="\f".charCodeAt(0),Yo="	".charCodeAt(0),Zo="\r".charCodeAt(0),BF="[".charCodeAt(0),zF="]".charCodeAt(0),$F="(".charCodeAt(0),UF=")".charCodeAt(0),HF="{".charCodeAt(0),qF="}".charCodeAt(0),jF=";".charCodeAt(0),VF="*".charCodeAt(0),GF=":".charCodeAt(0),WF="@".charCodeAt(0),Qo=/[\t\n\f\r "#'()/;[\\\]{}]/g,Jo=/[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g,KF=/.[\r\n"'(/\\]/,Rm=/[\da-f]/i;var XF=function(t,r={}){let n=t.css.valueOf(),i=r.ignoreErrors,a,o,s,u,l,c,f,d,h,p,m=n.length,g=0,v=[],w=[];function x(){return g}function N(H){throw t.error("Unclosed "+H,g)}function O(){return w.length===0&&g>=m}function A(H){if(w.length)return w.pop();if(g>=m)return;let z=H?H.ignoreUnclosed:!1;switch(a=n.charCodeAt(g),a){case Ko:case ua:case Yo:case Zo:case Xo:{o=g;do o+=1,a=n.charCodeAt(o);while(a===ua||a===Ko||a===Yo||a===Zo||a===Xo);p=["space",n.slice(g,o)],g=o-1;break}case BF:case zF:case HF:case qF:case GF:case jF:case UF:{let L=String.fromCharCode(a);p=[L,L,g];break}case $F:{if(d=v.length?v.pop()[1]:"",h=n.charCodeAt(g+1),d==="url"&&h!==f0&&h!==Cm&&h!==ua&&h!==Ko&&h!==Yo&&h!==Xo&&h!==Zo){o=g;do{if(c=!1,o=n.indexOf(")",o+1),o===-1)if(i||z){o=g;break}else N("bracket");for(f=o;n.charCodeAt(f-1)===Wo;)f-=1,c=!c}while(c);p=["brackets",n.slice(g,o+1),g,o],g=o}else o=n.indexOf(")",g+1),u=n.slice(g,o+1),o===-1||KF.test(u)?p=["(","(",g]:(p=["brackets",u,g,o],g=o);break}case f0:case Cm:{s=a===f0?"'":'"',o=g;do{if(c=!1,o=n.indexOf(s,o+1),o===-1)if(i||z){o=g+1;break}else N("string");for(f=o;n.charCodeAt(f-1)===Wo;)f-=1,c=!c}while(c);p=["string",n.slice(g,o+1),g,o],g=o;break}case WF:{Qo.lastIndex=g+1,Qo.test(n),Qo.lastIndex===0?o=n.length-1:o=Qo.lastIndex-2,p=["at-word",n.slice(g,o+1),g,o],g=o;break}case Wo:{for(o=g,l=!0;n.charCodeAt(o+1)===Wo;)o+=1,l=!l;if(a=n.charCodeAt(o+1),l&&a!==Mm&&a!==ua&&a!==Ko&&a!==Yo&&a!==Zo&&a!==Xo&&(o+=1,Rm.test(n.charAt(o)))){for(;Rm.test(n.charAt(o+1));)o+=1;n.charCodeAt(o+1)===ua&&(o+=1)}p=["word",n.slice(g,o+1),g,o],g=o;break}default:{a===Mm&&n.charCodeAt(g+1)===VF?(o=n.indexOf("*/",g+2)+1,o===0&&(i||z?o=n.length:N("comment")),p=["comment",n.slice(g,o+1),g,o],g=o):(Jo.lastIndex=g+1,Jo.test(n),Jo.lastIndex===0?o=n.length-1:o=Jo.lastIndex-2,p=["word",n.slice(g,o+1),g,o],v.push(p),g=o);break}}return g++,p}function D(H){w.push(H)}return{back:D,endOfFile:O,nextToken:A,position:x}};let Jv=pi,Ys=class extends Jv{constructor(t){super(t),this.type="atrule"}append(...t){return this.proxyOf.nodes||(this.nodes=[]),super.append(...t)}prepend(...t){return this.proxyOf.nodes||(this.nodes=[]),super.prepend(...t)}};var Nd=Ys;Ys.default=Ys;Jv.registerAtRule(Ys);let ey=pi,ty,ry,Wi=class extends ey{constructor(t){super(t),this.type="root",this.nodes||(this.nodes=[])}normalize(t,r,n){let i=super.normalize(t);if(r){if(n==="prepend")this.nodes.length>1?r.raws.before=this.nodes[1].raws.before:delete r.raws.before;else if(this.first!==r)for(let a of i)a.raws.before=r.raws.before}return i}removeChild(t,r){let n=this.index(t);return!r&&n===0&&this.nodes.length>1&&(this.nodes[1].raws.before=this.nodes[n].raws.before),super.removeChild(t)}toResult(t={}){return new ty(new ry,this,t).stringify()}};Wi.registerLazyResult=e=>{ty=e};Wi.registerProcessor=e=>{ry=e};var fo=Wi;Wi.default=Wi;ey.registerRoot(Wi);let Ha={comma(e){return Ha.split(e,[","],!0)},space(e){let t=[" ",`
`,"	"];return Ha.split(e,t)},split(e,t,r){let n=[],i="",a=!1,o=0,s=!1,u="",l=!1;for(let c of e)l?l=!1:c==="\\"?l=!0:s?c===u&&(s=!1):c==='"'||c==="'"?(s=!0,u=c):c==="("?o+=1:c===")"?o>0&&(o-=1):o===0&&t.includes(c)&&(a=!0),a?(i!==""&&n.push(i.trim()),i="",a=!1):i+=c;return(r||i!=="")&&n.push(i.trim()),n}};var ny=Ha;Ha.default=Ha;let iy=pi,YF=ny,Zs=class extends iy{constructor(t){super(t),this.type="rule",this.nodes||(this.nodes=[])}get selectors(){return YF.comma(this.selector)}set selectors(t){let r=this.selector?this.selector.match(/,\s*/):null,n=r?r[0]:","+this.raw("between","beforeOpen");this.selector=t.join(n)}};var _d=Zs;Zs.default=Zs;iy.registerRule(Zs);let ZF=qu,QF=XF,JF=Vu,eB=Nd,tB=fo,Im=_d;const Pm={empty:!0,space:!0};function rB(e){for(let t=e.length-1;t>=0;t--){let r=e[t],n=r[3]||r[2];if(n)return n}}let nB=class{constructor(t){this.input=t,this.root=new tB,this.current=this.root,this.spaces="",this.semicolon=!1,this.customProperty=!1,this.createTokenizer(),this.root.source={input:t,start:{column:1,line:1,offset:0}}}atrule(t){let r=new eB;r.name=t[1].slice(1),r.name===""&&this.unnamedAtrule(r,t),this.init(r,t[2]);let n,i,a,o=!1,s=!1,u=[],l=[];for(;!this.tokenizer.endOfFile();){if(t=this.tokenizer.nextToken(),n=t[0],n==="("||n==="["?l.push(n==="("?")":"]"):n==="{"&&l.length>0?l.push("}"):n===l[l.length-1]&&l.pop(),l.length===0)if(n===";"){r.source.end=this.getPosition(t[2]),r.source.end.offset++,this.semicolon=!0;break}else if(n==="{"){s=!0;break}else if(n==="}"){if(u.length>0){for(a=u.length-1,i=u[a];i&&i[0]==="space";)i=u[--a];i&&(r.source.end=this.getPosition(i[3]||i[2]),r.source.end.offset++)}this.end(t);break}else u.push(t);else u.push(t);if(this.tokenizer.endOfFile()){o=!0;break}}r.raws.between=this.spacesAndCommentsFromEnd(u),u.length?(r.raws.afterName=this.spacesAndCommentsFromStart(u),this.raw(r,"params",u),o&&(t=u[u.length-1],r.source.end=this.getPosition(t[3]||t[2]),r.source.end.offset++,this.spaces=r.raws.between,r.raws.between="")):(r.raws.afterName="",r.params=""),s&&(r.nodes=[],this.current=r)}checkMissedSemicolon(t){let r=this.colon(t);if(r===!1)return;let n=0,i;for(let a=r-1;a>=0&&(i=t[a],!(i[0]!=="space"&&(n+=1,n===2)));a--);throw this.input.error("Missed semicolon",i[0]==="word"?i[3]+1:i[2])}colon(t){let r=0,n,i,a;for(let[o,s]of t.entries()){if(n=s,i=n[0],i==="("&&(r+=1),i===")"&&(r-=1),r===0&&i===":")if(!a)this.doubleColon(n);else{if(a[0]==="word"&&a[1]==="progid")continue;return o}a=n}return!1}comment(t){let r=new JF;this.init(r,t[2]),r.source.end=this.getPosition(t[3]||t[2]),r.source.end.offset++;let n=t[1].slice(2,-2);if(/^\s*$/.test(n))r.text="",r.raws.left=n,r.raws.right="";else{let i=n.match(/^(\s*)([^]*\S)(\s*)$/);r.text=i[2],r.raws.left=i[1],r.raws.right=i[3]}}createTokenizer(){this.tokenizer=QF(this.input)}decl(t,r){let n=new ZF;this.init(n,t[0][2]);let i=t[t.length-1];for(i[0]===";"&&(this.semicolon=!0,t.pop()),n.source.end=this.getPosition(i[3]||i[2]||rB(t)),n.source.end.offset++;t[0][0]!=="word";)t.length===1&&this.unknownWord(t),n.raws.before+=t.shift()[1];for(n.source.start=this.getPosition(t[0][2]),n.prop="";t.length;){let l=t[0][0];if(l===":"||l==="space"||l==="comment")break;n.prop+=t.shift()[1]}n.raws.between="";let a;for(;t.length;)if(a=t.shift(),a[0]===":"){n.raws.between+=a[1];break}else a[0]==="word"&&/\w/.test(a[1])&&this.unknownWord([a]),n.raws.between+=a[1];(n.prop[0]==="_"||n.prop[0]==="*")&&(n.raws.before+=n.prop[0],n.prop=n.prop.slice(1));let o=[],s;for(;t.length&&(s=t[0][0],!(s!=="space"&&s!=="comment"));)o.push(t.shift());this.precheckMissedSemicolon(t);for(let l=t.length-1;l>=0;l--){if(a=t[l],a[1].toLowerCase()==="!important"){n.important=!0;let c=this.stringFrom(t,l);c=this.spacesFromEnd(t)+c,c!==" !important"&&(n.raws.important=c);break}else if(a[1].toLowerCase()==="important"){let c=t.slice(0),f="";for(let d=l;d>0;d--){let h=c[d][0];if(f.trim().indexOf("!")===0&&h!=="space")break;f=c.pop()[1]+f}f.trim().indexOf("!")===0&&(n.important=!0,n.raws.important=f,t=c)}if(a[0]!=="space"&&a[0]!=="comment")break}t.some(l=>l[0]!=="space"&&l[0]!=="comment")&&(n.raws.between+=o.map(l=>l[1]).join(""),o=[]),this.raw(n,"value",o.concat(t),r),n.value.includes(":")&&!r&&this.checkMissedSemicolon(t)}doubleColon(t){throw this.input.error("Double colon",{offset:t[2]},{offset:t[2]+t[1].length})}emptyRule(t){let r=new Im;this.init(r,t[2]),r.selector="",r.raws.between="",this.current=r}end(t){this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.semicolon=!1,this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.spaces="",this.current.parent?(this.current.source.end=this.getPosition(t[2]),this.current.source.end.offset++,this.current=this.current.parent):this.unexpectedClose(t)}endFile(){this.current.parent&&this.unclosedBlock(),this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.root.source.end=this.getPosition(this.tokenizer.position())}freeSemicolon(t){if(this.spaces+=t[1],this.current.nodes){let r=this.current.nodes[this.current.nodes.length-1];r&&r.type==="rule"&&!r.raws.ownSemicolon&&(r.raws.ownSemicolon=this.spaces,this.spaces="")}}getPosition(t){let r=this.input.fromOffset(t);return{column:r.col,line:r.line,offset:t}}init(t,r){this.current.push(t),t.source={input:this.input,start:this.getPosition(r)},t.raws.before=this.spaces,this.spaces="",t.type!=="comment"&&(this.semicolon=!1)}other(t){let r=!1,n=null,i=!1,a=null,o=[],s=t[1].startsWith("--"),u=[],l=t;for(;l;){if(n=l[0],u.push(l),n==="("||n==="[")a||(a=l),o.push(n==="("?")":"]");else if(s&&i&&n==="{")a||(a=l),o.push("}");else if(o.length===0)if(n===";")if(i){this.decl(u,s);return}else break;else if(n==="{"){this.rule(u);return}else if(n==="}"){this.tokenizer.back(u.pop()),r=!0;break}else n===":"&&(i=!0);else n===o[o.length-1]&&(o.pop(),o.length===0&&(a=null));l=this.tokenizer.nextToken()}if(this.tokenizer.endOfFile()&&(r=!0),o.length>0&&this.unclosedBracket(a),r&&i){if(!s)for(;u.length&&(l=u[u.length-1][0],!(l!=="space"&&l!=="comment"));)this.tokenizer.back(u.pop());this.decl(u,s)}else this.unknownWord(u)}parse(){let t;for(;!this.tokenizer.endOfFile();)switch(t=this.tokenizer.nextToken(),t[0]){case"space":this.spaces+=t[1];break;case";":this.freeSemicolon(t);break;case"}":this.end(t);break;case"comment":this.comment(t);break;case"at-word":this.atrule(t);break;case"{":this.emptyRule(t);break;default:this.other(t);break}this.endFile()}precheckMissedSemicolon(){}raw(t,r,n,i){let a,o,s=n.length,u="",l=!0,c,f;for(let d=0;d<s;d+=1)a=n[d],o=a[0],o==="space"&&d===s-1&&!i?l=!1:o==="comment"?(f=n[d-1]?n[d-1][0]:"empty",c=n[d+1]?n[d+1][0]:"empty",!Pm[f]&&!Pm[c]?u.slice(-1)===","?l=!1:u+=a[1]:l=!1):u+=a[1];if(!l){let d=n.reduce((h,p)=>h+p[1],"");t.raws[r]={raw:d,value:u}}t[r]=u}rule(t){t.pop();let r=new Im;this.init(r,t[0][2]),r.raws.between=this.spacesAndCommentsFromEnd(t),this.raw(r,"selector",t),this.current=r}spacesAndCommentsFromEnd(t){let r,n="";for(;t.length&&(r=t[t.length-1][0],!(r!=="space"&&r!=="comment"));)n=t.pop()[1]+n;return n}spacesAndCommentsFromStart(t){let r,n="";for(;t.length&&(r=t[0][0],!(r!=="space"&&r!=="comment"));)n+=t.shift()[1];return n}spacesFromEnd(t){let r,n="";for(;t.length&&(r=t[t.length-1][0],r==="space");)n=t.pop()[1]+n;return n}stringFrom(t,r){let n="";for(let i=r;i<t.length;i++)n+=t[i][1];return t.splice(r,t.length-r),n}unclosedBlock(){let t=this.current.source.start;throw this.input.error("Unclosed block",t.line,t.column)}unclosedBracket(t){throw this.input.error("Unclosed bracket",{offset:t[2]},{offset:t[2]+1})}unexpectedClose(t){throw this.input.error("Unexpected }",{offset:t[2]},{offset:t[2]+1})}unknownWord(t){throw this.input.error("Unknown word",{offset:t[0][2]},{offset:t[0][2]+t[0][1].length})}unnamedAtrule(t,r){throw this.input.error("At-rule without name",{offset:r[2]},{offset:r[2]+r[1].length})}};var iB=nB;let aB=pi,oB=iB,sB=ju;function Qs(e,t){let r=new sB(e,t),n=new oB(r);try{n.parse()}catch(i){throw i}return n.root}var Cd=Qs;Qs.default=Qs;aB.registerParse(Qs);let{isClean:Mr,my:uB}=co,lB=$v,cB=Uu,fB=pi,dB=kd,Dm=Od,hB=Cd,pB=fo;const mB={atrule:"AtRule",comment:"Comment",decl:"Declaration",document:"Document",root:"Root",rule:"Rule"},gB={AtRule:!0,AtRuleExit:!0,Comment:!0,CommentExit:!0,Declaration:!0,DeclarationExit:!0,Document:!0,DocumentExit:!0,Once:!0,OnceExit:!0,postcssPlugin:!0,prepare:!0,Root:!0,RootExit:!0,Rule:!0,RuleExit:!0},bB={Once:!0,postcssPlugin:!0,prepare:!0},Ki=0;function la(e){return typeof e=="object"&&typeof e.then=="function"}function ay(e){let t=!1,r=mB[e.type];return e.type==="decl"?t=e.prop.toLowerCase():e.type==="atrule"&&(t=e.name.toLowerCase()),t&&e.append?[r,r+"-"+t,Ki,r+"Exit",r+"Exit-"+t]:t?[r,r+"-"+t,r+"Exit",r+"Exit-"+t]:e.append?[r,Ki,r+"Exit"]:[r,r+"Exit"]}function Lm(e){let t;return e.type==="document"?t=["Document",Ki,"DocumentExit"]:e.type==="root"?t=["Root",Ki,"RootExit"]:t=ay(e),{eventIndex:0,events:t,iterator:0,node:e,visitorIndex:0,visitors:[]}}function qc(e){return e[Mr]=!1,e.nodes&&e.nodes.forEach(t=>qc(t)),e}let jc={},Xi=class oy{constructor(t,r,n){this.stringified=!1,this.processed=!1;let i;if(typeof r=="object"&&r!==null&&(r.type==="root"||r.type==="document"))i=qc(r);else if(r instanceof oy||r instanceof Dm)i=qc(r.root),r.map&&(typeof n.map>"u"&&(n.map={}),n.map.inline||(n.map.inline=!1),n.map.prev=r.map);else{let a=hB;n.syntax&&(a=n.syntax.parse),n.parser&&(a=n.parser),a.parse&&(a=a.parse);try{i=a(r,n)}catch(o){this.processed=!0,this.error=o}i&&!i[uB]&&fB.rebuild(i)}this.result=new Dm(t,i,n),this.helpers={...jc,postcss:jc,result:this.result},this.plugins=this.processor.plugins.map(a=>typeof a=="object"&&a.prepare?{...a,...a.prepare(this.result)}:a)}async(){return this.error?Promise.reject(this.error):this.processed?Promise.resolve(this.result):(this.processing||(this.processing=this.runAsync()),this.processing)}catch(t){return this.async().catch(t)}finally(t){return this.async().then(t,t)}getAsyncError(){throw new Error("Use process(css).then(cb) to work with async plugins")}handleError(t,r){let n=this.result.lastPlugin;try{r&&r.addToError(t),this.error=t,t.name==="CssSyntaxError"&&!t.plugin?(t.plugin=n.postcssPlugin,t.setMessage()):n.postcssVersion}catch(i){console&&console.error&&console.error(i)}return t}prepareVisitors(){this.listeners={};let t=(r,n,i)=>{this.listeners[n]||(this.listeners[n]=[]),this.listeners[n].push([r,i])};for(let r of this.plugins)if(typeof r=="object")for(let n in r){if(!gB[n]&&/^[A-Z]/.test(n))throw new Error(`Unknown event ${n} in ${r.postcssPlugin}. Try to update PostCSS (${this.processor.version} now).`);if(!bB[n])if(typeof r[n]=="object")for(let i in r[n])i==="*"?t(r,n,r[n][i]):t(r,n+"-"+i.toLowerCase(),r[n][i]);else typeof r[n]=="function"&&t(r,n,r[n])}this.hasListener=Object.keys(this.listeners).length>0}async runAsync(){this.plugin=0;for(let t=0;t<this.plugins.length;t++){let r=this.plugins[t],n=this.runOnRoot(r);if(la(n))try{await n}catch(i){throw this.handleError(i)}}if(this.prepareVisitors(),this.hasListener){let t=this.result.root;for(;!t[Mr];){t[Mr]=!0;let r=[Lm(t)];for(;r.length>0;){let n=this.visitTick(r);if(la(n))try{await n}catch(i){let a=r[r.length-1].node;throw this.handleError(i,a)}}}if(this.listeners.OnceExit)for(let[r,n]of this.listeners.OnceExit){this.result.lastPlugin=r;try{if(t.type==="document"){let i=t.nodes.map(a=>n(a,this.helpers));await Promise.all(i)}else await n(t,this.helpers)}catch(i){throw this.handleError(i)}}}return this.processed=!0,this.stringify()}runOnRoot(t){this.result.lastPlugin=t;try{if(typeof t=="object"&&t.Once){if(this.result.root.type==="document"){let r=this.result.root.nodes.map(n=>t.Once(n,this.helpers));return la(r[0])?Promise.all(r):r}return t.Once(this.result.root,this.helpers)}else if(typeof t=="function")return t(this.result.root,this.result)}catch(r){throw this.handleError(r)}}stringify(){if(this.error)throw this.error;if(this.stringified)return this.result;this.stringified=!0,this.sync();let t=this.result.opts,r=cB;t.syntax&&(r=t.syntax.stringify),t.stringifier&&(r=t.stringifier),r.stringify&&(r=r.stringify);let i=new lB(r,this.result.root,this.result.opts).generate();return this.result.css=i[0],this.result.map=i[1],this.result}sync(){if(this.error)throw this.error;if(this.processed)return this.result;if(this.processed=!0,this.processing)throw this.getAsyncError();for(let t of this.plugins){let r=this.runOnRoot(t);if(la(r))throw this.getAsyncError()}if(this.prepareVisitors(),this.hasListener){let t=this.result.root;for(;!t[Mr];)t[Mr]=!0,this.walkSync(t);if(this.listeners.OnceExit)if(t.type==="document")for(let r of t.nodes)this.visitSync(this.listeners.OnceExit,r);else this.visitSync(this.listeners.OnceExit,t)}return this.result}then(t,r){return this.async().then(t,r)}toString(){return this.css}visitSync(t,r){for(let[n,i]of t){this.result.lastPlugin=n;let a;try{a=i(r,this.helpers)}catch(o){throw this.handleError(o,r.proxyOf)}if(r.type!=="root"&&r.type!=="document"&&!r.parent)return!0;if(la(a))throw this.getAsyncError()}}visitTick(t){let r=t[t.length-1],{node:n,visitors:i}=r;if(n.type!=="root"&&n.type!=="document"&&!n.parent){t.pop();return}if(i.length>0&&r.visitorIndex<i.length){let[o,s]=i[r.visitorIndex];r.visitorIndex+=1,r.visitorIndex===i.length&&(r.visitors=[],r.visitorIndex=0),this.result.lastPlugin=o;try{return s(n.toProxy(),this.helpers)}catch(u){throw this.handleError(u,n)}}if(r.iterator!==0){let o=r.iterator,s;for(;s=n.nodes[n.indexes[o]];)if(n.indexes[o]+=1,!s[Mr]){s[Mr]=!0,t.push(Lm(s));return}r.iterator=0,delete n.indexes[o]}let a=r.events;for(;r.eventIndex<a.length;){let o=a[r.eventIndex];if(r.eventIndex+=1,o===Ki){n.nodes&&n.nodes.length&&(n[Mr]=!0,r.iterator=n.getIterator());return}else if(this.listeners[o]){r.visitors=this.listeners[o];return}}t.pop()}walkSync(t){t[Mr]=!0;let r=ay(t);for(let n of r)if(n===Ki)t.nodes&&t.each(i=>{i[Mr]||this.walkSync(i)});else{let i=this.listeners[n];if(i&&this.visitSync(i,t.toProxy()))return}}warnings(){return this.sync().warnings()}get content(){return this.stringify().content}get css(){return this.stringify().css}get map(){return this.stringify().map}get messages(){return this.sync().messages}get opts(){return this.result.opts}get processor(){return this.result.processor}get root(){return this.sync().root}get[Symbol.toStringTag](){return"LazyResult"}};Xi.registerPostcss=e=>{jc=e};var sy=Xi;Xi.default=Xi;pB.registerLazyResult(Xi);dB.registerLazyResult(Xi);let vB=$v,yB=Uu,wB=Cd;const xB=Od;let Vc=class{constructor(t,r,n){r=r.toString(),this.stringified=!1,this._processor=t,this._css=r,this._opts=n,this._map=void 0;let i,a=yB;this.result=new xB(this._processor,i,this._opts),this.result.css=r;let o=this;Object.defineProperty(this.result,"root",{get(){return o.root}});let s=new vB(a,i,this._opts,r);if(s.isMap()){let[u,l]=s.generate();u&&(this.result.css=u),l&&(this.result.map=l)}else s.clearAnnotation(),this.result.css=s.css}async(){return this.error?Promise.reject(this.error):Promise.resolve(this.result)}catch(t){return this.async().catch(t)}finally(t){return this.async().then(t,t)}sync(){if(this.error)throw this.error;return this.result}then(t,r){return this.async().then(t,r)}toString(){return this._css}warnings(){return[]}get content(){return this.result.css}get css(){return this.result.css}get map(){return this.result.map}get messages(){return[]}get opts(){return this.result.opts}get processor(){return this.result.processor}get root(){if(this._root)return this._root;let t,r=wB;try{t=r(this._css,this._opts)}catch(n){this.error=n}if(this.error)throw this.error;return this._root=t,t}get[Symbol.toStringTag](){return"NoWorkResult"}};var EB=Vc;Vc.default=Vc;let SB=EB,TB=sy,AB=kd,kB=fo,qa=class{constructor(t=[]){this.version="8.4.33",this.plugins=this.normalize(t)}normalize(t){let r=[];for(let n of t)if(n.postcss===!0?n=n():n.postcss&&(n=n.postcss),typeof n=="object"&&Array.isArray(n.plugins))r=r.concat(n.plugins);else if(typeof n=="object"&&n.postcssPlugin)r.push(n);else if(typeof n=="function")r.push(n);else if(!(typeof n=="object"&&(n.parse||n.stringify)))throw new Error(n+" is not a PostCSS plugin");return r}process(t,r={}){return!this.plugins.length&&!r.parser&&!r.stringifier&&!r.syntax?new SB(this,t,r):new TB(this,t,r)}use(t){return this.plugins=this.plugins.concat(this.normalize([t])),this}};var OB=qa;qa.default=qa;kB.registerProcessor(qa);AB.registerProcessor(qa);let NB=qu,_B=Dv,CB=Vu,MB=Nd,RB=ju,IB=fo,PB=_d;function ja(e,t){if(Array.isArray(e))return e.map(i=>ja(i));let{inputs:r,...n}=e;if(r){t=[];for(let i of r){let a={...i,__proto__:RB.prototype};a.map&&(a.map={...a.map,__proto__:_B.prototype}),t.push(a)}}if(n.nodes&&(n.nodes=e.nodes.map(i=>ja(i,t))),n.source){let{inputId:i,...a}=n.source;n.source=a,i!=null&&(n.source.input=t[i])}if(n.type==="root")return new IB(n);if(n.type==="decl")return new NB(n);if(n.type==="rule")return new PB(n);if(n.type==="comment")return new CB(n);if(n.type==="atrule")return new MB(n);throw new Error("Unknown node type: "+e.type)}var DB=ja;ja.default=ja;let LB=Sd,uy=qu,FB=sy,BB=pi,Md=OB,zB=Uu,$B=DB,ly=kd,UB=Qv,cy=Vu,fy=Nd,HB=Od,qB=ju,jB=Cd,VB=ny,dy=_d,hy=fo,GB=Hu;function Ve(...e){return e.length===1&&Array.isArray(e[0])&&(e=e[0]),new Md(e)}Ve.plugin=function(t,r){let n=!1;function i(...o){console&&console.warn&&!n&&(n=!0,console.warn(t+`: postcss.plugin was deprecated. Migration guide:
https://evilmartians.com/chronicles/postcss-8-plugin-migration`),{}.LANG&&{}.LANG.startsWith("cn")&&console.warn(t+`: 里面 postcss.plugin 被弃用. 迁移指南:
https://www.w3ctech.com/topic/2226`));let s=r(...o);return s.postcssPlugin=t,s.postcssVersion=new Md().version,s}let a;return Object.defineProperty(i,"postcss",{get(){return a||(a=i()),a}}),i.process=function(o,s,u){return Ve([i(u)]).process(o,s)},i};Ve.stringify=zB;Ve.parse=jB;Ve.fromJSON=$B;Ve.list=VB;Ve.comment=e=>new cy(e);Ve.atRule=e=>new fy(e);Ve.decl=e=>new uy(e);Ve.rule=e=>new dy(e);Ve.root=e=>new hy(e);Ve.document=e=>new ly(e);Ve.CssSyntaxError=LB;Ve.Declaration=uy;Ve.Container=BB;Ve.Processor=Md;Ve.Document=ly;Ve.Comment=cy;Ve.Warning=UB;Ve.AtRule=fy;Ve.Result=HB;Ve.Input=qB;Ve.Rule=dy;Ve.Root=hy;Ve.Node=GB;FB.registerPostcss(Ve);var WB=Ve;Ve.default=Ve;const KB=nv,Fm=GL,{isPlainObject:XB}=xd,Bm=sF,YB=uF,{parse:ZB}=WB,QB=["img","audio","video","picture","svg","object","map","iframe","embed"],JB=["script","style"];function ha(e,t){e&&Object.keys(e).forEach(function(r){t(e[r],r)})}function rn(e,t){return{}.hasOwnProperty.call(e,t)}function zm(e,t){const r=[];return ha(e,function(n){t(n)&&r.push(n)}),r}function ez(e){for(const t in e)if(rn(e,t))return!1;return!0}function tz(e){return e.map(function(t){if(!t.url)throw new Error("URL missing");return t.url+(t.w?` ${t.w}w`:"")+(t.h?` ${t.h}h`:"")+(t.d?` ${t.d}x`:"")}).join(", ")}var rz=Va;const nz=/^[^\0\t\n\f\r /<=>]+$/;function Va(e,t,r){if(e==null)return"";typeof e=="number"&&(e=e.toString());let n="",i="";function a(C,U){const $=this;this.tag=C,this.attribs=U||{},this.tagPosition=n.length,this.text="",this.mediaChildren=[],this.updateParentNodeText=function(){if(g.length){const V=g[g.length-1];V.text+=$.text}},this.updateParentNodeMediaChildren=function(){g.length&&QB.includes(this.tag)&&g[g.length-1].mediaChildren.push(this.tag)}}t=Object.assign({},Va.defaults,t),t.parser=Object.assign({},iz,t.parser);const o=function(C){return t.allowedTags===!1||(t.allowedTags||[]).indexOf(C)>-1};JB.forEach(function(C){o(C)&&!t.allowVulnerableTags&&console.warn(`

⚠️ Your \`allowedTags\` option includes, \`${C}\`, which is inherently
vulnerable to XSS attacks. Please remove it from \`allowedTags\`.
Or, to disable this warning, add the \`allowVulnerableTags\` option
and ensure you are accounting for this risk.

`)});const s=t.nonTextTags||["script","style","textarea","option"];let u,l;t.allowedAttributes&&(u={},l={},ha(t.allowedAttributes,function(C,U){u[U]=[];const $=[];C.forEach(function(V){typeof V=="string"&&V.indexOf("*")>=0?$.push(Fm(V).replace(/\\\*/g,".*")):u[U].push(V)}),$.length&&(l[U]=new RegExp("^("+$.join("|")+")$"))}));const c={},f={},d={};ha(t.allowedClasses,function(C,U){if(u&&(rn(u,U)||(u[U]=[]),u[U].push("class")),c[U]=C,Array.isArray(C)){const $=[];c[U]=[],d[U]=[],C.forEach(function(V){typeof V=="string"&&V.indexOf("*")>=0?$.push(Fm(V).replace(/\\\*/g,".*")):V instanceof RegExp?d[U].push(V):c[U].push(V)}),$.length&&(f[U]=new RegExp("^("+$.join("|")+")$"))}});const h={};let p;ha(t.transformTags,function(C,U){let $;typeof C=="function"?$=C:typeof C=="string"&&($=Va.simpleTransform(C)),U==="*"?p=$:h[U]=$});let m,g,v,w,x,N,O=!1;D();const A=new KB.Parser({onopentag:function(C,U){if(t.enforceHtmlBoundary&&C==="html"&&D(),x){N++;return}const $=new a(C,U);g.push($);let V=!1;const se=!!$.text;let _;if(rn(h,C)&&(_=h[C](C,U),$.attribs=U=_.attribs,_.text!==void 0&&($.innerText=_.text),C!==_.tagName&&($.name=C=_.tagName,w[m]=_.tagName)),p&&(_=p(C,U),$.attribs=U=_.attribs,C!==_.tagName&&($.name=C=_.tagName,w[m]=_.tagName)),(!o(C)||t.disallowedTagsMode==="recursiveEscape"&&!ez(v)||t.nestingLimit!=null&&m>=t.nestingLimit)&&(V=!0,v[m]=!0,t.disallowedTagsMode==="discard"&&s.indexOf(C)!==-1&&(x=!0,N=1),v[m]=!0),m++,V){if(t.disallowedTagsMode==="discard")return;i=n,n=""}n+="<"+C,C==="script"&&(t.allowedScriptHostnames||t.allowedScriptDomains)&&($.innerText=""),(!u||rn(u,C)||u["*"])&&ha(U,function(oe,ne){if(!nz.test(ne)){delete $.attribs[ne];return}if(oe===""&&(t.nonBooleanAttributes.includes(ne)||t.nonBooleanAttributes.includes("*"))){delete $.attribs[ne];return}let T=!1;if(!u||rn(u,C)&&u[C].indexOf(ne)!==-1||u["*"]&&u["*"].indexOf(ne)!==-1||rn(l,C)&&l[C].test(ne)||l["*"]&&l["*"].test(ne))T=!0;else if(u&&u[C]){for(const G of u[C])if(XB(G)&&G.name&&G.name===ne){T=!0;let ee="";if(G.multiple===!0){const le=oe.split(" ");for(const we of le)G.values.indexOf(we)!==-1&&(ee===""?ee=we:ee+=" "+we)}else G.values.indexOf(oe)>=0&&(ee=oe);oe=ee}}if(T){if(t.allowedSchemesAppliedToAttributes.indexOf(ne)!==-1&&z(C,oe)){delete $.attribs[ne];return}if(C==="script"&&ne==="src"){let G=!0;try{const ee=L(oe);if(t.allowedScriptHostnames||t.allowedScriptDomains){const le=(t.allowedScriptHostnames||[]).find(function(Oe){return Oe===ee.url.hostname}),we=(t.allowedScriptDomains||[]).find(function(Oe){return ee.url.hostname===Oe||ee.url.hostname.endsWith(`.${Oe}`)});G=le||we}}catch{G=!1}if(!G){delete $.attribs[ne];return}}if(C==="iframe"&&ne==="src"){let G=!0;try{const ee=L(oe);if(ee.isRelativeUrl)G=rn(t,"allowIframeRelativeUrls")?t.allowIframeRelativeUrls:!t.allowedIframeHostnames&&!t.allowedIframeDomains;else if(t.allowedIframeHostnames||t.allowedIframeDomains){const le=(t.allowedIframeHostnames||[]).find(function(Oe){return Oe===ee.url.hostname}),we=(t.allowedIframeDomains||[]).find(function(Oe){return ee.url.hostname===Oe||ee.url.hostname.endsWith(`.${Oe}`)});G=le||we}}catch{G=!1}if(!G){delete $.attribs[ne];return}}if(ne==="srcset")try{let G=YB(oe);if(G.forEach(function(ee){z("srcset",ee.url)&&(ee.evil=!0)}),G=zm(G,function(ee){return!ee.evil}),G.length)oe=tz(zm(G,function(ee){return!ee.evil})),$.attribs[ne]=oe;else{delete $.attribs[ne];return}}catch{delete $.attribs[ne];return}if(ne==="class"){const G=c[C],ee=c["*"],le=f[C],we=d[C],Oe=f["*"],qe=[le,Oe].concat(we).filter(function(ve){return ve});if(G&&ee?oe=F(oe,Bm(G,ee),qe):oe=F(oe,G||ee,qe),!oe.length){delete $.attribs[ne];return}}if(ne==="style"){if(t.parseStyleAttributes)try{const G=ZB(C+" {"+oe+"}"),ee=I(G,t.allowedStyles);if(oe=k(ee),oe.length===0){delete $.attribs[ne];return}}catch{typeof window<"u"&&console.warn('Failed to parse "'+C+" {"+oe+`}", If you're running this in a browser, we recommend to disable style parsing: options.parseStyleAttributes: false, since this only works in a node environment due to a postcss dependency, More info: https://github.com/apostrophecms/sanitize-html/issues/547`),delete $.attribs[ne];return}else if(t.allowedStyles)throw new Error("allowedStyles option cannot be used together with parseStyleAttributes: false.")}n+=" "+ne,oe&&oe.length&&(n+='="'+H(oe,!0)+'"')}else delete $.attribs[ne]}),t.selfClosing.indexOf(C)!==-1?n+=" />":(n+=">",$.innerText&&!se&&!t.textFilter&&(n+=H($.innerText),O=!0)),V&&(n=i+H(n),i="")},ontext:function(C){if(x)return;const U=g[g.length-1];let $;if(U&&($=U.tag,C=U.innerText!==void 0?U.innerText:C),t.disallowedTagsMode==="discard"&&($==="script"||$==="style"))n+=C;else{const V=H(C,!1);t.textFilter&&!O?n+=t.textFilter(V,$):O||(n+=V)}if(g.length){const V=g[g.length-1];V.text+=C}},onclosetag:function(C,U){if(x)if(N--,!N)x=!1;else return;const $=g.pop();if(!$)return;if($.tag!==C){g.push($);return}x=t.enforceHtmlBoundary?C==="html":!1,m--;const V=v[m];if(V){if(delete v[m],t.disallowedTagsMode==="discard"){$.updateParentNodeText();return}i=n,n=""}if(w[m]&&(C=w[m],delete w[m]),t.exclusiveFilter&&t.exclusiveFilter($)){n=n.substr(0,$.tagPosition);return}if($.updateParentNodeMediaChildren(),$.updateParentNodeText(),t.selfClosing.indexOf(C)!==-1||U&&!o(C)&&["escape","recursiveEscape"].indexOf(t.disallowedTagsMode)>=0){V&&(n=i,i="");return}n+="</"+C+">",V&&(n=i+H(n),i=""),O=!1}},t.parser);return A.write(e),A.end(),n;function D(){n="",m=0,g=[],v={},w={},x=!1,N=0}function H(C,U){return typeof C!="string"&&(C=C+""),t.parser.decodeEntities&&(C=C.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;"),U&&(C=C.replace(/"/g,"&quot;"))),C=C.replace(/&(?![a-zA-Z0-9#]{1,20};)/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;"),U&&(C=C.replace(/"/g,"&quot;")),C}function z(C,U){for(U=U.replace(/[\x00-\x20]+/g,"");;){const se=U.indexOf("<!--");if(se===-1)break;const _=U.indexOf("-->",se+4);if(_===-1)break;U=U.substring(0,se)+U.substring(_+3)}const $=U.match(/^([a-zA-Z][a-zA-Z0-9.\-+]*):/);if(!$)return U.match(/^[/\\]{2}/)?!t.allowProtocolRelative:!1;const V=$[1].toLowerCase();return rn(t.allowedSchemesByTag,C)?t.allowedSchemesByTag[C].indexOf(V)===-1:!t.allowedSchemes||t.allowedSchemes.indexOf(V)===-1}function L(C){if(C=C.replace(/^(\w+:)?\s*[\\/]\s*[\\/]/,"$1//"),C.startsWith("relative:"))throw new Error("relative: exploit attempt");let U="relative://relative-site";for(let se=0;se<100;se++)U+=`/${se}`;const $=new URL(C,U);return{isRelativeUrl:$&&$.hostname==="relative-site"&&$.protocol==="relative:",url:$}}function I(C,U){if(!U)return C;const $=C.nodes[0];let V;return U[$.selector]&&U["*"]?V=Bm(U[$.selector],U["*"]):V=U[$.selector]||U["*"],V&&(C.nodes[0].nodes=$.nodes.reduce(M(V),[])),C}function k(C){return C.nodes[0].nodes.reduce(function(U,$){return U.push(`${$.prop}:${$.value}${$.important?" !important":""}`),U},[]).join(";")}function M(C){return function(U,$){return rn(C,$.prop)&&C[$.prop].some(function(se){return se.test($.value)})&&U.push($),U}}function F(C,U,$){return U?(C=C.split(/\s+/),C.filter(function(V){return U.indexOf(V)!==-1||$.some(function(se){return se.test(V)})}).join(" ")):C}}const iz={decodeEntities:!0};Va.defaults={allowedTags:["address","article","aside","footer","header","h1","h2","h3","h4","h5","h6","hgroup","main","nav","section","blockquote","dd","div","dl","dt","figcaption","figure","hr","li","main","ol","p","pre","ul","a","abbr","b","bdi","bdo","br","cite","code","data","dfn","em","i","kbd","mark","q","rb","rp","rt","rtc","ruby","s","samp","small","span","strong","sub","sup","time","u","var","wbr","caption","col","colgroup","table","tbody","td","tfoot","th","thead","tr"],nonBooleanAttributes:["abbr","accept","accept-charset","accesskey","action","allow","alt","as","autocapitalize","autocomplete","blocking","charset","cite","class","color","cols","colspan","content","contenteditable","coords","crossorigin","data","datetime","decoding","dir","dirname","download","draggable","enctype","enterkeyhint","fetchpriority","for","form","formaction","formenctype","formmethod","formtarget","headers","height","hidden","high","href","hreflang","http-equiv","id","imagesizes","imagesrcset","inputmode","integrity","is","itemid","itemprop","itemref","itemtype","kind","label","lang","list","loading","low","max","maxlength","media","method","min","minlength","name","nonce","optimum","pattern","ping","placeholder","popover","popovertarget","popovertargetaction","poster","preload","referrerpolicy","rel","rows","rowspan","sandbox","scope","shape","size","sizes","slot","span","spellcheck","src","srcdoc","srclang","srcset","start","step","style","tabindex","target","title","translate","type","usemap","value","width","wrap","onauxclick","onafterprint","onbeforematch","onbeforeprint","onbeforeunload","onbeforetoggle","onblur","oncancel","oncanplay","oncanplaythrough","onchange","onclick","onclose","oncontextlost","oncontextmenu","oncontextrestored","oncopy","oncuechange","oncut","ondblclick","ondrag","ondragend","ondragenter","ondragleave","ondragover","ondragstart","ondrop","ondurationchange","onemptied","onended","onerror","onfocus","onformdata","onhashchange","oninput","oninvalid","onkeydown","onkeypress","onkeyup","onlanguagechange","onload","onloadeddata","onloadedmetadata","onloadstart","onmessage","onmessageerror","onmousedown","onmouseenter","onmouseleave","onmousemove","onmouseout","onmouseover","onmouseup","onoffline","ononline","onpagehide","onpageshow","onpaste","onpause","onplay","onplaying","onpopstate","onprogress","onratechange","onreset","onresize","onrejectionhandled","onscroll","onscrollend","onsecuritypolicyviolation","onseeked","onseeking","onselect","onslotchange","onstalled","onstorage","onsubmit","onsuspend","ontimeupdate","ontoggle","onunhandledrejection","onunload","onvolumechange","onwaiting","onwheel"],disallowedTagsMode:"discard",allowedAttributes:{a:["href","name","target"],img:["src","srcset","alt","title","width","height","loading"]},selfClosing:["img","br","hr","area","base","basefont","input","link","meta"],allowedSchemes:["http","https","ftp","mailto","tel"],allowedSchemesByTag:{},allowedSchemesAppliedToAttributes:["href","src","cite"],allowProtocolRelative:!0,enforceHtmlBoundary:!1,parseStyleAttributes:!0};Va.simpleTransform=function(e,t,r){return r=r===void 0?!0:r,t=t||{},function(n,i){let a;if(r)for(a in t)i[a]=t[a];else i=t;return{tagName:e,attribs:i}}};const KU=Ce(rz);var Gc=function(e,t){return Gc=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(r,n){r.__proto__=n}||function(r,n){for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(r[i]=n[i])},Gc(e,t)};function Er(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");Gc(e,t);function r(){this.constructor=e}e.prototype=t===null?Object.create(t):(r.prototype=t.prototype,new r)}var fe=function(){return fe=Object.assign||function(t){for(var r,n=1,i=arguments.length;n<i;n++){r=arguments[n];for(var a in r)Object.prototype.hasOwnProperty.call(r,a)&&(t[a]=r[a])}return t},fe.apply(this,arguments)};function Gu(e,t){var r={};for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&t.indexOf(n)<0&&(r[n]=e[n]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var i=0,n=Object.getOwnPropertySymbols(e);i<n.length;i++)t.indexOf(n[i])<0&&Object.prototype.propertyIsEnumerable.call(e,n[i])&&(r[n[i]]=e[n[i]]);return r}function Br(e,t,r){if(r||arguments.length===2)for(var n=0,i=t.length,a;n<i;n++)(a||!(n in t))&&(a||(a=Array.prototype.slice.call(t,0,n)),a[n]=t[n]);return e.concat(a||Array.prototype.slice.call(t))}var py={exports:{}},We={};/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Tt=typeof Symbol=="function"&&Symbol.for,Rd=Tt?Symbol.for("react.element"):60103,Id=Tt?Symbol.for("react.portal"):60106,Wu=Tt?Symbol.for("react.fragment"):60107,Ku=Tt?Symbol.for("react.strict_mode"):60108,Xu=Tt?Symbol.for("react.profiler"):60114,Yu=Tt?Symbol.for("react.provider"):60109,Zu=Tt?Symbol.for("react.context"):60110,Pd=Tt?Symbol.for("react.async_mode"):60111,Qu=Tt?Symbol.for("react.concurrent_mode"):60111,Ju=Tt?Symbol.for("react.forward_ref"):60112,el=Tt?Symbol.for("react.suspense"):60113,az=Tt?Symbol.for("react.suspense_list"):60120,tl=Tt?Symbol.for("react.memo"):60115,rl=Tt?Symbol.for("react.lazy"):60116,oz=Tt?Symbol.for("react.block"):60121,sz=Tt?Symbol.for("react.fundamental"):60117,uz=Tt?Symbol.for("react.responder"):60118,lz=Tt?Symbol.for("react.scope"):60119;function sr(e){if(typeof e=="object"&&e!==null){var t=e.$$typeof;switch(t){case Rd:switch(e=e.type,e){case Pd:case Qu:case Wu:case Xu:case Ku:case el:return e;default:switch(e=e&&e.$$typeof,e){case Zu:case Ju:case rl:case tl:case Yu:return e;default:return t}}case Id:return t}}}function my(e){return sr(e)===Qu}We.AsyncMode=Pd;We.ConcurrentMode=Qu;We.ContextConsumer=Zu;We.ContextProvider=Yu;We.Element=Rd;We.ForwardRef=Ju;We.Fragment=Wu;We.Lazy=rl;We.Memo=tl;We.Portal=Id;We.Profiler=Xu;We.StrictMode=Ku;We.Suspense=el;We.isAsyncMode=function(e){return my(e)||sr(e)===Pd};We.isConcurrentMode=my;We.isContextConsumer=function(e){return sr(e)===Zu};We.isContextProvider=function(e){return sr(e)===Yu};We.isElement=function(e){return typeof e=="object"&&e!==null&&e.$$typeof===Rd};We.isForwardRef=function(e){return sr(e)===Ju};We.isFragment=function(e){return sr(e)===Wu};We.isLazy=function(e){return sr(e)===rl};We.isMemo=function(e){return sr(e)===tl};We.isPortal=function(e){return sr(e)===Id};We.isProfiler=function(e){return sr(e)===Xu};We.isStrictMode=function(e){return sr(e)===Ku};We.isSuspense=function(e){return sr(e)===el};We.isValidElementType=function(e){return typeof e=="string"||typeof e=="function"||e===Wu||e===Qu||e===Xu||e===Ku||e===el||e===az||typeof e=="object"&&e!==null&&(e.$$typeof===rl||e.$$typeof===tl||e.$$typeof===Yu||e.$$typeof===Zu||e.$$typeof===Ju||e.$$typeof===sz||e.$$typeof===uz||e.$$typeof===lz||e.$$typeof===oz)};We.typeOf=sr;py.exports=We;var cz=py.exports,gy=cz,fz={$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},dz={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},by={};by[gy.ForwardRef]=fz;by[gy.Memo]=dz;function vy(e,t,r){if(r===void 0&&(r=Error),!e)throw new r(t)}var Fe;(function(e){e[e.EXPECT_ARGUMENT_CLOSING_BRACE=1]="EXPECT_ARGUMENT_CLOSING_BRACE",e[e.EMPTY_ARGUMENT=2]="EMPTY_ARGUMENT",e[e.MALFORMED_ARGUMENT=3]="MALFORMED_ARGUMENT",e[e.EXPECT_ARGUMENT_TYPE=4]="EXPECT_ARGUMENT_TYPE",e[e.INVALID_ARGUMENT_TYPE=5]="INVALID_ARGUMENT_TYPE",e[e.EXPECT_ARGUMENT_STYLE=6]="EXPECT_ARGUMENT_STYLE",e[e.INVALID_NUMBER_SKELETON=7]="INVALID_NUMBER_SKELETON",e[e.INVALID_DATE_TIME_SKELETON=8]="INVALID_DATE_TIME_SKELETON",e[e.EXPECT_NUMBER_SKELETON=9]="EXPECT_NUMBER_SKELETON",e[e.EXPECT_DATE_TIME_SKELETON=10]="EXPECT_DATE_TIME_SKELETON",e[e.UNCLOSED_QUOTE_IN_ARGUMENT_STYLE=11]="UNCLOSED_QUOTE_IN_ARGUMENT_STYLE",e[e.EXPECT_SELECT_ARGUMENT_OPTIONS=12]="EXPECT_SELECT_ARGUMENT_OPTIONS",e[e.EXPECT_PLURAL_ARGUMENT_OFFSET_VALUE=13]="EXPECT_PLURAL_ARGUMENT_OFFSET_VALUE",e[e.INVALID_PLURAL_ARGUMENT_OFFSET_VALUE=14]="INVALID_PLURAL_ARGUMENT_OFFSET_VALUE",e[e.EXPECT_SELECT_ARGUMENT_SELECTOR=15]="EXPECT_SELECT_ARGUMENT_SELECTOR",e[e.EXPECT_PLURAL_ARGUMENT_SELECTOR=16]="EXPECT_PLURAL_ARGUMENT_SELECTOR",e[e.EXPECT_SELECT_ARGUMENT_SELECTOR_FRAGMENT=17]="EXPECT_SELECT_ARGUMENT_SELECTOR_FRAGMENT",e[e.EXPECT_PLURAL_ARGUMENT_SELECTOR_FRAGMENT=18]="EXPECT_PLURAL_ARGUMENT_SELECTOR_FRAGMENT",e[e.INVALID_PLURAL_ARGUMENT_SELECTOR=19]="INVALID_PLURAL_ARGUMENT_SELECTOR",e[e.DUPLICATE_PLURAL_ARGUMENT_SELECTOR=20]="DUPLICATE_PLURAL_ARGUMENT_SELECTOR",e[e.DUPLICATE_SELECT_ARGUMENT_SELECTOR=21]="DUPLICATE_SELECT_ARGUMENT_SELECTOR",e[e.MISSING_OTHER_CLAUSE=22]="MISSING_OTHER_CLAUSE",e[e.INVALID_TAG=23]="INVALID_TAG",e[e.INVALID_TAG_NAME=25]="INVALID_TAG_NAME",e[e.UNMATCHED_CLOSING_TAG=26]="UNMATCHED_CLOSING_TAG",e[e.UNCLOSED_TAG=27]="UNCLOSED_TAG"})(Fe||(Fe={}));var it;(function(e){e[e.literal=0]="literal",e[e.argument=1]="argument",e[e.number=2]="number",e[e.date=3]="date",e[e.time=4]="time",e[e.select=5]="select",e[e.plural=6]="plural",e[e.pound=7]="pound",e[e.tag=8]="tag"})(it||(it={}));var Yi;(function(e){e[e.number=0]="number",e[e.dateTime=1]="dateTime"})(Yi||(Yi={}));function $m(e){return e.type===it.literal}function hz(e){return e.type===it.argument}function yy(e){return e.type===it.number}function wy(e){return e.type===it.date}function xy(e){return e.type===it.time}function Ey(e){return e.type===it.select}function Sy(e){return e.type===it.plural}function pz(e){return e.type===it.pound}function Ty(e){return e.type===it.tag}function Ay(e){return!!(e&&typeof e=="object"&&e.type===Yi.number)}function Wc(e){return!!(e&&typeof e=="object"&&e.type===Yi.dateTime)}var ky=/[ \xA0\u1680\u2000-\u200A\u202F\u205F\u3000]/,mz=/(?:[Eec]{1,6}|G{1,5}|[Qq]{1,5}|(?:[yYur]+|U{1,5})|[ML]{1,5}|d{1,2}|D{1,3}|F{1}|[abB]{1,5}|[hkHK]{1,2}|w{1,2}|W{1}|m{1,2}|s{1,2}|[zZOvVxX]{1,4})(?=([^']*'[^']*')*[^']*$)/g;function gz(e){var t={};return e.replace(mz,function(r){var n=r.length;switch(r[0]){case"G":t.era=n===4?"long":n===5?"narrow":"short";break;case"y":t.year=n===2?"2-digit":"numeric";break;case"Y":case"u":case"U":case"r":throw new RangeError("`Y/u/U/r` (year) patterns are not supported, use `y` instead");case"q":case"Q":throw new RangeError("`q/Q` (quarter) patterns are not supported");case"M":case"L":t.month=["numeric","2-digit","short","long","narrow"][n-1];break;case"w":case"W":throw new RangeError("`w/W` (week) patterns are not supported");case"d":t.day=["numeric","2-digit"][n-1];break;case"D":case"F":case"g":throw new RangeError("`D/F/g` (day) patterns are not supported, use `d` instead");case"E":t.weekday=n===4?"long":n===5?"narrow":"short";break;case"e":if(n<4)throw new RangeError("`e..eee` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][n-4];break;case"c":if(n<4)throw new RangeError("`c..ccc` (weekday) patterns are not supported");t.weekday=["short","long","narrow","short"][n-4];break;case"a":t.hour12=!0;break;case"b":case"B":throw new RangeError("`b/B` (period) patterns are not supported, use `a` instead");case"h":t.hourCycle="h12",t.hour=["numeric","2-digit"][n-1];break;case"H":t.hourCycle="h23",t.hour=["numeric","2-digit"][n-1];break;case"K":t.hourCycle="h11",t.hour=["numeric","2-digit"][n-1];break;case"k":t.hourCycle="h24",t.hour=["numeric","2-digit"][n-1];break;case"j":case"J":case"C":throw new RangeError("`j/J/C` (hour) patterns are not supported, use `h/H/K/k` instead");case"m":t.minute=["numeric","2-digit"][n-1];break;case"s":t.second=["numeric","2-digit"][n-1];break;case"S":case"A":throw new RangeError("`S/A` (second) patterns are not supported, use `s` instead");case"z":t.timeZoneName=n<4?"short":"long";break;case"Z":case"O":case"v":case"V":case"X":case"x":throw new RangeError("`Z/O/v/V/X/x` (timeZone) patterns are not supported, use `z` instead")}return""}),t}var bz=/[\t-\r \x85\u200E\u200F\u2028\u2029]/i;function vz(e){if(e.length===0)throw new Error("Number skeleton cannot be empty");for(var t=e.split(bz).filter(function(d){return d.length>0}),r=[],n=0,i=t;n<i.length;n++){var a=i[n],o=a.split("/");if(o.length===0)throw new Error("Invalid number skeleton");for(var s=o[0],u=o.slice(1),l=0,c=u;l<c.length;l++){var f=c[l];if(f.length===0)throw new Error("Invalid number skeleton")}r.push({stem:s,options:u})}return r}function yz(e){return e.replace(/^(.*?)-/,"")}var Um=/^\.(?:(0+)(\*)?|(#+)|(0+)(#+))$/g,Oy=/^(@+)?(\+|#+)?[rs]?$/g,wz=/(\*)(0+)|(#+)(0+)|(0+)/g,Ny=/^(0+)$/;function Hm(e){var t={};return e[e.length-1]==="r"?t.roundingPriority="morePrecision":e[e.length-1]==="s"&&(t.roundingPriority="lessPrecision"),e.replace(Oy,function(r,n,i){return typeof i!="string"?(t.minimumSignificantDigits=n.length,t.maximumSignificantDigits=n.length):i==="+"?t.minimumSignificantDigits=n.length:n[0]==="#"?t.maximumSignificantDigits=n.length:(t.minimumSignificantDigits=n.length,t.maximumSignificantDigits=n.length+(typeof i=="string"?i.length:0)),""}),t}function _y(e){switch(e){case"sign-auto":return{signDisplay:"auto"};case"sign-accounting":case"()":return{currencySign:"accounting"};case"sign-always":case"+!":return{signDisplay:"always"};case"sign-accounting-always":case"()!":return{signDisplay:"always",currencySign:"accounting"};case"sign-except-zero":case"+?":return{signDisplay:"exceptZero"};case"sign-accounting-except-zero":case"()?":return{signDisplay:"exceptZero",currencySign:"accounting"};case"sign-never":case"+_":return{signDisplay:"never"}}}function xz(e){var t;if(e[0]==="E"&&e[1]==="E"?(t={notation:"engineering"},e=e.slice(2)):e[0]==="E"&&(t={notation:"scientific"},e=e.slice(1)),t){var r=e.slice(0,2);if(r==="+!"?(t.signDisplay="always",e=e.slice(2)):r==="+?"&&(t.signDisplay="exceptZero",e=e.slice(2)),!Ny.test(e))throw new Error("Malformed concise eng/scientific notation");t.minimumIntegerDigits=e.length}return t}function qm(e){var t={},r=_y(e);return r||t}function Ez(e){for(var t={},r=0,n=e;r<n.length;r++){var i=n[r];switch(i.stem){case"percent":case"%":t.style="percent";continue;case"%x100":t.style="percent",t.scale=100;continue;case"currency":t.style="currency",t.currency=i.options[0];continue;case"group-off":case",_":t.useGrouping=!1;continue;case"precision-integer":case".":t.maximumFractionDigits=0;continue;case"measure-unit":case"unit":t.style="unit",t.unit=yz(i.options[0]);continue;case"compact-short":case"K":t.notation="compact",t.compactDisplay="short";continue;case"compact-long":case"KK":t.notation="compact",t.compactDisplay="long";continue;case"scientific":t=fe(fe(fe({},t),{notation:"scientific"}),i.options.reduce(function(u,l){return fe(fe({},u),qm(l))},{}));continue;case"engineering":t=fe(fe(fe({},t),{notation:"engineering"}),i.options.reduce(function(u,l){return fe(fe({},u),qm(l))},{}));continue;case"notation-simple":t.notation="standard";continue;case"unit-width-narrow":t.currencyDisplay="narrowSymbol",t.unitDisplay="narrow";continue;case"unit-width-short":t.currencyDisplay="code",t.unitDisplay="short";continue;case"unit-width-full-name":t.currencyDisplay="name",t.unitDisplay="long";continue;case"unit-width-iso-code":t.currencyDisplay="symbol";continue;case"scale":t.scale=parseFloat(i.options[0]);continue;case"integer-width":if(i.options.length>1)throw new RangeError("integer-width stems only accept a single optional option");i.options[0].replace(wz,function(u,l,c,f,d,h){if(l)t.minimumIntegerDigits=c.length;else{if(f&&d)throw new Error("We currently do not support maximum integer digits");if(h)throw new Error("We currently do not support exact integer digits")}return""});continue}if(Ny.test(i.stem)){t.minimumIntegerDigits=i.stem.length;continue}if(Um.test(i.stem)){if(i.options.length>1)throw new RangeError("Fraction-precision stems only accept a single optional option");i.stem.replace(Um,function(u,l,c,f,d,h){return c==="*"?t.minimumFractionDigits=l.length:f&&f[0]==="#"?t.maximumFractionDigits=f.length:d&&h?(t.minimumFractionDigits=d.length,t.maximumFractionDigits=d.length+h.length):(t.minimumFractionDigits=l.length,t.maximumFractionDigits=l.length),""});var a=i.options[0];a==="w"?t=fe(fe({},t),{trailingZeroDisplay:"stripIfInteger"}):a&&(t=fe(fe({},t),Hm(a)));continue}if(Oy.test(i.stem)){t=fe(fe({},t),Hm(i.stem));continue}var o=_y(i.stem);o&&(t=fe(fe({},t),o));var s=xz(i.stem);s&&(t=fe(fe({},t),s))}return t}var es={"001":["H","h"],AC:["H","h","hb","hB"],AD:["H","hB"],AE:["h","hB","hb","H"],AF:["H","hb","hB","h"],AG:["h","hb","H","hB"],AI:["H","h","hb","hB"],AL:["h","H","hB"],AM:["H","hB"],AO:["H","hB"],AR:["H","h","hB","hb"],AS:["h","H"],AT:["H","hB"],AU:["h","hb","H","hB"],AW:["H","hB"],AX:["H"],AZ:["H","hB","h"],BA:["H","hB","h"],BB:["h","hb","H","hB"],BD:["h","hB","H"],BE:["H","hB"],BF:["H","hB"],BG:["H","hB","h"],BH:["h","hB","hb","H"],BI:["H","h"],BJ:["H","hB"],BL:["H","hB"],BM:["h","hb","H","hB"],BN:["hb","hB","h","H"],BO:["H","hB","h","hb"],BQ:["H"],BR:["H","hB"],BS:["h","hb","H","hB"],BT:["h","H"],BW:["H","h","hb","hB"],BY:["H","h"],BZ:["H","h","hb","hB"],CA:["h","hb","H","hB"],CC:["H","h","hb","hB"],CD:["hB","H"],CF:["H","h","hB"],CG:["H","hB"],CH:["H","hB","h"],CI:["H","hB"],CK:["H","h","hb","hB"],CL:["H","h","hB","hb"],CM:["H","h","hB"],CN:["H","hB","hb","h"],CO:["h","H","hB","hb"],CP:["H"],CR:["H","h","hB","hb"],CU:["H","h","hB","hb"],CV:["H","hB"],CW:["H","hB"],CX:["H","h","hb","hB"],CY:["h","H","hb","hB"],CZ:["H"],DE:["H","hB"],DG:["H","h","hb","hB"],DJ:["h","H"],DK:["H"],DM:["h","hb","H","hB"],DO:["h","H","hB","hb"],DZ:["h","hB","hb","H"],EA:["H","h","hB","hb"],EC:["H","hB","h","hb"],EE:["H","hB"],EG:["h","hB","hb","H"],EH:["h","hB","hb","H"],ER:["h","H"],ES:["H","hB","h","hb"],ET:["hB","hb","h","H"],FI:["H"],FJ:["h","hb","H","hB"],FK:["H","h","hb","hB"],FM:["h","hb","H","hB"],FO:["H","h"],FR:["H","hB"],GA:["H","hB"],GB:["H","h","hb","hB"],GD:["h","hb","H","hB"],GE:["H","hB","h"],GF:["H","hB"],GG:["H","h","hb","hB"],GH:["h","H"],GI:["H","h","hb","hB"],GL:["H","h"],GM:["h","hb","H","hB"],GN:["H","hB"],GP:["H","hB"],GQ:["H","hB","h","hb"],GR:["h","H","hb","hB"],GT:["H","h","hB","hb"],GU:["h","hb","H","hB"],GW:["H","hB"],GY:["h","hb","H","hB"],HK:["h","hB","hb","H"],HN:["H","h","hB","hb"],HR:["H","hB"],HU:["H","h"],IC:["H","h","hB","hb"],ID:["H"],IE:["H","h","hb","hB"],IL:["H","hB"],IM:["H","h","hb","hB"],IN:["h","H"],IO:["H","h","hb","hB"],IQ:["h","hB","hb","H"],IR:["hB","H"],IS:["H"],IT:["H","hB"],JE:["H","h","hb","hB"],JM:["h","hb","H","hB"],JO:["h","hB","hb","H"],JP:["H","K","h"],KE:["hB","hb","H","h"],KG:["H","h","hB","hb"],KH:["hB","h","H","hb"],KI:["h","hb","H","hB"],KM:["H","h","hB","hb"],KN:["h","hb","H","hB"],KP:["h","H","hB","hb"],KR:["h","H","hB","hb"],KW:["h","hB","hb","H"],KY:["h","hb","H","hB"],KZ:["H","hB"],LA:["H","hb","hB","h"],LB:["h","hB","hb","H"],LC:["h","hb","H","hB"],LI:["H","hB","h"],LK:["H","h","hB","hb"],LR:["h","hb","H","hB"],LS:["h","H"],LT:["H","h","hb","hB"],LU:["H","h","hB"],LV:["H","hB","hb","h"],LY:["h","hB","hb","H"],MA:["H","h","hB","hb"],MC:["H","hB"],MD:["H","hB"],ME:["H","hB","h"],MF:["H","hB"],MG:["H","h"],MH:["h","hb","H","hB"],MK:["H","h","hb","hB"],ML:["H"],MM:["hB","hb","H","h"],MN:["H","h","hb","hB"],MO:["h","hB","hb","H"],MP:["h","hb","H","hB"],MQ:["H","hB"],MR:["h","hB","hb","H"],MS:["H","h","hb","hB"],MT:["H","h"],MU:["H","h"],MV:["H","h"],MW:["h","hb","H","hB"],MX:["H","h","hB","hb"],MY:["hb","hB","h","H"],MZ:["H","hB"],NA:["h","H","hB","hb"],NC:["H","hB"],NE:["H"],NF:["H","h","hb","hB"],NG:["H","h","hb","hB"],NI:["H","h","hB","hb"],NL:["H","hB"],NO:["H","h"],NP:["H","h","hB"],NR:["H","h","hb","hB"],NU:["H","h","hb","hB"],NZ:["h","hb","H","hB"],OM:["h","hB","hb","H"],PA:["h","H","hB","hb"],PE:["H","hB","h","hb"],PF:["H","h","hB"],PG:["h","H"],PH:["h","hB","hb","H"],PK:["h","hB","H"],PL:["H","h"],PM:["H","hB"],PN:["H","h","hb","hB"],PR:["h","H","hB","hb"],PS:["h","hB","hb","H"],PT:["H","hB"],PW:["h","H"],PY:["H","h","hB","hb"],QA:["h","hB","hb","H"],RE:["H","hB"],RO:["H","hB"],RS:["H","hB","h"],RU:["H"],RW:["H","h"],SA:["h","hB","hb","H"],SB:["h","hb","H","hB"],SC:["H","h","hB"],SD:["h","hB","hb","H"],SE:["H"],SG:["h","hb","H","hB"],SH:["H","h","hb","hB"],SI:["H","hB"],SJ:["H"],SK:["H"],SL:["h","hb","H","hB"],SM:["H","h","hB"],SN:["H","h","hB"],SO:["h","H"],SR:["H","hB"],SS:["h","hb","H","hB"],ST:["H","hB"],SV:["H","h","hB","hb"],SX:["H","h","hb","hB"],SY:["h","hB","hb","H"],SZ:["h","hb","H","hB"],TA:["H","h","hb","hB"],TC:["h","hb","H","hB"],TD:["h","H","hB"],TF:["H","h","hB"],TG:["H","hB"],TH:["H","h"],TJ:["H","h"],TL:["H","hB","hb","h"],TM:["H","h"],TN:["h","hB","hb","H"],TO:["h","H"],TR:["H","hB"],TT:["h","hb","H","hB"],TW:["hB","hb","h","H"],TZ:["hB","hb","H","h"],UA:["H","hB","h"],UG:["hB","hb","H","h"],UM:["h","hb","H","hB"],US:["h","hb","H","hB"],UY:["H","h","hB","hb"],UZ:["H","hB","h"],VA:["H","h","hB"],VC:["h","hb","H","hB"],VE:["h","H","hB","hb"],VG:["h","hb","H","hB"],VI:["h","hb","H","hB"],VN:["H","h"],VU:["h","H"],WF:["H","hB"],WS:["h","H"],XK:["H","hB","h"],YE:["h","hB","hb","H"],YT:["H","hB"],ZA:["H","h","hb","hB"],ZM:["h","hb","H","hB"],ZW:["H","h"],"af-ZA":["H","h","hB","hb"],"ar-001":["h","hB","hb","H"],"ca-ES":["H","h","hB"],"en-001":["h","hb","H","hB"],"es-BO":["H","h","hB","hb"],"es-BR":["H","h","hB","hb"],"es-EC":["H","h","hB","hb"],"es-ES":["H","h","hB","hb"],"es-GQ":["H","h","hB","hb"],"es-PE":["H","h","hB","hb"],"fr-CA":["H","h","hB"],"gl-ES":["H","h","hB"],"gu-IN":["hB","hb","h","H"],"hi-IN":["hB","h","H"],"it-CH":["H","h","hB"],"it-IT":["H","h","hB"],"kn-IN":["hB","h","H"],"ml-IN":["hB","h","H"],"mr-IN":["hB","hb","h","H"],"pa-IN":["hB","hb","h","H"],"ta-IN":["hB","h","hb","H"],"te-IN":["hB","h","H"],"zu-ZA":["H","hB","hb","h"]};function Sz(e,t){for(var r="",n=0;n<e.length;n++){var i=e.charAt(n);if(i==="j"){for(var a=0;n+1<e.length&&e.charAt(n+1)===i;)a++,n++;var o=1+(a&1),s=a<2?1:3+(a>>1),u="a",l=Tz(t);for((l=="H"||l=="k")&&(s=0);s-- >0;)r+=u;for(;o-- >0;)r=l+r}else i==="J"?r+="H":r+=i}return r}function Tz(e){var t=e.hourCycle;if(t===void 0&&e.hourCycles&&e.hourCycles.length&&(t=e.hourCycles[0]),t)switch(t){case"h24":return"k";case"h23":return"H";case"h12":return"h";case"h11":return"K";default:throw new Error("Invalid hourCycle")}var r=e.language,n;r!=="root"&&(n=e.maximize().region);var i=es[n||""]||es[r||""]||es["".concat(r,"-001")]||es["001"];return i[0]}var d0,Az=new RegExp("^".concat(ky.source,"*")),kz=new RegExp("".concat(ky.source,"*$"));function Be(e,t){return{start:e,end:t}}var Oz=!!String.prototype.startsWith&&"_a".startsWith("a",1),Nz=!!String.fromCodePoint,_z=!!Object.fromEntries,Cz=!!String.prototype.codePointAt,Mz=!!String.prototype.trimStart,Rz=!!String.prototype.trimEnd,Iz=!!Number.isSafeInteger,Pz=Iz?Number.isSafeInteger:function(e){return typeof e=="number"&&isFinite(e)&&Math.floor(e)===e&&Math.abs(e)<=9007199254740991},Kc=!0;try{var Dz=My("([^\\p{White_Space}\\p{Pattern_Syntax}]*)","yu");Kc=((d0=Dz.exec("a"))===null||d0===void 0?void 0:d0[0])==="a"}catch{Kc=!1}var jm=Oz?function(t,r,n){return t.startsWith(r,n)}:function(t,r,n){return t.slice(n,n+r.length)===r},Xc=Nz?String.fromCodePoint:function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];for(var n="",i=t.length,a=0,o;i>a;){if(o=t[a++],o>1114111)throw RangeError(o+" is not a valid code point");n+=o<65536?String.fromCharCode(o):String.fromCharCode(((o-=65536)>>10)+55296,o%1024+56320)}return n},Vm=_z?Object.fromEntries:function(t){for(var r={},n=0,i=t;n<i.length;n++){var a=i[n],o=a[0],s=a[1];r[o]=s}return r},Cy=Cz?function(t,r){return t.codePointAt(r)}:function(t,r){var n=t.length;if(!(r<0||r>=n)){var i=t.charCodeAt(r),a;return i<55296||i>56319||r+1===n||(a=t.charCodeAt(r+1))<56320||a>57343?i:(i-55296<<10)+(a-56320)+65536}},Lz=Mz?function(t){return t.trimStart()}:function(t){return t.replace(Az,"")},Fz=Rz?function(t){return t.trimEnd()}:function(t){return t.replace(kz,"")};function My(e,t){return new RegExp(e,t)}var Yc;if(Kc){var Gm=My("([^\\p{White_Space}\\p{Pattern_Syntax}]*)","yu");Yc=function(t,r){var n;Gm.lastIndex=r;var i=Gm.exec(t);return(n=i[1])!==null&&n!==void 0?n:""}}else Yc=function(t,r){for(var n=[];;){var i=Cy(t,r);if(i===void 0||Ry(i)||Uz(i))break;n.push(i),r+=i>=65536?2:1}return Xc.apply(void 0,n)};var Bz=function(){function e(t,r){r===void 0&&(r={}),this.message=t,this.position={offset:0,line:1,column:1},this.ignoreTag=!!r.ignoreTag,this.locale=r.locale,this.requiresOtherClause=!!r.requiresOtherClause,this.shouldParseSkeletons=!!r.shouldParseSkeletons}return e.prototype.parse=function(){if(this.offset()!==0)throw Error("parser can only be used once");return this.parseMessage(0,"",!1)},e.prototype.parseMessage=function(t,r,n){for(var i=[];!this.isEOF();){var a=this.char();if(a===123){var o=this.parseArgument(t,n);if(o.err)return o;i.push(o.val)}else{if(a===125&&t>0)break;if(a===35&&(r==="plural"||r==="selectordinal")){var s=this.clonePosition();this.bump(),i.push({type:it.pound,location:Be(s,this.clonePosition())})}else if(a===60&&!this.ignoreTag&&this.peek()===47){if(n)break;return this.error(Fe.UNMATCHED_CLOSING_TAG,Be(this.clonePosition(),this.clonePosition()))}else if(a===60&&!this.ignoreTag&&Zc(this.peek()||0)){var o=this.parseTag(t,r);if(o.err)return o;i.push(o.val)}else{var o=this.parseLiteral(t,r);if(o.err)return o;i.push(o.val)}}}return{val:i,err:null}},e.prototype.parseTag=function(t,r){var n=this.clonePosition();this.bump();var i=this.parseTagName();if(this.bumpSpace(),this.bumpIf("/>"))return{val:{type:it.literal,value:"<".concat(i,"/>"),location:Be(n,this.clonePosition())},err:null};if(this.bumpIf(">")){var a=this.parseMessage(t+1,r,!0);if(a.err)return a;var o=a.val,s=this.clonePosition();if(this.bumpIf("</")){if(this.isEOF()||!Zc(this.char()))return this.error(Fe.INVALID_TAG,Be(s,this.clonePosition()));var u=this.clonePosition(),l=this.parseTagName();return i!==l?this.error(Fe.UNMATCHED_CLOSING_TAG,Be(u,this.clonePosition())):(this.bumpSpace(),this.bumpIf(">")?{val:{type:it.tag,value:i,children:o,location:Be(n,this.clonePosition())},err:null}:this.error(Fe.INVALID_TAG,Be(s,this.clonePosition())))}else return this.error(Fe.UNCLOSED_TAG,Be(n,this.clonePosition()))}else return this.error(Fe.INVALID_TAG,Be(n,this.clonePosition()))},e.prototype.parseTagName=function(){var t=this.offset();for(this.bump();!this.isEOF()&&$z(this.char());)this.bump();return this.message.slice(t,this.offset())},e.prototype.parseLiteral=function(t,r){for(var n=this.clonePosition(),i="";;){var a=this.tryParseQuote(r);if(a){i+=a;continue}var o=this.tryParseUnquoted(t,r);if(o){i+=o;continue}var s=this.tryParseLeftAngleBracket();if(s){i+=s;continue}break}var u=Be(n,this.clonePosition());return{val:{type:it.literal,value:i,location:u},err:null}},e.prototype.tryParseLeftAngleBracket=function(){return!this.isEOF()&&this.char()===60&&(this.ignoreTag||!zz(this.peek()||0))?(this.bump(),"<"):null},e.prototype.tryParseQuote=function(t){if(this.isEOF()||this.char()!==39)return null;switch(this.peek()){case 39:return this.bump(),this.bump(),"'";case 123:case 60:case 62:case 125:break;case 35:if(t==="plural"||t==="selectordinal")break;return null;default:return null}this.bump();var r=[this.char()];for(this.bump();!this.isEOF();){var n=this.char();if(n===39)if(this.peek()===39)r.push(39),this.bump();else{this.bump();break}else r.push(n);this.bump()}return Xc.apply(void 0,r)},e.prototype.tryParseUnquoted=function(t,r){if(this.isEOF())return null;var n=this.char();return n===60||n===123||n===35&&(r==="plural"||r==="selectordinal")||n===125&&t>0?null:(this.bump(),Xc(n))},e.prototype.parseArgument=function(t,r){var n=this.clonePosition();if(this.bump(),this.bumpSpace(),this.isEOF())return this.error(Fe.EXPECT_ARGUMENT_CLOSING_BRACE,Be(n,this.clonePosition()));if(this.char()===125)return this.bump(),this.error(Fe.EMPTY_ARGUMENT,Be(n,this.clonePosition()));var i=this.parseIdentifierIfPossible().value;if(!i)return this.error(Fe.MALFORMED_ARGUMENT,Be(n,this.clonePosition()));if(this.bumpSpace(),this.isEOF())return this.error(Fe.EXPECT_ARGUMENT_CLOSING_BRACE,Be(n,this.clonePosition()));switch(this.char()){case 125:return this.bump(),{val:{type:it.argument,value:i,location:Be(n,this.clonePosition())},err:null};case 44:return this.bump(),this.bumpSpace(),this.isEOF()?this.error(Fe.EXPECT_ARGUMENT_CLOSING_BRACE,Be(n,this.clonePosition())):this.parseArgumentOptions(t,r,i,n);default:return this.error(Fe.MALFORMED_ARGUMENT,Be(n,this.clonePosition()))}},e.prototype.parseIdentifierIfPossible=function(){var t=this.clonePosition(),r=this.offset(),n=Yc(this.message,r),i=r+n.length;this.bumpTo(i);var a=this.clonePosition(),o=Be(t,a);return{value:n,location:o}},e.prototype.parseArgumentOptions=function(t,r,n,i){var a,o=this.clonePosition(),s=this.parseIdentifierIfPossible().value,u=this.clonePosition();switch(s){case"":return this.error(Fe.EXPECT_ARGUMENT_TYPE,Be(o,u));case"number":case"date":case"time":{this.bumpSpace();var l=null;if(this.bumpIf(",")){this.bumpSpace();var c=this.clonePosition(),f=this.parseSimpleArgStyleIfPossible();if(f.err)return f;var d=Fz(f.val);if(d.length===0)return this.error(Fe.EXPECT_ARGUMENT_STYLE,Be(this.clonePosition(),this.clonePosition()));var h=Be(c,this.clonePosition());l={style:d,styleLocation:h}}var p=this.tryParseArgumentClose(i);if(p.err)return p;var m=Be(i,this.clonePosition());if(l&&jm(l==null?void 0:l.style,"::",0)){var g=Lz(l.style.slice(2));if(s==="number"){var f=this.parseNumberSkeletonFromString(g,l.styleLocation);return f.err?f:{val:{type:it.number,value:n,location:m,style:f.val},err:null}}else{if(g.length===0)return this.error(Fe.EXPECT_DATE_TIME_SKELETON,m);var v=g;this.locale&&(v=Sz(g,this.locale));var d={type:Yi.dateTime,pattern:v,location:l.styleLocation,parsedOptions:this.shouldParseSkeletons?gz(v):{}},w=s==="date"?it.date:it.time;return{val:{type:w,value:n,location:m,style:d},err:null}}}return{val:{type:s==="number"?it.number:s==="date"?it.date:it.time,value:n,location:m,style:(a=l==null?void 0:l.style)!==null&&a!==void 0?a:null},err:null}}case"plural":case"selectordinal":case"select":{var x=this.clonePosition();if(this.bumpSpace(),!this.bumpIf(","))return this.error(Fe.EXPECT_SELECT_ARGUMENT_OPTIONS,Be(x,fe({},x)));this.bumpSpace();var N=this.parseIdentifierIfPossible(),O=0;if(s!=="select"&&N.value==="offset"){if(!this.bumpIf(":"))return this.error(Fe.EXPECT_PLURAL_ARGUMENT_OFFSET_VALUE,Be(this.clonePosition(),this.clonePosition()));this.bumpSpace();var f=this.tryParseDecimalInteger(Fe.EXPECT_PLURAL_ARGUMENT_OFFSET_VALUE,Fe.INVALID_PLURAL_ARGUMENT_OFFSET_VALUE);if(f.err)return f;this.bumpSpace(),N=this.parseIdentifierIfPossible(),O=f.val}var A=this.tryParsePluralOrSelectOptions(t,s,r,N);if(A.err)return A;var p=this.tryParseArgumentClose(i);if(p.err)return p;var D=Be(i,this.clonePosition());return s==="select"?{val:{type:it.select,value:n,options:Vm(A.val),location:D},err:null}:{val:{type:it.plural,value:n,options:Vm(A.val),offset:O,pluralType:s==="plural"?"cardinal":"ordinal",location:D},err:null}}default:return this.error(Fe.INVALID_ARGUMENT_TYPE,Be(o,u))}},e.prototype.tryParseArgumentClose=function(t){return this.isEOF()||this.char()!==125?this.error(Fe.EXPECT_ARGUMENT_CLOSING_BRACE,Be(t,this.clonePosition())):(this.bump(),{val:!0,err:null})},e.prototype.parseSimpleArgStyleIfPossible=function(){for(var t=0,r=this.clonePosition();!this.isEOF();){var n=this.char();switch(n){case 39:{this.bump();var i=this.clonePosition();if(!this.bumpUntil("'"))return this.error(Fe.UNCLOSED_QUOTE_IN_ARGUMENT_STYLE,Be(i,this.clonePosition()));this.bump();break}case 123:{t+=1,this.bump();break}case 125:{if(t>0)t-=1;else return{val:this.message.slice(r.offset,this.offset()),err:null};break}default:this.bump();break}}return{val:this.message.slice(r.offset,this.offset()),err:null}},e.prototype.parseNumberSkeletonFromString=function(t,r){var n=[];try{n=vz(t)}catch{return this.error(Fe.INVALID_NUMBER_SKELETON,r)}return{val:{type:Yi.number,tokens:n,location:r,parsedOptions:this.shouldParseSkeletons?Ez(n):{}},err:null}},e.prototype.tryParsePluralOrSelectOptions=function(t,r,n,i){for(var a,o=!1,s=[],u=new Set,l=i.value,c=i.location;;){if(l.length===0){var f=this.clonePosition();if(r!=="select"&&this.bumpIf("=")){var d=this.tryParseDecimalInteger(Fe.EXPECT_PLURAL_ARGUMENT_SELECTOR,Fe.INVALID_PLURAL_ARGUMENT_SELECTOR);if(d.err)return d;c=Be(f,this.clonePosition()),l=this.message.slice(f.offset,this.offset())}else break}if(u.has(l))return this.error(r==="select"?Fe.DUPLICATE_SELECT_ARGUMENT_SELECTOR:Fe.DUPLICATE_PLURAL_ARGUMENT_SELECTOR,c);l==="other"&&(o=!0),this.bumpSpace();var h=this.clonePosition();if(!this.bumpIf("{"))return this.error(r==="select"?Fe.EXPECT_SELECT_ARGUMENT_SELECTOR_FRAGMENT:Fe.EXPECT_PLURAL_ARGUMENT_SELECTOR_FRAGMENT,Be(this.clonePosition(),this.clonePosition()));var p=this.parseMessage(t+1,r,n);if(p.err)return p;var m=this.tryParseArgumentClose(h);if(m.err)return m;s.push([l,{value:p.val,location:Be(h,this.clonePosition())}]),u.add(l),this.bumpSpace(),a=this.parseIdentifierIfPossible(),l=a.value,c=a.location}return s.length===0?this.error(r==="select"?Fe.EXPECT_SELECT_ARGUMENT_SELECTOR:Fe.EXPECT_PLURAL_ARGUMENT_SELECTOR,Be(this.clonePosition(),this.clonePosition())):this.requiresOtherClause&&!o?this.error(Fe.MISSING_OTHER_CLAUSE,Be(this.clonePosition(),this.clonePosition())):{val:s,err:null}},e.prototype.tryParseDecimalInteger=function(t,r){var n=1,i=this.clonePosition();this.bumpIf("+")||this.bumpIf("-")&&(n=-1);for(var a=!1,o=0;!this.isEOF();){var s=this.char();if(s>=48&&s<=57)a=!0,o=o*10+(s-48),this.bump();else break}var u=Be(i,this.clonePosition());return a?(o*=n,Pz(o)?{val:o,err:null}:this.error(r,u)):this.error(t,u)},e.prototype.offset=function(){return this.position.offset},e.prototype.isEOF=function(){return this.offset()===this.message.length},e.prototype.clonePosition=function(){return{offset:this.position.offset,line:this.position.line,column:this.position.column}},e.prototype.char=function(){var t=this.position.offset;if(t>=this.message.length)throw Error("out of bound");var r=Cy(this.message,t);if(r===void 0)throw Error("Offset ".concat(t," is at invalid UTF-16 code unit boundary"));return r},e.prototype.error=function(t,r){return{val:null,err:{kind:t,message:this.message,location:r}}},e.prototype.bump=function(){if(!this.isEOF()){var t=this.char();t===10?(this.position.line+=1,this.position.column=1,this.position.offset+=1):(this.position.column+=1,this.position.offset+=t<65536?1:2)}},e.prototype.bumpIf=function(t){if(jm(this.message,t,this.offset())){for(var r=0;r<t.length;r++)this.bump();return!0}return!1},e.prototype.bumpUntil=function(t){var r=this.offset(),n=this.message.indexOf(t,r);return n>=0?(this.bumpTo(n),!0):(this.bumpTo(this.message.length),!1)},e.prototype.bumpTo=function(t){if(this.offset()>t)throw Error("targetOffset ".concat(t," must be greater than or equal to the current offset ").concat(this.offset()));for(t=Math.min(t,this.message.length);;){var r=this.offset();if(r===t)break;if(r>t)throw Error("targetOffset ".concat(t," is at invalid UTF-16 code unit boundary"));if(this.bump(),this.isEOF())break}},e.prototype.bumpSpace=function(){for(;!this.isEOF()&&Ry(this.char());)this.bump()},e.prototype.peek=function(){if(this.isEOF())return null;var t=this.char(),r=this.offset(),n=this.message.charCodeAt(r+(t>=65536?2:1));return n??null},e}();function Zc(e){return e>=97&&e<=122||e>=65&&e<=90}function zz(e){return Zc(e)||e===47}function $z(e){return e===45||e===46||e>=48&&e<=57||e===95||e>=97&&e<=122||e>=65&&e<=90||e==183||e>=192&&e<=214||e>=216&&e<=246||e>=248&&e<=893||e>=895&&e<=8191||e>=8204&&e<=8205||e>=8255&&e<=8256||e>=8304&&e<=8591||e>=11264&&e<=12271||e>=12289&&e<=55295||e>=63744&&e<=64975||e>=65008&&e<=65533||e>=65536&&e<=983039}function Ry(e){return e>=9&&e<=13||e===32||e===133||e>=8206&&e<=8207||e===8232||e===8233}function Uz(e){return e>=33&&e<=35||e===36||e>=37&&e<=39||e===40||e===41||e===42||e===43||e===44||e===45||e>=46&&e<=47||e>=58&&e<=59||e>=60&&e<=62||e>=63&&e<=64||e===91||e===92||e===93||e===94||e===96||e===123||e===124||e===125||e===126||e===161||e>=162&&e<=165||e===166||e===167||e===169||e===171||e===172||e===174||e===176||e===177||e===182||e===187||e===191||e===215||e===247||e>=8208&&e<=8213||e>=8214&&e<=8215||e===8216||e===8217||e===8218||e>=8219&&e<=8220||e===8221||e===8222||e===8223||e>=8224&&e<=8231||e>=8240&&e<=8248||e===8249||e===8250||e>=8251&&e<=8254||e>=8257&&e<=8259||e===8260||e===8261||e===8262||e>=8263&&e<=8273||e===8274||e===8275||e>=8277&&e<=8286||e>=8592&&e<=8596||e>=8597&&e<=8601||e>=8602&&e<=8603||e>=8604&&e<=8607||e===8608||e>=8609&&e<=8610||e===8611||e>=8612&&e<=8613||e===8614||e>=8615&&e<=8621||e===8622||e>=8623&&e<=8653||e>=8654&&e<=8655||e>=8656&&e<=8657||e===8658||e===8659||e===8660||e>=8661&&e<=8691||e>=8692&&e<=8959||e>=8960&&e<=8967||e===8968||e===8969||e===8970||e===8971||e>=8972&&e<=8991||e>=8992&&e<=8993||e>=8994&&e<=9e3||e===9001||e===9002||e>=9003&&e<=9083||e===9084||e>=9085&&e<=9114||e>=9115&&e<=9139||e>=9140&&e<=9179||e>=9180&&e<=9185||e>=9186&&e<=9254||e>=9255&&e<=9279||e>=9280&&e<=9290||e>=9291&&e<=9311||e>=9472&&e<=9654||e===9655||e>=9656&&e<=9664||e===9665||e>=9666&&e<=9719||e>=9720&&e<=9727||e>=9728&&e<=9838||e===9839||e>=9840&&e<=10087||e===10088||e===10089||e===10090||e===10091||e===10092||e===10093||e===10094||e===10095||e===10096||e===10097||e===10098||e===10099||e===10100||e===10101||e>=10132&&e<=10175||e>=10176&&e<=10180||e===10181||e===10182||e>=10183&&e<=10213||e===10214||e===10215||e===10216||e===10217||e===10218||e===10219||e===10220||e===10221||e===10222||e===10223||e>=10224&&e<=10239||e>=10240&&e<=10495||e>=10496&&e<=10626||e===10627||e===10628||e===10629||e===10630||e===10631||e===10632||e===10633||e===10634||e===10635||e===10636||e===10637||e===10638||e===10639||e===10640||e===10641||e===10642||e===10643||e===10644||e===10645||e===10646||e===10647||e===10648||e>=10649&&e<=10711||e===10712||e===10713||e===10714||e===10715||e>=10716&&e<=10747||e===10748||e===10749||e>=10750&&e<=11007||e>=11008&&e<=11055||e>=11056&&e<=11076||e>=11077&&e<=11078||e>=11079&&e<=11084||e>=11085&&e<=11123||e>=11124&&e<=11125||e>=11126&&e<=11157||e===11158||e>=11159&&e<=11263||e>=11776&&e<=11777||e===11778||e===11779||e===11780||e===11781||e>=11782&&e<=11784||e===11785||e===11786||e===11787||e===11788||e===11789||e>=11790&&e<=11798||e===11799||e>=11800&&e<=11801||e===11802||e===11803||e===11804||e===11805||e>=11806&&e<=11807||e===11808||e===11809||e===11810||e===11811||e===11812||e===11813||e===11814||e===11815||e===11816||e===11817||e>=11818&&e<=11822||e===11823||e>=11824&&e<=11833||e>=11834&&e<=11835||e>=11836&&e<=11839||e===11840||e===11841||e===11842||e>=11843&&e<=11855||e>=11856&&e<=11857||e===11858||e>=11859&&e<=11903||e>=12289&&e<=12291||e===12296||e===12297||e===12298||e===12299||e===12300||e===12301||e===12302||e===12303||e===12304||e===12305||e>=12306&&e<=12307||e===12308||e===12309||e===12310||e===12311||e===12312||e===12313||e===12314||e===12315||e===12316||e===12317||e>=12318&&e<=12319||e===12320||e===12336||e===64830||e===64831||e>=65093&&e<=65094}function Qc(e){e.forEach(function(t){if(delete t.location,Ey(t)||Sy(t))for(var r in t.options)delete t.options[r].location,Qc(t.options[r].value);else yy(t)&&Ay(t.style)||(wy(t)||xy(t))&&Wc(t.style)?delete t.style.location:Ty(t)&&Qc(t.children)})}function Hz(e,t){t===void 0&&(t={}),t=fe({shouldParseSkeletons:!0,requiresOtherClause:!0},t);var r=new Bz(e,t).parse();if(r.err){var n=SyntaxError(Fe[r.err.kind]);throw n.location=r.err.location,n.originalMessage=r.err.message,n}return t!=null&&t.captureLocation||Qc(r.val),r.val}function Ir(e,t){var r=t&&t.cache?t.cache:Kz,n=t&&t.serializer?t.serializer:Wz,i=t&&t.strategy?t.strategy:jz;return i(e,{cache:r,serializer:n})}function qz(e){return e==null||typeof e=="number"||typeof e=="boolean"}function Iy(e,t,r,n){var i=qz(n)?n:r(n),a=t.get(i);return typeof a>"u"&&(a=e.call(this,n),t.set(i,a)),a}function Py(e,t,r){var n=Array.prototype.slice.call(arguments,3),i=r(n),a=t.get(i);return typeof a>"u"&&(a=e.apply(this,n),t.set(i,a)),a}function Dd(e,t,r,n,i){return r.bind(t,e,n,i)}function jz(e,t){var r=e.length===1?Iy:Py;return Dd(e,this,r,t.cache.create(),t.serializer)}function Vz(e,t){return Dd(e,this,Py,t.cache.create(),t.serializer)}function Gz(e,t){return Dd(e,this,Iy,t.cache.create(),t.serializer)}var Wz=function(){return JSON.stringify(arguments)};function Ld(){this.cache=Object.create(null)}Ld.prototype.get=function(e){return this.cache[e]};Ld.prototype.set=function(e,t){this.cache[e]=t};var Kz={create:function(){return new Ld}},Pr={variadic:Vz,monadic:Gz},Vr;(function(e){e.MISSING_VALUE="MISSING_VALUE",e.INVALID_VALUE="INVALID_VALUE",e.MISSING_INTL_API="MISSING_INTL_API"})(Vr||(Vr={}));var qn=function(e){Er(t,e);function t(r,n,i){var a=e.call(this,r)||this;return a.code=n,a.originalMessage=i,a}return t.prototype.toString=function(){return"[formatjs Error: ".concat(this.code,"] ").concat(this.message)},t}(Error),Wm=function(e){Er(t,e);function t(r,n,i,a){return e.call(this,'Invalid values for "'.concat(r,'": "').concat(n,'". Options are "').concat(Object.keys(i).join('", "'),'"'),Vr.INVALID_VALUE,a)||this}return t}(qn),Xz=function(e){Er(t,e);function t(r,n,i){return e.call(this,'Value for "'.concat(r,'" must be of type ').concat(n),Vr.INVALID_VALUE,i)||this}return t}(qn),Yz=function(e){Er(t,e);function t(r,n){return e.call(this,'The intl string context variable "'.concat(r,'" was not provided to the string "').concat(n,'"'),Vr.MISSING_VALUE,n)||this}return t}(qn),Dt;(function(e){e[e.literal=0]="literal",e[e.object=1]="object"})(Dt||(Dt={}));function Zz(e){return e.length<2?e:e.reduce(function(t,r){var n=t[t.length-1];return!n||n.type!==Dt.literal||r.type!==Dt.literal?t.push(r):n.value+=r.value,t},[])}function Dy(e){return typeof e=="function"}function xs(e,t,r,n,i,a,o){if(e.length===1&&$m(e[0]))return[{type:Dt.literal,value:e[0].value}];for(var s=[],u=0,l=e;u<l.length;u++){var c=l[u];if($m(c)){s.push({type:Dt.literal,value:c.value});continue}if(pz(c)){typeof a=="number"&&s.push({type:Dt.literal,value:r.getNumberFormat(t).format(a)});continue}var f=c.value;if(!(i&&f in i))throw new Yz(f,o);var d=i[f];if(hz(c)){(!d||typeof d=="string"||typeof d=="number")&&(d=typeof d=="string"||typeof d=="number"?String(d):""),s.push({type:typeof d=="string"?Dt.literal:Dt.object,value:d});continue}if(wy(c)){var h=typeof c.style=="string"?n.date[c.style]:Wc(c.style)?c.style.parsedOptions:void 0;s.push({type:Dt.literal,value:r.getDateTimeFormat(t,h).format(d)});continue}if(xy(c)){var h=typeof c.style=="string"?n.time[c.style]:Wc(c.style)?c.style.parsedOptions:n.time.medium;s.push({type:Dt.literal,value:r.getDateTimeFormat(t,h).format(d)});continue}if(yy(c)){var h=typeof c.style=="string"?n.number[c.style]:Ay(c.style)?c.style.parsedOptions:void 0;h&&h.scale&&(d=d*(h.scale||1)),s.push({type:Dt.literal,value:r.getNumberFormat(t,h).format(d)});continue}if(Ty(c)){var p=c.children,m=c.value,g=i[m];if(!Dy(g))throw new Xz(m,"function",o);var v=xs(p,t,r,n,i,a),w=g(v.map(function(O){return O.value}));Array.isArray(w)||(w=[w]),s.push.apply(s,w.map(function(O){return{type:typeof O=="string"?Dt.literal:Dt.object,value:O}}))}if(Ey(c)){var x=c.options[d]||c.options.other;if(!x)throw new Wm(c.value,d,Object.keys(c.options),o);s.push.apply(s,xs(x.value,t,r,n,i));continue}if(Sy(c)){var x=c.options["=".concat(d)];if(!x){if(!Intl.PluralRules)throw new qn(`Intl.PluralRules is not available in this environment.
Try polyfilling it using "@formatjs/intl-pluralrules"
`,Vr.MISSING_INTL_API,o);var N=r.getPluralRules(t,{type:c.pluralType}).select(d-(c.offset||0));x=c.options[N]||c.options.other}if(!x)throw new Wm(c.value,d,Object.keys(c.options),o);s.push.apply(s,xs(x.value,t,r,n,i,d-(c.offset||0)));continue}}return Zz(s)}function Qz(e,t){return t?fe(fe(fe({},e||{}),t||{}),Object.keys(e).reduce(function(r,n){return r[n]=fe(fe({},e[n]),t[n]||{}),r},{})):e}function Jz(e,t){return t?Object.keys(e).reduce(function(r,n){return r[n]=Qz(e[n],t[n]),r},fe({},e)):e}function h0(e){return{create:function(){return{get:function(t){return e[t]},set:function(t,r){e[t]=r}}}}}function e$(e){return e===void 0&&(e={number:{},dateTime:{},pluralRules:{}}),{getNumberFormat:Ir(function(){for(var t,r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];return new((t=Intl.NumberFormat).bind.apply(t,Br([void 0],r,!1)))},{cache:h0(e.number),strategy:Pr.variadic}),getDateTimeFormat:Ir(function(){for(var t,r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];return new((t=Intl.DateTimeFormat).bind.apply(t,Br([void 0],r,!1)))},{cache:h0(e.dateTime),strategy:Pr.variadic}),getPluralRules:Ir(function(){for(var t,r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];return new((t=Intl.PluralRules).bind.apply(t,Br([void 0],r,!1)))},{cache:h0(e.pluralRules),strategy:Pr.variadic})}}var Ly=function(){function e(t,r,n,i){var a=this;if(r===void 0&&(r=e.defaultLocale),this.formatterCache={number:{},dateTime:{},pluralRules:{}},this.format=function(u){var l=a.formatToParts(u);if(l.length===1)return l[0].value;var c=l.reduce(function(f,d){return!f.length||d.type!==Dt.literal||typeof f[f.length-1]!="string"?f.push(d.value):f[f.length-1]+=d.value,f},[]);return c.length<=1?c[0]||"":c},this.formatToParts=function(u){return xs(a.ast,a.locales,a.formatters,a.formats,u,void 0,a.message)},this.resolvedOptions=function(){var u;return{locale:((u=a.resolvedLocale)===null||u===void 0?void 0:u.toString())||Intl.NumberFormat.supportedLocalesOf(a.locales)[0]}},this.getAst=function(){return a.ast},this.locales=r,this.resolvedLocale=e.resolveLocale(r),typeof t=="string"){if(this.message=t,!e.__parse)throw new TypeError("IntlMessageFormat.__parse must be set to process `message` of type `string`");var o=i||{};o.formatters;var s=Gu(o,["formatters"]);this.ast=e.__parse(t,fe(fe({},s),{locale:this.resolvedLocale}))}else this.ast=t;if(!Array.isArray(this.ast))throw new TypeError("A message must be provided as a String or AST.");this.formats=Jz(e.formats,n),this.formatters=i&&i.formatters||e$(this.formatterCache)}return Object.defineProperty(e,"defaultLocale",{get:function(){return e.memoizedDefaultLocale||(e.memoizedDefaultLocale=new Intl.NumberFormat().resolvedOptions().locale),e.memoizedDefaultLocale},enumerable:!1,configurable:!0}),e.memoizedDefaultLocale=null,e.resolveLocale=function(t){if(!(typeof Intl.Locale>"u")){var r=Intl.NumberFormat.supportedLocalesOf(t);return r.length>0?new Intl.Locale(r[0]):new Intl.Locale(typeof t=="string"?t:t[0])}},e.__parse=Hz,e.formats={number:{integer:{maximumFractionDigits:0},currency:{style:"currency"},percent:{style:"percent"}},date:{short:{month:"numeric",day:"numeric",year:"2-digit"},medium:{month:"short",day:"numeric",year:"numeric"},long:{month:"long",day:"numeric",year:"numeric"},full:{weekday:"long",month:"long",day:"numeric",year:"numeric"}},time:{short:{hour:"numeric",minute:"numeric"},medium:{hour:"numeric",minute:"numeric",second:"numeric"},long:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"},full:{hour:"numeric",minute:"numeric",second:"numeric",timeZoneName:"short"}}},e}(),ui;(function(e){e.FORMAT_ERROR="FORMAT_ERROR",e.UNSUPPORTED_FORMATTER="UNSUPPORTED_FORMATTER",e.INVALID_CONFIG="INVALID_CONFIG",e.MISSING_DATA="MISSING_DATA",e.MISSING_TRANSLATION="MISSING_TRANSLATION"})(ui||(ui={}));var ho=function(e){Er(t,e);function t(r,n,i){var a=this,o=i?i instanceof Error?i:new Error(String(i)):void 0;return a=e.call(this,"[@formatjs/intl Error ".concat(r,"] ").concat(n,`
`).concat(o?`
`.concat(o.message,`
`).concat(o.stack):""))||this,a.code=r,typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(a,t),a}return t}(Error),t$=function(e){Er(t,e);function t(r,n){return e.call(this,ui.UNSUPPORTED_FORMATTER,r,n)||this}return t}(ho),r$=function(e){Er(t,e);function t(r,n){return e.call(this,ui.INVALID_CONFIG,r,n)||this}return t}(ho),Km=function(e){Er(t,e);function t(r,n){return e.call(this,ui.MISSING_DATA,r,n)||this}return t}(ho),Sr=function(e){Er(t,e);function t(r,n,i){var a=e.call(this,ui.FORMAT_ERROR,"".concat(r,`
Locale: `).concat(n,`
`),i)||this;return a.locale=n,a}return t}(ho),p0=function(e){Er(t,e);function t(r,n,i,a){var o=e.call(this,"".concat(r,`
MessageID: `).concat(i==null?void 0:i.id,`
Default Message: `).concat(i==null?void 0:i.defaultMessage,`
Description: `).concat(i==null?void 0:i.description,`
`),n,a)||this;return o.descriptor=i,o.locale=n,o}return t}(Sr),n$=function(e){Er(t,e);function t(r,n){var i=e.call(this,ui.MISSING_TRANSLATION,'Missing message: "'.concat(r.id,'" for locale "').concat(n,'", using ').concat(r.defaultMessage?"default message (".concat(typeof r.defaultMessage=="string"?r.defaultMessage:r.defaultMessage.map(function(a){var o;return(o=a.value)!==null&&o!==void 0?o:JSON.stringify(a)}).join(),")"):"id"," as fallback."))||this;return i.descriptor=r,i}return t}(ho);function mi(e,t,r){return r===void 0&&(r={}),t.reduce(function(n,i){return i in e?n[i]=e[i]:i in r&&(n[i]=r[i]),n},{})}var i$=function(e){},a$=function(e){},Fy={formats:{},messages:{},timeZone:void 0,defaultLocale:"en",defaultFormats:{},fallbackOnEmptyString:!0,onError:i$,onWarn:a$};function By(){return{dateTime:{},number:{},message:{},relativeTime:{},pluralRules:{},list:{},displayNames:{}}}function Xn(e){return{create:function(){return{get:function(t){return e[t]},set:function(t,r){e[t]=r}}}}}function o$(e){e===void 0&&(e=By());var t=Intl.RelativeTimeFormat,r=Intl.ListFormat,n=Intl.DisplayNames,i=Ir(function(){for(var s,u=[],l=0;l<arguments.length;l++)u[l]=arguments[l];return new((s=Intl.DateTimeFormat).bind.apply(s,Br([void 0],u,!1)))},{cache:Xn(e.dateTime),strategy:Pr.variadic}),a=Ir(function(){for(var s,u=[],l=0;l<arguments.length;l++)u[l]=arguments[l];return new((s=Intl.NumberFormat).bind.apply(s,Br([void 0],u,!1)))},{cache:Xn(e.number),strategy:Pr.variadic}),o=Ir(function(){for(var s,u=[],l=0;l<arguments.length;l++)u[l]=arguments[l];return new((s=Intl.PluralRules).bind.apply(s,Br([void 0],u,!1)))},{cache:Xn(e.pluralRules),strategy:Pr.variadic});return{getDateTimeFormat:i,getNumberFormat:a,getMessageFormat:Ir(function(s,u,l,c){return new Ly(s,u,l,fe({formatters:{getNumberFormat:a,getDateTimeFormat:i,getPluralRules:o}},c||{}))},{cache:Xn(e.message),strategy:Pr.variadic}),getRelativeTimeFormat:Ir(function(){for(var s=[],u=0;u<arguments.length;u++)s[u]=arguments[u];return new(t.bind.apply(t,Br([void 0],s,!1)))},{cache:Xn(e.relativeTime),strategy:Pr.variadic}),getPluralRules:o,getListFormat:Ir(function(){for(var s=[],u=0;u<arguments.length;u++)s[u]=arguments[u];return new(r.bind.apply(r,Br([void 0],s,!1)))},{cache:Xn(e.list),strategy:Pr.variadic}),getDisplayNames:Ir(function(){for(var s=[],u=0;u<arguments.length;u++)s[u]=arguments[u];return new(n.bind.apply(n,Br([void 0],s,!1)))},{cache:Xn(e.displayNames),strategy:Pr.variadic})}}function Fd(e,t,r,n){var i=e&&e[t],a;if(i&&(a=i[r]),a)return a;n(new t$("No ".concat(t," format named: ").concat(r)))}function ts(e,t){return Object.keys(e).reduce(function(r,n){return r[n]=fe({timeZone:t},e[n]),r},{})}function Xm(e,t){var r=Object.keys(fe(fe({},e),t));return r.reduce(function(n,i){return n[i]=fe(fe({},e[i]||{}),t[i]||{}),n},{})}function Ym(e,t){if(!t)return e;var r=Ly.formats;return fe(fe(fe({},r),e),{date:Xm(ts(r.date,t),ts(e.date||{},t)),time:Xm(ts(r.time,t),ts(e.time||{},t))})}var Jc=function(e,t,r,n,i){var a=e.locale,o=e.formats,s=e.messages,u=e.defaultLocale,l=e.defaultFormats,c=e.fallbackOnEmptyString,f=e.onError,d=e.timeZone,h=e.defaultRichTextElements;r===void 0&&(r={id:""});var p=r.id,m=r.defaultMessage;vy(!!p,"[@formatjs/intl] An `id` must be provided to format a message. You can either:\n1. Configure your build toolchain with [babel-plugin-formatjs](https://formatjs.io/docs/tooling/babel-plugin)\nor [@formatjs/ts-transformer](https://formatjs.io/docs/tooling/ts-transformer) OR\n2. Configure your `eslint` config to include [eslint-plugin-formatjs](https://formatjs.io/docs/tooling/linter#enforce-id)\nto autofix this issue");var g=String(p),v=s&&Object.prototype.hasOwnProperty.call(s,g)&&s[g];if(Array.isArray(v)&&v.length===1&&v[0].type===it.literal)return v[0].value;if(!n&&v&&typeof v=="string"&&!h)return v.replace(/'\{(.*?)\}'/gi,"{$1}");if(n=fe(fe({},h),n||{}),o=Ym(o,d),l=Ym(l,d),!v){if(c===!1&&v==="")return v;if((!m||a&&a.toLowerCase()!==u.toLowerCase())&&f(new n$(r,a)),m)try{var w=t.getMessageFormat(m,u,l,i);return w.format(n)}catch(x){return f(new p0('Error formatting default message for: "'.concat(g,'", rendering default message verbatim'),a,r,x)),typeof m=="string"?m:g}return g}try{var w=t.getMessageFormat(v,a,o,fe({formatters:t},i||{}));return w.format(n)}catch(x){f(new p0('Error formatting message: "'.concat(g,'", using ').concat(m?"default message":"id"," as fallback."),a,r,x))}if(m)try{var w=t.getMessageFormat(m,u,l,i);return w.format(n)}catch(x){f(new p0('Error formatting the default message for: "'.concat(g,'", rendering message verbatim'),a,r,x))}return typeof v=="string"?v:typeof m=="string"?m:g},zy=["formatMatcher","timeZone","hour12","weekday","era","year","month","day","hour","minute","second","timeZoneName","hourCycle","dateStyle","timeStyle","calendar","numberingSystem","fractionalSecondDigits"];function nl(e,t,r,n){var i=e.locale,a=e.formats,o=e.onError,s=e.timeZone;n===void 0&&(n={});var u=n.format,l=fe(fe({},s&&{timeZone:s}),u&&Fd(a,t,u,o)),c=mi(n,zy,l);return t==="time"&&!c.hour&&!c.minute&&!c.second&&!c.timeStyle&&!c.dateStyle&&(c=fe(fe({},c),{hour:"numeric",minute:"numeric"})),r(i,c)}function s$(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];var i=r[0],a=r[1],o=a===void 0?{}:a,s=typeof i=="string"?new Date(i||0):i;try{return nl(e,"date",t,o).format(s)}catch(u){e.onError(new Sr("Error formatting date.",e.locale,u))}return String(s)}function u$(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];var i=r[0],a=r[1],o=a===void 0?{}:a,s=typeof i=="string"?new Date(i||0):i;try{return nl(e,"time",t,o).format(s)}catch(u){e.onError(new Sr("Error formatting time.",e.locale,u))}return String(s)}function l$(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];var i=r[0],a=r[1],o=r[2],s=o===void 0?{}:o,u=e.timeZone,l=e.locale,c=e.onError,f=mi(s,zy,u?{timeZone:u}:{});try{return t(l,f).formatRange(i,a)}catch(d){c(new Sr("Error formatting date time range.",e.locale,d))}return String(i)}function c$(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];var i=r[0],a=r[1],o=a===void 0?{}:a,s=typeof i=="string"?new Date(i||0):i;try{return nl(e,"date",t,o).formatToParts(s)}catch(u){e.onError(new Sr("Error formatting date.",e.locale,u))}return[]}function f$(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];var i=r[0],a=r[1],o=a===void 0?{}:a,s=typeof i=="string"?new Date(i||0):i;try{return nl(e,"time",t,o).formatToParts(s)}catch(u){e.onError(new Sr("Error formatting time.",e.locale,u))}return[]}var d$=["style","type","fallback","languageDisplay"];function h$(e,t,r,n){var i=e.locale,a=e.onError,o=Intl.DisplayNames;o||a(new qn(`Intl.DisplayNames is not available in this environment.
Try polyfilling it using "@formatjs/intl-displaynames"
`,Vr.MISSING_INTL_API));var s=mi(n,d$);try{return t(i,s).of(r)}catch(u){a(new Sr("Error formatting display name.",i,u))}}var p$=["type","style"],Zm=Date.now();function m$(e){return"".concat(Zm,"_").concat(e,"_").concat(Zm)}function g$(e,t,r,n){n===void 0&&(n={});var i=$y(e,t,r,n).reduce(function(a,o){var s=o.value;return typeof s!="string"?a.push(s):typeof a[a.length-1]=="string"?a[a.length-1]+=s:a.push(s),a},[]);return i.length===1?i[0]:i.length===0?"":i}function $y(e,t,r,n){var i=e.locale,a=e.onError;n===void 0&&(n={});var o=Intl.ListFormat;o||a(new qn(`Intl.ListFormat is not available in this environment.
Try polyfilling it using "@formatjs/intl-listformat"
`,Vr.MISSING_INTL_API));var s=mi(n,p$);try{var u={},l=r.map(function(c,f){if(typeof c=="object"){var d=m$(f);return u[d]=c,d}return String(c)});return t(i,s).formatToParts(l).map(function(c){return c.type==="literal"?c:fe(fe({},c),{value:u[c.value]||c.value})})}catch(c){a(new Sr("Error formatting list.",i,c))}return r}var b$=["type"];function v$(e,t,r,n){var i=e.locale,a=e.onError;n===void 0&&(n={}),Intl.PluralRules||a(new qn(`Intl.PluralRules is not available in this environment.
Try polyfilling it using "@formatjs/intl-pluralrules"
`,Vr.MISSING_INTL_API));var o=mi(n,b$);try{return t(i,o).select(r)}catch(s){a(new Sr("Error formatting plural.",i,s))}return"other"}var y$=["numeric","style"];function w$(e,t,r){var n=e.locale,i=e.formats,a=e.onError;r===void 0&&(r={});var o=r.format,s=!!o&&Fd(i,"relative",o,a)||{},u=mi(r,y$,s);return t(n,u)}function x$(e,t,r,n,i){i===void 0&&(i={}),n||(n="second");var a=Intl.RelativeTimeFormat;a||e.onError(new qn(`Intl.RelativeTimeFormat is not available in this environment.
Try polyfilling it using "@formatjs/intl-relativetimeformat"
`,Vr.MISSING_INTL_API));try{return w$(e,t,i).format(r,n)}catch(o){e.onError(new Sr("Error formatting relative time.",e.locale,o))}return String(r)}var E$=["style","currency","currencyDisplay","unit","unitDisplay","useGrouping","minimumIntegerDigits","minimumFractionDigits","maximumFractionDigits","minimumSignificantDigits","maximumSignificantDigits","compactDisplay","currencyDisplay","currencySign","notation","signDisplay","unit","unitDisplay","numberingSystem"];function Uy(e,t,r){var n=e.locale,i=e.formats,a=e.onError;r===void 0&&(r={});var o=r.format,s=o&&Fd(i,"number",o,a)||{},u=mi(r,E$,s);return t(n,u)}function S$(e,t,r,n){n===void 0&&(n={});try{return Uy(e,t,n).format(r)}catch(i){e.onError(new Sr("Error formatting number.",e.locale,i))}return String(r)}function T$(e,t,r,n){n===void 0&&(n={});try{return Uy(e,t,n).formatToParts(r)}catch(i){e.onError(new Sr("Error formatting number.",e.locale,i))}return[]}function A$(e){var t=e?e[Object.keys(e)[0]]:void 0;return typeof t=="string"}function k$(e){e.onWarn&&e.defaultRichTextElements&&A$(e.messages||{})&&e.onWarn(`[@formatjs/intl] "defaultRichTextElements" was specified but "message" was not pre-compiled. 
Please consider using "@formatjs/cli" to pre-compile your messages for performance.
For more details see https://formatjs.io/docs/getting-started/message-distribution`)}function O$(e,t){var r=o$(t),n=fe(fe({},Fy),e),i=n.locale,a=n.defaultLocale,o=n.onError;return i?!Intl.NumberFormat.supportedLocalesOf(i).length&&o?o(new Km('Missing locale data for locale: "'.concat(i,'" in Intl.NumberFormat. Using default locale: "').concat(a,'" as fallback. See https://formatjs.io/docs/react-intl#runtime-requirements for more details'))):!Intl.DateTimeFormat.supportedLocalesOf(i).length&&o&&o(new Km('Missing locale data for locale: "'.concat(i,'" in Intl.DateTimeFormat. Using default locale: "').concat(a,'" as fallback. See https://formatjs.io/docs/react-intl#runtime-requirements for more details'))):(o&&o(new r$('"locale" was not configured, using "'.concat(a,'" as fallback. See https://formatjs.io/docs/react-intl/api#intlshape for more details'))),n.locale=n.defaultLocale||"en"),k$(n),fe(fe({},n),{formatters:r,formatNumber:S$.bind(null,n,r.getNumberFormat),formatNumberToParts:T$.bind(null,n,r.getNumberFormat),formatRelativeTime:x$.bind(null,n,r.getRelativeTimeFormat),formatDate:s$.bind(null,n,r.getDateTimeFormat),formatDateToParts:c$.bind(null,n,r.getDateTimeFormat),formatTime:u$.bind(null,n,r.getDateTimeFormat),formatDateTimeRange:l$.bind(null,n,r.getDateTimeFormat),formatTimeToParts:f$.bind(null,n,r.getDateTimeFormat),formatPlural:v$.bind(null,n,r.getPluralRules),formatMessage:Jc.bind(null,n,r),$t:Jc.bind(null,n,r),formatList:g$.bind(null,n,r.getListFormat),formatListToParts:$y.bind(null,n,r.getListFormat),formatDisplayName:h$.bind(null,n,r.getDisplayNames)})}function Hy(e){vy(e,"[React Intl] Could not find required `intl` object. <IntlProvider> needs to exist in the component ancestry.")}var qy=fe(fe({},Fy),{textComponent:React.Fragment});function N$(e){return function(t){return e(React.Children.toArray(t))}}function _$(e,t){if(e===t)return!0;if(!e||!t)return!1;var r=Object.keys(e),n=Object.keys(t),i=r.length;if(n.length!==i)return!1;for(var a=0;a<i;a++){var o=r[a];if(e[o]!==t[o]||!Object.prototype.hasOwnProperty.call(t,o))return!1}return!0}var Bd=typeof window<"u"&&!window.__REACT_INTL_BYPASS_GLOBAL_CONTEXT__?window.__REACT_INTL_CONTEXT__||(window.__REACT_INTL_CONTEXT__=React.createContext(null)):React.createContext(null);Bd.Consumer;var C$=Bd.Provider,M$=C$,R$=Bd;function jy(){var e=React.useContext(R$);return Hy(e),e}var ef;(function(e){e.formatDate="FormattedDate",e.formatTime="FormattedTime",e.formatNumber="FormattedNumber",e.formatList="FormattedList",e.formatDisplayName="FormattedDisplayName"})(ef||(ef={}));var tf;(function(e){e.formatDate="FormattedDateParts",e.formatTime="FormattedTimeParts",e.formatNumber="FormattedNumberParts",e.formatList="FormattedListParts"})(tf||(tf={}));function Vy(e){var t=function(r){var n=jy(),i=r.value,a=r.children,o=Gu(r,["value","children"]),s=typeof i=="string"?new Date(i||0):i,u=e==="formatDate"?n.formatDateToParts(s,o):n.formatTimeToParts(s,o);return a(u)};return t.displayName=tf[e],t}function po(e){var t=function(r){var n=jy(),i=r.value,a=r.children,o=Gu(r,["value","children"]),s=n[e](i,o);if(typeof a=="function")return a(s);var u=n.textComponent||React.Fragment;return React.createElement(u,null,s)};return t.displayName=ef[e],t}function m0(e){return{locale:e.locale,timeZone:e.timeZone,fallbackOnEmptyString:e.fallbackOnEmptyString,formats:e.formats,textComponent:e.textComponent,messages:e.messages,defaultLocale:e.defaultLocale,defaultFormats:e.defaultFormats,onError:e.onError,onWarn:e.onWarn,wrapRichTextChunksInFragment:e.wrapRichTextChunksInFragment,defaultRichTextElements:e.defaultRichTextElements}}function Gy(e){return e&&Object.keys(e).reduce(function(t,r){var n=e[r];return t[r]=Dy(n)?N$(n):n,t},{})}var Qm=function(e,t,r,n){for(var i=[],a=4;a<arguments.length;a++)i[a-4]=arguments[a];var o=Gy(n),s=Jc.apply(void 0,Br([e,t,r,o],i,!1));return Array.isArray(s)?React.Children.toArray(s):s},Jm=function(e,t){var r=e.defaultRichTextElements,n=Gu(e,["defaultRichTextElements"]),i=Gy(r),a=O$(fe(fe(fe({},qy),n),{defaultRichTextElements:i}),t),o={locale:a.locale,timeZone:a.timeZone,fallbackOnEmptyString:a.fallbackOnEmptyString,formats:a.formats,defaultLocale:a.defaultLocale,defaultFormats:a.defaultFormats,messages:a.messages,onError:a.onError,defaultRichTextElements:i};return fe(fe({},a),{formatMessage:Qm.bind(null,o,a.formatters),$t:Qm.bind(null,o,a.formatters)})},I$=function(e){Er(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.cache=By(),r.state={cache:r.cache,intl:Jm(m0(r.props),r.cache),prevConfig:m0(r.props)},r}return t.getDerivedStateFromProps=function(r,n){var i=n.prevConfig,a=n.cache,o=m0(r);return _$(i,o)?null:{intl:Jm(o,a),prevConfig:o}},t.prototype.render=function(){return Hy(this.state.intl),React.createElement(M$,{value:this.state.intl},this.props.children)},t.displayName="IntlProvider",t.defaultProps=qy,t}(React.PureComponent);const XU=I$;po("formatDate");po("formatTime");po("formatNumber");po("formatList");po("formatDisplayName");Vy("formatDate");Vy("formatTime");export{H$ as $,tU as A,eU as B,fU as C,sU as D,lU as E,bU as F,K$ as G,he as H,TU as I,AU as J,NU as K,LA as L,q$ as M,CU as N,MU as O,_U as P,vt as Q,Xw as R,SU as S,V$ as T,B$ as U,U$ as V,z$ as W,$$ as X,KU as Y,ss as Z,j$ as _,G$ as a,L$ as a0,P$ as a1,z6 as a2,XU as a3,zd as a4,mU as b,OU as c,Y$ as d,X$ as e,Z$ as f,Q$ as g,aU as h,J$ as i,iU as j,pU as k,uU as l,nU as m,dU as n,hU as o,kU as p,yU as q,gU as r,vU as s,xU as t,rU as u,EU as v,cU as w,oU as x,wU as y,W$ as z};
